@@ -16,6 +16,7 @@
 #ifndef CVC5__API_UTILITIES_H
 #define CVC5__API_UTILITIES_H
 #include <cvc5/cvc5.h>
+#include <cvc5/cvc5_parser.h>
 #include <jni.h>
 
 #include <string>
@@ -38,6 +39,12 @@
         env->FindClass("io/github/cvc5/CVC5ApiRecoverableException");          \
     env->ThrowNew(exceptionClass, e.what());                                   \
   }                                                                            \
+  catch (const parser::ParserException& e)                                     \
+  {                                                                            \
+    jclass exceptionClass =                                                    \
+        env->FindClass("io/github/cvc5/CVC5ParserException");                  \
+    env->ThrowNew(exceptionClass, e.what());                                   \
+  }                                                                            \
   catch (const CVC5ApiException& e)                                            \
   {                                                                            \
     jclass exceptionClass = env->FindClass("io/github/cvc5/CVC5ApiException"); \
@@ -140,7 +147,7 @@ jobject getBooleanObject(JNIEnv* env, bool value);
 
 /**
  * a map from solver pointers to global references that need to be freed when
- * the java Solver.close method is called
+ * the java Solver.deletePointer method is called
  */
 inline std::map<jlong, std::vector<jobject> > globalReferences;
 
