@@ -10,10 +10,7 @@
  * directory for licensing information.
  * ****************************************************************************
  *
- * [[ Add one-line brief description here ]]
- *
- * [[ Add lengthier description here ]]
- * \todo document this file
+ * Payload class for empty sets.
  */
 
 #include "expr/emptyset.h"
@@ -51,18 +48,4 @@ bool EmptySet::operator==(const EmptySet& es) const
 {
   return getType() == es.getType();
 }
-
-bool EmptySet::operator!=(const EmptySet& es) const { return !(*this == es); }
-bool EmptySet::operator<(const EmptySet& es) const
-{
-  return getType() < es.getType();
-}
-
-bool EmptySet::operator<=(const EmptySet& es) const
-{
-  return getType() <= es.getType();
-}
-
-bool EmptySet::operator>(const EmptySet& es) const { return !(*this <= es); }
-bool EmptySet::operator>=(const EmptySet& es) const { return !(*this < es); }
 }  // namespace cvc5::internal
