@@ -35,6 +35,9 @@ namespace attr {
   struct TupleDatatypeTag
   {
   };
+  struct NullableDatatypeTag
+  {
+  };
   struct DatatypeIndexTag
   {
   };
@@ -56,6 +59,10 @@ using UnresolvedDatatypeAttr =
 using TupleDatatypeAttr =
     expr::Attribute<expr::attr::TupleDatatypeTag, TypeNode>;
 
+/** Mapping nullables to their datatype type encoding */
+using NullableDatatypeAttr =
+    expr::Attribute<expr::attr::NullableDatatypeTag, TypeNode>;
+
 /** Mapping datatype types to the index of their datatype in node manager */
 using DatatypeIndexAttr = Attribute<attr::DatatypeIndexTag, uint64_t>;
 
