@@ -252,6 +252,7 @@ NodeManager::~NodeManager()
   TypeNode dummy;
   d_tt_cache.d_children.clear();
   d_tt_cache.d_data = dummy;
+  d_nt_cache.clear();
   d_rt_cache.d_children.clear();
   d_rt_cache.d_data = dummy;
 
@@ -322,6 +323,13 @@ const DType& NodeManager::getDTypeFor(TypeNode tn) const
     Assert(!dtt.isNull());
     return getDTypeFor(dtt);
   }
+  else if (k == Kind::NULLABLE_TYPE)
+  {
+    // lookup its datatype encoding
+    TypeNode dtt = getAttribute(tn, expr::NullableDatatypeAttr());
+    Assert(!dtt.isNull());
+    return getDTypeFor(dtt);
+  }
   Assert(k == Kind::PARAMETRIC_DATATYPE);
   return getDTypeFor(tn[0]);
 }
@@ -687,6 +695,15 @@ std::vector<TypeNode> NodeManager::mkMutualDatatypeTypesInternal(
         typeNode = mkTypeNode(Kind::TUPLE_TYPE, tupleTypes);
         typeNode.setAttribute(expr::TupleDatatypeAttr(), dtt);
       }
+      if (dt.isNullable())
+      {
+        TypeNode dtt = typeNode;
+        const DTypeConstructor& some = dt[1];
+        Assert(some.getNumArgs() == 1);
+        // Set its datatype representation
+        typeNode = mkTypeNode(Kind::NULLABLE_TYPE, some[0].getType());
+        typeNode.setAttribute(expr::NullableDatatypeAttr(), dtt);
+      }
     }
     else
     {
@@ -941,6 +958,35 @@ TypeNode NodeManager::mkTupleType(const std::vector<TypeNode>& types)
   return d_tt_cache.getTupleType(this, types);
 }
 
+TypeNode NodeManager::mkNullableType(const TypeNode& type)
+{
+  Assert(!type.isNull());
+  auto it = d_nt_cache.find(type);
+  if (it != d_nt_cache.end())
+  {
+    return it->second;
+  }
+  // construct the corresponding datatype with two constructors
+  // null and some.
+  std::stringstream sst;
+  sst << "__cvc5_nullable_" << type;
+  DType dt(sst.str());
+  dt.setNullable();  
+  std::shared_ptr<DTypeConstructor> null =
+      std::make_shared<DTypeConstructor>("nullable.null");
+  dt.addConstructor(null);
+  std::shared_ptr<DTypeConstructor> some =
+      std::make_shared<DTypeConstructor>("nullable.some");  
+  some->addArg("nullable.val", type);
+  dt.addConstructor(some);
+  TypeNode datatype = mkDatatypeType(dt);
+  Assert(datatype.isNullable());
+  d_nt_cache[type] = datatype;
+  Trace("nullable-debug") << "NodeManager::mkNullableType(" << type
+                          << ") = " << datatype << std::endl;
+  return datatype;
+}
+
 TypeNode NodeManager::mkRecordType(const Record& rec)
 {
   return d_rt_cache.getRecordType(this, rec);
@@ -1054,12 +1100,10 @@ Node NodeManager::mkVar(const std::string& name,
   // variable is unique.
   std::vector<Node> cnodes;
   cnodes.push_back(mkConst(String(name, false)));
-  // Since we index only on Node, we must construct use mkGroundValue
-  // to construct a canonical node for the tn.
-  Node gt = mkGroundValue(type);
+  // Since we index only on Node, we must construct a SortToTerm here.
+  Node gt = mkConst(SortToTerm(type));
   cnodes.push_back(gt);
-  return d_skManager->mkSkolemFunction(
-      SkolemFunId::INPUT_VARIABLE, type, cnodes);
+  return d_skManager->mkSkolemFunction(SkolemFunId::INPUT_VARIABLE, cnodes);
 }
 
 Node NodeManager::mkBoundVar(const std::string& name, const TypeNode& type)
