@@ -37,7 +37,7 @@ bool OracleCaller::callOracle(const Node& fapp, std::vector<Node>& res)
     // don't bother setting runResult
     return false;
   }
-  Assert(fapp.getKind() == kind::APPLY_UF);
+  Assert(fapp.getKind() == Kind::APPLY_UF);
   Assert(getOracleFor(fapp.getOperator()) == d_oracleNode);
 
   Trace("oracle-calls") << "Call oracle " << fapp << std::endl;
@@ -59,7 +59,7 @@ bool OracleCaller::isOracleFunction(Node f)
 
 bool OracleCaller::isOracleFunctionApp(Node n)
 {
-  if (n.getKind() == kind::APPLY_UF)
+  if (n.getKind() == Kind::APPLY_UF)
   {
     return isOracleFunction(n.getOperator());
   }
@@ -74,15 +74,15 @@ Node OracleCaller::getOracleFor(const Node& n)
   {
     Assert(isOracleFunction(n));
     Node o = n.getAttribute(theory::OracleInterfaceAttribute());
-    Assert(o.getKind() == kind::ORACLE);
+    Assert(o.getKind() == Kind::ORACLE);
     return o;
   }
-  else if (n.getKind() == kind::FORALL)
+  else if (n.getKind() == Kind::FORALL)
   {
     // oracle interfaces have children, and the attribute is stored in 2nd child
     for (const Node& v : n[2][0])
     {
-      if (v.getKind() == kind::ORACLE)
+      if (v.getKind() == Kind::ORACLE)
       {
         return v;
       }
