@@ -1,10 +1,10 @@
 /******************************************************************************
  * Top contributors (to current version):
- *   Andres Noetzli
+ *   Andres Noetzli, Andrew Reynolds
  *
  * This file is part of the cvc5 project.
  *
- * Copyright (c) 2009-2022 by the authors listed in the file AUTHORS
+ * Copyright (c) 2009-2023 by the authors listed in the file AUTHORS
  * in the top-level source directory and their institutional affiliations.
  * All rights reserved.  See the file COPYING in the top-level source
  * directory for licensing information.
@@ -95,8 +95,8 @@ struct AInteger
 {
   static bool checkArg(TNode n, size_t arg)
   {
-    TypeNode t = n[arg].getType(true);
-    return t.isInteger();
+    TypeNode t = n[arg].getTypeOrNull();
+    return t.isInteger() || t.isFullyAbstract();
   }
   constexpr static const char* typeName = "integer";
 };
@@ -106,8 +106,8 @@ struct AReal
 {
   static bool checkArg(TNode n, size_t arg)
   {
-    TypeNode t = n[arg].getType(true);
-    return t.isReal();
+    TypeNode t = n[arg].getTypeOrNull();
+    return t.isReal() || t.isFullyAbstract();
   }
   constexpr static const char* typeName = "real";
 };
@@ -117,8 +117,8 @@ struct ARealOrInteger
 {
   static bool checkArg(TNode n, size_t arg)
   {
-    TypeNode t = n[arg].getType(true);
-    return t.isRealOrInt();
+    TypeNode t = n[arg].getTypeOrNull();
+    return t.isRealOrInt() || t.isFullyAbstract();
   }
   constexpr static const char* typeName = "real or integer";
 };
@@ -128,8 +128,8 @@ struct ARegExp
 {
   static bool checkArg(TNode n, size_t arg)
   {
-    TypeNode t = n[arg].getType(true);
-    return t.isRegExp();
+    TypeNode t = n[arg].getTypeOrNull();
+    return t.isRegExp() || t.isFullyAbstract();
   }
   constexpr static const char* typeName = "regexp";
 };
@@ -139,8 +139,8 @@ struct AString
 {
   static bool checkArg(TNode n, size_t arg)
   {
-    TypeNode t = n[arg].getType(true);
-    return t.isString();
+    TypeNode t = n[arg].getTypeOrNull();
+    return t.isString() || t.isFullyAbstract();
   }
   constexpr static const char* typeName = "string";
 };
@@ -154,6 +154,10 @@ template <class R, class A0 = ANone, class A1 = ANone, class A2 = ANone>
 class SimpleTypeRule
 {
  public:
+  static TypeNode preComputeType(NodeManager* nm, TNode n)
+  {
+    return R::mkType(nm);
+  }
   static TypeNode computeType(NodeManager* nm,
                               TNode n,
                               bool check,
@@ -163,24 +167,31 @@ class SimpleTypeRule
     {
       if (!A0::checkArg(n, 0))
       {
-        std::stringstream msg;
-        msg << "Expecting a " << A0::typeName
-            << " term as the first argument in '" << n.getKind() << "'";
-        throw TypeCheckingExceptionPrivate(n, msg.str());
+        if (errOut)
+        {
+          (*errOut) << "Expecting a " << A0::typeName
+                    << " term as the first argument in '" << n.getKind() << "'";
+        }
+        return TypeNode::null();
       }
       if (!A1::checkArg(n, 1))
       {
-        std::stringstream msg;
-        msg << "Expecting a " << A1::typeName
-            << " term as the second argument in '" << n.getKind() << "'";
-        throw TypeCheckingExceptionPrivate(n, msg.str());
+        if (errOut)
+        {
+          (*errOut) << "Expecting a " << A1::typeName
+                    << " term as the second argument in '" << n.getKind()
+                    << "'";
+        }
+        return TypeNode::null();
       }
       if (!A2::checkArg(n, 2))
       {
-        std::stringstream msg;
-        msg << "Expecting a " << A2::typeName
-            << " term as the third argument in '" << n.getKind() << "'";
-        throw TypeCheckingExceptionPrivate(n, msg.str());
+        if (errOut)
+        {
+          (*errOut) << "Expecting a " << A2::typeName
+                    << " term as the third argument in '" << n.getKind() << "'";
+        }
+        return TypeNode::null();
       }
     }
     return R::mkType(nm);
@@ -196,6 +207,10 @@ template <class R, class A>
 class SimpleTypeRuleVar
 {
  public:
+  static TypeNode preComputeType(NodeManager* nm, TNode n)
+  {
+    return R::mkType(nm);
+  }
   static TypeNode computeType(NodeManager* nm,
                               TNode n,
                               bool check,
@@ -207,10 +222,12 @@ class SimpleTypeRuleVar
       {
         if (!A::checkArg(n, i))
         {
-          std::stringstream msg;
-          msg << "Expecting a " << A::typeName << " term as argument " << i
-              << " in '" << n.getKind() << "'";
-          throw TypeCheckingExceptionPrivate(n, msg.str());
+          if (errOut)
+          {
+            (*errOut) << "Expecting a " << A::typeName << " term as argument "
+                      << i << " in '" << n.getKind() << "'";
+          }
+          return TypeNode::null();
         }
       }
     }
