@@ -471,6 +471,9 @@ class CVC5_EXPORT TypeNode
   /** Is this a Set type? */
   bool isSet() const;
 
+  /** Is this a Relation type (set of tuples)? */
+  bool isRelation() const;
+
   /** Is this a Bag type? */
   bool isBag() const;
 
@@ -624,6 +627,9 @@ class CVC5_EXPORT TypeNode
   /** Is this a tuple type? */
   bool isTuple() const;
 
+  /** Is this a nullable type? */
+  bool isNullable() const;
+
   /** Is this a record type? */
   bool isRecord() const;
 
@@ -633,6 +639,9 @@ class CVC5_EXPORT TypeNode
   /** Get the constituent types of a tuple type */
   std::vector<TypeNode> getTupleTypes() const;
 
+  /** Get the element type (for nullable types) */
+  TypeNode getNullableElementType() const;
+
   /** Is this a regexp type */
   bool isRegExp() const;
 
