@@ -4,7 +4,7 @@
  *
  * This file is part of the cvc5 project.
  *
- * Copyright (c) 2009-2022 by the authors listed in the file AUTHORS
+ * Copyright (c) 2009-2023 by the authors listed in the file AUTHORS
  * in the top-level source directory and their institutional affiliations.
  * All rights reserved.  See the file COPYING in the top-level source
  * directory for licensing information.
@@ -28,7 +28,9 @@ namespace cvc5::main {
  * Print overall command-line option usage message to the given output stream
  * with binary being the command to run cvc5.
  */
-void printUsage(const std::string& binary, std::ostream& os);
+void printUsage(const std::string& binary,
+                std::ostream& os,
+                bool printRegular = false);
 
 /**
  * Initialize the Options object options based on the given
