@@ -58,11 +58,10 @@ class ExecutionContext
    * Execute the given commands.
    * Returns true if the commands have been executed without being interrupted.
    */
-  bool solveCommands(std::vector<std::unique_ptr<cvc5::parser::Command>>& cmds);
+  bool solveCommands(std::vector<cvc5::parser::Command>& cmds);
 
   /** Parse the remaining input from d_parser into a vector of commands */
-  std::vector<std::unique_ptr<cvc5::parser::Command>> parseCommands(
-      parser::InputParser* parser);
+  std::vector<cvc5::parser::Command> parseCommands(parser::InputParser* parser);
 };
 
 /**
