@@ -4,7 +4,7 @@
  *
  * This file is part of the cvc5 project.
  *
- * Copyright (c) 2009-2022 by the authors listed in the file AUTHORS
+ * Copyright (c) 2009-2023 by the authors listed in the file AUTHORS
  * in the top-level source directory and their institutional affiliations.
  * All rights reserved.  See the file COPYING in the top-level source
  * directory for licensing information.
@@ -62,9 +62,18 @@ void set(Options& opts,
  */
 struct CVC5_EXPORT OptionInfo
 {
+  enum class Category
+  {
+    COMMON,
+    EXPERT,
+    REGULAR,
+    UNDOCUMENTED
+  };
+
   std::string name;
   std::vector<std::string> aliases;
   bool setByUser;
+  Category category;
 
   /** No information about the options value */
   struct VoidInfo
