@@ -1,10 +1,10 @@
 /******************************************************************************
  * Top contributors (to current version):
- *   Gereon Kremer
+ *   Gereon Kremer, Alex Ozdemir
  *
  * This file is part of the cvc5 project.
  *
- * Copyright (c) 2009-2022 by the authors listed in the file AUTHORS
+ * Copyright (c) 2009-2023 by the authors listed in the file AUTHORS
  * in the top-level source directory and their institutional affiliations.
  * All rights reserved.  See the file COPYING in the top-level source
  * directory for licensing information.
@@ -228,7 +228,11 @@ OptionInfo getInfo(const Options& opts, const std::string& name)
   // clang-format off
   ${getinfo_impl}$
   // clang-format on
-  return OptionInfo{"", {}, false, OptionInfo::VoidInfo{}};
+  return OptionInfo{"",
+                    {},
+                    false,
+                    OptionInfo::Category::UNDOCUMENTED,
+                    OptionInfo::VoidInfo{}};
 }
 
 #undef DO_SEMANTIC_CHECKS_BY_DEFAULT
