@@ -4,7 +4,7 @@
  *
  * This file is part of the cvc5 project.
  *
- * Copyright (c) 2009-2022 by the authors listed in the file AUTHORS
+ * Copyright (c) 2009-2023 by the authors listed in the file AUTHORS
  * in the top-level source directory and their institutional affiliations.
  * All rights reserved.  See the file COPYING in the top-level source
  * directory for licensing information.
@@ -25,18 +25,10 @@ std::ostream& operator<<(std::ostream& os, const ParseOp& p)
   {
     out << " :expr " << p.d_expr;
   }
-  if (!p.d_op.isNull())
-  {
-    out << " :op " << p.d_op;
-  }
-  if (p.d_kind != cvc5::NULL_TERM)
+  if (p.d_kind != cvc5::Kind::NULL_TERM)
   {
     out << " :kind " << p.d_kind;
   }
-  if (!p.d_type.isNull())
-  {
-    out << " :type " << p.d_type;
-  }
   if (!p.d_name.empty())
   {
     out << " :name " << p.d_name;
