@@ -1,10 +1,10 @@
 /******************************************************************************
  * Top contributors (to current version):
- *   Andrew Reynolds, Mathias Preiner, Andres Noetzli
+ *   Andrew Reynolds, Andres Noetzli, Mathias Preiner
  *
  * This file is part of the cvc5 project.
  *
- * Copyright (c) 2009-2022 by the authors listed in the file AUTHORS
+ * Copyright (c) 2009-2023 by the authors listed in the file AUTHORS
  * in the top-level source directory and their institutional affiliations.
  * All rights reserved.  See the file COPYING in the top-level source
  * directory for licensing information.
@@ -35,8 +35,6 @@ namespace cvc5 {
  * (1) A kind.
  * (2) A string name.
  * (3) An expression expr.
- * (4) A type t.
- * (5) An operator object.
  *
  * Examples:
  *
@@ -49,27 +47,22 @@ namespace cvc5 {
  * AST expression representing generic tuple select, and we do not have enough
  * type information at this point to know the type of the tuple we will be
  * selecting from.
- * - For array constant specifications prior to type ascription e.g. when we
- * have parsed "const", we store (1), setting the kind to STORE_ALL.
  * - For array constant specifications (as const (Array T1 T2)), we store (1)
- * and (4), where kind is set to STORE_ALL and type is set to (Array T1 T2).
+ * and (3), where kind is set to INTERNAL_KIND and expr is set to a placeholder
+ * variable of type (Array T1 T2).
  * When parsing this as an operator e.g. ((as const (Array T1 T2)) t), we
  * interpret this operator by converting the next parsed constant of type T2 to
  * an Array of type (Array T1 T2) over that constant.
  */
 struct ParseOp
 {
-  ParseOp(cvc5::Kind k = cvc5::NULL_TERM) : d_kind(k) {}
+  ParseOp(cvc5::Kind k = cvc5::Kind::NULL_TERM) : d_kind(k) {}
   /** The kind associated with the parsed operator, if it exists */
   cvc5::Kind d_kind;
   /** The name associated with the parsed operator, if it exists */
   std::string d_name;
   /** The expression associated with the parsed operator, if it exists */
   cvc5::Term d_expr;
-  /** The type associated with the parsed operator, if it exists */
-  cvc5::Sort d_type;
-  /** The operator associated with the parsed operator, if it exists */
-  cvc5::Op d_op;
   /**
    * The indices if the operator is indexed, but cvc5::Op is the null operator.
    * This is the case for operator symbols that cannot be resolved to a kind
@@ -82,7 +75,7 @@ struct ParseOp
   bool operator==(const ParseOp& p) const
   {
     return d_kind == p.d_kind && d_name == p.d_name && d_expr == p.d_expr
-           && d_type == p.d_type && d_op == p.d_op && d_indices == p.d_indices;
+           && d_indices == p.d_indices;
   }
 };
 
