@@ -80,8 +80,10 @@ enum Token : uint32_t
   GET_QE_DISJUNCT_TOK,
   GET_QE_TOK,
   GET_TIMEOUT_CORE_TOK,
+  GET_TIMEOUT_CORE_ASSUMING_TOK,
   GET_UNSAT_ASSUMPTIONS_TOK,
   GET_UNSAT_CORE_TOK,
+  GET_UNSAT_CORE_LEMMAS_TOK,
   GET_VALUE_TOK,
   HEX_LITERAL,
   INCLUDE_TOK,
