@@ -40,7 +40,7 @@ namespace passes {
 bool BVGauss::is_bv_const(Node n)
 {
   if (n.isConst()) { return true; }
-  return rewrite(n).getKind() == kind::CONST_BITVECTOR;
+  return rewrite(n).getKind() == Kind::CONST_BITVECTOR;
 }
 
 Node BVGauss::get_bv_const(Node n)
@@ -101,11 +101,11 @@ uint32_t BVGauss::getMinBwExpr(Node expr)
     else if (it->second == 0)
     {
       Kind k = n.getKind();
-      Assert(k != kind::CONST_BITVECTOR);
+      Assert(k != Kind::CONST_BITVECTOR);
       Assert(!is_bv_const(n));
       switch (k)
       {
-        case kind::BITVECTOR_EXTRACT:
+        case Kind::BITVECTOR_EXTRACT:
         {
           const unsigned size = bv::utils::getSize(n);
           const unsigned low = bv::utils::getExtractLow(n);
@@ -116,13 +116,13 @@ uint32_t BVGauss::getMinBwExpr(Node expr)
           break;
         }
 
-        case kind::BITVECTOR_ZERO_EXTEND:
+        case Kind::BITVECTOR_ZERO_EXTEND:
         {
           visited[n] = visited[n[0]];
           break;
         }
 
-        case kind::BITVECTOR_MULT:
+        case Kind::BITVECTOR_MULT:
         {
           Integer maxval = Integer(1);
           for (const Node& nn : n)
@@ -142,7 +142,7 @@ uint32_t BVGauss::getMinBwExpr(Node expr)
           break;
         }
 
-        case kind::BITVECTOR_CONCAT:
+        case Kind::BITVECTOR_CONCAT:
         {
           unsigned i, wnz, nc;
           for (i = 0, wnz = 0, nc = n.getNumChildren() - 1; i < nc; ++i)
@@ -161,20 +161,20 @@ uint32_t BVGauss::getMinBwExpr(Node expr)
           break;
         }
 
-        case kind::BITVECTOR_UREM:
-        case kind::BITVECTOR_LSHR:
-        case kind::BITVECTOR_ASHR:
+        case Kind::BITVECTOR_UREM:
+        case Kind::BITVECTOR_LSHR:
+        case Kind::BITVECTOR_ASHR:
         {
           visited[n] = visited[n[0]];
           break;
         }
 
-        case kind::BITVECTOR_OR:
-        case kind::BITVECTOR_NOR:
-        case kind::BITVECTOR_XOR:
-        case kind::BITVECTOR_XNOR:
-        case kind::BITVECTOR_AND:
-        case kind::BITVECTOR_NAND:
+        case Kind::BITVECTOR_OR:
+        case Kind::BITVECTOR_NOR:
+        case Kind::BITVECTOR_XOR:
+        case Kind::BITVECTOR_XNOR:
+        case Kind::BITVECTOR_AND:
+        case Kind::BITVECTOR_NAND:
         {
           unsigned wmax = 0;
           for (const Node &nn : n)
@@ -188,7 +188,7 @@ uint32_t BVGauss::getMinBwExpr(Node expr)
           break;
         }
 
-        case kind::BITVECTOR_ADD:
+        case Kind::BITVECTOR_ADD:
         {
           Integer maxval = Integer(0);
           for (const Node& nn : n)
@@ -434,10 +434,10 @@ BVGauss::Result BVGauss::gaussElimRewriteForUrem(
   for (size_t i = 0; i < neqs; ++i)
   {
     Node eq = equations[i];
-    Assert(eq.getKind() == kind::EQUAL);
+    Assert(eq.getKind() == Kind::EQUAL);
     Node urem, eqrhs;
 
-    if (eq[0].getKind() == kind::BITVECTOR_UREM)
+    if (eq[0].getKind() == Kind::BITVECTOR_UREM)
     {
       urem = eq[0];
       Assert(is_bv_const(eq[1]));
@@ -445,7 +445,7 @@ BVGauss::Result BVGauss::gaussElimRewriteForUrem(
     }
     else
     {
-      Assert(eq[1].getKind() == kind::BITVECTOR_UREM);
+      Assert(eq[1].getKind() == Kind::BITVECTOR_UREM);
       urem = eq[1];
       Assert(is_bv_const(eq[0]));
       eqrhs = eq[0];
@@ -486,11 +486,11 @@ BVGauss::Result BVGauss::gaussElimRewriteForUrem(
 
       /* Split into matrix columns */
       Kind k = n.getKind();
-      if (k == kind::BITVECTOR_ADD)
+      if (k == Kind::BITVECTOR_ADD)
       {
         for (const Node& nn : n) { stack.push_back(nn); }
       }
-      else if (k == kind::BITVECTOR_MULT)
+      else if (k == Kind::BITVECTOR_MULT)
       {
         Node n0, n1;
         /* Flatten mult expression. */
@@ -653,7 +653,7 @@ BVGauss::Result BVGauss::gaussElimRewriteForUrem(
            * e.g., x = 4 - 2y  --> x = 4 + 9y (modulo 11) */
           Integer m = iprime - lhs[prow][i];
           Node bv = bv::utils::mkConst(bv::utils::getSize(vvars[i]), m);
-          Node mult = nm->mkNode(kind::BITVECTOR_MULT, vvars[i], bv);
+          Node mult = nm->mkNode(Kind::BITVECTOR_MULT, vvars[i], bv);
           stack.push_back(mult);
         }
 
@@ -665,17 +665,17 @@ BVGauss::Result BVGauss::gaussElimRewriteForUrem(
         else
         {
           Node tmp = stack.size() == 1 ? stack[0]
-                                       : nm->mkNode(kind::BITVECTOR_ADD, stack);
+                                       : nm->mkNode(Kind::BITVECTOR_ADD, stack);
 
           if (rhs[prow] != 0)
           {
             tmp = nm->mkNode(
-                kind::BITVECTOR_ADD,
+                Kind::BITVECTOR_ADD,
                 bv::utils::mkConst(bv::utils::getSize(vvars[pcol]), rhs[prow]),
                 tmp);
           }
           Assert(!is_bv_const(tmp));
-          res[vvars[pcol]] = nm->mkNode(kind::BITVECTOR_UREM, tmp, prime);
+          res[vvars[pcol]] = nm->mkNode(Kind::BITVECTOR_UREM, tmp, prime);
         }
       }
     }
@@ -701,22 +701,22 @@ PreprocessingPassResult BVGauss::applyInternal(
     assertions.pop_back();
     cvc5::internal::Kind k = a.getKind();
 
-    if (k == kind::AND)
+    if (k == Kind::AND)
     {
       for (const Node& aa : a)
       {
         assertions.push_back(aa);
       }
     }
-    else if (k == kind::EQUAL)
+    else if (k == Kind::EQUAL)
     {
       Node urem;
 
-      if (is_bv_const(a[1]) && a[0].getKind() == kind::BITVECTOR_UREM)
+      if (is_bv_const(a[1]) && a[0].getKind() == Kind::BITVECTOR_UREM)
       {
         urem = a[0];
       }
-      else if (is_bv_const(a[0]) && a[1].getKind() == kind::BITVECTOR_UREM)
+      else if (is_bv_const(a[0]) && a[1].getKind() == Kind::BITVECTOR_UREM)
       {
         urem = a[1];
       }
@@ -725,7 +725,7 @@ PreprocessingPassResult BVGauss::applyInternal(
         continue;
       }
 
-      if (urem[0].getKind() == kind::BITVECTOR_ADD && is_bv_const(urem[1]))
+      if (urem[0].getKind() == Kind::BITVECTOR_ADD && is_bv_const(urem[1]))
       {
         equations[urem[1]].push_back(a);
       }
@@ -754,7 +754,6 @@ PreprocessingPassResult BVGauss::applyInternal(
     {
       if (ret == BVGauss::Result::NONE)
       {
-        assertionsToPreprocess->clear();
         Node n = nm->mkConst<bool>(false);
         assertionsToPreprocess->push_back(n);
         return PreprocessingPassResult::CONFLICT;
@@ -768,7 +767,7 @@ PreprocessingPassResult BVGauss::applyInternal(
         /* add resulting constraints */
         for (const auto& p : res)
         {
-          Node a = nm->mkNode(kind::EQUAL, p.first, p.second);
+          Node a = nm->mkNode(Kind::EQUAL, p.first, p.second);
           Trace("bv-gauss-elim") << "added assertion: " << a << std::endl;
           // add new assertion
           assertionsToPreprocess->push_back(a);
