@@ -55,11 +55,11 @@ PreprocessingPassResult PseudoBooleanProcessor::applyInternal(
 
 bool PseudoBooleanProcessor::decomposeAssertion(Node assertion, bool negated)
 {
-  if (assertion.getKind() != kind::GEQ)
+  if (assertion.getKind() != Kind::GEQ)
   {
     return false;
   }
-  Assert(assertion.getKind() == kind::GEQ);
+  Assert(assertion.getKind() == Kind::GEQ);
 
   Trace("pbs::rewrites") << "decomposeAssertion" << assertion << std::endl;
 
@@ -72,7 +72,7 @@ bool PseudoBooleanProcessor::decomposeAssertion(Node assertion, bool negated)
     return false;
   }
   // don't bother matching on anything other than + on the left hand side
-  if (l.getKind() != kind::ADD)
+  if (l.getKind() != Kind::ADD)
   {
     Trace("pbs::rewrites") << "not plus" << assertion << std::endl;
     return false;
@@ -209,7 +209,7 @@ void PseudoBooleanProcessor::learnRewrittenGeq(Node assertion,
                                                bool negated,
                                                Node orig)
 {
-  Assert(assertion.getKind() == kind::GEQ);
+  Assert(assertion.getKind() == Kind::GEQ);
   Assert(assertion == rewrite(assertion));
 
   // assume assertion is rewritten
@@ -230,7 +230,7 @@ void PseudoBooleanProcessor::learnRewrittenGeq(Node assertion,
         addLeqOne(l, orig);
       }
     }
-    else if (l.getKind() == kind::MULT && l.getNumChildren() == 2)
+    else if (l.getKind() == Kind::MULT && l.getNumChildren() == 2)
     {
       Node c = l[0], v = l[1];
       if (c.isConst() && c.getConst<Rational>().isNegativeOne())
@@ -258,15 +258,15 @@ void PseudoBooleanProcessor::learnInternal(Node assertion,
 {
   switch (assertion.getKind())
   {
-    case kind::GEQ:
-    case kind::GT:
-    case kind::LEQ:
-    case kind::LT:
+    case Kind::GEQ:
+    case Kind::GT:
+    case Kind::LEQ:
+    case Kind::LT:
     {
       Node rw = rewrite(assertion);
       if (assertion == rw)
       {
-        if (assertion.getKind() == kind::GEQ)
+        if (assertion.getKind() == Kind::GEQ)
         {
           learnRewrittenGeq(assertion, negated, orig);
         }
@@ -277,14 +277,14 @@ void PseudoBooleanProcessor::learnInternal(Node assertion,
       }
     }
     break;
-    case kind::NOT: learnInternal(assertion[0], !negated, orig); break;
+    case Kind::NOT: learnInternal(assertion[0], !negated, orig); break;
     default: break;  // do nothing
   }
 }
 
 void PseudoBooleanProcessor::learn(Node assertion)
 {
-  if (assertion.getKind() == kind::AND)
+  if (assertion.getKind() == Kind::AND)
   {
     Node::iterator ci = assertion.begin(), cend = assertion.end();
     for (; ci != cend; ++ci)
@@ -302,7 +302,7 @@ Node PseudoBooleanProcessor::mkGeqOne(Node v)
 {
   NodeManager* nm = NodeManager::currentNM();
   return nm->mkNode(
-      kind::GEQ, v, nm->mkConstRealOrInt(v.getType(), Rational(1)));
+      Kind::GEQ, v, nm->mkConstRealOrInt(v.getType(), Rational(1)));
 }
 
 void PseudoBooleanProcessor::learn(const std::vector<Node>& assertions)
@@ -327,7 +327,7 @@ void PseudoBooleanProcessor::addSub(Node from, Node to)
 
 void PseudoBooleanProcessor::learnGeqSub(Node geq)
 {
-  Assert(geq.getKind() == kind::GEQ);
+  Assert(geq.getKind() == Kind::GEQ);
   const bool negated = false;
   bool success = decomposeAssertion(geq, negated);
   if (!success)
@@ -379,7 +379,7 @@ void PseudoBooleanProcessor::learnGeqSub(Node geq)
     Node yGeq1 = mkGeqOne(y);
     Node zGeq1 = mkGeqOne(z);
     NodeManager* nm = NodeManager::currentNM();
-    Node dis = nm->mkNode(kind::OR, zGeq1.notNode(), xGeq1, yGeq1);
+    Node dis = nm->mkNode(Kind::OR, zGeq1.notNode(), xGeq1, yGeq1);
     addSub(geq, dis);
   }
 }
