@@ -54,16 +54,16 @@ Node RealToInt::realToIntInternal(TNode n, NodeMap& cache, std::vector<Node>& va
     Node ret = n;
     if (n.getNumChildren() > 0)
     {
-      if ((n.getKind() == kind::EQUAL && n[0].getType().isReal())
-          || n.getKind() == kind::GEQ || n.getKind() == kind::LT
-          || n.getKind() == kind::GT || n.getKind() == kind::LEQ)
+      if ((n.getKind() == Kind::EQUAL && n[0].getType().isReal())
+          || n.getKind() == Kind::GEQ || n.getKind() == Kind::LT
+          || n.getKind() == Kind::GT || n.getKind() == Kind::LEQ)
       {
         ret = rewrite(n);
         Trace("real-as-int-debug") << "Now looking at : " << ret << std::endl;
         if (!ret.isConst())
         {
-          Node ret_lit = ret.getKind() == kind::NOT ? ret[0] : ret;
-          bool ret_pol = ret.getKind() != kind::NOT;
+          Node ret_lit = ret.getKind() == Kind::NOT ? ret[0] : ret;
+          bool ret_pol = ret.getKind() != Kind::NOT;
           std::map<Node, Node> msum;
           if (ArithMSum::getMonomialSumLit(ret_lit, msum))
           {
@@ -87,7 +87,7 @@ Node RealToInt::realToIntInternal(TNode n, NodeMap& cache, std::vector<Node>& va
                           : (coeffs.size() == 1
                                  ? coeffs[0]
                                  : rewrite(NodeManager::currentNM()->mkNode(
-                                     kind::MULT, coeffs)));
+                                     Kind::MULT, coeffs)));
             std::vector<Node> sum;
             for (std::map<Node, Node>::iterator itm = msum.begin();
                  itm != msum.end();
@@ -121,7 +121,7 @@ Node RealToInt::realToIntInternal(TNode n, NodeMap& cache, std::vector<Node>& va
                 if (vv.getType().isInteger())
                 {
                   sum.push_back(
-                      NodeManager::currentNM()->mkNode(kind::MULT, c, vv));
+                      NodeManager::currentNM()->mkNode(Kind::MULT, c, vv));
                 }
                 else
                 {
@@ -134,7 +134,7 @@ Node RealToInt::realToIntInternal(TNode n, NodeMap& cache, std::vector<Node>& va
             Node sumt =
                 sum.empty()
                     ? nm->mkConstInt(Rational(0))
-                    : (sum.size() == 1 ? sum[0] : nm->mkNode(kind::ADD, sum));
+                    : (sum.size() == 1 ? sum[0] : nm->mkNode(Kind::ADD, sum));
             ret = nm->mkNode(
                 ret_lit.getKind(), sumt, nm->mkConstInt(Rational(0)));
             if (!ret_pol)
@@ -153,7 +153,8 @@ Node RealToInt::realToIntInternal(TNode n, NodeMap& cache, std::vector<Node>& va
         std::vector<Node> children;
         Kind k = n.getKind();
         // we change Real equalities to Int equalities
-        bool preserveTypes = k != EQUAL && (kindToTheoryId(k) != THEORY_ARITH);
+        bool preserveTypes =
+            k != Kind::EQUAL && (kindToTheoryId(k) != THEORY_ARITH);
         for (size_t i = 0; i < n.getNumChildren(); i++)
         {
           Node nc = realToIntInternal(n[i], cache, var_eq);
@@ -162,7 +163,7 @@ Node RealToInt::realToIntInternal(TNode n, NodeMap& cache, std::vector<Node>& va
           {
             if (!n[i].getType().isInteger() && nc.getType().isInteger())
             {
-              nc = nm->mkNode(TO_REAL, nc);
+              nc = nm->mkNode(Kind::TO_REAL, nc);
             }
           }
           childChanged = childChanged || nc != n[i];
@@ -183,7 +184,7 @@ Node RealToInt::realToIntInternal(TNode n, NodeMap& cache, std::vector<Node>& va
       TypeNode tn = n.getType();
       if (tn.isReal() && !tn.isInteger())
       {
-        if (n.getKind() == kind::BOUND_VARIABLE)
+        if (n.getKind() == Kind::BOUND_VARIABLE)
         {
           // cannot change the type of quantified variables, since this leads
           // to incompleteness.
@@ -194,9 +195,9 @@ Node RealToInt::realToIntInternal(TNode n, NodeMap& cache, std::vector<Node>& va
         }
         else if (n.isVar())
         {
-          Node toIntN = nm->mkNode(kind::TO_INTEGER, n);
+          Node toIntN = nm->mkNode(Kind::TO_INTEGER, n);
           ret = sm->mkPurifySkolem(toIntN);
-          Node retToReal = nm->mkNode(kind::TO_REAL, ret);
+          Node retToReal = nm->mkNode(Kind::TO_REAL, ret);
           var_eq.push_back(n.eqNode(retToReal));
           // add the substitution to the preprocessing context, which ensures
           // the model for n is correct, as well as substituting it in the input
@@ -216,11 +217,19 @@ Node RealToInt::realToIntInternal(TNode n, NodeMap& cache, std::vector<Node>& va
 PreprocessingPassResult RealToInt::applyInternal(
     AssertionPipeline* assertionsToPreprocess)
 {
+  // this pass is refutation unsound, "unsat" will be "unknown"
+  assertionsToPreprocess->markRefutationUnsound();
   std::vector<Node> var_eq;
   for (unsigned i = 0, size = assertionsToPreprocess->size(); i < size; ++i)
   {
     assertionsToPreprocess->replace(
-        i, realToIntInternal((*assertionsToPreprocess)[i], d_cache, var_eq));
+        i,
+        rewrite(
+            realToIntInternal((*assertionsToPreprocess)[i], d_cache, var_eq)));
+    if (assertionsToPreprocess->isInConflict())
+    {
+      return PreprocessingPassResult::CONFLICT;
+    }
   }
   return PreprocessingPassResult::NO_CONFLICT;
 }
