@@ -50,6 +50,10 @@ PreprocessingPassResult StringsEagerPp::applyInternal(
     if (prev != rew)
     {
       assertionsToPreprocess->replace(i, rewrite(rew));
+      if (assertionsToPreprocess->isInConflict())
+      {
+        return PreprocessingPassResult::CONFLICT;
+      }
     }
   }
 
