@@ -46,8 +46,8 @@ enum class ProofNodeClusterType : uint8_t
   // ======== CNF
   // Type of proof node cluster that is below SAT and above THEORY_LEMMA or
   // PRE_PROCESSING.
-  // The rules, that are described by the PfRule enumeration, are in the range
-  // between NOT_NOT_ELIM and CNF_ITE_NEG3.
+  // The rules, that are described by the ProofRule enumeration, are in the
+  // range between NOT_NOT_ELIM and CNF_ITE_NEG3.
   CNF,
   // ======== THEORY_LEMMA
   // Proof nodes contained in a SCOPE which starts just after a SAT or CNF proof
@@ -167,26 +167,26 @@ class DotPrinter : protected EnvObj
    */
   inline bool isInput(const ProofNode* pn);
 
-  /** Verify if the rule is in the SAT range (i.e. a PfRule that is
+  /** Verify if the rule is in the SAT range (i.e. a ProofRule that is
    * CHAIN_RESOLUTION, FACTORING, REORDERING, MACRO_RESOLUTION or
    * MACRO_RESOLUTION_TRUST).
    * @param rule The rule to be verified.
    * @return The bool indicating if the rule is or not in the SAT range.
    */
-  inline bool isSat(const PfRule& rule);
+  inline bool isSat(const ProofRule& rule);
 
   /** Verify if the rule is in the CNF range (between NOT_NOT_ELIM and
-   * CNF_ITE_NEG3) in the PfRule enumeration.
+   * CNF_ITE_NEG3) in the ProofRule enumeration.
    * @param rule The rule to be verified.
    * @return The bool indicating if the rule is or not in the CNF range.
    */
-  inline bool isCNF(const PfRule& rule);
+  inline bool isCNF(const ProofRule& rule);
 
   /** Verify if the rule is a SCOPE
    * @param rule The rule to be verified.
    * @return The bool indicating if the rule is or not a SCOPE.
    */
-  inline bool isSCOPE(const PfRule& rule);
+  inline bool isSCOPE(const ProofRule& rule);
 
   /** Verify if the rule is in the theory lemma range (open interval between
    * CNF_ITE_NEG3 and LFSC_RULE) or if the rule is a SCOPE or THEORY_LEMMA.
@@ -194,13 +194,13 @@ class DotPrinter : protected EnvObj
    * @return The bool indicating whether the rule is for a theory lemma
    * range.
    */
-  inline bool isTheoryLemma(const PfRule& rule);
+  inline bool isTheoryLemma(const ProofNode* pn);
 
   /** Verify if the rule is an ASSUME
    * @param rule The rule to be verified.
    * @return The bool indicating if the rule is or not an ASSUME.
    */
-  inline bool isASSUME(const PfRule& rule);
+  inline bool isASSUME(const ProofRule& rule);
 
   /** All unique subproofs of a given proof node (counting itself). */
   std::map<const ProofNode*, size_t> d_subpfCounter;
