@@ -44,7 +44,7 @@ void LazyTreeProofGenerator::closeChild()
 {
   Trace("proof-ltpg") << "closeChild() start" << std::endl
                       << *this << std::endl;
-  Assert(getCurrent().d_rule != PfRule::UNKNOWN);
+  Assert(getCurrent().d_rule != ProofRule::UNKNOWN);
   d_stack.pop_back();
   Trace("proof-ltpg") << "closeChild() end" << std::endl << *this << std::endl;
 }
@@ -54,7 +54,7 @@ detail::TreeProofNode& LazyTreeProofGenerator::getCurrent()
   return *d_stack.back();
 }
 void LazyTreeProofGenerator::setCurrent(size_t objectId,
-                                        PfRule rule,
+                                        ProofRule rule,
                                         const std::vector<Node>& premise,
                                         std::vector<Node> args,
                                         Node proven)
@@ -95,7 +95,7 @@ std::shared_ptr<ProofNode> LazyTreeProofGenerator::getProof(
   // Store scope size to reset scope afterwards
   std::size_t before = scope.size();
   std::vector<std::shared_ptr<ProofNode>> children;
-  if (pn.d_rule == PfRule::SCOPE)
+  if (pn.d_rule == ProofRule::SCOPE)
   {
     // Extend scope for all but the root node
     if (&pn != &d_proof)
