@@ -671,6 +671,11 @@ TypeNode LfscNodeConverter::postConvertType(TypeNode tn)
       std::string name = tn.getUninterpretedSortConstructor().getName();
       op = getSymbolInternal(k, ftype, name, false);
     }
+    else if (k == Kind::NULLABLE_TYPE)
+    {
+      TypeNode ftype = nm->mkFunctionType(d_sortType, d_sortType);
+      op = getSymbolInternal(k, ftype, "Nullable", false);
+    }
     else
     {
       std::map<Kind, Node>::iterator it = d_typeKindToNodeCons.find(k);
@@ -794,21 +799,7 @@ Node LfscNodeConverter::maybeMkSkolemFun(Node k, bool macroApply)
   TypeNode tn = k.getType();
   if (sm->isSkolemFunction(k, sfi, cacheVal))
   {
-    if (sfi == SkolemFunId::SHARED_SELECTOR)
-    {
-      // a skolem corresponding to shared selector should print in
-      // LFSC as (sel T n) where T is the type and n is the index of the
-      // shared selector.
-      TypeNode fselt = nm->mkFunctionType(tn.getDatatypeSelectorDomainType(),
-                                          tn.getDatatypeSelectorRangeType());
-      TypeNode intType = nm->integerType();
-      TypeNode selt = nm->mkFunctionType({d_sortType, intType}, fselt);
-      Node sel = getSymbolInternal(k.getKind(), selt, "sel");
-      Node kn = typeAsNode(convertType(tn.getDatatypeSelectorRangeType()));
-      Assert(!cacheVal.isNull() && cacheVal.getKind() == Kind::CONST_RATIONAL);
-      return mkApplyUf(sel, {kn, cacheVal});
-    }
-    else if (sfi == SkolemFunId::RE_UNFOLD_POS_COMPONENT)
+    if (sfi == SkolemFunId::RE_UNFOLD_POS_COMPONENT)
     {
       // a skolem corresponding to a regular expression unfolding component
       // should print as (skolem_re_unfold_pos t R n) where the skolem is the
