@@ -51,7 +51,7 @@ class LfscPrintChannel
    * Print an application of the trusting the result res, whose source is the
    * given proof rule.
    */
-  virtual void printTrust(TNode res, PfRule src) {}
+  virtual void printTrust(TNode res, ProofRule src) {}
   /** Print the opening of the rule of proof rule pn, e.g. "(and_elim ". */
   virtual void printOpenRule(const ProofNode* pn) {}
   /** Print the opening of LFSC rule lr, e.g. "(cong " */
@@ -72,7 +72,7 @@ class LfscPrintChannelOut : public LfscPrintChannel
   void printNode(TNode n) override;
   void printTypeNode(TypeNode tn) override;
   void printHole() override;
-  void printTrust(TNode res, PfRule src) override;
+  void printTrust(TNode res, ProofRule src) override;
   void printOpenRule(const ProofNode* pn) override;
   void printOpenLfscRule(LfscRule lr) override;
   void printCloseRule(size_t nparen = 1) override;
@@ -89,7 +89,7 @@ class LfscPrintChannelOut : public LfscPrintChannel
   static void printTypeNodeInternal(std::ostream& out, TypeNode tn);
   static void printRule(std::ostream& out, const ProofNode* pn);
   static void printId(std::ostream& out, size_t id, const std::string& prefix);
-  static void printDslProofRuleId(std::ostream& out, rewriter::DslPfRule id);
+  static void printDslProofRuleId(std::ostream& out, rewriter::DslProofRule id);
   //------------------- end helper methods
  private:
   /**
@@ -111,17 +111,17 @@ class LfscPrintChannelPre : public LfscPrintChannel
  public:
   LfscPrintChannelPre(LetBinding& lbind);
   void printNode(TNode n) override;
-  void printTrust(TNode res, PfRule src) override;
+  void printTrust(TNode res, ProofRule src) override;
   void printOpenRule(const ProofNode* pn) override;
 
   /** Get the DSL rewrites */
-  const std::unordered_set<rewriter::DslPfRule>& getDslRewrites() const;
+  const std::unordered_set<rewriter::DslProofRule>& getDslRewrites() const;
 
  private:
   /** The let binding */
   LetBinding& d_lbind;
   /** The DSL rules we have seen */
-  std::unordered_set<rewriter::DslPfRule> d_dprs;
+  std::unordered_set<rewriter::DslProofRule> d_dprs;
 };
 
 }  // namespace proof
