@@ -24,6 +24,7 @@
 #include "expr/node.h"
 #include "proof/proof_generator.h"
 #include "proof/proof_step_buffer.h"
+#include "proof/trust_id.h"
 #include "smt/env_obj.h"
 
 namespace cvc5::internal {
@@ -193,11 +194,22 @@ class CDProof : protected EnvObj, public ProofGenerator
    * is CDPOverwrite::ALWAYS (resp. CDPOverwrite::NEVER).
    */
   bool addStep(Node expected,
-               PfRule id,
+               ProofRule id,
                const std::vector<Node>& children,
                const std::vector<Node>& args,
                bool ensureChildren = false,
                CDPOverwrite opolicy = CDPOverwrite::ASSUME_ONLY);
+  /**
+   * Version with trusted id. The arguments are optional additional arguments
+   * to the required arguments of ProofRule::TRUST. If none are provided, the
+   * trust id and the conclusion will be the arguments of the step.
+   */
+  bool addTrustedStep(Node expected,
+                      TrustId id,
+                      const std::vector<Node>& children,
+                      const std::vector<Node>& args,
+                      bool ensureChildren = false,
+                      CDPOverwrite opolicy = CDPOverwrite::ASSUME_ONLY);
   /** Version with ProofStep */
   bool addStep(Node expected,
                const ProofStep& step,
@@ -264,7 +276,9 @@ class CDProof : protected EnvObj, public ProofGenerator
    * Returns true if we should overwrite proof node pn with a step having id
    * newId, based on policy opol.
    */
-  static bool shouldOverwrite(ProofNode* pn, PfRule newId, CDPOverwrite opol);
+  static bool shouldOverwrite(ProofNode* pn,
+                              ProofRule newId,
+                              CDPOverwrite opol);
   /** Returns true if pn is an assumption. */
   static bool isAssumption(ProofNode* pn);
   /**
