@@ -4,7 +4,7 @@
  *
  * This file is part of the cvc5 project.
  *
- * Copyright (c) 2009-2022 by the authors listed in the file AUTHORS
+ * Copyright (c) 2009-2023 by the authors listed in the file AUTHORS
  * in the top-level source directory and their institutional affiliations.
  * All rights reserved.  See the file COPYING in the top-level source
  * directory for licensing information.
@@ -43,10 +43,10 @@ class LearnedDb
   void addLearnedLiteral(const Node& lit, modes::LearnedLitType ltype);
   /** Get the learned literals for the given type */
   std::vector<Node> getLearnedLiterals(
-      modes::LearnedLitType ltype = modes::LEARNED_LIT_INPUT) const;
+      modes::LearnedLitType ltype = modes::LearnedLitType::INPUT) const;
   /** Get number of learned literals for the given type */
   size_t getNumLearnedLiterals(
-      modes::LearnedLitType ltype = modes::LEARNED_LIT_INPUT) const;
+      modes::LearnedLitType ltype = modes::LearnedLitType::INPUT) const;
   /** To string debug */
   std::string toStringDebug() const;
 
