@@ -111,7 +111,7 @@ bool SkolemDefManager::hasSkolems(TNode n)
         // introduced in a lemma prior to its definition being introduced.
         // This is for example the case in strings reduction for Booleans,
         // ground term purification for E-matching, etc.
-        d_hasSkolems[cur] = (ck == kind::SKOLEM
+        d_hasSkolems[cur] = (ck == Kind::SKOLEM
                              && (d_skDefs.find(cur) != d_skDefs.end()
                                  || cur.getType().isBoolean()));
       }
