@@ -80,10 +80,8 @@ void TheoryPreregistrar::notifySatLiteral(TNode n)
   }
 }
 
-void TheoryPreregistrar::notifyBacktrack(uint32_t nlevels)
+void TheoryPreregistrar::notifyBacktrack()
 {
-  (void)nlevels;
-
   uint32_t level = d_env.getContext()->getLevel();
   for (size_t i = 0, n = d_sat_literals.size(); i < n; ++i)
   {
@@ -104,7 +102,7 @@ void TheoryPreregistrar::notifyBacktrack(uint32_t nlevels)
     // at a higher level than the current SAT context level. These literals
     // are popped from the SAT context on backtrack but remain in the SAT
     // solver, and thus must be reregistered.
-    Trace("prereg") << "reregister: " << n << std::endl;
+    Trace("prereg") << "reregister: " << node << std::endl;
     // Note: This call potentially adds to d_sat_literals, which we are
     //       currently iterating over. This is not an issue, though, since
     //       a) we access it by index and b) any literals added through this
@@ -127,7 +125,7 @@ bool TheoryPreregistrar::notifyAsserted(TNode n)
   }
   // otherwise, we always ensure it is preregistered now, which does nothing
   // if it is already preregistered
-  TNode natom = n.getKind() == kind::NOT ? n[0] : n;
+  TNode natom = n.getKind() == Kind::NOT ? n[0] : n;
   Trace("prereg") << "preregister (lazy): " << natom << std::endl;
   d_theoryEngine->preRegister(natom);
   return true;
