@@ -26,6 +26,7 @@
 #include "expr/subs.h"
 #include "prop/learned_db.h"
 #include "smt/env_obj.h"
+#include "theory/trust_substitutions.h"
 
 namespace cvc5::internal {
 
@@ -69,6 +70,13 @@ class ZeroLevelLearner : protected EnvObj
   /** compute type for learned literal */
   modes::LearnedLitType computeLearnedLiteralType(const Node& lit);
 
+  /**
+   * Get inferred simplifications. This is a (term) substitution that can be
+   * applied to construct simpler terms that are equivalent based on
+   * literals learned at decision level zero.
+   */
+  theory::TrustSubstitutionMap& getSimplifications();
+
  private:
   static void getAtoms(TNode a,
                        std::unordered_set<TNode>& visited,
@@ -109,6 +117,14 @@ class ZeroLevelLearner : protected EnvObj
   size_t d_deepRestartThreshold;
   /** learnable learned literal types (for deep restart), based on option */
   std::unordered_set<modes::LearnedLitType> d_learnedTypes;
+  /** Should we track the simplification map? */
+  bool d_trackSimplifications;
+  /**
+   * Simplification map. This is a substitution that is globally valid based
+   * on the literals learned at decision level zero.
+   */
+  theory::TrustSubstitutionMap d_tsmap;
+
 }; /* class ZeroLevelLearner */
 
 }  // namespace prop
