@@ -46,14 +46,15 @@ bool DifficultyPostprocessCallback::shouldUpdate(std::shared_ptr<ProofNode> pn,
                                                  const std::vector<Node>& fa,
                                                  bool& continueUpdate)
 {
-  PfRule r = pn->getRule();
-  if (r == PfRule::ASSUME)
+  ProofRule r = pn->getRule();
+  if (r == ProofRule::ASSUME)
   {
     Trace("difficulty-debug")
         << "  found assume: " << pn->getResult() << std::endl;
     d_accMap[pn->getResult()] += d_currDifficulty;
   }
-  else if (r == PfRule::MACRO_SR_EQ_INTRO || r == PfRule::MACRO_SR_PRED_INTRO)
+  else if (r == ProofRule::MACRO_SR_EQ_INTRO
+           || r == ProofRule::MACRO_SR_PRED_INTRO)
   {
     // premise is just a substitution, ignore
     continueUpdate = false;
