@@ -4,7 +4,7 @@
  *
  * This file is part of the cvc5 project.
  *
- * Copyright (c) 2009-2022 by the authors listed in the file AUTHORS
+ * Copyright (c) 2009-2023 by the authors listed in the file AUTHORS
  * in the top-level source directory and their institutional affiliations.
  * All rights reserved.  See the file COPYING in the top-level source
  * directory for licensing information.
@@ -18,11 +18,12 @@
 #include <sstream>
 
 #include "base/modal_exception.h"
+#include "options/quantifiers_options.h"
 #include "options/smt_options.h"
 #include "smt/env.h"
 #include "smt/set_defaults.h"
+#include "smt/sygus_solver.h"
 #include "theory/quantifiers/quantifiers_attributes.h"
-#include "theory/quantifiers/sygus/sygus_grammar_cons.h"
 #include "theory/quantifiers/sygus/sygus_interpol.h"
 #include "theory/smt_engine_subsolver.h"
 #include "theory/trust_substitutions.h"
@@ -82,6 +83,13 @@ void InterpolationSolver::checkInterpol(Node interpol,
   Assert(interpol.getType().isBoolean());
   Trace("check-interpol")
       << "SolverEngine::checkInterpol: get expanded assertions" << std::endl;
+  bool canTrustResult = SygusSolver::canTrustSynthesisResult(options());
+  if (!canTrustResult)
+  {
+    warning() << "Running check-interpolants is not guaranteed to pass with "
+                 "the current options."
+              << std::endl;
+  }
 
   Options subOptions;
   subOptions.copyValues(d_env.getOptions());
@@ -129,19 +137,25 @@ void InterpolationSolver::checkInterpol(Node interpol,
       if (j == 0)
       {
         serr << "SolverEngine::checkInterpol(): negated produced solution "
-                "cannot "
-                "be shown "
+                "cannot be shown "
                 "satisfiable with assertions, result was "
              << r;
       }
       else
       {
         serr << "SolverEngine::checkInterpol(): negated conjecture cannot be "
-                "shown "
-                "satisfiable with produced solution, result was "
+                "shown satisfiable with produced solution, result was "
              << r;
       }
-      InternalError() << serr.str();
+      bool hardFailure = canTrustResult && !r.isUnknown();
+      if (hardFailure)
+      {
+        InternalError() << serr.str();
+      }
+      else
+      {
+        warning() << serr.str() << std::endl;
+      }
     }
   }
 }
