@@ -23,6 +23,7 @@
 #include <unordered_set>
 
 #include "proof/proof_node_updater.h"
+#include "proof/trust_id.h"
 #include "rewriter/rewrites.h"
 #include "smt/env_obj.h"
 #include "theory/inference_id.h"
@@ -50,7 +51,7 @@ class ProofFinalCallback : protected EnvObj, public ProofNodeUpdaterCallback
 
  private:
   /** Counts number of postprocessed proof nodes for each kind of proof rule */
-  HistogramStat<PfRule> d_ruleCount;
+  HistogramStat<ProofRule> d_ruleCount;
   /**
    * Counts number of postprocessed proof nodes of rule INSTANTIATE that were
    * marked with the given inference id.
@@ -61,9 +62,14 @@ class ProofFinalCallback : protected EnvObj, public ProofNodeUpdaterCallback
    * marked with the given inference id.
    */
   HistogramStat<theory::InferenceId> d_annotationRuleIds;
-  /** Counts number of postprocessed proof nodes for each kind of DSL proof rule
+  /**
+   * Counts number of postprocessed proof nodes for each kind of DSL proof rule
    */
-  HistogramStat<rewriter::DslPfRule> d_dslRuleCount;
+  HistogramStat<rewriter::DslProofRule> d_dslRuleCount;
+  /**
+   * Counts number of postprocessed proof nodes for each trusted step
+   */
+  HistogramStat<TrustId> d_trustIds;
   /** Total number of postprocessed rule applications */
   IntStat d_totalRuleCount;
   /** The minimum pedantic level of any rule encountered */
