@@ -123,7 +123,7 @@ TrustNode RemoveTermFormulas::runLemma(
   // assertionPre                 assertionPre = newAssertion
   // ------------------------------------------------------- EQ_RESOLVE
   // newAssertion
-  d_lp->addStep(newAssertion, PfRule::EQ_RESOLVE, {assertionPre, naEq}, {});
+  d_lp->addStep(newAssertion, ProofRule::EQ_RESOLVE, {assertionPre, naEq}, {});
   return TrustNode::mkTrustLemma(newAssertion, d_lp.get());
 }
 
@@ -280,7 +280,7 @@ Node RemoveTermFormulas::runCurrentInternal(TNode node,
   ProofGenerator* newAssertionPg = nullptr;
   // Handle non-Boolean ITEs here. Boolean ones (within terms) are handled
   // in the "non-variable Boolean term within term" case below.
-  if (node.getKind() == kind::ITE && !nodeType.isBoolean())
+  if (node.getKind() == Kind::ITE && !nodeType.isBoolean())
   {
     if (!nodeType.isFirstClass())
     {
@@ -310,7 +310,7 @@ Node RemoveTermFormulas::runCurrentInternal(TNode node,
 
       // The new assertion
       newAssertion = nodeManager->mkNode(
-          kind::ITE, node[0], skolem.eqNode(node[1]), skolem.eqNode(node[2]));
+          Kind::ITE, node[0], skolem.eqNode(node[1]), skolem.eqNode(node[2]));
 
       // we justify it internally
       if (isProofEnabled())
@@ -328,18 +328,18 @@ Node RemoveTermFormulas::runCurrentInternal(TNode node,
         // Note that the MACRO_SR_PRED_INTRO step holds due to conversion
         // of skolem into its witness form, which is node.
         Node axiom = getAxiomFor(node);
-        d_lp->addStep(axiom, PfRule::REMOVE_TERM_FORMULA_AXIOM, {}, {node});
+        d_lp->addStep(axiom, ProofRule::REMOVE_TERM_FORMULA_AXIOM, {}, {node});
         Node eq = node.eqNode(skolem);
-        d_lp->addStep(eq, PfRule::MACRO_SR_PRED_INTRO, {}, {eq});
+        d_lp->addStep(eq, ProofRule::MACRO_SR_PRED_INTRO, {}, {eq});
         d_lp->addStep(newAssertion,
-                      PfRule::MACRO_SR_PRED_TRANSFORM,
+                      ProofRule::MACRO_SR_PRED_TRANSFORM,
                       {axiom, eq},
                       {newAssertion});
         newAssertionPg = d_lp.get();
       }
     }
   }
-  else if (node.getKind() == kind::WITNESS)
+  else if (node.getKind() == Kind::WITNESS)
   {
     // If a witness choice
     //   For details on this operator, see
@@ -370,7 +370,7 @@ Node RemoveTermFormulas::runCurrentInternal(TNode node,
         if (isProofEnabled())
         {
           Node existsAssertion =
-              nodeManager->mkNode(kind::EXISTS, node[0], node[1]);
+              nodeManager->mkNode(Kind::EXISTS, node[0], node[1]);
           // -------------------- from skolem manager
           // (exists x. node[1])
           // -------------------- SKOLEMIZE
@@ -378,10 +378,11 @@ Node RemoveTermFormulas::runCurrentInternal(TNode node,
           ProofGenerator* expg = sm->getProofGenerator(existsAssertion);
           d_lp->addLazyStep(existsAssertion,
                             expg,
-                            PfRule::WITNESS_AXIOM,
+                            TrustId::WITNESS_AXIOM,
                             true,
                             "RemoveTermFormulas::run:skolem_pf");
-          d_lp->addStep(newAssertion, PfRule::SKOLEMIZE, {existsAssertion}, {});
+          d_lp->addStep(
+              newAssertion, ProofRule::SKOLEMIZE, {existsAssertion}, {});
           newAssertionPg = d_lp.get();
         }
       }
@@ -426,7 +427,7 @@ Node RemoveTermFormulas::runCurrentInternal(TNode node,
       // conversion proof generator.
       pg->addRewriteStep(node,
                          skolem,
-                         PfRule::MACRO_SR_PRED_INTRO,
+                         ProofRule::MACRO_SR_PRED_INTRO,
                          {},
                          {node.eqNode(skolem)},
                          true,
@@ -450,7 +451,7 @@ Node RemoveTermFormulas::runCurrentInternal(TNode node,
           // ---------------- MACRO_SR_PRED_INTRO
           // newAssertion
           d_lp->addStep(
-              newAssertion, PfRule::MACRO_SR_PRED_INTRO, {}, {newAssertion});
+              newAssertion, ProofRule::MACRO_SR_PRED_INTRO, {}, {newAssertion});
         }
       }
       Trace("rtf-debug") << "*** term formula removal introduced " << skolem
@@ -486,9 +487,9 @@ Node RemoveTermFormulas::getAxiomFor(Node n)
 {
   NodeManager* nm = NodeManager::currentNM();
   Kind k = n.getKind();
-  if (k == kind::ITE)
+  if (k == Kind::ITE)
   {
-    return nm->mkNode(kind::ITE, n[0], n.eqNode(n[1]), n.eqNode(n[2]));
+    return nm->mkNode(Kind::ITE, n[0], n.eqNode(n[1]), n.eqNode(n[2]));
   }
   return Node::null();
 }
