@@ -39,7 +39,8 @@ namespace arith {
  */
 std::optional<bool> isExpressionZero(Env& env,
                                      Node expr,
-                                     const ArithSubs& subs);
+                                     const ArithSubs& subs,
+                                     bool traverseNlMult);
 }
 }  // namespace theory
 }  // namespace cvc5::internal
