@@ -38,35 +38,35 @@ Kind joinKinds(Kind k1, Kind k2)
   }
   Assert(isRelationOperator(k1));
   Assert(isRelationOperator(k2));
-  if (k1 == EQUAL)
+  if (k1 == Kind::EQUAL)
   {
-    if (k2 == LEQ || k2 == GEQ)
+    if (k2 == Kind::LEQ || k2 == Kind::GEQ)
     {
       return k1;
     }
   }
-  else if (k1 == LT)
+  else if (k1 == Kind::LT)
   {
-    if (k2 == LEQ)
+    if (k2 == Kind::LEQ)
     {
       return k1;
     }
   }
-  else if (k1 == LEQ)
+  else if (k1 == Kind::LEQ)
   {
-    if (k2 == GEQ)
+    if (k2 == Kind::GEQ)
     {
-      return EQUAL;
+      return Kind::EQUAL;
     }
   }
-  else if (k1 == GT)
+  else if (k1 == Kind::GT)
   {
-    if (k2 == GEQ)
+    if (k2 == Kind::GEQ)
     {
       return k1;
     }
   }
-  return UNDEFINED_KIND;
+  return Kind::UNDEFINED_KIND;
 }
 
 Kind transKinds(Kind k1, Kind k2)
@@ -81,25 +81,25 @@ Kind transKinds(Kind k1, Kind k2)
   }
   Assert(isRelationOperator(k1));
   Assert(isRelationOperator(k2));
-  if (k1 == EQUAL)
+  if (k1 == Kind::EQUAL)
   {
     return k2;
   }
-  else if (k1 == LT)
+  else if (k1 == Kind::LT)
   {
-    if (k2 == LEQ)
+    if (k2 == Kind::LEQ)
     {
       return k1;
     }
   }
-  else if (k1 == GT)
+  else if (k1 == Kind::GT)
   {
-    if (k2 == GEQ)
+    if (k2 == Kind::GEQ)
     {
       return k1;
     }
   }
-  return UNDEFINED_KIND;
+  return Kind::UNDEFINED_KIND;
 }
 
 Node mkZero(const TypeNode& tn)
@@ -121,9 +121,9 @@ Node mkOne(const TypeNode& tn, bool isNeg)
 bool isTranscendentalKind(Kind k)
 {
   // many operators are eliminated during rewriting
-  Assert(k != TANGENT && k != COSINE && k != COSECANT
-         && k != SECANT && k != COTANGENT);
-  return k == EXPONENTIAL || k == SINE || k == PI;
+  Assert(k != Kind::TANGENT && k != Kind::COSINE && k != Kind::COSECANT
+         && k != Kind::SECANT && k != Kind::COTANGENT);
+  return k == Kind::EXPONENTIAL || k == Kind::SINE || k == Kind::PI;
 }
 
 Node getApproximateConstant(Node c, bool isLower, unsigned prec)
@@ -183,7 +183,7 @@ Node getApproximateConstant(Node c, bool isLower, unsigned prec)
         curr_r = Rational(curr - 1) / den;
       }
       curr_r = curr_r * pow_ten;
-      cret = nm->mkConst(CONST_RATIONAL, csign == 1 ? curr_r : -curr_r);
+      cret = nm->mkConst(Kind::CONST_RATIONAL, csign == 1 ? curr_r : -curr_r);
     }
     else
     {
@@ -225,7 +225,8 @@ void printRationalApprox(const char* c, Node cr, unsigned prec)
 Node mkBounded(Node l, Node a, Node u)
 {
   NodeManager* nm = NodeManager::currentNM();
-  return nm->mkNode(AND, nm->mkNode(GEQ, a, l), nm->mkNode(LEQ, a, u));
+  return nm->mkNode(
+      Kind::AND, nm->mkNode(Kind::GEQ, a, l), nm->mkNode(Kind::LEQ, a, u));
 }
 
 Rational leastIntGreaterThan(const Rational& q) { return q.floor() + 1; }
@@ -286,11 +287,11 @@ Node mkEquality(const Node& a, const Node& b)
   // if they have the same type, just make them equal
   if (a.getType() == b.getType())
   {
-    return nm->mkNode(EQUAL, a, b);
+    return nm->mkNode(Kind::EQUAL, a, b);
   }
   // otherwise subtract and set equal to zero
   Node diff = nm->mkNode(Kind::SUB, a, b);
-  return nm->mkNode(EQUAL, diff, mkZero(diff.getType()));
+  return nm->mkNode(Kind::EQUAL, diff, mkZero(diff.getType()));
 }
 
 std::pair<Node,Node> mkSameType(const Node& a, const Node& b)
@@ -304,10 +305,10 @@ std::pair<Node,Node> mkSameType(const Node& a, const Node& b)
   NodeManager* nm = NodeManager::currentNM();
   if (at.isInteger() && bt.isReal())
   {
-    return {nm->mkNode(kind::TO_REAL, a), b};
+    return {nm->mkNode(Kind::TO_REAL, a), b};
   }
   Assert(at.isReal() && bt.isInteger());
-  return {a, nm->mkNode(kind::TO_REAL, b)};
+  return {a, nm->mkNode(Kind::TO_REAL, b)};
 }
 
 /* ------------------------------------------------------------------------- */
@@ -324,14 +325,14 @@ Node eliminateBv2Nat(TNode node)
   for (unsigned bit = 0; bit < size; ++bit, i *= 2)
   {
     Node cond =
-        nm->mkNode(kind::EQUAL,
+        nm->mkNode(Kind::EQUAL,
                    nm->mkNode(nm->mkConst(BitVectorExtract(bit, bit)), node[0]),
                    bvone);
     children.push_back(
-        nm->mkNode(kind::ITE, cond, nm->mkConstInt(Rational(i)), z));
+        nm->mkNode(Kind::ITE, cond, nm->mkConstInt(Rational(i)), z));
   }
   // avoid plus with one child
-  return children.size() == 1 ? children[0] : nm->mkNode(kind::ADD, children);
+  return children.size() == 1 ? children[0] : nm->mkNode(Kind::ADD, children);
 }
 
 Node eliminateInt2Bv(TNode node)
@@ -346,18 +347,18 @@ Node eliminateInt2Bv(TNode node)
   while (v.size() < size)
   {
     Node cond = nm->mkNode(
-        kind::GEQ,
+        Kind::GEQ,
         nm->mkNode(
-            kind::INTS_MODULUS_TOTAL, node[0], nm->mkConstInt(Rational(i))),
+            Kind::INTS_MODULUS_TOTAL, node[0], nm->mkConstInt(Rational(i))),
         nm->mkConstInt(Rational(i, 2)));
-    v.push_back(nm->mkNode(kind::ITE, cond, bvone, bvzero));
+    v.push_back(nm->mkNode(Kind::ITE, cond, bvone, bvzero));
     i *= 2;
   }
   if (v.size() == 1)
   {
     return v[0];
   }
-  NodeBuilder result(kind::BITVECTOR_CONCAT);
+  NodeBuilder result(Kind::BITVECTOR_CONCAT);
   result.append(v.rbegin(), v.rend());
   return Node(result);
 }
