@@ -4,7 +4,7 @@
  *
  * This file is part of the cvc5 project.
  *
- * Copyright (c) 2009-2022 by the authors listed in the file AUTHORS
+ * Copyright (c) 2009-2023 by the authors listed in the file AUTHORS
  * in the top-level source directory and their institutional affiliations.
  * All rights reserved.  See the file COPYING in the top-level source
  * directory for licensing information.
@@ -24,9 +24,9 @@
 #include "proof/proof_node_manager.h"
 #include "proof/trust_node.h"
 #include "smt/env_obj.h"
-#include "theory/arith/arith_state.h"
 #include "theory/arith/inference_manager.h"
 #include "theory/arith/pp_rewrite_eq.h"
+#include "theory/theory_state.h"
 #include "util/rational.h"
 
 namespace cvc5::internal {
@@ -42,7 +42,7 @@ class BranchAndBound : protected EnvObj
 {
  public:
   BranchAndBound(Env& env,
-                 ArithState& s,
+                 TheoryState& s,
                  InferenceManager& im,
                  PreprocessRewriteEq& ppre);
   ~BranchAndBound() {}
@@ -52,23 +52,14 @@ class BranchAndBound : protected EnvObj
    *
    * @param var The variable to branch on
    * @param value Its current model value
-   * @param doPurify If true, we send the lemma (= k var) and branch on k
-   * instead, where k is the purification skolem for var.
-   *
-   * Note if doPurify is true, this method additionally includes a purification
-   * lemma as described above. If doPurify is false, this method may choose
-   * to set doPurify if necessary, in the case that the inequality is eliminated
-   * by rewriting. This can be the case when var is (bv2nat x).
    */
-  std::vector<TrustNode> branchIntegerVariable(TNode var,
-                                               Rational value,
-                                               bool doPurify = false);
+  std::vector<TrustNode> branchIntegerVariable(TNode var, Rational value);
 
  private:
   /** Are proofs enabled? */
   bool proofsEnabled() const;
   /** Reference to the state */
-  ArithState& d_astate;
+  TheoryState& d_astate;
   /** Reference to the inference manager */
   InferenceManager& d_im;
   /** Reference to the preprocess rewriter for equality */
