@@ -4,7 +4,7 @@
  *
  * This file is part of the cvc5 project.
  *
- * Copyright (c) 2009-2022 by the authors listed in the file AUTHORS
+ * Copyright (c) 2009-2023 by the authors listed in the file AUTHORS
  * in the top-level source directory and their institutional affiliations.
  * All rights reserved.  See the file COPYING in the top-level source
  * directory for licensing information.
@@ -46,7 +46,6 @@
 #include "theory/arith/linear/matrix.h"
 #include "theory/arith/linear/normal_form.h"
 #include "theory/arith/linear/partial_model.h"
-#include "theory/arith/proof_checker.h"
 #include "theory/arith/linear/soi_simplex.h"
 #include "theory/arith/theory_arith.h"
 #include "theory/valuation.h"
@@ -100,8 +99,6 @@ class TheoryArithPrivate : protected EnvObj
   // For proofs
   /** Manages the proof nodes of this theory. */
   ProofNodeManager* d_pnm;
-  /** Checks the proof rules of this theory. */
-  ArithProofRuleChecker d_checker;
   /** Stores proposition(node)/proof pairs. */
   std::unique_ptr<EagerProofGenerator> d_pfGen;
 
@@ -504,8 +501,6 @@ private:
    */
   bool foundNonlinear() const;
 
-  /** get the proof checker of this theory */
-  ArithProofRuleChecker* getProofChecker();
   /** get the congruence manager, if we are using one */
   ArithCongruenceManager* getCongruenceManager();
 
