@@ -29,25 +29,25 @@ namespace coverings {
 void CoveringsProofRuleChecker::registerTo(ProofChecker* pc)
 {
   // trusted rules
-  pc->registerTrustedChecker(PfRule::ARITH_NL_COVERING_DIRECT, this, 2);
-  pc->registerTrustedChecker(PfRule::ARITH_NL_COVERING_RECURSIVE, this, 2);
+  pc->registerTrustedChecker(ProofRule::ARITH_NL_COVERING_DIRECT, this, 2);
+  pc->registerTrustedChecker(ProofRule::ARITH_NL_COVERING_RECURSIVE, this, 2);
 }
 
-Node CoveringsProofRuleChecker::checkInternal(PfRule id,
-                                        const std::vector<Node>& children,
-                                        const std::vector<Node>& args)
+Node CoveringsProofRuleChecker::checkInternal(ProofRule id,
+                                              const std::vector<Node>& children,
+                                              const std::vector<Node>& args)
 {
   Trace("nl-cov-checker") << "Checking " << id << std::endl;
   for (const auto& c : children)
   {
     Trace("nl-cov-checker") << "\t" << c << std::endl;
   }
-  if (id == PfRule::ARITH_NL_COVERING_DIRECT)
+  if (id == ProofRule::ARITH_NL_COVERING_DIRECT)
   {
     Assert(args.size() == 1);
     return args[0];
   }
-  if (id == PfRule::ARITH_NL_COVERING_RECURSIVE)
+  if (id == ProofRule::ARITH_NL_COVERING_RECURSIVE)
   {
     Assert(args.size() == 1);
     return args[0];
