@@ -82,7 +82,7 @@ class CoveringsProofGenerator : protected EnvObj
     d_current->pruneChildren([&f](const detail::TreeProofNode& tpn) {
       // The direct children of recursive rules are scopes, but the ids are
       // attached to their children
-      if (tpn.d_rule == PfRule::SCOPE && tpn.d_children.size() == 1)
+      if (tpn.d_rule == ProofRule::SCOPE && tpn.d_children.size() == 1)
       {
         return f(tpn.d_children[0].d_objectId);
       }
