@@ -136,7 +136,7 @@ void MonomialDb::registerMonomial(Node n)
   d_monomials.push_back(n);
   Trace("nl-ext-debug") << "Register monomial : " << n << std::endl;
   Kind k = n.getKind();
-  if (k == NONLINEAR_MULT)
+  if (k == Kind::NONLINEAR_MULT)
   {
     // get exponent count
     unsigned nchild = n.getNumChildren();
@@ -158,7 +158,7 @@ void MonomialDb::registerMonomial(Node n)
   }
   else
   {
-    Assert(k != ADD && k != MULT);
+    Assert(k != Kind::ADD && k != Kind::MULT);
     d_m_exp[n][n] = 1;
     d_m_vlist[n].push_back(n);
     d_m_degree[n] = 1;
@@ -184,8 +184,9 @@ void MonomialDb::registerMonomialSubset(Node a, Node b)
 
   // currently use real type here
   TypeNode tn = NodeManager::currentNM()->realType();
-  Node mult_term = safeConstructNaryType(tn, MULT, diff_children);
-  Node nlmult_term = safeConstructNaryType(tn, NONLINEAR_MULT, diff_children);
+  Node mult_term = safeConstructNaryType(tn, Kind::MULT, diff_children);
+  Node nlmult_term =
+      safeConstructNaryType(tn, Kind::NONLINEAR_MULT, diff_children);
   d_m_contain_mult[a][b] = mult_term;
   d_m_contain_umult[a][b] = nlmult_term;
   Trace("nl-ext-mindex") << "..." << a << " is a subset of " << b
@@ -327,7 +328,7 @@ Node MonomialDb::mkMonomialRemFactor(Node n,
         << "......rem, now " << inc << " factors of " << v << std::endl;
     children.insert(children.end(), inc, v);
   }
-  Node ret = safeConstructNaryType(n.getType(), MULT, children);
+  Node ret = safeConstructNaryType(n.getType(), Kind::MULT, children);
   Trace("nl-ext-mono-factor") << "...return : " << ret << std::endl;
   return ret;
 }
