@@ -392,7 +392,7 @@ Node ran_to_node(const poly::AlgebraicNumber& an, const Node& ran_variable)
                  // var < upper_bound
                  nm->mkNode(Kind::LT, ran_variable, upper));
   return nm->mkNode(
-      kind::WITNESS, nm->mkNode(kind::BOUND_VAR_LIST, ran_variable), pred);
+      Kind::WITNESS, nm->mkNode(Kind::BOUND_VAR_LIST, ran_variable), pred);
 }
 
 Node value_to_node(const poly::Value& v, const Node& ran_variable)
@@ -649,7 +649,7 @@ std::optional<Rational> get_upper_bound(const Node& n)
  */
 std::tuple<Node, Rational, Rational> detect_ran_encoding(const Node& w)
 {
-  Assert(w.getKind()==WITNESS) << "Invalid node structure.";
+  Assert(w.getKind() == Kind::WITNESS) << "Invalid node structure.";
   Node n = w[1];
   Assert(n.getKind() == Kind::AND) << "Invalid node structure.";
   Assert(n.getNumChildren() == 3) << "Invalid node structure.";
@@ -824,11 +824,11 @@ Node PolyConverter::ran_to_defining_polynomial(const RealAlgebraicNumber& ran,
                                                const Node& ran_variable)
 {
   Node witness = ran_to_node(ran, ran_variable);
-  if (witness.getKind() == kind::WITNESS)
+  if (witness.getKind() == Kind::WITNESS)
   {
-    Assert(witness[1].getKind() == kind::AND
+    Assert(witness[1].getKind() == Kind::AND
            && witness[1].getNumChildren() == 3);
-    Assert(witness[1][0].getKind() == kind::EQUAL);
+    Assert(witness[1][0].getKind() == Kind::EQUAL);
     Assert(!witness[1][0][0].isConst());
     return witness[1][0][0];
   }
@@ -840,11 +840,11 @@ Node PolyConverter::ran_to_lower(const RealAlgebraicNumber& ran)
   NodeManager* nm = NodeManager::currentNM();
   Node ran_variable = nm->mkBoundVar(nm->realType());
   Node witness = ran_to_node(ran, ran_variable);
-  if (witness.getKind() == kind::WITNESS)
+  if (witness.getKind() == Kind::WITNESS)
   {
-    Assert(witness[1].getKind() == kind::AND
+    Assert(witness[1].getKind() == Kind::AND
            && witness[1].getNumChildren() == 3);
-    Assert(witness[1][1].getKind() == kind::LT);
+    Assert(witness[1][1].getKind() == Kind::LT);
     Assert(witness[1][1][0].isConst());
     return witness[1][1][0];
   }
@@ -857,11 +857,11 @@ Node PolyConverter::ran_to_upper(const RealAlgebraicNumber& ran)
   NodeManager* nm = NodeManager::currentNM();
   Node ran_variable = nm->mkBoundVar(nm->realType());
   Node witness = ran_to_node(ran, ran_variable);
-  if (witness.getKind() == kind::WITNESS)
+  if (witness.getKind() == Kind::WITNESS)
   {
-    Assert(witness[1].getKind() == kind::AND
+    Assert(witness[1].getKind() == Kind::AND
            && witness[1].getNumChildren() == 3);
-    Assert(witness[1][2].getKind() == kind::LT);
+    Assert(witness[1][2].getKind() == Kind::LT);
     Assert(witness[1][2][1].isConst());
     return witness[1][2][1];
   }
