@@ -35,7 +35,7 @@ class RationalEnumerator : public TypeEnumeratorBase<RationalEnumerator> {
   RationalEnumerator(TypeNode type, TypeEnumeratorProperties* tep = nullptr)
       : TypeEnumeratorBase<RationalEnumerator>(type), d_rat(0)
   {
-    Assert(type.getKind() == kind::TYPE_CONSTANT
+    Assert(type.getKind() == Kind::TYPE_CONSTANT
            && type.getConst<TypeConstant>() == REAL_TYPE);
   }
 
@@ -79,7 +79,7 @@ class IntegerEnumerator : public TypeEnumeratorBase<IntegerEnumerator> {
   IntegerEnumerator(TypeNode type, TypeEnumeratorProperties* tep = nullptr)
       : TypeEnumeratorBase<IntegerEnumerator>(type), d_int(0)
   {
-    Assert(type.getKind() == kind::TYPE_CONSTANT
+    Assert(type.getKind() == Kind::TYPE_CONSTANT
            && type.getConst<TypeConstant>() == INTEGER_TYPE);
   }
 
