@@ -20,7 +20,7 @@
 
 #include "expr/node.h"
 #include "proof/eager_proof_generator.h"
-#include "proof/proof_rule.h"
+#include "cvc5/cvc5_proof_rule.h"
 #include "theory/theory_inference_manager.h"
 
 namespace cvc5::internal {
@@ -46,14 +46,15 @@ class InferenceManager : public TheoryInferenceManager
    * @return true if the fact was successfully asserted, and false if the
    * fact was redundant.
    */
-  bool assertInference(TNode atom, bool polarity, InferenceId id, TNode reason, PfRule pfr);
+  bool assertInference(
+      TNode atom, bool polarity, InferenceId id, TNode reason, ProofRule pfr);
   /**
    * Send lemma (exp => conc) based on proof rule id with properties p.
    */
   bool arrayLemma(Node conc,
                   InferenceId id,
                   Node exp,
-                  PfRule pfr,
+                  ProofRule pfr,
                   LemmaProperty p = LemmaProperty::NONE);
 
  private:
@@ -61,7 +62,7 @@ class InferenceManager : public TheoryInferenceManager
    * Converts a conclusion, explanation and proof rule id used by the array
    * theory to the set of arguments required for a proof rule application.
    */
-  void convert(PfRule& id,
+  void convert(ProofRule& id,
                Node conc,
                Node exp,
                std::vector<Node>& children,
