@@ -132,16 +132,13 @@ Node BagsUtils::evaluate(Rewriter* rewriter, TNode n)
   {
     case Kind::BAG_MAKE: return evaluateMakeBag(n);
     case Kind::BAG_COUNT: return evaluateBagCount(n);
-    case Kind::BAG_DUPLICATE_REMOVAL: return evaluateDuplicateRemoval(n);
+    case Kind::BAG_SETOF: return evaluateSetof(n);
     case Kind::BAG_UNION_DISJOINT: return evaluateUnionDisjoint(n);
     case Kind::BAG_UNION_MAX: return evaluateUnionMax(n);
     case Kind::BAG_INTER_MIN: return evaluateIntersectionMin(n);
     case Kind::BAG_DIFFERENCE_SUBTRACT: return evaluateDifferenceSubtract(n);
     case Kind::BAG_DIFFERENCE_REMOVE: return evaluateDifferenceRemove(n);
     case Kind::BAG_CARD: return evaluateCard(n);
-    case Kind::BAG_IS_SINGLETON: return evaluateIsSingleton(n);
-    case Kind::BAG_FROM_SET: return evaluateFromSet(n);
-    case Kind::BAG_TO_SET: return evaluateToSet(n);
     case Kind::BAG_MAP: return evaluateBagMap(n);
     case Kind::BAG_FILTER: return evaluateBagFilter(n);
     case Kind::BAG_FOLD: return evaluateBagFold(n);
@@ -301,16 +298,16 @@ Node BagsUtils::evaluateBagCount(TNode n)
   return nm->mkConstInt(Rational(0));
 }
 
-Node BagsUtils::evaluateDuplicateRemoval(TNode n)
+Node BagsUtils::evaluateSetof(TNode n)
 {
-  Assert(n.getKind() == Kind::BAG_DUPLICATE_REMOVAL);
+  Assert(n.getKind() == Kind::BAG_SETOF);
 
   // Examples
   // --------
-  //  - (bag.duplicate_removal (as bag.empty (Bag String))) = (as bag.empty (Bag
+  //  - (bag.setof (as bag.empty (Bag String))) = (as bag.empty (Bag
   //  String))
-  //  - (bag.duplicate_removal (bag "x" 4)) = (bag "x" 1)
-  //  - (bag.duplicate_removal (bag.disjoint_union (bag "x" 3) (bag "y" 5)) =
+  //  - (bag.setof (bag "x" 4)) = (bag "x" 1)
+  //  - (bag.setof (bag.disjoint_union (bag "x" 3) (bag "y" 5)) =
   //     (bag.disjoint_union (bag "x" 1) (bag "y" 1)
 
   std::map<Node, Rational> oldElements = getBagElements(n[0]);
@@ -630,73 +627,6 @@ Node BagsUtils::evaluateCard(TNode n)
   return sumNode;
 }
 
-Node BagsUtils::evaluateIsSingleton(TNode n)
-{
-  Assert(n.getKind() == Kind::BAG_IS_SINGLETON);
-  // Examples
-  // --------
-  // - (bag.is_singleton (as bag.empty (Bag String))) = false
-  // - (bag.is_singleton (bag "x" 1)) = true
-  // - (bag.is_singleton (bag "x" 4)) = false
-  // - (bag.is_singleton (bag.union_disjoint (bag "x" 1) (bag "y" 1)))
-  // = false
-
-  if (n[0].getKind() == Kind::BAG_MAKE && n[0][1].getConst<Rational>().isOne())
-  {
-    return NodeManager::currentNM()->mkConst(true);
-  }
-  return NodeManager::currentNM()->mkConst(false);
-}
-
-Node BagsUtils::evaluateFromSet(TNode n)
-{
-  Assert(n.getKind() == Kind::BAG_FROM_SET);
-
-  // Examples
-  // --------
-  //  - (bag.from_set (as set.empty (Set String))) = (as bag.empty (Bag String))
-  //  - (bag.from_set (set.singleton "x")) = (bag "x" 1)
-  //  - (bag.from_set (set.union (set.singleton "x") (set.singleton "y"))) =
-  //     (bag.disjoint_union (bag "x" 1) (bag "y" 1))
-
-  NodeManager* nm = NodeManager::currentNM();
-  std::set<Node> setElements =
-      sets::NormalForm::getElementsFromNormalConstant(n[0]);
-  Rational one = Rational(1);
-  std::map<Node, Rational> bagElements;
-  for (const Node& element : setElements)
-  {
-    bagElements[element] = one;
-  }
-  TypeNode bagType = nm->mkBagType(n[0].getType().getSetElementType());
-  Node bag = constructConstantBagFromElements(bagType, bagElements);
-  return bag;
-}
-
-Node BagsUtils::evaluateToSet(TNode n)
-{
-  Assert(n.getKind() == Kind::BAG_TO_SET);
-
-  // Examples
-  // --------
-  //  - (bag.to_set (as bag.empty (Bag String))) = (as set.empty (Set String))
-  //  - (bag.to_set (bag "x" 4)) = (set.singleton "x")
-  //  - (bag.to_set (bag.disjoint_union (bag "x" 3) (bag "y" 5)) =
-  //     (set.union (set.singleton "x") (set.singleton "y")))
-
-  NodeManager* nm = NodeManager::currentNM();
-  std::map<Node, Rational> bagElements = getBagElements(n[0]);
-  std::set<Node> setElements;
-  std::map<Node, Rational>::const_reverse_iterator it;
-  for (it = bagElements.rbegin(); it != bagElements.rend(); it++)
-  {
-    setElements.insert(it->first);
-  }
-  TypeNode setType = nm->mkSetType(n[0].getType().getBagElementType());
-  Node set = sets::NormalForm::elementsToSet(setElements, setType);
-  return set;
-}
-
 Node BagsUtils::evaluateBagMap(TNode n)
 {
   Assert(n.getKind() == Kind::BAG_MAP);
