@@ -34,8 +34,7 @@ const char* toString(Rewrite r)
     case Rewrite::CONSTANT_EVALUATION: return "CONSTANT_EVALUATION";
     case Rewrite::COUNT_EMPTY: return "COUNT_EMPTY";
     case Rewrite::COUNT_BAG_MAKE: return "COUNT_BAG_MAKE";
-    case Rewrite::DUPLICATE_REMOVAL_BAG_MAKE:
-      return "DUPLICATE_REMOVAL_BAG_MAKE";
+    case Rewrite::SETOF_BAG_MAKE: return "SETOF_BAG_MAKE";
     case Rewrite::EQ_CONST_FALSE: return "EQ_CONST_FALSE";
     case Rewrite::EQ_REFL: return "EQ_REFL";
     case Rewrite::EQ_SYM: return "EQ_SYM";
