@@ -39,7 +39,7 @@ enum class Rewrite : uint32_t
   CONSTANT_EVALUATION,
   COUNT_EMPTY,
   COUNT_BAG_MAKE,
-  DUPLICATE_REMOVAL_BAG_MAKE,
+  SETOF_BAG_MAKE,
   EQ_CONST_FALSE,
   EQ_REFL,
   EQ_SYM,
