@@ -171,24 +171,23 @@ TypeNode MemberTypeRule::computeType(NodeManager* nodeManager,
   return nodeManager->booleanType();
 }
 
-TypeNode DuplicateRemovalTypeRule::preComputeType(NodeManager* nm, TNode n)
+TypeNode SetofTypeRule::preComputeType(NodeManager* nm, TNode n)
 {
   return TypeNode::null();
 }
-TypeNode DuplicateRemovalTypeRule::computeType(NodeManager* nodeManager,
-                                               TNode n,
-                                               bool check,
-                                               std::ostream* errOut)
+TypeNode SetofTypeRule::computeType(NodeManager* nodeManager,
+                                    TNode n,
+                                    bool check,
+                                    std::ostream* errOut)
 {
-  Assert(n.getKind() == Kind::BAG_DUPLICATE_REMOVAL);
+  Assert(n.getKind() == Kind::BAG_SETOF);
   TypeNode bagType = n[0].getType(check);
   if (check)
   {
     if (!bagType.isBag())
     {
       std::stringstream ss;
-      ss << "Applying BAG_DUPLICATE_REMOVAL on a non-bag argument in term "
-         << n;
+      ss << "Applying BAG_SETOF on a non-bag argument in term " << n;
       throw TypeCheckingExceptionPrivate(n, ss.str());
     }
   }
@@ -236,28 +235,6 @@ bool BagMakeTypeRule::computeIsConst(NodeManager* nodeManager, TNode n)
          && n[1].getConst<Rational>().sgn() == 1;
 }
 
-TypeNode IsSingletonTypeRule::preComputeType(NodeManager* nm, TNode n)
-{
-  return nm->booleanType();
-}
-TypeNode IsSingletonTypeRule::computeType(NodeManager* nodeManager,
-                                          TNode n,
-                                          bool check,
-                                          std::ostream* errOut)
-{
-  Assert(n.getKind() == Kind::BAG_IS_SINGLETON);
-  TypeNode bagType = n[0].getType(check);
-  if (check)
-  {
-    if (!bagType.isBag())
-    {
-      throw TypeCheckingExceptionPrivate(
-          n, "BAG_IS_SINGLETON operator expects a bag, a non-bag is found");
-    }
-  }
-  return nodeManager->booleanType();
-}
-
 TypeNode EmptyBagTypeRule::preComputeType(NodeManager* nm, TNode n)
 {
   return TypeNode::null();
@@ -316,54 +293,6 @@ TypeNode ChooseTypeRule::computeType(NodeManager* nodeManager,
   return bagType.getBagElementType();
 }
 
-TypeNode FromSetTypeRule::preComputeType(NodeManager* nm, TNode n)
-{
-  return TypeNode::null();
-}
-TypeNode FromSetTypeRule::computeType(NodeManager* nodeManager,
-                                      TNode n,
-                                      bool check,
-                                      std::ostream* errOut)
-{
-  Assert(n.getKind() == Kind::BAG_FROM_SET);
-  TypeNode setType = n[0].getType(check);
-  if (check)
-  {
-    if (!setType.isSet())
-    {
-      throw TypeCheckingExceptionPrivate(
-          n, "bag.from_set operator expects a set, a non-set is found");
-    }
-  }
-  TypeNode elementType = setType.getSetElementType();
-  TypeNode bagType = nodeManager->mkBagType(elementType);
-  return bagType;
-}
-
-TypeNode ToSetTypeRule::preComputeType(NodeManager* nm, TNode n)
-{
-  return TypeNode::null();
-}
-TypeNode ToSetTypeRule::computeType(NodeManager* nodeManager,
-                                    TNode n,
-                                    bool check,
-                                    std::ostream* errOut)
-{
-  Assert(n.getKind() == Kind::BAG_TO_SET);
-  TypeNode bagType = n[0].getType(check);
-  if (check)
-  {
-    if (!bagType.isBag())
-    {
-      throw TypeCheckingExceptionPrivate(
-          n, "bag.to_set operator expects a bag, a non-bag is found");
-    }
-  }
-  TypeNode elementType = bagType.getBagElementType();
-  TypeNode setType = nodeManager->mkSetType(elementType);
-  return setType;
-}
-
 TypeNode BagMapTypeRule::preComputeType(NodeManager* nm, TNode n)
 {
   return TypeNode::null();
