@@ -17,6 +17,7 @@
 
 #include "expr/attribute.h"
 #include "expr/skolem_manager.h"
+#include "theory/builtin/generic_op.h"
 #include "util/uninterpreted_sort_value.h"
 
 namespace cvc5::internal {
@@ -32,25 +33,23 @@ TypeNode EqualityTypeRule::computeType(NodeManager* nodeManager,
                                        bool check,
                                        std::ostream* errOut)
 {
-  TypeNode booleanType = nodeManager->booleanType();
-
   if (check)
   {
-    TypeNode lhsType = n[0].getType(check);
-    TypeNode rhsType = n[1].getType(check);
-
-    if (lhsType != rhsType)
+    TypeNode lhsType = n[0].getTypeOrNull();
+    TypeNode rhsType = n[1].getTypeOrNull();
+    if (!lhsType.isComparableTo(rhsType))
     {
-      std::stringstream ss;
-      ss << "Subexpressions must have the same type:" << std::endl;
-      ss << "Equation: " << n << std::endl;
-      ss << "Type 1: " << lhsType << std::endl;
-      ss << "Type 2: " << rhsType << std::endl;
-
-      throw TypeCheckingExceptionPrivate(n, ss.str());
+      if (errOut)
+      {
+        (*errOut) << "Subexpressions must have the same type:" << std::endl;
+        (*errOut) << "Equation: " << n << std::endl;
+        (*errOut) << "Type 1: " << lhsType << std::endl;
+        (*errOut) << "Type 2: " << rhsType << std::endl;
+      }
+      return TypeNode::null();
     }
   }
-  return booleanType;
+  return nodeManager->booleanType();
 }
 
 TypeNode DistinctTypeRule::preComputeType(NodeManager* nm, TNode n)
@@ -66,14 +65,18 @@ TypeNode DistinctTypeRule::computeType(NodeManager* nodeManager,
   {
     TNode::iterator child_it = n.begin();
     TNode::iterator child_it_end = n.end();
-    TypeNode joinType = (*child_it).getType(check);
+    TypeNode joinType = (*child_it).getTypeOrNull();
     for (++child_it; child_it != child_it_end; ++child_it)
     {
       TypeNode currentType = (*child_it).getType();
-      if (joinType != currentType)
+      joinType = joinType.leastUpperBound(currentType);
+      if (joinType.isNull())
       {
-        throw TypeCheckingExceptionPrivate(
-            n, "Not all arguments are of the same type");
+        if (errOut)
+        {
+          (*errOut) << "Not all arguments are of the same type";
+        }
+        return TypeNode::null();
       }
     }
   }
@@ -89,13 +92,6 @@ TypeNode SExprTypeRule::computeType(NodeManager* nodeManager,
                                     bool check,
                                     std::ostream* errOut)
 {
-  if (check)
-  {
-    for (TNode c : n)
-    {
-      c.getType(check);
-    }
-  }
   return nodeManager->sExprType();
 }
 
@@ -121,36 +117,46 @@ TypeNode WitnessTypeRule::computeType(NodeManager* nodeManager,
                                       bool check,
                                       std::ostream* errOut)
 {
-  if (n[0].getType(check) != nodeManager->boundVarListType())
+  if (n[0].getTypeOrNull() != nodeManager->boundVarListType())
   {
-    std::stringstream ss;
-    ss << "expected a bound var list for WITNESS expression, got `"
-       << n[0].getType().toString() << "'";
-    throw TypeCheckingExceptionPrivate(n, ss.str());
+    if (errOut)
+    {
+      (*errOut) << "expected a bound var list for WITNESS expression, got `"
+                << n[0].getType().toString() << "'";
+    }
+    return TypeNode::null();
   }
   if (n[0].getNumChildren() != 1)
   {
-    std::stringstream ss;
-    ss << "expected a bound var list with one argument for WITNESS expression";
-    throw TypeCheckingExceptionPrivate(n, ss.str());
+    if (errOut)
+    {
+      (*errOut) << "expected a bound var list with one argument for WITNESS "
+                   "expression";
+    }
+    return TypeNode::null();
   }
   if (check)
   {
-    TypeNode rangeType = n[1].getType(check);
+    TypeNode rangeType = n[1].getTypeOrNull();
     if (!rangeType.isBoolean())
     {
-      std::stringstream ss;
-      ss << "expected a body of a WITNESS expression to have Boolean type";
-      throw TypeCheckingExceptionPrivate(n, ss.str());
+      if (errOut)
+      {
+        (*errOut)
+            << "expected a body of a WITNESS expression to have Boolean type";
+      }
+      return TypeNode::null();
     }
     if (n.getNumChildren() == 3)
     {
-      if (n[2].getType(check) != nodeManager->instPatternListType())
+      if (n[2].getTypeOrNull() != nodeManager->instPatternListType())
       {
-        throw TypeCheckingExceptionPrivate(
-            n,
-            "third argument of witness is not instantiation "
-            "pattern list");
+        if (errOut)
+        {
+          (*errOut)
+              << "third argument of witness is not instantiation pattern list";
+        }
+        return TypeNode::null();
       }
     }
   }
@@ -160,16 +166,22 @@ TypeNode WitnessTypeRule::computeType(NodeManager* nodeManager,
 
 TypeNode ApplyIndexedSymbolicTypeRule::preComputeType(NodeManager* nm, TNode n)
 {
-  return nm->mkAbstractType(Kind::ABSTRACT_TYPE);
+  return TypeNode::null();
 }
 TypeNode ApplyIndexedSymbolicTypeRule::computeType(NodeManager* nodeManager,
                                                    TNode n,
                                                    bool check,
                                                    std::ostream* errOut)
 {
-  // Note that this could be more precise by case splitting on the kind
-  // of indexed operator, but we don't do this for simplicity.
-  return nodeManager->mkAbstractType(Kind::ABSTRACT_TYPE);
+  // get the concrete application version of this, if possible
+  Node cn = GenericOp::getConcreteApp(n);
+  if (cn == n)
+  {
+    // if it cannot be made concrete, it has abstract type
+    return nodeManager->mkAbstractType(Kind::ABSTRACT_TYPE);
+  }
+  // if we can make concrete, return its type
+  return cn.getType();
 }
 /**
  * Attribute for caching the ground term for each type. Maps TypeNode to the
