@@ -30,9 +30,8 @@ namespace bv {
 template<> inline
 bool RewriteRule<EvalAnd>::applies(TNode node) {
   Unreachable();
-  return (node.getKind() == kind::BITVECTOR_AND &&
-          node.getNumChildren() == 2 &&
-          utils::isBvConstTerm(node));
+  return (node.getKind() == Kind::BITVECTOR_AND && node.getNumChildren() == 2
+          && utils::isBvConstTerm(node));
 }
 
 template<> inline
@@ -49,9 +48,8 @@ Node RewriteRule<EvalAnd>::apply(TNode node) {
 template<> inline
 bool RewriteRule<EvalOr>::applies(TNode node) {
   Unreachable();
-  return (node.getKind() == kind::BITVECTOR_OR &&
-          node.getNumChildren() == 2 &&
-          utils::isBvConstTerm(node));
+  return (node.getKind() == Kind::BITVECTOR_OR && node.getNumChildren() == 2
+          && utils::isBvConstTerm(node));
 }
 
 template<> inline
@@ -68,9 +66,8 @@ Node RewriteRule<EvalOr>::apply(TNode node) {
 template<> inline
 bool RewriteRule<EvalXor>::applies(TNode node) {
   Unreachable();
-  return (node.getKind() == kind::BITVECTOR_XOR &&
-          node.getNumChildren() == 2 &&
-          utils::isBvConstTerm(node));
+  return (node.getKind() == Kind::BITVECTOR_XOR && node.getNumChildren() == 2
+          && utils::isBvConstTerm(node));
 }
 
 template<> inline
@@ -86,7 +83,7 @@ Node RewriteRule<EvalXor>::apply(TNode node) {
 
 // template<> inline
 // bool RewriteRule<EvalXnor>::applies(TNode node) {
-//   return (node.getKind() == kind::BITVECTOR_XNOR &&
+//   return (node.getKind() == Kind::BITVECTOR_XNOR &&
 //           utils::isBvConstTerm(node));
 // }
 
@@ -101,8 +98,7 @@ Node RewriteRule<EvalXor>::apply(TNode node) {
 // }
 template<> inline
 bool RewriteRule<EvalNot>::applies(TNode node) {
-  return (node.getKind() == kind::BITVECTOR_NOT &&
-          utils::isBvConstTerm(node));
+  return (node.getKind() == Kind::BITVECTOR_NOT && utils::isBvConstTerm(node));
 }
 
 template<> inline
@@ -115,7 +111,7 @@ Node RewriteRule<EvalNot>::apply(TNode node) {
 
 // template<> inline
 // bool RewriteRule<EvalComp>::applies(TNode node) {
-//   return (node.getKind() == kind::BITVECTOR_COMP &&
+//   return (node.getKind() == Kind::BITVECTOR_COMP &&
 //           utils::isBvConstTerm(node));
 // }
 
@@ -136,8 +132,7 @@ Node RewriteRule<EvalNot>::apply(TNode node) {
 
 template<> inline
 bool RewriteRule<EvalMult>::applies(TNode node) {
-  return (node.getKind() == kind::BITVECTOR_MULT &&
-          utils::isBvConstTerm(node));
+  return (node.getKind() == Kind::BITVECTOR_MULT && utils::isBvConstTerm(node));
 }
 
 template<> inline
@@ -154,7 +149,7 @@ Node RewriteRule<EvalMult>::apply(TNode node) {
 template <>
 inline bool RewriteRule<EvalAdd>::applies(TNode node)
 {
-  return (node.getKind() == kind::BITVECTOR_ADD && utils::isBvConstTerm(node));
+  return (node.getKind() == Kind::BITVECTOR_ADD && utils::isBvConstTerm(node));
 }
 
 template <>
@@ -171,7 +166,7 @@ inline Node RewriteRule<EvalAdd>::apply(TNode node)
 
 // template<> inline
 // bool RewriteRule<EvalSub>::applies(TNode node) {
-//   return (node.getKind() == kind::BITVECTOR_SUB &&
+//   return (node.getKind() == Kind::BITVECTOR_SUB &&
 //           utils::isBvConstTerm(node));
 // }
 
@@ -186,8 +181,7 @@ inline Node RewriteRule<EvalAdd>::apply(TNode node)
 // }
 template<> inline
 bool RewriteRule<EvalNeg>::applies(TNode node) {
-  return (node.getKind() == kind::BITVECTOR_NEG &&
-          utils::isBvConstTerm(node));
+  return (node.getKind() == Kind::BITVECTOR_NEG && utils::isBvConstTerm(node));
 }
 
 template<> inline
@@ -200,7 +194,7 @@ Node RewriteRule<EvalNeg>::apply(TNode node) {
 }
 template<> inline
 bool RewriteRule<EvalUdiv>::applies(TNode node) {
-  return utils::isBvConstTerm(node) && node.getKind() == kind::BITVECTOR_UDIV;
+  return utils::isBvConstTerm(node) && node.getKind() == Kind::BITVECTOR_UDIV;
 }
 
 template<> inline
@@ -214,7 +208,7 @@ Node RewriteRule<EvalUdiv>::apply(TNode node) {
 }
 template<> inline
 bool RewriteRule<EvalUrem>::applies(TNode node) {
-  return utils::isBvConstTerm(node) && node.getKind() == kind::BITVECTOR_UREM;
+  return utils::isBvConstTerm(node) && node.getKind() == Kind::BITVECTOR_UREM;
 }
 
 template<> inline
@@ -228,8 +222,7 @@ Node RewriteRule<EvalUrem>::apply(TNode node) {
 
 template<> inline
 bool RewriteRule<EvalShl>::applies(TNode node) {
-  return (node.getKind() == kind::BITVECTOR_SHL &&
-          utils::isBvConstTerm(node));
+  return (node.getKind() == Kind::BITVECTOR_SHL && utils::isBvConstTerm(node));
 }
 
 template<> inline
@@ -244,8 +237,7 @@ Node RewriteRule<EvalShl>::apply(TNode node) {
 
 template<> inline
 bool RewriteRule<EvalLshr>::applies(TNode node) {
-  return (node.getKind() == kind::BITVECTOR_LSHR &&
-          utils::isBvConstTerm(node));
+  return (node.getKind() == Kind::BITVECTOR_LSHR && utils::isBvConstTerm(node));
 }
 
 template<> inline
@@ -260,8 +252,7 @@ Node RewriteRule<EvalLshr>::apply(TNode node) {
 
 template<> inline
 bool RewriteRule<EvalAshr>::applies(TNode node) {
-  return (node.getKind() == kind::BITVECTOR_ASHR &&
-          utils::isBvConstTerm(node));
+  return (node.getKind() == Kind::BITVECTOR_ASHR && utils::isBvConstTerm(node));
 }
 
 template<> inline
@@ -276,8 +267,7 @@ Node RewriteRule<EvalAshr>::apply(TNode node) {
 
 template<> inline
 bool RewriteRule<EvalUlt>::applies(TNode node) {
-  return (node.getKind() == kind::BITVECTOR_ULT &&
-          utils::isBvConstTerm(node));
+  return (node.getKind() == Kind::BITVECTOR_ULT && utils::isBvConstTerm(node));
 }
 
 template<> inline
@@ -294,8 +284,8 @@ Node RewriteRule<EvalUlt>::apply(TNode node) {
 
 template<> inline
 bool RewriteRule<EvalUltBv>::applies(TNode node) {
-  return (node.getKind() == kind::BITVECTOR_ULTBV &&
-          utils::isBvConstTerm(node));
+  return (node.getKind() == Kind::BITVECTOR_ULTBV
+          && utils::isBvConstTerm(node));
 }
 
 template<> inline
@@ -312,8 +302,7 @@ Node RewriteRule<EvalUltBv>::apply(TNode node) {
 
 template<> inline
 bool RewriteRule<EvalSlt>::applies(TNode node) {
-  return (node.getKind() == kind::BITVECTOR_SLT &&
-          utils::isBvConstTerm(node));
+  return (node.getKind() == Kind::BITVECTOR_SLT && utils::isBvConstTerm(node));
 }
 
 template<> inline
@@ -331,8 +320,8 @@ Node RewriteRule<EvalSlt>::apply(TNode node) {
 
 template<> inline
 bool RewriteRule<EvalSltBv>::applies(TNode node) {
-  return (node.getKind() == kind::BITVECTOR_SLTBV &&
-          utils::isBvConstTerm(node));
+  return (node.getKind() == Kind::BITVECTOR_SLTBV
+          && utils::isBvConstTerm(node));
 }
 
 template<> inline
@@ -351,8 +340,7 @@ Node RewriteRule<EvalSltBv>::apply(TNode node) {
 template<> inline
 bool RewriteRule<EvalITEBv>::applies(TNode node) {
   Trace("bv-rewrite") << "RewriteRule<EvalITEBv>::applies(" << node << ")" << std::endl;
-  return (node.getKind() == kind::BITVECTOR_ITE &&
-          utils::isBvConstTerm(node));
+  return (node.getKind() == Kind::BITVECTOR_ITE && utils::isBvConstTerm(node));
 }
 
 template<> inline
@@ -370,8 +358,7 @@ Node RewriteRule<EvalITEBv>::apply(TNode node) {
 
 template<> inline
 bool RewriteRule<EvalUle>::applies(TNode node) {
-  return (node.getKind() == kind::BITVECTOR_ULE &&
-          utils::isBvConstTerm(node));
+  return (node.getKind() == Kind::BITVECTOR_ULE && utils::isBvConstTerm(node));
 }
 
 template<> inline
@@ -388,8 +375,7 @@ Node RewriteRule<EvalUle>::apply(TNode node) {
 
 template<> inline
 bool RewriteRule<EvalSle>::applies(TNode node) {
-  return (node.getKind() == kind::BITVECTOR_SLE &&
-          utils::isBvConstTerm(node));
+  return (node.getKind() == Kind::BITVECTOR_SLE && utils::isBvConstTerm(node));
 }
 
 template<> inline
@@ -406,8 +392,8 @@ Node RewriteRule<EvalSle>::apply(TNode node) {
 
 template<> inline
 bool RewriteRule<EvalExtract>::applies(TNode node) {
-  return (node.getKind() == kind::BITVECTOR_EXTRACT &&
-          utils::isBvConstTerm(node));
+  return (node.getKind() == Kind::BITVECTOR_EXTRACT
+          && utils::isBvConstTerm(node));
 }
 
 template<> inline
@@ -424,8 +410,8 @@ Node RewriteRule<EvalExtract>::apply(TNode node) {
 
 template<> inline
 bool RewriteRule<EvalConcat>::applies(TNode node) {
-  return (node.getKind() == kind::BITVECTOR_CONCAT &&
-          utils::isBvConstTerm(node));
+  return (node.getKind() == Kind::BITVECTOR_CONCAT
+          && utils::isBvConstTerm(node));
 }
 
 template<> inline
@@ -442,8 +428,8 @@ Node RewriteRule<EvalConcat>::apply(TNode node) {
 
 template<> inline
 bool RewriteRule<EvalSignExtend>::applies(TNode node) {
-  return (node.getKind() == kind::BITVECTOR_SIGN_EXTEND &&
-          utils::isBvConstTerm(node));
+  return (node.getKind() == Kind::BITVECTOR_SIGN_EXTEND
+          && utils::isBvConstTerm(node));
 }
 
 template<> inline
@@ -459,8 +445,7 @@ Node RewriteRule<EvalSignExtend>::apply(TNode node) {
 
 template<> inline
 bool RewriteRule<EvalEquals>::applies(TNode node) {
-  return (node.getKind() == kind::EQUAL &&
-          utils::isBvConstTerm(node));
+  return (node.getKind() == Kind::EQUAL && utils::isBvConstTerm(node));
 }
 
 template<> inline
@@ -477,8 +462,7 @@ Node RewriteRule<EvalEquals>::apply(TNode node) {
 
 template<> inline
 bool RewriteRule<EvalComp>::applies(TNode node) {
-  return (node.getKind() == kind::BITVECTOR_COMP &&
-          utils::isBvConstTerm(node));
+  return (node.getKind() == Kind::BITVECTOR_COMP && utils::isBvConstTerm(node));
 }
 
 template<> inline
@@ -495,7 +479,7 @@ Node RewriteRule<EvalComp>::apply(TNode node) {
 template <>
 inline bool RewriteRule<EvalEagerAtom>::applies(TNode node)
 {
-  return (node.getKind() == kind::BITVECTOR_EAGER_ATOM && node[0].isConst());
+  return (node.getKind() == Kind::BITVECTOR_EAGER_ATOM && node[0].isConst());
 }
 
 template <>
