@@ -31,7 +31,7 @@ namespace bv {
 template <>
 inline bool RewriteRule<UgtEliminate>::applies(TNode node)
 {
-  return (node.getKind() == kind::BITVECTOR_UGT);
+  return (node.getKind() == Kind::BITVECTOR_UGT);
 }
 
 template <>
@@ -41,14 +41,14 @@ inline Node RewriteRule<UgtEliminate>::apply(TNode node)
                       << std::endl;
   TNode a = node[0];
   TNode b = node[1];
-  Node result = NodeManager::currentNM()->mkNode(kind::BITVECTOR_ULT, b, a);
+  Node result = NodeManager::currentNM()->mkNode(Kind::BITVECTOR_ULT, b, a);
   return result;
 }
 
 template <>
 inline bool RewriteRule<UgeEliminate>::applies(TNode node)
 {
-  return (node.getKind() == kind::BITVECTOR_UGE);
+  return (node.getKind() == Kind::BITVECTOR_UGE);
 }
 
 template <>
@@ -58,14 +58,14 @@ inline Node RewriteRule<UgeEliminate>::apply(TNode node)
                       << std::endl;
   TNode a = node[0];
   TNode b = node[1];
-  Node result = NodeManager::currentNM()->mkNode(kind::BITVECTOR_ULE, b, a);
+  Node result = NodeManager::currentNM()->mkNode(Kind::BITVECTOR_ULE, b, a);
   return result;
 }
 
 template <>
 inline bool RewriteRule<SgtEliminate>::applies(TNode node)
 {
-  return (node.getKind() == kind::BITVECTOR_SGT);
+  return (node.getKind() == Kind::BITVECTOR_SGT);
 }
 
 template <>
@@ -75,14 +75,14 @@ inline Node RewriteRule<SgtEliminate>::apply(TNode node)
                       << std::endl;
   TNode a = node[0];
   TNode b = node[1];
-  Node result = NodeManager::currentNM()->mkNode(kind::BITVECTOR_SLT, b, a);
+  Node result = NodeManager::currentNM()->mkNode(Kind::BITVECTOR_SLT, b, a);
   return result;
 }
 
 template <>
 inline bool RewriteRule<SgeEliminate>::applies(TNode node)
 {
-  return (node.getKind() == kind::BITVECTOR_SGE);
+  return (node.getKind() == Kind::BITVECTOR_SGE);
 }
 
 template <>
@@ -92,14 +92,14 @@ inline Node RewriteRule<SgeEliminate>::apply(TNode node)
                       << std::endl;
   TNode a = node[0];
   TNode b = node[1];
-  Node result = NodeManager::currentNM()->mkNode(kind::BITVECTOR_SLE, b, a);
+  Node result = NodeManager::currentNM()->mkNode(Kind::BITVECTOR_SLE, b, a);
   return result;
 }
 
 template <>
 inline bool RewriteRule<SltEliminate>::applies(TNode node)
 {
-  return (node.getKind() == kind::BITVECTOR_SLT); 
+  return (node.getKind() == Kind::BITVECTOR_SLT);
 }
 
 template <>
@@ -111,16 +111,16 @@ inline Node RewriteRule<SltEliminate>::apply(TNode node)
   unsigned size = utils::getSize(node[0]);
   Integer val = Integer(1).multiplyByPow2(size - 1);
   Node pow_two = utils::mkConst(size, val);
-  Node a = nm->mkNode(kind::BITVECTOR_ADD, node[0], pow_two);
-  Node b = nm->mkNode(kind::BITVECTOR_ADD, node[1], pow_two);
+  Node a = nm->mkNode(Kind::BITVECTOR_ADD, node[0], pow_two);
+  Node b = nm->mkNode(Kind::BITVECTOR_ADD, node[1], pow_two);
 
-  return nm->mkNode(kind::BITVECTOR_ULT, a, b);
+  return nm->mkNode(Kind::BITVECTOR_ULT, a, b);
 }
 
 template <>
 inline bool RewriteRule<SleEliminate>::applies(TNode node)
 {
-  return (node.getKind() == kind::BITVECTOR_SLE); 
+  return (node.getKind() == Kind::BITVECTOR_SLE);
 }
 
 template <>
@@ -131,14 +131,14 @@ inline Node RewriteRule<SleEliminate>::apply(TNode node)
   NodeManager *nm = NodeManager::currentNM();
   TNode a = node[0];
   TNode b = node[1];
-  Node b_slt_a = nm->mkNode(kind::BITVECTOR_SLT, b, a);
-  return nm->mkNode(kind::NOT, b_slt_a);
+  Node b_slt_a = nm->mkNode(Kind::BITVECTOR_SLT, b, a);
+  return nm->mkNode(Kind::NOT, b_slt_a);
 }
 
 template <>
 inline bool RewriteRule<UleEliminate>::applies(TNode node)
 {
-  return (node.getKind() == kind::BITVECTOR_ULE); 
+  return (node.getKind() == Kind::BITVECTOR_ULE);
 }
 
 template <>
@@ -149,14 +149,14 @@ inline Node RewriteRule<UleEliminate>::apply(TNode node)
   NodeManager *nm = NodeManager::currentNM();
   TNode a = node[0];
   TNode b = node[1];
-  Node b_ult_a = nm->mkNode(kind::BITVECTOR_ULT, b, a);
-  return nm->mkNode(kind::NOT, b_ult_a);
+  Node b_ult_a = nm->mkNode(Kind::BITVECTOR_ULT, b, a);
+  return nm->mkNode(Kind::NOT, b_ult_a);
 }
 
 template <>
 inline bool RewriteRule<CompEliminate>::applies(TNode node)
 {
-  return (node.getKind() == kind::BITVECTOR_COMP); 
+  return (node.getKind() == Kind::BITVECTOR_COMP);
 }
 
 template <>
@@ -165,17 +165,17 @@ inline Node RewriteRule<CompEliminate>::apply(TNode node)
   Trace("bv-rewrite") << "RewriteRule<CompEliminate>(" << node << ")"
                       << std::endl;
   NodeManager *nm = NodeManager::currentNM();
-  Node comp = nm->mkNode(kind::EQUAL, node[0], node[1]);
+  Node comp = nm->mkNode(Kind::EQUAL, node[0], node[1]);
   Node one = utils::mkConst(1, 1);
   Node zero = utils::mkConst(1, 0);
 
-  return nm->mkNode(kind::ITE, comp, one, zero);
+  return nm->mkNode(Kind::ITE, comp, one, zero);
 }
 
 template <>
 inline bool RewriteRule<SubEliminate>::applies(TNode node)
 {
-  return (node.getKind() == kind::BITVECTOR_SUB); 
+  return (node.getKind() == Kind::BITVECTOR_SUB);
 }
 
 template <>
@@ -184,16 +184,16 @@ inline Node RewriteRule<SubEliminate>::apply(TNode node)
   Trace("bv-rewrite") << "RewriteRule<SubEliminate>(" << node << ")"
                       << std::endl;
   NodeManager *nm = NodeManager::currentNM();
-  Node negb = nm->mkNode(kind::BITVECTOR_NEG, node[1]);
+  Node negb = nm->mkNode(Kind::BITVECTOR_NEG, node[1]);
   Node a = node[0];
 
-  return nm->mkNode(kind::BITVECTOR_ADD, a, negb);
+  return nm->mkNode(Kind::BITVECTOR_ADD, a, negb);
 }
 
 template <>
 inline bool RewriteRule<RepeatEliminate>::applies(TNode node)
 {
-  return (node.getKind() == kind::BITVECTOR_REPEAT);
+  return (node.getKind() == Kind::BITVECTOR_REPEAT);
 }
 
 template <>
@@ -207,7 +207,7 @@ inline Node RewriteRule<RepeatEliminate>::apply(TNode node)
   if(amount == 1) {
     return a; 
   }
-  NodeBuilder result(kind::BITVECTOR_CONCAT);
+  NodeBuilder result(Kind::BITVECTOR_CONCAT);
   for(unsigned i = 0; i < amount; ++i) {
     result << node[0]; 
   }
@@ -218,7 +218,7 @@ inline Node RewriteRule<RepeatEliminate>::apply(TNode node)
 template <>
 inline bool RewriteRule<RotateLeftEliminate>::applies(TNode node)
 {
-  return (node.getKind() == kind::BITVECTOR_ROTATE_LEFT);
+  return (node.getKind() == Kind::BITVECTOR_ROTATE_LEFT);
 }
 
 template <>
@@ -243,7 +243,7 @@ inline Node RewriteRule<RotateLeftEliminate>::apply(TNode node)
 template <>
 inline bool RewriteRule<RotateRightEliminate>::applies(TNode node)
 {
-  return (node.getKind() == kind::BITVECTOR_ROTATE_RIGHT);
+  return (node.getKind() == Kind::BITVECTOR_ROTATE_RIGHT);
 }
 
 template <>
@@ -268,8 +268,7 @@ inline Node RewriteRule<RotateRightEliminate>::apply(TNode node)
 template <>
 inline bool RewriteRule<NandEliminate>::applies(TNode node)
 {
-  return (node.getKind() == kind::BITVECTOR_NAND &&
-          node.getNumChildren() == 2);
+  return (node.getKind() == Kind::BITVECTOR_NAND && node.getNumChildren() == 2);
 }
 
 template <>
@@ -280,15 +279,15 @@ inline Node RewriteRule<NandEliminate>::apply(TNode node)
   NodeManager *nm = NodeManager::currentNM();
   TNode a = node[0];
   TNode b = node[1];
-  Node andNode = nm->mkNode(kind::BITVECTOR_AND, a, b);
-  Node result = nm->mkNode(kind::BITVECTOR_NOT, andNode);
+  Node andNode = nm->mkNode(Kind::BITVECTOR_AND, a, b);
+  Node result = nm->mkNode(Kind::BITVECTOR_NOT, andNode);
   return result;
 }
 
 template <>
 inline bool RewriteRule<NorEliminate>::applies(TNode node)
 {
-  return (node.getKind() == kind::BITVECTOR_NOR && node.getNumChildren() == 2);
+  return (node.getKind() == Kind::BITVECTOR_NOR && node.getNumChildren() == 2);
 }
 
 template <>
@@ -299,16 +298,15 @@ inline Node RewriteRule<NorEliminate>::apply(TNode node)
   NodeManager *nm = NodeManager::currentNM();
   TNode a = node[0];
   TNode b = node[1];
-  Node orNode = nm->mkNode(kind::BITVECTOR_OR, a, b);
-  Node result = nm->mkNode(kind::BITVECTOR_NOT, orNode);
+  Node orNode = nm->mkNode(Kind::BITVECTOR_OR, a, b);
+  Node result = nm->mkNode(Kind::BITVECTOR_NOT, orNode);
   return result;
 }
 
 template <>
 inline bool RewriteRule<XnorEliminate>::applies(TNode node)
 {
-  return (node.getKind() == kind::BITVECTOR_XNOR &&
-          node.getNumChildren() == 2);
+  return (node.getKind() == Kind::BITVECTOR_XNOR && node.getNumChildren() == 2);
 }
 
 template <>
@@ -319,15 +317,15 @@ inline Node RewriteRule<XnorEliminate>::apply(TNode node)
   NodeManager *nm = NodeManager::currentNM();
   TNode a = node[0];
   TNode b = node[1];
-  Node xorNode = nm->mkNode(kind::BITVECTOR_XOR, a, b);
-  Node result = nm->mkNode(kind::BITVECTOR_NOT, xorNode);
+  Node xorNode = nm->mkNode(Kind::BITVECTOR_XOR, a, b);
+  Node result = nm->mkNode(Kind::BITVECTOR_NOT, xorNode);
   return result;
 }
 
 template <>
 inline bool RewriteRule<SdivEliminate>::applies(TNode node)
 {
-  return (node.getKind() == kind::BITVECTOR_SDIV);
+  return (node.getKind() == Kind::BITVECTOR_SDIV);
 }
 
 template <>
@@ -343,19 +341,19 @@ inline Node RewriteRule<SdivEliminate>::apply(TNode node)
 
   Node one = utils::mkConst(1, 1);
   Node a_lt_0 =
-      nm->mkNode(kind::EQUAL, utils::mkExtract(a, size - 1, size - 1), one);
+      nm->mkNode(Kind::EQUAL, utils::mkExtract(a, size - 1, size - 1), one);
   Node b_lt_0 =
-      nm->mkNode(kind::EQUAL, utils::mkExtract(b, size - 1, size - 1), one);
+      nm->mkNode(Kind::EQUAL, utils::mkExtract(b, size - 1, size - 1), one);
   Node abs_a =
-      nm->mkNode(kind::ITE, a_lt_0, nm->mkNode(kind::BITVECTOR_NEG, a), a);
+      nm->mkNode(Kind::ITE, a_lt_0, nm->mkNode(Kind::BITVECTOR_NEG, a), a);
   Node abs_b =
-      nm->mkNode(kind::ITE, b_lt_0, nm->mkNode(kind::BITVECTOR_NEG, b), b);
+      nm->mkNode(Kind::ITE, b_lt_0, nm->mkNode(Kind::BITVECTOR_NEG, b), b);
 
-  Node a_udiv_b = nm->mkNode(kind::BITVECTOR_UDIV, abs_a, abs_b);
-  Node neg_result = nm->mkNode(kind::BITVECTOR_NEG, a_udiv_b);
+  Node a_udiv_b = nm->mkNode(Kind::BITVECTOR_UDIV, abs_a, abs_b);
+  Node neg_result = nm->mkNode(Kind::BITVECTOR_NEG, a_udiv_b);
 
-  Node condition = nm->mkNode(kind::XOR, a_lt_0, b_lt_0);
-  Node result = nm->mkNode(kind::ITE, condition, neg_result, a_udiv_b);
+  Node condition = nm->mkNode(Kind::XOR, a_lt_0, b_lt_0);
+  Node result = nm->mkNode(Kind::ITE, condition, neg_result, a_udiv_b);
 
   return result;
 }
@@ -369,7 +367,7 @@ inline Node RewriteRule<SdivEliminate>::apply(TNode node)
 template <>
 inline bool RewriteRule<SdivEliminateFewerBitwiseOps>::applies(TNode node)
 {
-  return (node.getKind() == kind::BITVECTOR_SDIV);
+  return (node.getKind() == Kind::BITVECTOR_SDIV);
 }
 
 template <>
@@ -382,17 +380,18 @@ inline Node RewriteRule<SdivEliminateFewerBitwiseOps>::apply(TNode node)
   TNode a = node[0];
   TNode b = node[1];
   unsigned size = utils::getSize(a);
-  Node a_lt_0 = nm->mkNode(kind::BITVECTOR_UGE, a, utils::mkMinSigned(size));
-  Node b_lt_0 = nm->mkNode(kind::BITVECTOR_UGE, b, utils::mkMinSigned(size));
+  Node a_lt_0 = nm->mkNode(Kind::BITVECTOR_UGE, a, utils::mkMinSigned(size));
+  Node b_lt_0 = nm->mkNode(Kind::BITVECTOR_UGE, b, utils::mkMinSigned(size));
   Node abs_a =
-      nm->mkNode(kind::ITE, a_lt_0, nm->mkNode(kind::BITVECTOR_NEG, a), a);
+      nm->mkNode(Kind::ITE, a_lt_0, nm->mkNode(Kind::BITVECTOR_NEG, a), a);
   Node abs_b =
-      nm->mkNode(kind::ITE, b_lt_0, nm->mkNode(kind::BITVECTOR_NEG, b), b);
+      nm->mkNode(Kind::ITE, b_lt_0, nm->mkNode(Kind::BITVECTOR_NEG, b), b);
 
-  Node a_udiv_b = nm->mkNode(kind::BITVECTOR_UDIV, abs_a, abs_b);
-  Node neg_result = nm->mkNode(kind::BITVECTOR_NEG, a_udiv_b);
+  Node a_udiv_b = nm->mkNode(Kind::BITVECTOR_UDIV, abs_a, abs_b);
+  Node neg_result = nm->mkNode(Kind::BITVECTOR_NEG, a_udiv_b);
 
-  Node result = nm->mkNode(kind::ITE, a_lt_0.xorNode(b_lt_0), neg_result, a_udiv_b);
+  Node result =
+      nm->mkNode(Kind::ITE, a_lt_0.xorNode(b_lt_0), neg_result, a_udiv_b);
 
   return result;
 }
@@ -400,7 +399,7 @@ inline Node RewriteRule<SdivEliminateFewerBitwiseOps>::apply(TNode node)
 template <>
 inline bool RewriteRule<SremEliminate>::applies(TNode node)
 {
-  return (node.getKind() == kind::BITVECTOR_SREM);
+  return (node.getKind() == Kind::BITVECTOR_SREM);
 }
 
 template <>
@@ -415,18 +414,18 @@ inline Node RewriteRule<SremEliminate>::apply(TNode node)
 
   Node one = utils::mkConst(1, 1);
   Node a_lt_0 =
-      nm->mkNode(kind::EQUAL, utils::mkExtract(a, size - 1, size - 1), one);
+      nm->mkNode(Kind::EQUAL, utils::mkExtract(a, size - 1, size - 1), one);
   Node b_lt_0 =
-      nm->mkNode(kind::EQUAL, utils::mkExtract(b, size - 1, size - 1), one);
+      nm->mkNode(Kind::EQUAL, utils::mkExtract(b, size - 1, size - 1), one);
   Node abs_a =
-      nm->mkNode(kind::ITE, a_lt_0, nm->mkNode(kind::BITVECTOR_NEG, a), a);
+      nm->mkNode(Kind::ITE, a_lt_0, nm->mkNode(Kind::BITVECTOR_NEG, a), a);
   Node abs_b =
-      nm->mkNode(kind::ITE, b_lt_0, nm->mkNode(kind::BITVECTOR_NEG, b), b);
+      nm->mkNode(Kind::ITE, b_lt_0, nm->mkNode(Kind::BITVECTOR_NEG, b), b);
 
-  Node a_urem_b = nm->mkNode(kind::BITVECTOR_UREM, abs_a, abs_b);
-  Node neg_result = nm->mkNode(kind::BITVECTOR_NEG, a_urem_b);
+  Node a_urem_b = nm->mkNode(Kind::BITVECTOR_UREM, abs_a, abs_b);
+  Node neg_result = nm->mkNode(Kind::BITVECTOR_NEG, a_urem_b);
 
-  Node result = nm->mkNode(kind::ITE, a_lt_0, neg_result, a_urem_b);
+  Node result = nm->mkNode(Kind::ITE, a_lt_0, neg_result, a_urem_b);
 
   return result;
 }
@@ -440,7 +439,7 @@ inline Node RewriteRule<SremEliminate>::apply(TNode node)
 template <>
 inline bool RewriteRule<SremEliminateFewerBitwiseOps>::applies(TNode node)
 {
-  return (node.getKind() == kind::BITVECTOR_SREM);
+  return (node.getKind() == Kind::BITVECTOR_SREM);
 }
 
 template <>
@@ -452,16 +451,16 @@ inline Node RewriteRule<SremEliminateFewerBitwiseOps>::apply(TNode node)
   TNode a = node[0];
   TNode b = node[1];
   unsigned size = utils::getSize(a);
-  Node a_lt_0 = nm->mkNode(kind::BITVECTOR_UGE, a, utils::mkMinSigned(size));
-  Node b_lt_0 = nm->mkNode(kind::BITVECTOR_UGE, b, utils::mkMinSigned(size));
+  Node a_lt_0 = nm->mkNode(Kind::BITVECTOR_UGE, a, utils::mkMinSigned(size));
+  Node b_lt_0 = nm->mkNode(Kind::BITVECTOR_UGE, b, utils::mkMinSigned(size));
   Node abs_a =
-      nm->mkNode(kind::ITE, a_lt_0, nm->mkNode(kind::BITVECTOR_NEG, a), a);
+      nm->mkNode(Kind::ITE, a_lt_0, nm->mkNode(Kind::BITVECTOR_NEG, a), a);
   Node abs_b =
-      nm->mkNode(kind::ITE, b_lt_0, nm->mkNode(kind::BITVECTOR_NEG, b), b);
-  Node a_urem_b = nm->mkNode(kind::BITVECTOR_UREM, abs_a, abs_b);
-  Node neg_result = nm->mkNode(kind::BITVECTOR_NEG, a_urem_b);
+      nm->mkNode(Kind::ITE, b_lt_0, nm->mkNode(Kind::BITVECTOR_NEG, b), b);
+  Node a_urem_b = nm->mkNode(Kind::BITVECTOR_UREM, abs_a, abs_b);
+  Node neg_result = nm->mkNode(Kind::BITVECTOR_NEG, a_urem_b);
 
-  Node result = nm->mkNode(kind::ITE, a_lt_0, neg_result, a_urem_b);
+  Node result = nm->mkNode(Kind::ITE, a_lt_0, neg_result, a_urem_b);
 
   return result;
 }
@@ -469,7 +468,7 @@ inline Node RewriteRule<SremEliminateFewerBitwiseOps>::apply(TNode node)
 template <>
 inline bool RewriteRule<SmodEliminate>::applies(TNode node)
 {
-  return (node.getKind() == kind::BITVECTOR_SMOD);
+  return (node.getKind() == Kind::BITVECTOR_SMOD);
 }
 
 template <>
@@ -505,12 +504,12 @@ inline Node RewriteRule<SmodEliminate>::apply(TNode node)
   Node bit0 = utils::mkConst(1, 0);
 
   Node abs_s =
-      msb_s.eqNode(bit0).iteNode(s, nm->mkNode(kind::BITVECTOR_NEG, s));
+      msb_s.eqNode(bit0).iteNode(s, nm->mkNode(Kind::BITVECTOR_NEG, s));
   Node abs_t =
-      msb_t.eqNode(bit0).iteNode(t, nm->mkNode(kind::BITVECTOR_NEG, t));
+      msb_t.eqNode(bit0).iteNode(t, nm->mkNode(Kind::BITVECTOR_NEG, t));
 
-  Node u = nm->mkNode(kind::BITVECTOR_UREM, abs_s, abs_t);
-  Node neg_u = nm->mkNode(kind::BITVECTOR_NEG, u);
+  Node u = nm->mkNode(Kind::BITVECTOR_UREM, abs_s, abs_t);
+  Node neg_u = nm->mkNode(Kind::BITVECTOR_NEG, u);
 
   Node cond0 = u.eqNode(utils::mkConst(size, 0));
   Node cond1 = msb_s.eqNode(bit0).andNode(msb_t.eqNode(bit0));
@@ -522,8 +521,8 @@ inline Node RewriteRule<SmodEliminate>::apply(TNode node)
       cond1.iteNode(
           u,
           cond2.iteNode(
-              nm->mkNode(kind::BITVECTOR_ADD, neg_u, t),
-              cond3.iteNode(nm->mkNode(kind::BITVECTOR_ADD, u, t), neg_u))));
+              nm->mkNode(Kind::BITVECTOR_ADD, neg_u, t),
+              cond3.iteNode(nm->mkNode(Kind::BITVECTOR_ADD, u, t), neg_u))));
 
   return result;
 }
@@ -537,7 +536,7 @@ inline Node RewriteRule<SmodEliminate>::apply(TNode node)
 template <>
 inline bool RewriteRule<SmodEliminateFewerBitwiseOps>::applies(TNode node)
 {
-  return (node.getKind() == kind::BITVECTOR_SMOD);
+  return (node.getKind() == Kind::BITVECTOR_SMOD);
 }
 
 template <>
@@ -568,29 +567,29 @@ inline Node RewriteRule<SmodEliminateFewerBitwiseOps>::apply(TNode node)
    *               (bvneg u))))))))
    */
 
-  Node s_lt_0 = nm->mkNode(kind::BITVECTOR_UGE, s, utils::mkMinSigned(size));
-  Node t_lt_0 = nm->mkNode(kind::BITVECTOR_UGE, t, utils::mkMinSigned(size));
+  Node s_lt_0 = nm->mkNode(Kind::BITVECTOR_UGE, s, utils::mkMinSigned(size));
+  Node t_lt_0 = nm->mkNode(Kind::BITVECTOR_UGE, t, utils::mkMinSigned(size));
   Node abs_s =
-      nm->mkNode(kind::ITE, s_lt_0, nm->mkNode(kind::BITVECTOR_NEG, s), s);
+      nm->mkNode(Kind::ITE, s_lt_0, nm->mkNode(Kind::BITVECTOR_NEG, s), s);
   Node abs_t =
-      nm->mkNode(kind::ITE, t_lt_0, nm->mkNode(kind::BITVECTOR_NEG, t), t);
+      nm->mkNode(Kind::ITE, t_lt_0, nm->mkNode(Kind::BITVECTOR_NEG, t), t);
 
-  Node u = nm->mkNode(kind::BITVECTOR_UREM, abs_s, abs_t);
-  Node neg_u = nm->mkNode(kind::BITVECTOR_NEG, u);
+  Node u = nm->mkNode(Kind::BITVECTOR_UREM, abs_s, abs_t);
+  Node neg_u = nm->mkNode(Kind::BITVECTOR_NEG, u);
 
   Node cond0 = u.eqNode(utils::mkConst(size, 0));
   Node cond1 =
-      nm->mkNode(kind::NOT, s_lt_0).andNode(nm->mkNode(kind::NOT, t_lt_0));
-  Node cond2 = s_lt_0.andNode(nm->mkNode(kind::NOT, t_lt_0));
-  Node cond3 = nm->mkNode(kind::NOT, s_lt_0).andNode(t_lt_0);
+      nm->mkNode(Kind::NOT, s_lt_0).andNode(nm->mkNode(Kind::NOT, t_lt_0));
+  Node cond2 = s_lt_0.andNode(nm->mkNode(Kind::NOT, t_lt_0));
+  Node cond3 = nm->mkNode(Kind::NOT, s_lt_0).andNode(t_lt_0);
 
   Node result = cond0.iteNode(
       u,
       cond1.iteNode(
           u,
           cond2.iteNode(
-              nm->mkNode(kind::BITVECTOR_ADD, neg_u, t),
-              cond3.iteNode(nm->mkNode(kind::BITVECTOR_ADD, u, t), neg_u))));
+              nm->mkNode(Kind::BITVECTOR_ADD, neg_u, t),
+              cond3.iteNode(nm->mkNode(Kind::BITVECTOR_ADD, u, t), neg_u))));
 
   return result;
 }
@@ -598,7 +597,7 @@ inline Node RewriteRule<SmodEliminateFewerBitwiseOps>::apply(TNode node)
 template <>
 inline bool RewriteRule<ZeroExtendEliminate>::applies(TNode node)
 {
-  return (node.getKind() == kind::BITVECTOR_ZERO_EXTEND); 
+  return (node.getKind() == Kind::BITVECTOR_ZERO_EXTEND);
 }
 
 template <>
@@ -621,7 +620,7 @@ inline Node RewriteRule<ZeroExtendEliminate>::apply(TNode node)
 template <>
 inline bool RewriteRule<SignExtendEliminate>::applies(TNode node)
 {
-  return (node.getKind() == kind::BITVECTOR_SIGN_EXTEND); 
+  return (node.getKind() == Kind::BITVECTOR_SIGN_EXTEND);
 }
 
 template <>
@@ -644,7 +643,7 @@ inline Node RewriteRule<SignExtendEliminate>::apply(TNode node)
 template <>
 inline bool RewriteRule<RedorEliminate>::applies(TNode node)
 {
-  return (node.getKind() == kind::BITVECTOR_REDOR);
+  return (node.getKind() == Kind::BITVECTOR_REDOR);
 }
 
 template <>
@@ -656,14 +655,14 @@ inline Node RewriteRule<RedorEliminate>::apply(TNode node)
   unsigned size = utils::getSize(node[0]);
   NodeManager* nm = NodeManager::currentNM();
   return nm->mkNode(
-      kind::BITVECTOR_NOT,
-      nm->mkNode(kind::BITVECTOR_COMP, a, utils::mkConst(size, 0)));
+      Kind::BITVECTOR_NOT,
+      nm->mkNode(Kind::BITVECTOR_COMP, a, utils::mkConst(size, 0)));
 }
 
 template <>
 inline bool RewriteRule<RedandEliminate>::applies(TNode node)
 {
-  return (node.getKind() == kind::BITVECTOR_REDAND);
+  return (node.getKind() == Kind::BITVECTOR_REDAND);
 }
 
 template <>
@@ -674,14 +673,31 @@ inline Node RewriteRule<RedandEliminate>::apply(TNode node)
   TNode a = node[0];
   unsigned size = utils::getSize(node[0]);
   Node result = NodeManager::currentNM()->mkNode(
-      kind::BITVECTOR_COMP, a, utils::mkOnes(size));
+      Kind::BITVECTOR_COMP, a, utils::mkOnes(size));
   return result;
 }
 
+template <>
+inline bool RewriteRule<NegoEliminate>::applies(TNode node)
+{
+  return (node.getKind() == Kind::BITVECTOR_NEGO);
+}
+
+template <>
+inline Node RewriteRule<NegoEliminate>::apply(TNode node)
+{
+  Trace("bv-rewrite") << "RewriteRule<NegoEliminate>(" << node << ")"
+                      << std::endl;
+  return NodeManager::currentNM()->mkNode(
+      Kind::EQUAL,
+      node[0],
+      utils::mkMinSigned(node[0].getType().getBitVectorSize()));
+}
+
 template <>
 inline bool RewriteRule<UaddoEliminate>::applies(TNode node)
 {
-  return (node.getKind() == kind::BITVECTOR_UADDO);
+  return (node.getKind() == Kind::BITVECTOR_UADDO);
 }
 
 template <>
@@ -695,19 +711,19 @@ inline Node RewriteRule<UaddoEliminate>::apply(TNode node)
   Node bvZero = utils::mkZero(1);
   Node bvOne = utils::mkOne(1);
 
-  Node add = nm->mkNode(kind::BITVECTOR_ADD,
+  Node add = nm->mkNode(Kind::BITVECTOR_ADD,
                         utils::mkConcat(bvZero, node[0]),
                         utils::mkConcat(bvZero, node[1]));
 
   uint32_t size = add.getType().getBitVectorSize();
   return nm->mkNode(
-      kind::EQUAL, utils::mkExtract(add, size - 1, size - 1), bvOne);
+      Kind::EQUAL, utils::mkExtract(add, size - 1, size - 1), bvOne);
 }
 
 template <>
 inline bool RewriteRule<SaddoEliminate>::applies(TNode node)
 {
-  return (node.getKind() == kind::BITVECTOR_SADDO);
+  return (node.getKind() == Kind::BITVECTOR_SADDO);
 }
 
 template <>
@@ -728,28 +744,28 @@ inline Node RewriteRule<SaddoEliminate>::apply(TNode node)
       nm->mkConst<BitVectorExtract>(BitVectorExtract(size - 1, size - 1));
   Node sign0 = nm->mkNode(extOp, node[0]);
   Node sign1 = nm->mkNode(extOp, node[1]);
-  Node add = nm->mkNode(kind::BITVECTOR_ADD, node[0], node[1]);
+  Node add = nm->mkNode(Kind::BITVECTOR_ADD, node[0], node[1]);
   Node signa = nm->mkNode(extOp, add);
 
-  Node both_neg = nm->mkNode(kind::AND,
-                             nm->mkNode(kind::EQUAL, sign0, one),
-                             nm->mkNode(kind::EQUAL, sign1, one));
-  Node both_pos = nm->mkNode(kind::AND,
-                             nm->mkNode(kind::EQUAL, sign0, zero),
-                             nm->mkNode(kind::EQUAL, sign1, zero));
+  Node both_neg = nm->mkNode(Kind::AND,
+                             nm->mkNode(Kind::EQUAL, sign0, one),
+                             nm->mkNode(Kind::EQUAL, sign1, one));
+  Node both_pos = nm->mkNode(Kind::AND,
+                             nm->mkNode(Kind::EQUAL, sign0, zero),
+                             nm->mkNode(Kind::EQUAL, sign1, zero));
 
-  Node result_neg = nm->mkNode(kind::EQUAL, signa, one);
-  Node result_pos = nm->mkNode(kind::EQUAL, signa, zero);
+  Node result_neg = nm->mkNode(Kind::EQUAL, signa, one);
+  Node result_pos = nm->mkNode(Kind::EQUAL, signa, zero);
 
-  return nm->mkNode(kind::OR,
-                    nm->mkNode(kind::AND, both_neg, result_pos),
-                    nm->mkNode(kind::AND, both_pos, result_neg));
+  return nm->mkNode(Kind::OR,
+                    nm->mkNode(Kind::AND, both_neg, result_pos),
+                    nm->mkNode(Kind::AND, both_pos, result_neg));
 }
 
 template <>
 inline bool RewriteRule<UmuloEliminate>::applies(TNode node)
 {
-  return (node.getKind() == kind::BITVECTOR_UMULO);
+  return (node.getKind() == Kind::BITVECTOR_UMULO);
 }
 
 template <>
@@ -778,24 +794,24 @@ inline Node RewriteRule<UmuloEliminate>::apply(TNode node)
   for (size_t i = 1; i < size; ++i)
   {
     tmp.push_back(
-        nm->mkNode(kind::BITVECTOR_AND, utils::mkExtract(node[1], i, i), uppc));
-    uppc = nm->mkNode(kind::BITVECTOR_OR,
+        nm->mkNode(Kind::BITVECTOR_AND, utils::mkExtract(node[1], i, i), uppc));
+    uppc = nm->mkNode(Kind::BITVECTOR_OR,
                       utils::mkExtract(node[0], size - 1 - i, size - 1 - i),
                       uppc);
   }
   Node bvZero = utils::mkZero(1);
   Node zext_t1 = utils::mkConcat(bvZero, node[0]);
   Node zext_t2 = utils::mkConcat(bvZero, node[1]);
-  Node mul = nm->mkNode(kind::BITVECTOR_MULT, zext_t1, zext_t2);
+  Node mul = nm->mkNode(Kind::BITVECTOR_MULT, zext_t1, zext_t2);
   tmp.push_back(utils::mkExtract(mul, size, size));
   return nm->mkNode(
-      kind::EQUAL, nm->mkNode(kind::BITVECTOR_OR, tmp), utils::mkOne(1));
+      Kind::EQUAL, nm->mkNode(Kind::BITVECTOR_OR, tmp), utils::mkOne(1));
 }
 
 template <>
 inline bool RewriteRule<SmuloEliminate>::applies(TNode node)
 {
-  return (node.getKind() == kind::BITVECTOR_SMULO);
+  return (node.getKind() == Kind::BITVECTOR_SMULO);
 }
 
 template <>
@@ -816,18 +832,18 @@ inline Node RewriteRule<SmuloEliminate>::apply(TNode node)
   if (size == 1)
   {
     return nm->mkNode(
-        kind::EQUAL, nm->mkNode(kind::BITVECTOR_AND, node[0], node[1]), one);
+        Kind::EQUAL, nm->mkNode(Kind::BITVECTOR_AND, node[0], node[1]), one);
   }
 
   Node sextOp1 = nm->mkConst<BitVectorSignExtend>(BitVectorSignExtend(1));
-  Node mul = nm->mkNode(kind::BITVECTOR_MULT,
+  Node mul = nm->mkNode(Kind::BITVECTOR_MULT,
                         nm->mkNode(sextOp1, node[0]),
                         nm->mkNode(sextOp1, node[1]));
 
   if (size == 2)
   {
-    return nm->mkNode(kind::EQUAL,
-                      nm->mkNode(kind::BITVECTOR_XOR,
+    return nm->mkNode(Kind::EQUAL,
+                      nm->mkNode(Kind::BITVECTOR_XOR,
                                  utils::mkExtract(mul, size, size),
                                  utils::mkExtract(mul, size - 1, size - 1)),
                       one);
@@ -838,28 +854,28 @@ inline Node RewriteRule<SmuloEliminate>::apply(TNode node)
   Node sign0 = utils::mkExtract(node[0], size - 1, size - 1);
   Node sign1 = utils::mkExtract(node[1], size - 1, size - 1);
   Node xor0 =
-      nm->mkNode(kind::BITVECTOR_XOR, node[0], nm->mkNode(sextOpN, sign0));
+      nm->mkNode(Kind::BITVECTOR_XOR, node[0], nm->mkNode(sextOpN, sign0));
   Node xor1 =
-      nm->mkNode(kind::BITVECTOR_XOR, node[1], nm->mkNode(sextOpN, sign1));
+      nm->mkNode(Kind::BITVECTOR_XOR, node[1], nm->mkNode(sextOpN, sign1));
 
   Node ppc = utils::mkExtract(xor0, size - 2, size - 2);
-  Node res = nm->mkNode(kind::BITVECTOR_AND, utils::mkExtract(xor1, 1, 1), ppc);
+  Node res = nm->mkNode(Kind::BITVECTOR_AND, utils::mkExtract(xor1, 1, 1), ppc);
   for (uint32_t i = 1; i < size - 2; ++i)
   {
-    ppc = nm->mkNode(kind::BITVECTOR_OR,
+    ppc = nm->mkNode(Kind::BITVECTOR_OR,
                      ppc,
                      utils::mkExtract(xor0, size - 2 - i, size - 2 - i));
     res = nm->mkNode(
-        kind::BITVECTOR_OR,
+        Kind::BITVECTOR_OR,
         res,
         nm->mkNode(
-            kind::BITVECTOR_AND, utils::mkExtract(xor1, i + 1, i + 1), ppc));
+            Kind::BITVECTOR_AND, utils::mkExtract(xor1, i + 1, i + 1), ppc));
   }
   return nm->mkNode(
-      kind::EQUAL,
-      nm->mkNode(kind::BITVECTOR_OR,
+      Kind::EQUAL,
+      nm->mkNode(Kind::BITVECTOR_OR,
                  res,
-                 nm->mkNode(kind::BITVECTOR_XOR,
+                 nm->mkNode(Kind::BITVECTOR_XOR,
                             utils::mkExtract(mul, size, size),
                             utils::mkExtract(mul, size - 1, size - 1))),
       one);
@@ -868,7 +884,7 @@ inline Node RewriteRule<SmuloEliminate>::apply(TNode node)
 template <>
 inline bool RewriteRule<UsuboEliminate>::applies(TNode node)
 {
-  return (node.getKind() == kind::BITVECTOR_USUBO);
+  return (node.getKind() == Kind::BITVECTOR_USUBO);
 }
 
 template <>
@@ -881,20 +897,20 @@ inline Node RewriteRule<UsuboEliminate>::apply(TNode node)
   Node one = utils::mkOne(1);
 
   Node zextOp = nm->mkConst<BitVectorZeroExtend>(BitVectorZeroExtend(1));
-  Node sub = nm->mkNode(kind::BITVECTOR_SUB,
+  Node sub = nm->mkNode(Kind::BITVECTOR_SUB,
                         nm->mkNode(zextOp, node[0]),
                         nm->mkNode(zextOp, node[1]));
   uint32_t size = sub.getType().getBitVectorSize();
 
   Node extOp =
       nm->mkConst<BitVectorExtract>(BitVectorExtract(size - 1, size - 1));
-  return nm->mkNode(kind::EQUAL, nm->mkNode(extOp, sub), one);
+  return nm->mkNode(Kind::EQUAL, nm->mkNode(extOp, sub), one);
 }
 
 template <>
 inline bool RewriteRule<SsuboEliminate>::applies(TNode node)
 {
-  return (node.getKind() == kind::BITVECTOR_SSUBO);
+  return (node.getKind() == Kind::BITVECTOR_SSUBO);
 }
 
 template <>
@@ -917,28 +933,28 @@ inline Node RewriteRule<SsuboEliminate>::apply(TNode node)
 
   Node sign0 = nm->mkNode(extOp, node[0]);
   Node sign1 = nm->mkNode(extOp, node[1]);
-  Node sub = nm->mkNode(kind::BITVECTOR_SUB, node[0], node[1]);
+  Node sub = nm->mkNode(Kind::BITVECTOR_SUB, node[0], node[1]);
   Node signs = nm->mkNode(extOp, sub);
 
-  Node neg_pos = nm->mkNode(kind::AND,
-                            nm->mkNode(kind::EQUAL, sign0, one),
-                            nm->mkNode(kind::EQUAL, sign1, zero));
-  Node pos_neg = nm->mkNode(kind::AND,
-                            nm->mkNode(kind::EQUAL, sign0, zero),
-                            nm->mkNode(kind::EQUAL, sign1, one));
+  Node neg_pos = nm->mkNode(Kind::AND,
+                            nm->mkNode(Kind::EQUAL, sign0, one),
+                            nm->mkNode(Kind::EQUAL, sign1, zero));
+  Node pos_neg = nm->mkNode(Kind::AND,
+                            nm->mkNode(Kind::EQUAL, sign0, zero),
+                            nm->mkNode(Kind::EQUAL, sign1, one));
 
-  Node result_neg = nm->mkNode(kind::EQUAL, signs, one);
-  Node result_pos = nm->mkNode(kind::EQUAL, signs, zero);
+  Node result_neg = nm->mkNode(Kind::EQUAL, signs, one);
+  Node result_pos = nm->mkNode(Kind::EQUAL, signs, zero);
 
-  return nm->mkNode(kind::OR,
-                    nm->mkNode(kind::AND, neg_pos, result_pos),
-                    nm->mkNode(kind::AND, pos_neg, result_neg));
+  return nm->mkNode(Kind::OR,
+                    nm->mkNode(Kind::AND, neg_pos, result_pos),
+                    nm->mkNode(Kind::AND, pos_neg, result_neg));
 }
 
 template <>
 inline bool RewriteRule<SdivoEliminate>::applies(TNode node)
 {
-  return (node.getKind() == kind::BITVECTOR_SDIVO);
+  return (node.getKind() == Kind::BITVECTOR_SDIVO);
 }
 
 template <>
@@ -949,9 +965,9 @@ inline Node RewriteRule<SdivoEliminate>::apply(TNode node)
   // Overflow if node[0] = min_signed and node[1] = -1
   NodeManager* nm = NodeManager::currentNM();
   uint64_t size = node[0].getType().getBitVectorSize();
-  return nm->mkNode(kind::AND,
-                    nm->mkNode(kind::EQUAL, node[0], utils::mkMinSigned(size)),
-                    nm->mkNode(kind::EQUAL, node[1], utils::mkOnes(size)));
+  return nm->mkNode(Kind::AND,
+                    nm->mkNode(Kind::EQUAL, node[0], utils::mkMinSigned(size)),
+                    nm->mkNode(Kind::EQUAL, node[1], utils::mkOnes(size)));
 }
 
 }  // namespace bv
