@@ -329,11 +329,11 @@ EvalResult Evaluator::evalInternal(
       {
         // APPLY_UF is a special case where we look up the operator and apply
         // beta reduction if possible
-        case kind::APPLY_UF:
+        case Kind::APPLY_UF:
         {
           Trace("evaluator") << "Evaluate " << currNode << std::endl;
           TNode op = currNode.getOperator();
-          if (op.getKind() == kind::FUNCTION_ARRAY_CONST)
+          if (op.getKind() == Kind::FUNCTION_ARRAY_CONST)
           {
             // If we have a function constant as the operator, it was not
             // processed. We require converting to a lambda now.
@@ -346,7 +346,7 @@ EvalResult Evaluator::evalInternal(
             op = evalAsNode[op];
           }
           Trace("evaluator") << "Operator evaluated to " << op << std::endl;
-          if (op.getKind() != kind::LAMBDA)
+          if (op.getKind() != Kind::LAMBDA)
           {
             // this node is not evaluatable due to operator, must add to
             // evalAsNode
@@ -393,17 +393,17 @@ EvalResult Evaluator::evalInternal(
           }
         }
         break;
-        case kind::CONST_BOOLEAN:
+        case Kind::CONST_BOOLEAN:
           results[currNode] = EvalResult(currNodeVal.getConst<bool>());
           break;
 
-        case kind::NOT:
+        case Kind::NOT:
         {
           results[currNode] = EvalResult(!(results[currNode[0]].d_bool));
           break;
         }
 
-        case kind::AND:
+        case Kind::AND:
         {
           bool res = results[currNode[0]].d_bool;
           for (size_t i = 1, end = currNode.getNumChildren(); i < end; i++)
@@ -414,7 +414,7 @@ EvalResult Evaluator::evalInternal(
           break;
         }
 
-        case kind::OR:
+        case Kind::OR:
         {
           bool res = results[currNode[0]].d_bool;
           for (size_t i = 1, end = currNode.getNumChildren(); i < end; i++)
@@ -424,7 +424,7 @@ EvalResult Evaluator::evalInternal(
           results[currNode] = EvalResult(res);
           break;
         }
-        case kind::XOR:
+        case Kind::XOR:
         {
           bool res = results[currNode[0]].d_bool;
           for (size_t i = 1, end = currNode.getNumChildren(); i < end; i++)
@@ -435,21 +435,21 @@ EvalResult Evaluator::evalInternal(
           break;
         }
 
-        case kind::CONST_RATIONAL:
-        case kind::CONST_INTEGER:
+        case Kind::CONST_RATIONAL:
+        case Kind::CONST_INTEGER:
         {
           const Rational& r = currNodeVal.getConst<Rational>();
           results[currNode] = EvalResult(r);
           break;
         }
-        case kind::UNINTERPRETED_SORT_VALUE:
+        case Kind::UNINTERPRETED_SORT_VALUE:
         {
           const UninterpretedSortValue& av =
               currNodeVal.getConst<UninterpretedSortValue>();
           results[currNode] = EvalResult(av);
           break;
         }
-        case kind::ADD:
+        case Kind::ADD:
         {
           Rational res = results[currNode[0]].d_rat;
           for (size_t i = 1, end = currNode.getNumChildren(); i < end; i++)
@@ -460,7 +460,7 @@ EvalResult Evaluator::evalInternal(
           break;
         }
 
-        case kind::SUB:
+        case Kind::SUB:
         {
           const Rational& x = results[currNode[0]].d_rat;
           const Rational& y = results[currNode[1]].d_rat;
@@ -468,14 +468,14 @@ EvalResult Evaluator::evalInternal(
           break;
         }
 
-        case kind::NEG:
+        case Kind::NEG:
         {
           const Rational& x = results[currNode[0]].d_rat;
           results[currNode] = EvalResult(-x);
           break;
         }
-        case kind::MULT:
-        case kind::NONLINEAR_MULT:
+        case Kind::MULT:
+        case Kind::NONLINEAR_MULT:
         {
           Rational res = results[currNode[0]].d_rat;
           for (size_t i = 1, end = currNode.getNumChildren(); i < end; i++)
@@ -485,25 +485,25 @@ EvalResult Evaluator::evalInternal(
           results[currNode] = EvalResult(res);
           break;
         }
-        case kind::DIVISION:
-        case kind::DIVISION_TOTAL:
-        case kind::INTS_DIVISION:
-        case kind::INTS_DIVISION_TOTAL:
-        case kind::INTS_MODULUS:
-        case kind::INTS_MODULUS_TOTAL:
+        case Kind::DIVISION:
+        case Kind::DIVISION_TOTAL:
+        case Kind::INTS_DIVISION:
+        case Kind::INTS_DIVISION_TOTAL:
+        case Kind::INTS_MODULUS:
+        case Kind::INTS_MODULUS_TOTAL:
         {
           Rational res = results[currNode[0]].d_rat;
           bool divbyzero = false;
           Kind k = currNodeVal.getKind();
-          bool isReal = (k == kind::DIVISION || k == kind::DIVISION_TOTAL);
+          bool isReal = (k == Kind::DIVISION || k == Kind::DIVISION_TOTAL);
           bool isMod =
-              (k == kind::INTS_MODULUS || k == kind::INTS_MODULUS_TOTAL);
+              (k == Kind::INTS_MODULUS || k == Kind::INTS_MODULUS_TOTAL);
           for (size_t i = 1, end = currNode.getNumChildren(); i < end; i++)
           {
             if (results[currNode[i]].d_rat.isZero())
             {
-              if (k == kind::DIVISION_TOTAL || k == kind::INTS_DIVISION_TOTAL
-                  || k == kind::INTS_MODULUS_TOTAL)
+              if (k == Kind::DIVISION_TOTAL || k == Kind::INTS_DIVISION_TOTAL
+                  || k == Kind::INTS_MODULUS_TOTAL)
               {
                 res = Rational(0);
                 continue;
@@ -540,61 +540,61 @@ EvalResult Evaluator::evalInternal(
           }
           break;
         }
-        case kind::GEQ:
+        case Kind::GEQ:
         {
           const Rational& x = results[currNode[0]].d_rat;
           const Rational& y = results[currNode[1]].d_rat;
           results[currNode] = EvalResult(x >= y);
           break;
         }
-        case kind::LEQ:
+        case Kind::LEQ:
         {
           const Rational& x = results[currNode[0]].d_rat;
           const Rational& y = results[currNode[1]].d_rat;
           results[currNode] = EvalResult(x <= y);
           break;
         }
-        case kind::GT:
+        case Kind::GT:
         {
           const Rational& x = results[currNode[0]].d_rat;
           const Rational& y = results[currNode[1]].d_rat;
           results[currNode] = EvalResult(x > y);
           break;
         }
-        case kind::LT:
+        case Kind::LT:
         {
           const Rational& x = results[currNode[0]].d_rat;
           const Rational& y = results[currNode[1]].d_rat;
           results[currNode] = EvalResult(x < y);
           break;
         }
-        case kind::ABS:
+        case Kind::ABS:
         {
           const Rational& x = results[currNode[0]].d_rat;
           results[currNode] = EvalResult(x.abs());
           break;
         }
-        case kind::TO_REAL:
+        case Kind::TO_REAL:
         {
           // casting to real is a no-op
           const Rational& x = results[currNode[0]].d_rat;
           results[currNode] = EvalResult(x);
           break;
         }
-        case kind::TO_INTEGER:
+        case Kind::TO_INTEGER:
         {
           // casting to int takes the floor
           const Rational& x = results[currNode[0]].d_rat.floor();
           results[currNode] = EvalResult(x);
           break;
         }
-        case kind::IS_INTEGER:
+        case Kind::IS_INTEGER:
         {
           const Rational& x = results[currNode[0]].d_rat;
           results[currNode] = EvalResult(x.isIntegral());
           break;
         }
-        case kind::POW2:
+        case Kind::POW2:
         {
           const Rational& x = results[currNode[0]].d_rat;
           bool valid = false;
@@ -614,11 +614,11 @@ EvalResult Evaluator::evalInternal(
           }
           break;
         }
-        case kind::CONST_STRING:
+        case Kind::CONST_STRING:
           results[currNode] = EvalResult(currNodeVal.getConst<String>());
           break;
 
-        case kind::STRING_CONCAT:
+        case Kind::STRING_CONCAT:
         {
           String res = results[currNode[0]].d_str;
           for (size_t i = 1, end = currNode.getNumChildren(); i < end; i++)
@@ -629,14 +629,14 @@ EvalResult Evaluator::evalInternal(
           break;
         }
 
-        case kind::STRING_LENGTH:
+        case Kind::STRING_LENGTH:
         {
           const String& s = results[currNode[0]].d_str;
           results[currNode] = EvalResult(Rational(s.size()));
           break;
         }
 
-        case kind::STRING_SUBSTR:
+        case Kind::STRING_SUBSTR:
         {
           const String& s = results[currNode[0]].d_str;
           Integer s_len(s.size());
@@ -659,7 +659,7 @@ EvalResult Evaluator::evalInternal(
           }
           break;
         }
-        case kind::SEQ_NTH:
+        case Kind::SEQ_NTH:
         {
           // only strings evaluate
           Assert (currNode[0].getType().isString());
@@ -677,7 +677,7 @@ EvalResult Evaluator::evalInternal(
           break;
         }
 
-        case kind::STRING_UPDATE:
+        case Kind::STRING_UPDATE:
         {
           const String& s = results[currNode[0]].d_str;
           Integer s_len(s.size());
@@ -694,7 +694,7 @@ EvalResult Evaluator::evalInternal(
           }
           break;
         }
-        case kind::STRING_CHARAT:
+        case Kind::STRING_CHARAT:
         {
           const String& s = results[currNode[0]].d_str;
           Integer s_len(s.size());
@@ -710,7 +710,7 @@ EvalResult Evaluator::evalInternal(
           break;
         }
 
-        case kind::STRING_CONTAINS:
+        case Kind::STRING_CONTAINS:
         {
           const String& s = results[currNode[0]].d_str;
           const String& t = results[currNode[1]].d_str;
@@ -718,7 +718,7 @@ EvalResult Evaluator::evalInternal(
           break;
         }
 
-        case kind::STRING_INDEXOF:
+        case Kind::STRING_INDEXOF:
         {
           const String& s = results[currNode[0]].d_str;
           Integer s_len(s.size());
@@ -744,7 +744,7 @@ EvalResult Evaluator::evalInternal(
           break;
         }
 
-        case kind::STRING_REPLACE:
+        case Kind::STRING_REPLACE:
         {
           const String& s = results[currNode[0]].d_str;
           const String& x = results[currNode[1]].d_str;
@@ -753,7 +753,7 @@ EvalResult Evaluator::evalInternal(
           break;
         }
 
-        case kind::STRING_PREFIX:
+        case Kind::STRING_PREFIX:
         {
           const String& t = results[currNode[0]].d_str;
           const String& s = results[currNode[1]].d_str;
@@ -768,7 +768,7 @@ EvalResult Evaluator::evalInternal(
           break;
         }
 
-        case kind::STRING_SUFFIX:
+        case Kind::STRING_SUFFIX:
         {
           const String& t = results[currNode[0]].d_str;
           const String& s = results[currNode[1]].d_str;
@@ -783,7 +783,7 @@ EvalResult Evaluator::evalInternal(
           break;
         }
 
-        case kind::STRING_ITOS:
+        case Kind::STRING_ITOS:
         {
           Integer i = results[currNode[0]].d_rat.getNumerator();
           if (i.strictlyNegative())
@@ -797,7 +797,7 @@ EvalResult Evaluator::evalInternal(
           break;
         }
 
-        case kind::STRING_STOI:
+        case Kind::STRING_STOI:
         {
           const String& s = results[currNode[0]].d_str;
           if (s.isNumber())
@@ -811,7 +811,7 @@ EvalResult Evaluator::evalInternal(
           break;
         }
 
-        case kind::STRING_FROM_CODE:
+        case Kind::STRING_FROM_CODE:
         {
           Integer i = results[currNode[0]].d_rat.getNumerator();
           if (i >= 0 && i < d_alphaCard)
@@ -826,7 +826,7 @@ EvalResult Evaluator::evalInternal(
           break;
         }
 
-        case kind::STRING_TO_CODE:
+        case Kind::STRING_TO_CODE:
         {
           const String& s = results[currNode[0]].d_str;
           if (s.size() == 1)
@@ -840,19 +840,19 @@ EvalResult Evaluator::evalInternal(
           break;
         }
 
-        case kind::CONST_BITVECTOR:
+        case Kind::CONST_BITVECTOR:
           results[currNode] = EvalResult(currNodeVal.getConst<BitVector>());
           break;
 
-        case kind::BITVECTOR_NOT:
+        case Kind::BITVECTOR_NOT:
           results[currNode] = EvalResult(~results[currNode[0]].d_bv);
           break;
 
-        case kind::BITVECTOR_NEG:
+        case Kind::BITVECTOR_NEG:
           results[currNode] = EvalResult(-results[currNode[0]].d_bv);
           break;
 
-        case kind::BITVECTOR_EXTRACT:
+        case Kind::BITVECTOR_EXTRACT:
         {
           unsigned lo = bv::utils::getExtractLow(currNodeVal);
           unsigned hi = bv::utils::getExtractHigh(currNodeVal);
@@ -861,7 +861,7 @@ EvalResult Evaluator::evalInternal(
           break;
         }
 
-        case kind::BITVECTOR_CONCAT:
+        case Kind::BITVECTOR_CONCAT:
         {
           BitVector res = results[currNode[0]].d_bv;
           for (size_t i = 1, end = currNode.getNumChildren(); i < end; i++)
@@ -872,7 +872,7 @@ EvalResult Evaluator::evalInternal(
           break;
         }
 
-        case kind::BITVECTOR_ADD:
+        case Kind::BITVECTOR_ADD:
         {
           BitVector res = results[currNode[0]].d_bv;
           for (size_t i = 1, end = currNode.getNumChildren(); i < end; i++)
@@ -883,7 +883,7 @@ EvalResult Evaluator::evalInternal(
           break;
         }
 
-        case kind::BITVECTOR_MULT:
+        case Kind::BITVECTOR_MULT:
         {
           BitVector res = results[currNode[0]].d_bv;
           for (size_t i = 1, end = currNode.getNumChildren(); i < end; i++)
@@ -893,7 +893,7 @@ EvalResult Evaluator::evalInternal(
           results[currNode] = EvalResult(res);
           break;
         }
-        case kind::BITVECTOR_AND:
+        case Kind::BITVECTOR_AND:
         {
           BitVector res = results[currNode[0]].d_bv;
           for (size_t i = 1, end = currNode.getNumChildren(); i < end; i++)
@@ -904,7 +904,7 @@ EvalResult Evaluator::evalInternal(
           break;
         }
 
-        case kind::BITVECTOR_OR:
+        case Kind::BITVECTOR_OR:
         {
           BitVector res = results[currNode[0]].d_bv;
           for (size_t i = 1, end = currNode.getNumChildren(); i < end; i++)
@@ -915,7 +915,7 @@ EvalResult Evaluator::evalInternal(
           break;
         }
 
-        case kind::BITVECTOR_XOR:
+        case Kind::BITVECTOR_XOR:
         {
           BitVector res = results[currNode[0]].d_bv;
           for (size_t i = 1, end = currNode.getNumChildren(); i < end; i++)
@@ -925,91 +925,91 @@ EvalResult Evaluator::evalInternal(
           results[currNode] = EvalResult(res);
           break;
         }
-        case kind::BITVECTOR_UDIV:
+        case Kind::BITVECTOR_UDIV:
         {
           BitVector res = results[currNode[0]].d_bv;
           res = res.unsignedDivTotal(results[currNode[1]].d_bv);
           results[currNode] = EvalResult(res);
           break;
         }
-        case kind::BITVECTOR_UREM:
+        case Kind::BITVECTOR_UREM:
         {
           BitVector res = results[currNode[0]].d_bv;
           res = res.unsignedRemTotal(results[currNode[1]].d_bv);
           results[currNode] = EvalResult(res);
           break;
         }
-        case kind::BITVECTOR_SHL:
+        case Kind::BITVECTOR_SHL:
         {
           BitVector res = results[currNode[0]].d_bv;
           res = res.leftShift(results[currNode[1]].d_bv);
           results[currNode] = EvalResult(res);
           break;
         }
-        case kind::BITVECTOR_ASHR:
+        case Kind::BITVECTOR_ASHR:
         {
           BitVector res = results[currNode[0]].d_bv;
           res = res.arithRightShift(results[currNode[1]].d_bv);
           results[currNode] = EvalResult(res);
           break;
         }
-        case kind::BITVECTOR_ULT:
+        case Kind::BITVECTOR_ULT:
         {
           BitVector res = results[currNode[0]].d_bv;
           bool b = res.unsignedLessThan(results[currNode[1]].d_bv);
           results[currNode] = EvalResult(b);
           break;
         }
-        case kind::BITVECTOR_SLT:
+        case Kind::BITVECTOR_SLT:
         {
           BitVector res = results[currNode[0]].d_bv;
           bool b = res.signedLessThan(results[currNode[1]].d_bv);
           results[currNode] = EvalResult(b);
           break;
         }
-        case kind::BITVECTOR_SLE:
+        case Kind::BITVECTOR_SLE:
         {
           BitVector res = results[currNode[0]].d_bv;
           bool b = res.signedLessThanEq(results[currNode[1]].d_bv);
           results[currNode] = EvalResult(b);
           break;
         }
-        case kind::BITVECTOR_ULE:
+        case Kind::BITVECTOR_ULE:
         {
           BitVector res = results[currNode[0]].d_bv;
           bool b = res.unsignedLessThanEq(results[currNode[1]].d_bv);
           results[currNode] = EvalResult(b);
           break;
         }
-        case kind::BITVECTOR_UGT:
+        case Kind::BITVECTOR_UGT:
         {
           BitVector res = results[currNode[1]].d_bv;
           bool b = res.unsignedLessThan(results[currNode[0]].d_bv);
           results[currNode] = EvalResult(b);
           break;
         }
-        case kind::BITVECTOR_SGT:
+        case Kind::BITVECTOR_SGT:
         {
           BitVector res = results[currNode[1]].d_bv;
           bool b = res.signedLessThan(results[currNode[0]].d_bv);
           results[currNode] = EvalResult(b);
           break;
         }
-        case kind::BITVECTOR_SGE:
+        case Kind::BITVECTOR_SGE:
         {
           BitVector res = results[currNode[1]].d_bv;
           bool b = res.signedLessThanEq(results[currNode[0]].d_bv);
           results[currNode] = EvalResult(b);
           break;
         }
-        case kind::BITVECTOR_UGE:
+        case Kind::BITVECTOR_UGE:
         {
           BitVector res = results[currNode[1]].d_bv;
           bool b = res.unsignedLessThanEq(results[currNode[0]].d_bv);
           results[currNode] = EvalResult(b);
           break;
         }
-        case kind::BITVECTOR_SIGN_EXTEND:
+        case Kind::BITVECTOR_SIGN_EXTEND:
         {
           BitVector res = results[currNode[0]].d_bv;
           unsigned amount = currNode.getOperator()
@@ -1018,7 +1018,7 @@ EvalResult Evaluator::evalInternal(
           results[currNode] = EvalResult(res.signExtend(amount));
           break;
         }
-        case kind::BITVECTOR_ZERO_EXTEND:
+        case Kind::BITVECTOR_ZERO_EXTEND:
         {
           BitVector res = results[currNode[0]].d_bv;
           unsigned amount = currNode.getOperator()
@@ -1028,7 +1028,7 @@ EvalResult Evaluator::evalInternal(
           break;
         }
 
-        case kind::EQUAL:
+        case Kind::EQUAL:
         {
           EvalResult lhs = results[currNode[0]];
           EvalResult rhs = results[currNode[1]];
@@ -1079,7 +1079,7 @@ EvalResult Evaluator::evalInternal(
           break;
         }
 
-        case kind::ITE:
+        case Kind::ITE:
         {
           if (results[currNode[0]].d_bool)
           {
@@ -1091,13 +1091,13 @@ EvalResult Evaluator::evalInternal(
           }
           break;
         }
-        case kind::BITVECTOR_TO_NAT:
+        case Kind::BITVECTOR_TO_NAT:
         {
           BitVector res = results[currNode[0]].d_bv;
           results[currNode] = EvalResult(Rational(res.toInteger()));
           break;
         }
-        case kind::INT_TO_BITVECTOR:
+        case Kind::INT_TO_BITVECTOR:
         {
           Integer i = results[currNode[0]].d_rat.getNumerator();
           const uint32_t size =
