@@ -49,7 +49,7 @@ Node buildConjunct(const std::vector<TNode> &assumptions) {
   } else {
     // \todo see bv::utils::flattenAnd
 
-    NodeBuilder conjunction(kind::AND);
+    NodeBuilder conjunction(Kind::AND);
     for (std::vector<TNode>::const_iterator it = assumptions.begin();
          it != assumptions.end(); ++it) {
       conjunction << *it;
@@ -95,45 +95,45 @@ void TheoryFp::finishInit()
   Assert(d_equalityEngine != nullptr);
 
   // Kinds that are to be handled in the congruence closure
-  d_equalityEngine->addFunctionKind(kind::FLOATINGPOINT_ABS);
-  d_equalityEngine->addFunctionKind(kind::FLOATINGPOINT_NEG);
-  d_equalityEngine->addFunctionKind(kind::FLOATINGPOINT_ADD);
-  d_equalityEngine->addFunctionKind(kind::FLOATINGPOINT_MULT);
-  d_equalityEngine->addFunctionKind(kind::FLOATINGPOINT_DIV);
-  d_equalityEngine->addFunctionKind(kind::FLOATINGPOINT_FMA);
-  d_equalityEngine->addFunctionKind(kind::FLOATINGPOINT_SQRT);
-  d_equalityEngine->addFunctionKind(kind::FLOATINGPOINT_REM);
-  d_equalityEngine->addFunctionKind(kind::FLOATINGPOINT_RTI);
-  d_equalityEngine->addFunctionKind(kind::FLOATINGPOINT_MIN_TOTAL);
-  d_equalityEngine->addFunctionKind(kind::FLOATINGPOINT_MAX_TOTAL);
+  d_equalityEngine->addFunctionKind(Kind::FLOATINGPOINT_ABS);
+  d_equalityEngine->addFunctionKind(Kind::FLOATINGPOINT_NEG);
+  d_equalityEngine->addFunctionKind(Kind::FLOATINGPOINT_ADD);
+  d_equalityEngine->addFunctionKind(Kind::FLOATINGPOINT_MULT);
+  d_equalityEngine->addFunctionKind(Kind::FLOATINGPOINT_DIV);
+  d_equalityEngine->addFunctionKind(Kind::FLOATINGPOINT_FMA);
+  d_equalityEngine->addFunctionKind(Kind::FLOATINGPOINT_SQRT);
+  d_equalityEngine->addFunctionKind(Kind::FLOATINGPOINT_REM);
+  d_equalityEngine->addFunctionKind(Kind::FLOATINGPOINT_RTI);
+  d_equalityEngine->addFunctionKind(Kind::FLOATINGPOINT_MIN_TOTAL);
+  d_equalityEngine->addFunctionKind(Kind::FLOATINGPOINT_MAX_TOTAL);
 
-  d_equalityEngine->addFunctionKind(kind::FLOATINGPOINT_LEQ);
-  d_equalityEngine->addFunctionKind(kind::FLOATINGPOINT_LT);
-  d_equalityEngine->addFunctionKind(kind::FLOATINGPOINT_IS_NORMAL);
-  d_equalityEngine->addFunctionKind(kind::FLOATINGPOINT_IS_SUBNORMAL);
-  d_equalityEngine->addFunctionKind(kind::FLOATINGPOINT_IS_ZERO);
-  d_equalityEngine->addFunctionKind(kind::FLOATINGPOINT_IS_INF);
-  d_equalityEngine->addFunctionKind(kind::FLOATINGPOINT_IS_NAN);
-  d_equalityEngine->addFunctionKind(kind::FLOATINGPOINT_IS_NEG);
-  d_equalityEngine->addFunctionKind(kind::FLOATINGPOINT_IS_POS);
+  d_equalityEngine->addFunctionKind(Kind::FLOATINGPOINT_LEQ);
+  d_equalityEngine->addFunctionKind(Kind::FLOATINGPOINT_LT);
+  d_equalityEngine->addFunctionKind(Kind::FLOATINGPOINT_IS_NORMAL);
+  d_equalityEngine->addFunctionKind(Kind::FLOATINGPOINT_IS_SUBNORMAL);
+  d_equalityEngine->addFunctionKind(Kind::FLOATINGPOINT_IS_ZERO);
+  d_equalityEngine->addFunctionKind(Kind::FLOATINGPOINT_IS_INF);
+  d_equalityEngine->addFunctionKind(Kind::FLOATINGPOINT_IS_NAN);
+  d_equalityEngine->addFunctionKind(Kind::FLOATINGPOINT_IS_NEG);
+  d_equalityEngine->addFunctionKind(Kind::FLOATINGPOINT_IS_POS);
 
-  d_equalityEngine->addFunctionKind(kind::FLOATINGPOINT_TO_FP_FROM_IEEE_BV);
-  d_equalityEngine->addFunctionKind(kind::FLOATINGPOINT_TO_FP_FROM_FP);
-  d_equalityEngine->addFunctionKind(kind::FLOATINGPOINT_TO_FP_FROM_REAL);
-  d_equalityEngine->addFunctionKind(kind::FLOATINGPOINT_TO_FP_FROM_SBV);
-  d_equalityEngine->addFunctionKind(kind::FLOATINGPOINT_TO_FP_FROM_UBV);
+  d_equalityEngine->addFunctionKind(Kind::FLOATINGPOINT_TO_FP_FROM_IEEE_BV);
+  d_equalityEngine->addFunctionKind(Kind::FLOATINGPOINT_TO_FP_FROM_FP);
+  d_equalityEngine->addFunctionKind(Kind::FLOATINGPOINT_TO_FP_FROM_REAL);
+  d_equalityEngine->addFunctionKind(Kind::FLOATINGPOINT_TO_FP_FROM_SBV);
+  d_equalityEngine->addFunctionKind(Kind::FLOATINGPOINT_TO_FP_FROM_UBV);
 
-  d_equalityEngine->addFunctionKind(kind::FLOATINGPOINT_TO_UBV_TOTAL);
-  d_equalityEngine->addFunctionKind(kind::FLOATINGPOINT_TO_SBV_TOTAL);
-  d_equalityEngine->addFunctionKind(kind::FLOATINGPOINT_TO_REAL_TOTAL);
+  d_equalityEngine->addFunctionKind(Kind::FLOATINGPOINT_TO_UBV_TOTAL);
+  d_equalityEngine->addFunctionKind(Kind::FLOATINGPOINT_TO_SBV_TOTAL);
+  d_equalityEngine->addFunctionKind(Kind::FLOATINGPOINT_TO_REAL_TOTAL);
 
-  d_equalityEngine->addFunctionKind(kind::FLOATINGPOINT_COMPONENT_NAN);
-  d_equalityEngine->addFunctionKind(kind::FLOATINGPOINT_COMPONENT_INF);
-  d_equalityEngine->addFunctionKind(kind::FLOATINGPOINT_COMPONENT_ZERO);
-  d_equalityEngine->addFunctionKind(kind::FLOATINGPOINT_COMPONENT_SIGN);
-  d_equalityEngine->addFunctionKind(kind::FLOATINGPOINT_COMPONENT_EXPONENT);
-  d_equalityEngine->addFunctionKind(kind::FLOATINGPOINT_COMPONENT_SIGNIFICAND);
-  d_equalityEngine->addFunctionKind(kind::ROUNDINGMODE_BITBLAST);
+  d_equalityEngine->addFunctionKind(Kind::FLOATINGPOINT_COMPONENT_NAN);
+  d_equalityEngine->addFunctionKind(Kind::FLOATINGPOINT_COMPONENT_INF);
+  d_equalityEngine->addFunctionKind(Kind::FLOATINGPOINT_COMPONENT_ZERO);
+  d_equalityEngine->addFunctionKind(Kind::FLOATINGPOINT_COMPONENT_SIGN);
+  d_equalityEngine->addFunctionKind(Kind::FLOATINGPOINT_COMPONENT_EXPONENT);
+  d_equalityEngine->addFunctionKind(Kind::FLOATINGPOINT_COMPONENT_SIGNIFICAND);
+  d_equalityEngine->addFunctionKind(Kind::ROUNDINGMODE_BITBLAST);
 }
 
 TrustNode TheoryFp::ppRewrite(TNode node, std::vector<SkolemLemma>& lems)
@@ -149,15 +149,15 @@ TrustNode TheoryFp::ppRewrite(TNode node, std::vector<SkolemLemma>& lems)
 
   // The following kinds should have been removed by the
   // rewriter/expandDefinition
-  Assert(node.getKind() != kind::FLOATINGPOINT_SUB
-         && node.getKind() != kind::FLOATINGPOINT_MIN
-         && node.getKind() != kind::FLOATINGPOINT_MAX
-         && node.getKind() != kind::FLOATINGPOINT_EQ
-         && node.getKind() != kind::FLOATINGPOINT_GEQ
-         && node.getKind() != kind::FLOATINGPOINT_GT
-         && node.getKind() != kind::FLOATINGPOINT_TO_UBV
-         && node.getKind() != kind::FLOATINGPOINT_TO_SBV
-         && node.getKind() != kind::FLOATINGPOINT_TO_REAL)
+  Assert(node.getKind() != Kind::FLOATINGPOINT_SUB
+         && node.getKind() != Kind::FLOATINGPOINT_MIN
+         && node.getKind() != Kind::FLOATINGPOINT_MAX
+         && node.getKind() != Kind::FLOATINGPOINT_EQ
+         && node.getKind() != Kind::FLOATINGPOINT_GEQ
+         && node.getKind() != Kind::FLOATINGPOINT_GT
+         && node.getKind() != Kind::FLOATINGPOINT_TO_UBV
+         && node.getKind() != Kind::FLOATINGPOINT_TO_SBV
+         && node.getKind() != Kind::FLOATINGPOINT_TO_REAL)
       << "Expected floating-point kind " << node.getKind() << " to be removed";
 
   return TrustNode::null();
@@ -168,7 +168,7 @@ bool TheoryFp::refineAbstraction(TheoryModel *m, TNode abstract, TNode concrete)
   Trace("fp-refineAbstraction") << "TheoryFp::refineAbstraction(): " << abstract
                                 << " vs. " << concrete << std::endl;
   Kind k = concrete.getKind();
-  if (k == kind::FLOATINGPOINT_TO_REAL_TOTAL)
+  if (k == Kind::FLOATINGPOINT_TO_REAL_TOTAL)
   {
     // Get the values
     Assert(m->hasTerm(abstract));
@@ -190,7 +190,7 @@ bool TheoryFp::refineAbstraction(TheoryModel *m, TNode abstract, TNode concrete)
     NodeManager *nm = NodeManager::currentNM();
 
     Node evaluate =
-        nm->mkNode(kind::FLOATINGPOINT_TO_REAL_TOTAL, floatValue, undefValue);
+        nm->mkNode(Kind::FLOATINGPOINT_TO_REAL_TOTAL, floatValue, undefValue);
     Node concreteValue = rewrite(evaluate);
     Assert(concreteValue.isConst());
 
@@ -212,63 +212,63 @@ bool TheoryFp::refineAbstraction(TheoryModel *m, TNode abstract, TNode concrete)
              || floatValue.getConst<FloatingPoint>().isSubnormal());
 
       Node defined = nm->mkNode(
-          kind::AND,
-          nm->mkNode(kind::NOT,
-                     nm->mkNode(kind::FLOATINGPOINT_IS_NAN, concrete[0])),
-          nm->mkNode(kind::NOT,
-                     nm->mkNode(kind::FLOATINGPOINT_IS_INF, concrete[0])));
+          Kind::AND,
+          nm->mkNode(Kind::NOT,
+                     nm->mkNode(Kind::FLOATINGPOINT_IS_NAN, concrete[0])),
+          nm->mkNode(Kind::NOT,
+                     nm->mkNode(Kind::FLOATINGPOINT_IS_INF, concrete[0])));
       // First the "forward" constraints
       Node fg = nm->mkNode(
-          kind::IMPLIES,
+          Kind::IMPLIES,
           defined,
           nm->mkNode(
-              kind::EQUAL,
-              nm->mkNode(kind::FLOATINGPOINT_GEQ, concrete[0], floatValue),
-              nm->mkNode(kind::GEQ, abstract, concreteValue)));
+              Kind::EQUAL,
+              nm->mkNode(Kind::FLOATINGPOINT_GEQ, concrete[0], floatValue),
+              nm->mkNode(Kind::GEQ, abstract, concreteValue)));
       handleLemma(fg, InferenceId::FP_PREPROCESS);
 
       Node fl = nm->mkNode(
-          kind::IMPLIES,
+          Kind::IMPLIES,
           defined,
           nm->mkNode(
-              kind::EQUAL,
-              nm->mkNode(kind::FLOATINGPOINT_LEQ, concrete[0], floatValue),
-              nm->mkNode(kind::LEQ, abstract, concreteValue)));
+              Kind::EQUAL,
+              nm->mkNode(Kind::FLOATINGPOINT_LEQ, concrete[0], floatValue),
+              nm->mkNode(Kind::LEQ, abstract, concreteValue)));
       handleLemma(fl, InferenceId::FP_PREPROCESS);
 
       // Then the backwards constraints
       Node floatAboveAbstract = rewrite(
-          nm->mkNode(kind::FLOATINGPOINT_TO_FP_FROM_REAL,
+          nm->mkNode(Kind::FLOATINGPOINT_TO_FP_FROM_REAL,
                      nm->mkConst(FloatingPointToFPReal(
                          concrete[0].getType().getConst<FloatingPointSize>())),
                      nm->mkConst(RoundingMode::ROUND_TOWARD_POSITIVE),
                      abstractValue));
 
       Node bg = nm->mkNode(
-          kind::IMPLIES,
+          Kind::IMPLIES,
           defined,
           nm->mkNode(
-              kind::EQUAL,
+              Kind::EQUAL,
               nm->mkNode(
-                  kind::FLOATINGPOINT_GEQ, concrete[0], floatAboveAbstract),
-              nm->mkNode(kind::GEQ, abstract, abstractValue)));
+                  Kind::FLOATINGPOINT_GEQ, concrete[0], floatAboveAbstract),
+              nm->mkNode(Kind::GEQ, abstract, abstractValue)));
       handleLemma(bg, InferenceId::FP_PREPROCESS);
 
       Node floatBelowAbstract = rewrite(
-          nm->mkNode(kind::FLOATINGPOINT_TO_FP_FROM_REAL,
+          nm->mkNode(Kind::FLOATINGPOINT_TO_FP_FROM_REAL,
                      nm->mkConst(FloatingPointToFPReal(
                          concrete[0].getType().getConst<FloatingPointSize>())),
                      nm->mkConst(RoundingMode::ROUND_TOWARD_NEGATIVE),
                      abstractValue));
 
       Node bl = nm->mkNode(
-          kind::IMPLIES,
+          Kind::IMPLIES,
           defined,
           nm->mkNode(
-              kind::EQUAL,
+              Kind::EQUAL,
               nm->mkNode(
-                  kind::FLOATINGPOINT_LEQ, concrete[0], floatBelowAbstract),
-              nm->mkNode(kind::LEQ, abstract, abstractValue)));
+                  Kind::FLOATINGPOINT_LEQ, concrete[0], floatBelowAbstract),
+              nm->mkNode(Kind::LEQ, abstract, abstractValue)));
       handleLemma(bl, InferenceId::FP_PREPROCESS);
       // TODO : see if the overflow conditions could be improved #1914
 
@@ -280,7 +280,7 @@ bool TheoryFp::refineAbstraction(TheoryModel *m, TNode abstract, TNode concrete)
       return false;
     }
   }
-  else if (k == kind::FLOATINGPOINT_TO_FP_FROM_REAL)
+  else if (k == Kind::FLOATINGPOINT_TO_FP_FROM_REAL)
   {
     // Get the values
     Assert(m->hasTerm(abstract)) << "Term " << abstract << " not in model";
@@ -306,7 +306,7 @@ bool TheoryFp::refineAbstraction(TheoryModel *m, TNode abstract, TNode concrete)
     NodeManager *nm = NodeManager::currentNM();
 
     Node evaluate =
-        nm->mkNode(kind::FLOATINGPOINT_TO_FP_FROM_REAL,
+        nm->mkNode(Kind::FLOATINGPOINT_TO_FP_FROM_REAL,
                    nm->mkConst(FloatingPointToFPReal(
                        concrete.getType().getConst<FloatingPointSize>())),
                    rmValue,
@@ -329,52 +329,52 @@ bool TheoryFp::refineAbstraction(TheoryModel *m, TNode abstract, TNode concrete)
       Assert(!abstractValue.getConst<FloatingPoint>().isNaN());
       Assert(!concreteValue.getConst<FloatingPoint>().isNaN());
 
-      Node correctRoundingMode = nm->mkNode(kind::EQUAL, concrete[0], rmValue);
+      Node correctRoundingMode = nm->mkNode(Kind::EQUAL, concrete[0], rmValue);
       // TODO : Generalise to all rounding modes  #1914
 
       // First the "forward" constraints
       Node fg = nm->mkNode(
-          kind::IMPLIES,
+          Kind::IMPLIES,
           correctRoundingMode,
           nm->mkNode(
-              kind::EQUAL,
-              nm->mkNode(kind::GEQ, concrete[1], realValue),
-              nm->mkNode(kind::FLOATINGPOINT_GEQ, abstract, concreteValue)));
+              Kind::EQUAL,
+              nm->mkNode(Kind::GEQ, concrete[1], realValue),
+              nm->mkNode(Kind::FLOATINGPOINT_GEQ, abstract, concreteValue)));
       handleLemma(fg, InferenceId::FP_PREPROCESS);
 
       Node fl = nm->mkNode(
-          kind::IMPLIES,
+          Kind::IMPLIES,
           correctRoundingMode,
           nm->mkNode(
-              kind::EQUAL,
-              nm->mkNode(kind::LEQ, concrete[1], realValue),
-              nm->mkNode(kind::FLOATINGPOINT_LEQ, abstract, concreteValue)));
+              Kind::EQUAL,
+              nm->mkNode(Kind::LEQ, concrete[1], realValue),
+              nm->mkNode(Kind::FLOATINGPOINT_LEQ, abstract, concreteValue)));
       handleLemma(fl, InferenceId::FP_PREPROCESS);
 
       // Then the backwards constraints
       if (!abstractValue.getConst<FloatingPoint>().isInfinite())
       {
         Node realValueOfAbstract =
-            rewrite(nm->mkNode(kind::FLOATINGPOINT_TO_REAL_TOTAL,
+            rewrite(nm->mkNode(Kind::FLOATINGPOINT_TO_REAL_TOTAL,
                                abstractValue,
                                nm->mkConstReal(Rational(0U))));
 
         Node bg = nm->mkNode(
-            kind::IMPLIES,
+            Kind::IMPLIES,
             correctRoundingMode,
             nm->mkNode(
-                kind::EQUAL,
-                nm->mkNode(kind::GEQ, concrete[1], realValueOfAbstract),
-                nm->mkNode(kind::FLOATINGPOINT_GEQ, abstract, abstractValue)));
+                Kind::EQUAL,
+                nm->mkNode(Kind::GEQ, concrete[1], realValueOfAbstract),
+                nm->mkNode(Kind::FLOATINGPOINT_GEQ, abstract, abstractValue)));
         handleLemma(bg, InferenceId::FP_PREPROCESS);
 
         Node bl = nm->mkNode(
-            kind::IMPLIES,
+            Kind::IMPLIES,
             correctRoundingMode,
             nm->mkNode(
-                kind::EQUAL,
-                nm->mkNode(kind::LEQ, concrete[1], realValueOfAbstract),
-                nm->mkNode(kind::FLOATINGPOINT_LEQ, abstract, abstractValue)));
+                Kind::EQUAL,
+                nm->mkNode(Kind::LEQ, concrete[1], realValueOfAbstract),
+                nm->mkNode(Kind::FLOATINGPOINT_LEQ, abstract, abstractValue)));
         handleLemma(bl, InferenceId::FP_PREPROCESS);
       }
 
@@ -427,7 +427,7 @@ void TheoryFp::wordBlastAndEquateTerm(TNode node)
 
     handleLemma(
         nm->mkNode(
-            kind::EQUAL, addA, nm->mkConst(cvc5::internal::BitVector(1U, 1U))),
+            Kind::EQUAL, addA, nm->mkConst(cvc5::internal::BitVector(1U, 1U))),
         InferenceId::FP_EQUATE_TERM);
 
     ++oldSize;
@@ -446,16 +446,16 @@ void TheoryFp::wordBlastAndEquateTerm(TNode node)
 
       handleLemma(
           nm->mkNode(
-              kind::EQUAL,
+              Kind::EQUAL,
               node,
-              nm->mkNode(kind::EQUAL,
+              nm->mkNode(Kind::EQUAL,
                          wordBlasted,
                          nm->mkConst(cvc5::internal::BitVector(1U, 1U)))),
           InferenceId::FP_EQUATE_TERM);
     }
     else
     {
-      Assert((node.getKind() == kind::EQUAL));
+      Assert((node.getKind() == Kind::EQUAL));
     }
   }
   else if (node.getType().isBitVector())
@@ -465,7 +465,7 @@ void TheoryFp::wordBlastAndEquateTerm(TNode node)
       Assert(wordBlasted.getType().isBitVector());
 
       handleLemma(
-          NodeManager::currentNM()->mkNode(kind::EQUAL, node, wordBlasted),
+          NodeManager::currentNM()->mkNode(Kind::EQUAL, node, wordBlasted),
           InferenceId::FP_EQUATE_TERM);
     }
   }
@@ -478,12 +478,12 @@ void TheoryFp::registerTerm(TNode node)
   Trace("fp-registerTerm") << "TheoryFp::registerTerm(): " << node << std::endl;
 
   Kind k = node.getKind();
-  Assert(k != kind::FLOATINGPOINT_SUB && k != kind::FLOATINGPOINT_EQ
-         && k != kind::FLOATINGPOINT_GEQ && k != kind::FLOATINGPOINT_GT);
+  Assert(k != Kind::FLOATINGPOINT_SUB && k != Kind::FLOATINGPOINT_EQ
+         && k != Kind::FLOATINGPOINT_GEQ && k != Kind::FLOATINGPOINT_GT);
 
   // Add to the equality engine, always. This is required to ensure
   // getEqualityStatus works as expected when theory combination is enabled.
-  if (k == kind::EQUAL)
+  if (k == Kind::EQUAL)
   {
     d_state.addEqualityEngineTriggerPredicate(node);
   }
@@ -503,37 +503,37 @@ void TheoryFp::registerTerm(TNode node)
 
   // Give the expansion of classifications in terms of equalities
   // This should make equality reasoning slightly more powerful.
-  if ((k == kind::FLOATINGPOINT_IS_NAN) || (k == kind::FLOATINGPOINT_IS_ZERO)
-      || (k == kind::FLOATINGPOINT_IS_INF))
+  if ((k == Kind::FLOATINGPOINT_IS_NAN) || (k == Kind::FLOATINGPOINT_IS_ZERO)
+      || (k == Kind::FLOATINGPOINT_IS_INF))
   {
     NodeManager* nm = NodeManager::currentNM();
     FloatingPointSize s = node[0].getType().getConst<FloatingPointSize>();
     Node equalityAlias = Node::null();
 
-    if (k == kind::FLOATINGPOINT_IS_NAN)
+    if (k == Kind::FLOATINGPOINT_IS_NAN)
     {
       equalityAlias = nm->mkNode(
-          kind::EQUAL, node[0], nm->mkConst(FloatingPoint::makeNaN(s)));
+          Kind::EQUAL, node[0], nm->mkConst(FloatingPoint::makeNaN(s)));
     }
-    else if (k == kind::FLOATINGPOINT_IS_ZERO)
+    else if (k == Kind::FLOATINGPOINT_IS_ZERO)
     {
       equalityAlias = nm->mkNode(
-          kind::OR,
-          nm->mkNode(kind::EQUAL,
+          Kind::OR,
+          nm->mkNode(Kind::EQUAL,
                      node[0],
                      nm->mkConst(FloatingPoint::makeZero(s, true))),
-          nm->mkNode(kind::EQUAL,
+          nm->mkNode(Kind::EQUAL,
                      node[0],
                      nm->mkConst(FloatingPoint::makeZero(s, false))));
     }
-    else if (k == kind::FLOATINGPOINT_IS_INF)
+    else if (k == Kind::FLOATINGPOINT_IS_INF)
     {
       equalityAlias =
-          nm->mkNode(kind::OR,
-                     nm->mkNode(kind::EQUAL,
+          nm->mkNode(Kind::OR,
+                     nm->mkNode(Kind::EQUAL,
                                 node[0],
                                 nm->mkConst(FloatingPoint::makeInf(s, true))),
-                     nm->mkNode(kind::EQUAL,
+                     nm->mkNode(Kind::EQUAL,
                                 node[0],
                                 nm->mkConst(FloatingPoint::makeInf(s, false))));
     }
@@ -542,10 +542,10 @@ void TheoryFp::registerTerm(TNode node)
       Unreachable() << "Only isNaN, isInf and isZero have aliases";
     }
 
-    handleLemma(nm->mkNode(kind::EQUAL, node, equalityAlias),
+    handleLemma(nm->mkNode(Kind::EQUAL, node, equalityAlias),
                 InferenceId::FP_REGISTER_TERM);
   }
-  else if (k == kind::FLOATINGPOINT_TO_REAL_TOTAL)
+  else if (k == Kind::FLOATINGPOINT_TO_REAL_TOTAL)
   {
     // Purify (fp.to_real x)
     NodeManager* nm = NodeManager::currentNM();
@@ -555,23 +555,23 @@ void TheoryFp::registerTerm(TNode node)
     d_abstractionMap.insert(sk, node);
 
     Node pd =
-        nm->mkNode(kind::IMPLIES,
-                   nm->mkNode(kind::OR,
-                              nm->mkNode(kind::FLOATINGPOINT_IS_NAN, node[0]),
-                              nm->mkNode(kind::FLOATINGPOINT_IS_INF, node[0])),
-                   nm->mkNode(kind::EQUAL, node, node[1]));
+        nm->mkNode(Kind::IMPLIES,
+                   nm->mkNode(Kind::OR,
+                              nm->mkNode(Kind::FLOATINGPOINT_IS_NAN, node[0]),
+                              nm->mkNode(Kind::FLOATINGPOINT_IS_INF, node[0])),
+                   nm->mkNode(Kind::EQUAL, node, node[1]));
     handleLemma(pd, InferenceId::FP_REGISTER_TERM);
 
     Node z = nm->mkNode(
-        kind::IMPLIES,
-        nm->mkNode(kind::FLOATINGPOINT_IS_ZERO, node[0]),
-        nm->mkNode(kind::EQUAL, node, nm->mkConstReal(Rational(0U))));
+        Kind::IMPLIES,
+        nm->mkNode(Kind::FLOATINGPOINT_IS_ZERO, node[0]),
+        nm->mkNode(Kind::EQUAL, node, nm->mkConstReal(Rational(0U))));
     handleLemma(z, InferenceId::FP_REGISTER_TERM);
     return;
 
     // TODO : bounds on the output from largest floats, #1914
   }
-  else if (k == kind::FLOATINGPOINT_TO_FP_FROM_REAL)
+  else if (k == Kind::FLOATINGPOINT_TO_FP_FROM_REAL)
   {
     // Purify ((_ to_fp eb sb) rm x)
     NodeManager* nm = NodeManager::currentNM();
@@ -581,13 +581,13 @@ void TheoryFp::registerTerm(TNode node)
     d_abstractionMap.insert(sk, node);
 
     Node nnan =
-        nm->mkNode(kind::NOT, nm->mkNode(kind::FLOATINGPOINT_IS_NAN, node));
+        nm->mkNode(Kind::NOT, nm->mkNode(Kind::FLOATINGPOINT_IS_NAN, node));
     handleLemma(nnan, InferenceId::FP_REGISTER_TERM);
 
     Node z = nm->mkNode(
-        kind::IMPLIES,
-        nm->mkNode(kind::EQUAL, node[1], nm->mkConstReal(Rational(0U))),
-        nm->mkNode(kind::EQUAL,
+        Kind::IMPLIES,
+        nm->mkNode(Kind::EQUAL, node[1], nm->mkConstReal(Rational(0U))),
+        nm->mkNode(Kind::EQUAL,
                    node,
                    nm->mkConst(FloatingPoint::makeZero(
                        node.getType().getConst<FloatingPointSize>(), false))));
@@ -713,7 +713,7 @@ bool TheoryFp::preNotifyFact(
     wordBlastAndEquateTerm(atom);
   }
 
-  if (atom.getKind() == kind::EQUAL)
+  if (atom.getKind() == Kind::EQUAL)
   {
     Assert(!(atom[0].getType().isFloatingPoint()
              || atom[0].getType().isRoundingMode())
@@ -787,10 +787,10 @@ Node TheoryFp::getCandidateModelValue(TNode node)
     Node value;
 
     Kind kind = cur.getKind();
-    if (kind == kind::FLOATINGPOINT_TO_FP_FROM_SBV
-        || kind == kind::FLOATINGPOINT_TO_FP_FROM_UBV
-        || kind == kind::FLOATINGPOINT_TO_FP_FROM_REAL
-        || kind == kind::FLOATINGPOINT_TO_FP_FROM_IEEE_BV
+    if (kind == Kind::FLOATINGPOINT_TO_FP_FROM_SBV
+        || kind == Kind::FLOATINGPOINT_TO_FP_FROM_UBV
+        || kind == Kind::FLOATINGPOINT_TO_FP_FROM_REAL
+        || kind == Kind::FLOATINGPOINT_TO_FP_FROM_IEEE_BV
         || Theory::isLeafOf(cur, theory::THEORY_FP))
     {
       if (cur.getType().isFloatingPoint() || cur.getType().isRoundingMode())
@@ -850,11 +850,14 @@ TrustNode TheoryFp::explain(TNode n)
   // come from the equality engine so this should be sufficient...
   std::vector<TNode> assumptions;
 
-  bool polarity = n.getKind() != kind::NOT;
+  bool polarity = n.getKind() != Kind::NOT;
   TNode atom = polarity ? n : n[0];
-  if (atom.getKind() == kind::EQUAL) {
+  if (atom.getKind() == Kind::EQUAL)
+  {
     d_equalityEngine->explainEquality(atom[0], atom[1], polarity, assumptions);
-  } else {
+  }
+  else
+  {
     d_equalityEngine->explainPredicate(atom, polarity, assumptions);
   }
 
@@ -931,13 +934,13 @@ bool TheoryFp::collectModelValues(TheoryModel* m,
       // assignable, meaning that the model builder can pick an arbitrary value
       // for it if it hasn't been assigned in the equality engine).
       NodeManager* nm = NodeManager::currentNM();
-      Node compNaN = nm->mkNode(kind::FLOATINGPOINT_COMPONENT_NAN, node);
-      Node compInf = nm->mkNode(kind::FLOATINGPOINT_COMPONENT_INF, node);
-      Node compZero = nm->mkNode(kind::FLOATINGPOINT_COMPONENT_ZERO, node);
+      Node compNaN = nm->mkNode(Kind::FLOATINGPOINT_COMPONENT_NAN, node);
+      Node compInf = nm->mkNode(Kind::FLOATINGPOINT_COMPONENT_INF, node);
+      Node compZero = nm->mkNode(Kind::FLOATINGPOINT_COMPONENT_ZERO, node);
       Node compExponent =
-          nm->mkNode(kind::FLOATINGPOINT_COMPONENT_EXPONENT, node);
+          nm->mkNode(Kind::FLOATINGPOINT_COMPONENT_EXPONENT, node);
       Node compSignificand =
-          nm->mkNode(kind::FLOATINGPOINT_COMPONENT_SIGNIFICAND, node);
+          nm->mkNode(Kind::FLOATINGPOINT_COMPONENT_SIGNIFICAND, node);
 
       eq::EqualityEngine* ee = m->getEqualityEngine();
       Assert(ee->hasTerm(compNaN));
