@@ -141,10 +141,10 @@ Node BvInstantiator::hasProcessAssertion(CegInstantiator* ci,
     // always use model values at full effort
     return Node::null();
   }
-  Node atom = lit.getKind() == NOT ? lit[0] : lit;
-  bool pol = lit.getKind() != NOT;
+  Node atom = lit.getKind() == Kind::NOT ? lit[0] : lit;
+  bool pol = lit.getKind() != Kind::NOT;
   Kind k = atom.getKind();
-  if (k != EQUAL && k != BITVECTOR_ULT && k != BITVECTOR_SLT)
+  if (k != Kind::EQUAL && k != Kind::BITVECTOR_ULT && k != Kind::BITVECTOR_SLT)
   {
     // others are unhandled
     return Node::null();
@@ -155,7 +155,7 @@ Node BvInstantiator::hasProcessAssertion(CegInstantiator* ci,
   }
   else if (options().quantifiers.cegqiBvIneqMode
                == options::CegqiBvIneqMode::KEEP
-           || (pol && k == EQUAL))
+           || (pol && k == Kind::EQUAL))
   {
     return lit;
   }
@@ -181,11 +181,12 @@ Node BvInstantiator::hasProcessAssertion(CegInstantiator* ci,
     //   (not) s ~ t  --->  s = t + ( s^M - t^M )
     if (sm != tm)
     {
-      Node slack = rewrite(nm->mkNode(BITVECTOR_SUB, sm, tm));
+      Node slack = rewrite(nm->mkNode(Kind::BITVECTOR_SUB, sm, tm));
       Assert(slack.isConst());
       // remember the slack value for the asserted literal
       d_alit_to_model_slack[lit] = slack;
-      ret = nm->mkNode(EQUAL, s, nm->mkNode(BITVECTOR_ADD, t, slack));
+      ret =
+          nm->mkNode(Kind::EQUAL, s, nm->mkNode(Kind::BITVECTOR_ADD, t, slack));
       Trace("cegqi-bv") << "Slack is " << slack << std::endl;
     }
     else
@@ -197,7 +198,7 @@ Node BvInstantiator::hasProcessAssertion(CegInstantiator* ci,
   {
     // turn disequality into an inequality
     // e.g. s != t becomes s < t or t < s
-    if (k == EQUAL)
+    if (k == Kind::EQUAL)
     {
       if (Random::getRandom().pickWithProb(0.5))
       {
@@ -219,7 +220,7 @@ Node BvInstantiator::hasProcessAssertion(CegInstantiator* ci,
     else
     {
       Node bv_one = bv::utils::mkOne(bv::utils::getSize(s));
-      ret = nm->mkNode(BITVECTOR_ADD, s, bv_one).eqNode(t);
+      ret = nm->mkNode(Kind::BITVECTOR_ADD, s, bv_one).eqNode(t);
     }
   }
   Trace("cegqi-bv") << "Process " << lit << " as " << ret << std::endl;
@@ -409,7 +410,7 @@ Node BvInstantiator::rewriteAssertionForSolvePv(CegInstantiator* ci,
       }
       else
       {
-        if (cur.getKind() == WITNESS)
+        if (cur.getKind() == Kind::WITNESS)
         {
           // must replace variables of choice functions
           // with new variables to avoid variable
@@ -486,7 +487,7 @@ Node BvInstantiator::rewriteAssertionForSolvePv(CegInstantiator* ci,
       }
 
       // if was witness, pop context
-      if (cur.getKind() == WITNESS)
+      if (cur.getKind() == Kind::WITNESS)
       {
         Assert(curr_subs.find(cur[0][0]) != curr_subs.end());
         curr_subs.erase(cur[0][0]);
@@ -542,19 +543,19 @@ Node BvInstantiator::rewriteTermForSolvePv(
 
   // [1] rewrite cases of non-invertible operators
 
-  if (n.getKind() == EQUAL)
+  if (n.getKind() == Kind::EQUAL)
   {
     TNode lhs = children[0];
     TNode rhs = children[1];
 
     /* rewrite: x * x = x -> x < 2 */
-    if ((lhs == pv && rhs.getKind() == BITVECTOR_MULT && rhs[0] == pv
+    if ((lhs == pv && rhs.getKind() == Kind::BITVECTOR_MULT && rhs[0] == pv
          && rhs[1] == pv)
-        || (rhs == pv && lhs.getKind() == BITVECTOR_MULT && lhs[0] == pv
+        || (rhs == pv && lhs.getKind() == Kind::BITVECTOR_MULT && lhs[0] == pv
             && lhs[1] == pv))
     {
       return nm->mkNode(
-          BITVECTOR_ULT,
+          Kind::BITVECTOR_ULT,
           pv,
           bv::utils::mkConst(BitVector(bv::utils::getSize(pv), Integer(2))));
     }
@@ -576,12 +577,13 @@ Node BvInstantiator::rewriteTermForSolvePv(
       return result;
     }
   }
-  else if (n.getKind() == BITVECTOR_MULT || n.getKind() == BITVECTOR_ADD)
+  else if (n.getKind() == Kind::BITVECTOR_MULT
+           || n.getKind() == Kind::BITVECTOR_ADD)
   {
     if (options().quantifiers.cegqiBvLinearize && contains_pv[n])
     {
       Node result;
-      if (n.getKind() == BITVECTOR_MULT)
+      if (n.getKind() == Kind::BITVECTOR_MULT)
       {
         result = d_util.normalizePvMult(pv, children, contains_pv);
       }
@@ -618,8 +620,8 @@ struct SortBvExtractInterval
 {
   bool operator()(Node i, Node j)
   {
-    Assert(i.getKind() == BITVECTOR_EXTRACT);
-    Assert(j.getKind() == BITVECTOR_EXTRACT);
+    Assert(i.getKind() == Kind::BITVECTOR_EXTRACT);
+    Assert(j.getKind() == Kind::BITVECTOR_EXTRACT);
     BitVectorExtract ie = i.getOperator().getConst<BitVectorExtract>();
     BitVectorExtract je = j.getOperator().getConst<BitVectorExtract>();
     if (ie.d_high > je.d_high)
@@ -703,7 +705,7 @@ void BvInstantiatorPreprocess::registerCounterexampleLemma(
         vars.push_back(var);
       }
 
-      Node conc = nm->mkNode(kind::BITVECTOR_CONCAT, children);
+      Node conc = nm->mkNode(Kind::BITVECTOR_CONCAT, children);
       Assert(conc.getType() == es.first.getType());
       Node eq_lem = conc.eqNode(es.first);
       Trace("cegqi-bv-pp") << "Introduced : " << eq_lem << std::endl;
@@ -743,11 +745,11 @@ void BvInstantiatorPreprocess::collectExtracts(
     if (visited.find(cur) == visited.end())
     {
       visited.insert(cur);
-      if (cur.getKind() != FORALL)
+      if (cur.getKind() != Kind::FORALL)
       {
-        if (cur.getKind() == BITVECTOR_EXTRACT)
+        if (cur.getKind() == Kind::BITVECTOR_EXTRACT)
         {
-          if (cur[0].getKind() == INST_CONSTANT)
+          if (cur[0].getKind() == Kind::INST_CONSTANT)
           {
             extract_map[cur[0]].push_back(cur);
           }
