@@ -73,7 +73,7 @@ void CegInstantiator::computeProgVars( Node n ){
   if( d_prog_var.find( n )==d_prog_var.end() ){
     d_prog_var[n].clear();
     Kind k = n.getKind();
-    if (k == kind::WITNESS)
+    if (k == Kind::WITNESS)
     {
       Assert(d_prog_var.find(n[0][0]) == d_prog_var.end());
       // ignore the bound variable
@@ -104,11 +104,12 @@ void CegInstantiator::computeProgVars( Node n ){
       d_prog_var[n].insert(d_prog_var[n[i]].begin(), d_prog_var[n[i]].end());
     }
     // selectors applied to program variables are also variables
-    if (k == APPLY_SELECTOR && d_prog_var[n].find(n[0]) != d_prog_var[n].end())
+    if (k == Kind::APPLY_SELECTOR
+        && d_prog_var[n].find(n[0]) != d_prog_var[n].end())
     {
       d_prog_var[n].insert(n);
     }
-    if (k == kind::WITNESS)
+    if (k == Kind::WITNESS)
     {
       d_prog_var.erase(n[0][0]);
     }
@@ -123,11 +124,13 @@ bool CegInstantiator::isEligible( Node n ) {
 
 CegHandledStatus CegInstantiator::isCbqiKind(Kind k)
 {
-  if (quantifiers::TermUtil::isBoolConnective(k) || k == ADD || k == GEQ
-      || k == EQUAL || k == MULT || k == NONLINEAR_MULT || k == DIVISION
-      || k == DIVISION_TOTAL || k == INTS_DIVISION || k == INTS_DIVISION_TOTAL
-      || k == INTS_MODULUS || k == INTS_MODULUS_TOTAL || k == TO_INTEGER
-      || k == IS_INTEGER || k == TO_REAL)
+  if (quantifiers::TermUtil::isBoolConnective(k) || k == Kind::ADD
+      || k == Kind::GEQ || k == Kind::EQUAL || k == Kind::MULT
+      || k == Kind::NONLINEAR_MULT || k == Kind::DIVISION
+      || k == Kind::DIVISION_TOTAL || k == Kind::INTS_DIVISION
+      || k == Kind::INTS_DIVISION_TOTAL || k == Kind::INTS_MODULUS
+      || k == Kind::INTS_MODULUS_TOTAL || k == Kind::TO_INTEGER
+      || k == Kind::IS_INTEGER || k == Kind::TO_REAL)
   {
     return CEG_HANDLED;
   }
@@ -156,9 +159,10 @@ CegHandledStatus CegInstantiator::isCbqiTerm(Node n)
     if (visited.find(cur) == visited.end())
     {
       visited.insert(cur);
-      if (cur.getKind() != BOUND_VARIABLE && TermUtil::hasBoundVarAttr(cur))
+      if (cur.getKind() != Kind::BOUND_VARIABLE
+          && TermUtil::hasBoundVarAttr(cur))
       {
-        if (cur.getKind() == FORALL || cur.getKind() == WITNESS)
+        if (cur.getKind() == Kind::FORALL || cur.getKind() == Kind::WITNESS)
         {
           visit.push_back(cur[1]);
         }
@@ -270,7 +274,7 @@ CegHandledStatus CegInstantiator::isCbqiQuantPrefix(Node q)
 
 CegHandledStatus CegInstantiator::isCbqiQuant(Node q, bool cegqiAll)
 {
-  Assert(q.getKind() == FORALL);
+  Assert(q.getKind() == Kind::FORALL);
   // compute attributes
   QAttributes qa;
   QuantAttributes::computeQuantAttributes(q, qa);
@@ -288,7 +292,7 @@ CegHandledStatus CegInstantiator::isCbqiQuant(Node q, bool cegqiAll)
   {
     for (const Node& pat : q[2])
     {
-      if (pat.getKind() == INST_PATTERN)
+      if (pat.getKind() == Kind::INST_PATTERN)
       {
         return CEG_UNHANDLED;
       }
@@ -999,7 +1003,7 @@ bool CegInstantiator::doAddInstantiation(std::vector<Node>& vars,
 bool CegInstantiator::isEligibleForInstantiation(Node n) const
 {
   Kind nk = n.getKind();
-  if (nk != INST_CONSTANT && nk != SKOLEM)
+  if (nk != Kind::INST_CONSTANT && nk != Kind::SKOLEM)
   {
     return true;
   }
@@ -1054,11 +1058,11 @@ Node CegInstantiator::applySubstitution( TypeNode tn, Node n, std::vector< Node
           Assert(vars[i].getType().isInteger());
           Assert(prop[i].d_coeff.isConst());
           Node nn = NodeManager::currentNM()->mkNode(
-              MULT,
+              Kind::MULT,
               subs[i],
               NodeManager::currentNM()->mkConstReal(
                   Rational(1) / prop[i].d_coeff.getConst<Rational>()));
-          nn = NodeManager::currentNM()->mkNode( kind::TO_INTEGER, nn );
+          nn = NodeManager::currentNM()->mkNode(Kind::TO_INTEGER, nn);
           nn = rewrite(nn);
           nsubs.push_back( nn );
         }else{
@@ -1089,7 +1093,8 @@ Node CegInstantiator::applySubstitution( TypeNode tn, Node n, std::vector< Node
               if( pv_prop.d_coeff.isNull() ){
                 pv_prop.d_coeff = prop[index].d_coeff;
               }else{
-                pv_prop.d_coeff = NodeManager::currentNM()->mkNode( MULT, pv_prop.d_coeff, prop[index].d_coeff );
+                pv_prop.d_coeff = NodeManager::currentNM()->mkNode(
+                    Kind::MULT, pv_prop.d_coeff, prop[index].d_coeff);
               }
             }
           }else{
@@ -1119,13 +1124,13 @@ Node CegInstantiator::applySubstitution( TypeNode tn, Node n, std::vector< Node
             if (!v.isNull())
             {
               Assert(v.getType() == type);
-              c = nm->mkNode(MULT, c, v);
+              c = nm->mkNode(Kind::MULT, c, v);
             }
             children.push_back( c );
             Trace("sygus-si-apply-subs-debug") << "Add child : " << c << std::endl;
           }
-          Node nretc =
-              children.size() == 1 ? children[0] : nm->mkNode(ADD, children);
+          Node nretc = children.size() == 1 ? children[0]
+                                            : nm->mkNode(Kind::ADD, children);
           nretc = rewrite(nretc);
           //ensure that nret does not contain vars
           if (!expr::hasSubterm(nretc, vars))
@@ -1158,21 +1163,25 @@ Node CegInstantiator::applySubstitutionToLiteral( Node lit, std::vector< Node >&
   if( is_basic ){
    lret = lit.substitute( vars.begin(), vars.end(), subs.begin(), subs.end() );
   }else{
-    Node atom = lit.getKind()==NOT ? lit[0] : lit;
-    bool pol = lit.getKind()!=NOT;
+    Node atom = lit.getKind() == Kind::NOT ? lit[0] : lit;
+    bool pol = lit.getKind() != Kind::NOT;
     //arithmetic inequalities and disequalities
-    if (atom.getKind() == GEQ
-        || (atom.getKind() == EQUAL && !pol && atom[0].getType().isRealOrInt()))
+    if (atom.getKind() == Kind::GEQ
+        || (atom.getKind() == Kind::EQUAL && !pol
+            && atom[0].getType().isRealOrInt()))
     {
       NodeManager* nm = NodeManager::currentNM();
-      Assert(atom.getKind() != GEQ || atom[1].isConst());
+      Assert(atom.getKind() != Kind::GEQ || atom[1].isConst());
       Node atom_lhs;
       Node atom_rhs;
-      if( atom.getKind()==GEQ ){
+      if (atom.getKind() == Kind::GEQ)
+      {
         atom_lhs = atom[0];
         atom_rhs = atom[1];
-      }else{
-        atom_lhs = nm->mkNode(SUB, atom[0], atom[1]);
+      }
+      else
+      {
+        atom_lhs = nm->mkNode(Kind::SUB, atom[0], atom[1]);
         atom_lhs = rewrite(atom_lhs);
         atom_rhs = nm->mkConstRealOrInt(atom_lhs.getType(), Rational(0));
       }
@@ -1189,7 +1198,7 @@ Node CegInstantiator::applySubstitutionToLiteral( Node lit, std::vector< Node >&
                                      atom_lhs_prop);
         if( !atom_lhs.isNull() ){
           if( !atom_lhs_prop.d_coeff.isNull() ){
-            atom_rhs = nm->mkNode(MULT, atom_lhs_prop.d_coeff, atom_rhs);
+            atom_rhs = nm->mkNode(Kind::MULT, atom_lhs_prop.d_coeff, atom_rhs);
             atom_rhs = rewrite(atom_rhs);
           }
           lret = nm->mkNode(atom.getKind(), atom_lhs, atom_rhs);
@@ -1275,7 +1284,7 @@ void CegInstantiator::processAssertions() {
          ++it)
     {
       Node lit = (*it).d_assertion;
-      Node atom = lit.getKind() == NOT ? lit[0] : lit;
+      Node atom = lit.getKind() == Kind::NOT ? lit[0] : lit;
       if (d_is_nested_quant
           || std::find(d_ce_atoms.begin(), d_ce_atoms.end(), atom)
                  != d_ce_atoms.end())
@@ -1411,7 +1420,7 @@ void CegInstantiator::collectCeAtoms(Node n)
     if (visited.find(cur) == visited.end())
     {
       visited.insert(cur);
-      if (cur.getKind() == FORALL)
+      if (cur.getKind() == Kind::FORALL)
       {
         d_is_nested_quant = true;
       }
