@@ -385,7 +385,7 @@ bool InstStrategyAutoGenTriggers::generatePatternTerms(Node f)
   int32_t last_weight = -1;
   for (const Node& p : patTermsF)
   {
-    Assert(p.getKind() != NOT);
+    Assert(p.getKind() != Kind::NOT);
     bool newVar = false;
     inst::TriggerTermInfo& tip = tinfo[p];
     for (const Node& v : tip.d_fv)
@@ -438,7 +438,7 @@ bool InstStrategyAutoGenTriggers::generatePatternTerms(Node f)
       }
       for (size_t i = 0; i < 2; i++)
       {
-        d_vc_partition[i][f] = nm->mkNode(BOUND_VAR_LIST, vcs[i]);
+        d_vc_partition[i][f] = nm->mkNode(Kind::BOUND_VAR_LIST, vcs[i]);
       }
     }
     else
@@ -574,15 +574,15 @@ void InstStrategyAutoGenTriggers::addTrigger( inst::Trigger * tr, Node q ) {
     // partial trigger : generate implication to mark user pattern
     Node pat =
         d_qreg.substituteInstConstantsToBoundVariables(tr->getInstPattern(), q);
-    Node ipl = nm->mkNode(INST_PATTERN_LIST, pat);
-    Node qq = nm->mkNode(FORALL,
+    Node ipl = nm->mkNode(Kind::INST_PATTERN_LIST, pat);
+    Node qq = nm->mkNode(Kind::FORALL,
                          d_vc_partition[1][q],
-                         nm->mkNode(FORALL, d_vc_partition[0][q], q[1]),
+                         nm->mkNode(Kind::FORALL, d_vc_partition[0][q], q[1]),
                          ipl);
     Trace("auto-gen-trigger-partial")
         << "Make partially specified user pattern: " << std::endl;
     Trace("auto-gen-trigger-partial") << "  " << qq << std::endl;
-    Node lem = nm->mkNode(OR, q.negate(), qq);
+    Node lem = nm->mkNode(Kind::OR, q.negate(), qq);
     d_qim.addPendingLemma(lem, InferenceId::QUANTIFIERS_PARTIAL_TRIGGER_REDUCE);
     return;
   }
@@ -625,7 +625,7 @@ bool InstStrategyAutoGenTriggers::hasUserPatterns( Node q ) {
   bool hasPat = false;
   for (const Node& ip : q[2])
   {
-    if (ip.getKind() == INST_PATTERN)
+    if (ip.getKind() == Kind::INST_PATTERN)
     {
       hasPat = true;
       break;
@@ -636,7 +636,7 @@ bool InstStrategyAutoGenTriggers::hasUserPatterns( Node q ) {
 }
 
 void InstStrategyAutoGenTriggers::addUserNoPattern( Node q, Node pat ) {
-  Assert(pat.getKind() == INST_NO_PATTERN && pat.getNumChildren() == 1);
+  Assert(pat.getKind() == Kind::INST_NO_PATTERN && pat.getNumChildren() == 1);
   std::vector<Node>& ung = d_user_no_gen[q];
   if (std::find(ung.begin(), ung.end(), pat[0]) == ung.end())
   {
