@@ -34,59 +34,90 @@ PatternTermSelector::PatternTermSelector(const Options& opts,
                                          options::TriggerSelMode tstrt,
                                          const std::vector<Node>& exc,
                                          bool filterInst)
-    : d_opts(opts),
-      d_quant(q),
+    : d_quant(q),
       d_tstrt(tstrt),
       d_excluded(exc),
-      d_filterInst(filterInst)
+      d_filterInst(filterInst),
+      d_purifyTriggers(opts.quantifiers.purifyTriggers),
+      d_relTriggers(opts.quantifiers.relationalTriggers)
+{
+}
+
+PatternTermSelector::PatternTermSelector(Node q,
+                                         options::TriggerSelMode tstrt,
+                                         const std::vector<Node>& exc,
+                                         bool filterInst,
+                                         bool purifyTriggers,
+                                         bool relationalTriggers)
+    : d_quant(q),
+      d_tstrt(tstrt),
+      d_excluded(exc),
+      d_filterInst(filterInst),
+      d_purifyTriggers(purifyTriggers),
+      d_relTriggers(relationalTriggers)
 {
 }
 
 PatternTermSelector::~PatternTermSelector() {}
 
-bool PatternTermSelector::isUsable(const Options& opts, Node n, Node q)
+bool PatternTermSelector::isUsable(Node n, Node q) const
 {
-  if (quantifiers::TermUtil::getInstConstAttr(n) != q)
+  std::unordered_set<TNode> visited;
+  std::vector<TNode> visit;
+  TNode cur;
+  visit.push_back(n);
+  do
   {
-    return true;
-  }
-  if (TriggerTermInfo::isAtomicTrigger(n))
-  {
-    for (const Node& nc : n)
+    cur = visit.back();
+    visit.pop_back();
+    if (visited.find(cur) != visited.end())
     {
-      if (!isUsable(opts, nc, q))
+      continue;
+    }
+    visited.insert(cur);
+    if (quantifiers::TermUtil::getInstConstAttr(cur) != q)
+    {
+      continue;
+    }
+    if (TriggerTermInfo::isAtomicTrigger(cur))
+    {
+      visit.insert(visit.end(), cur.begin(), cur.end());
+      continue;
+    }
+    else if (cur.getKind() == Kind::INST_CONSTANT)
+    {
+      continue;
+    }
+    if (d_purifyTriggers)
+    {
+      Node x = getInversionVariable(cur);
+      if (!x.isNull())
       {
-        return false;
+        continue;
       }
     }
-    return true;
-  }
-  else if (n.getKind() == INST_CONSTANT)
-  {
-    return true;
-  }
-  if (opts.quantifiers.purifyTriggers)
-  {
-    Node x = getInversionVariable(n);
-    if (!x.isNull())
-    {
-      return true;
-    }
-  }
-  return false;
+    return false;
+  } while (!visit.empty());
+  return true;
 }
 
-Node PatternTermSelector::getIsUsableEq(const Options& opts, Node q, Node n)
+Node PatternTermSelector::getIsUsableEq(Node q, Node n) const
 {
   Assert(TriggerTermInfo::isRelationalTrigger(n));
+  // if not relational triggers, we should only consider this if we are of the
+  // form f(x) = c.
+  if (!d_relTriggers && n.getKind() != Kind::EQUAL)
+  {
+    return Node::null();
+  }
   for (size_t i = 0; i < 2; i++)
   {
-    if (isUsableEqTerms(opts, q, n[i], n[1 - i]))
+    if (isUsableEqTerms(q, n[i], n[1 - i]))
     {
-      if (i == 1 && n.getKind() == EQUAL
+      if (i == 1 && n.getKind() == Kind::EQUAL
           && !quantifiers::TermUtil::hasInstConstAttr(n[0]))
       {
-        return NodeManager::currentNM()->mkNode(EQUAL, n[1], n[0]);
+        return NodeManager::currentNM()->mkNode(Kind::EQUAL, n[1], n[0]);
       }
       else
       {
@@ -97,14 +128,11 @@ Node PatternTermSelector::getIsUsableEq(const Options& opts, Node q, Node n)
   return Node::null();
 }
 
-bool PatternTermSelector::isUsableEqTerms(const Options& opts,
-                                          Node q,
-                                          Node n1,
-                                          Node n2)
+bool PatternTermSelector::isUsableEqTerms(Node q, Node n1, Node n2) const
 {
-  if (n1.getKind() == INST_CONSTANT)
+  if (n1.getKind() == Kind::INST_CONSTANT)
   {
-    if (opts.quantifiers.relationalTriggers)
+    if (d_relTriggers)
     {
       Node q1 = quantifiers::TermUtil::getInstConstAttr(n1);
       if (q1 != q)
@@ -118,7 +146,7 @@ bool PatternTermSelector::isUsableEqTerms(const Options& opts,
         // x = c
         return true;
       }
-      if (n2.getKind() == INST_CONSTANT && q2 == q)
+      if (n2.getKind() == Kind::INST_CONSTANT && q2 == q)
       {
         // x = y
         return true;
@@ -127,43 +155,42 @@ bool PatternTermSelector::isUsableEqTerms(const Options& opts,
       // when n1 and n2 are swapped
     }
   }
-  else if (isUsableAtomicTrigger(opts, n1, q))
+  else if (isUsableAtomicTrigger(n1, q))
   {
-    if (opts.quantifiers.relationalTriggers && n2.getKind() == INST_CONSTANT
+    // only consider this form if we are doing relational triggers
+    if (d_relTriggers && n2.getKind() == Kind::INST_CONSTANT
         && quantifiers::TermUtil::getInstConstAttr(n2) == q
         && !expr::hasSubterm(n1, n2))
     {
-      // f(x) = y
+      // f(x) ~ y
       return true;
     }
     else if (!quantifiers::TermUtil::hasInstConstAttr(n2))
     {
-      // f(x) = c
+      // f(x) ~ c
       return true;
     }
   }
   return false;
 }
 
-Node PatternTermSelector::getIsUsableTrigger(const Options& opts,
-                                             Node n,
-                                             Node q)
+Node PatternTermSelector::getIsUsableTrigger(Node n, Node q) const
 {
   bool pol = true;
   Trace("trigger-debug") << "Is " << n << " a usable trigger?" << std::endl;
-  if (n.getKind() == NOT)
+  if (n.getKind() == Kind::NOT)
   {
     pol = !pol;
     n = n[0];
   }
   NodeManager* nm = NodeManager::currentNM();
-  if (n.getKind() == INST_CONSTANT)
+  if (n.getKind() == Kind::INST_CONSTANT)
   {
-    return pol ? n : nm->mkNode(EQUAL, n, nm->mkConst(true)).notNode();
+    return pol ? n : nm->mkNode(Kind::EQUAL, n, nm->mkConst(true)).notNode();
   }
   else if (TriggerTermInfo::isRelationalTrigger(n))
   {
-    Node rtr = getIsUsableEq(opts, q, n);
+    Node rtr = getIsUsableEq(q, n);
     if (rtr.isNull() && n[0].getType().isRealOrInt())
     {
       // try to solve relation
@@ -175,11 +202,11 @@ Node PatternTermSelector::getIsUsableTrigger(const Options& opts,
           bool trySolve = false;
           if (!it->first.isNull())
           {
-            if (it->first.getKind() == INST_CONSTANT)
+            if (it->first.getKind() == Kind::INST_CONSTANT)
             {
-              trySolve = opts.quantifiers.relationalTriggers;
+              trySolve = d_relTriggers;
             }
-            else if (isUsableTrigger(opts, it->first, q))
+            else if (isUsableTrigger(it->first, q))
             {
               trySolve = true;
             }
@@ -191,7 +218,7 @@ Node PatternTermSelector::getIsUsableTrigger(const Options& opts,
             Node veq;
             if (ArithMSum::isolate(it->first, m, veq, n.getKind()) != 0)
             {
-              rtr = getIsUsableEq(opts, q, veq);
+              rtr = getIsUsableEq(q, veq);
             }
             // either all solves will succeed or all solves will fail
             break;
@@ -214,25 +241,23 @@ Node PatternTermSelector::getIsUsableTrigger(const Options& opts,
   Trace("trigger-debug") << n << " usable : "
                          << (quantifiers::TermUtil::getInstConstAttr(n) == q)
                          << " " << TriggerTermInfo::isAtomicTrigger(n) << " "
-                         << isUsable(opts, n, q) << std::endl;
-  if (isUsableAtomicTrigger(opts, n, q))
+                         << isUsable(n, q) << std::endl;
+  if (isUsableAtomicTrigger(n, q))
   {
-    return pol ? n : nm->mkNode(EQUAL, n, nm->mkConst(true)).notNode();
+    return pol ? n : nm->mkNode(Kind::EQUAL, n, nm->mkConst(true)).notNode();
   }
   return Node::null();
 }
 
-bool PatternTermSelector::isUsableAtomicTrigger(const Options& opts,
-                                                Node n,
-                                                Node q)
+bool PatternTermSelector::isUsableAtomicTrigger(Node n, Node q) const
 {
   return quantifiers::TermUtil::getInstConstAttr(n) == q
-         && TriggerTermInfo::isAtomicTrigger(n) && isUsable(opts, n, q);
+         && TriggerTermInfo::isAtomicTrigger(n) && isUsable(n, q);
 }
 
-bool PatternTermSelector::isUsableTrigger(const Options& opts, Node n, Node q)
+bool PatternTermSelector::isUsableTrigger(Node n, Node q) const
 {
-  Node nu = getIsUsableTrigger(opts, n, q);
+  Node nu = getIsUsableTrigger(n, q);
   return !nu.isNull();
 }
 
@@ -268,7 +293,7 @@ void PatternTermSelector::collectTermsInternal(
       << "Collect pat terms " << n << " " << pol << " " << hasPol << " " << epol
       << " " << hasEPol << std::endl;
   Kind nk = n.getKind();
-  if (n.isClosure() || nk == INST_CONSTANT)
+  if (n.isClosure() || nk == Kind::INST_CONSTANT)
   {
     // do not traverse beneath quantified formulas
     return;
@@ -279,11 +304,11 @@ void PatternTermSelector::collectTermsInternal(
   {
     nu = n;
   }
-  else if (nk != NOT
+  else if (nk != Kind::NOT
            && std::find(d_excluded.begin(), d_excluded.end(), n)
                   == d_excluded.end())
   {
-    nu = getIsUsableTrigger(d_opts, n, d_quant);
+    nu = getIsUsableTrigger(n, d_quant);
     if (!nu.isNull() && nu != n)
     {
       collectTermsInternal(
@@ -296,11 +321,11 @@ void PatternTermSelector::collectTermsInternal(
   if (!nu.isNull())
   {
     Assert(nu == n);
-    Assert(nu.getKind() != NOT);
+    Assert(nu.getKind() != Kind::NOT);
     Trace("auto-gen-trigger-debug2")
         << "...found usable trigger : " << nu << std::endl;
     Node reqEq;
-    if (nu.getKind() == EQUAL)
+    if (nu.getKind() == Kind::EQUAL)
     {
       if (TriggerTermInfo::isAtomicTrigger(nu[0])
           && !quantifiers::TermUtil::hasInstConstAttr(nu[1]))
@@ -313,7 +338,7 @@ void PatternTermSelector::collectTermsInternal(
       }
     }
     Assert(reqEq.isNull() || !quantifiers::TermUtil::hasInstConstAttr(reqEq));
-    Assert(isUsableTrigger(d_opts, nu, d_quant));
+    Assert(isUsableTrigger(nu, d_quant));
     Trace("auto-gen-trigger-debug2")
         << "...add usable trigger : " << nu << std::endl;
     tinfo[nu].init(d_quant, nu, hasEPol ? (epol ? 1 : -1) : 0, reqEq);
@@ -480,7 +505,7 @@ void PatternTermSelector::collectInternal(
 int PatternTermSelector::isInstanceOf(Node n1,
                                       Node n2,
                                       const std::vector<Node>& fv1,
-                                      const std::vector<Node>& fv2)
+                                      const std::vector<Node>& fv2) const
 {
   Assert(n1 != n2);
   int status = 0;
@@ -510,7 +535,7 @@ int PatternTermSelector::isInstanceOf(Node n1,
     if (cur1.hasOperator() && cur2.hasOperator()
         && cur1.getNumChildren() == cur2.getNumChildren()
         && cur1.getOperator() == cur2.getOperator()
-        && cur1.getOperator().getKind() != INST_CONSTANT)
+        && cur1.getOperator().getKind() != Kind::INST_CONSTANT)
     {
       visit.push_back(std::pair<TNode, TNode>(cur1, cur2));
       for (size_t i = 0, size = cur1.getNumChildren(); i < size; i++)
@@ -519,7 +544,7 @@ int PatternTermSelector::isInstanceOf(Node n1,
         {
           visit.push_back(std::pair<TNode, TNode>(cur1[i], cur2[i]));
         }
-        else if (cur1[i].getKind() == INST_CONSTANT)
+        else if (cur1[i].getKind() == Kind::INST_CONSTANT)
         {
           if (subs_vars.find(cur1[i]) != subs_vars.end())
           {
@@ -539,7 +564,7 @@ int PatternTermSelector::isInstanceOf(Node n1,
       if (status == 0 || ((status == 1) == (r == 0)))
       {
         TNode curi = r == 0 ? cur1 : cur2;
-        if (curi.getKind() == INST_CONSTANT
+        if (curi.getKind() == Kind::INST_CONSTANT
             && subs_vars.find(curi) == subs_vars.end())
         {
           TNode curj = r == 0 ? cur2 : cur1;
@@ -568,7 +593,7 @@ int PatternTermSelector::isInstanceOf(Node n1,
   return status;
 }
 
-void PatternTermSelector::filterInstances(std::vector<Node>& nodes)
+void PatternTermSelector::filterInstances(std::vector<Node>& nodes) const
 {
   std::map<unsigned, std::vector<Node> > fvs;
   for (size_t i = 0, size = nodes.size(); i < size; i++)
@@ -621,11 +646,11 @@ void PatternTermSelector::filterInstances(std::vector<Node>& nodes)
 Node PatternTermSelector::getInversionVariable(Node n)
 {
   Kind nk = n.getKind();
-  if (nk == INST_CONSTANT)
+  if (nk == Kind::INST_CONSTANT)
   {
     return n;
   }
-  else if (nk == ADD || nk == MULT)
+  else if (nk == Kind::ADD || nk == Kind::MULT)
   {
     Node ret;
     for (const Node& nc : n)
@@ -647,7 +672,7 @@ Node PatternTermSelector::getInversionVariable(Node n)
           return Node::null();
         }
       }
-      else if (nk == MULT)
+      else if (nk == Kind::MULT)
       {
         if (!nc.isConst())
         {
@@ -667,11 +692,11 @@ Node PatternTermSelector::getInversionVariable(Node n)
 Node PatternTermSelector::getInversion(Node n, Node x)
 {
   Kind nk = n.getKind();
-  if (nk == INST_CONSTANT)
+  if (nk == Kind::INST_CONSTANT)
   {
     return x;
   }
-  else if (nk == ADD || nk == MULT)
+  else if (nk == Kind::ADD || nk == Kind::MULT)
   {
     NodeManager* nm = NodeManager::currentNM();
     int cindex = -1;
@@ -681,11 +706,11 @@ Node PatternTermSelector::getInversion(Node n, Node x)
       Node nc = n[i];
       if (!quantifiers::TermUtil::hasInstConstAttr(nc))
       {
-        if (nk == ADD)
+        if (nk == Kind::ADD)
         {
-          x = nm->mkNode(SUB, x, nc);
+          x = nm->mkNode(Kind::SUB, x, nc);
         }
-        else if (nk == MULT)
+        else if (nk == Kind::MULT)
         {
           Assert(nc.isConst());
           if (x.getType().isInteger())
@@ -693,17 +718,17 @@ Node PatternTermSelector::getInversion(Node n, Node x)
             Node coeff = nm->mkConstInt(nc.getConst<Rational>().abs());
             if (!nc.getConst<Rational>().abs().isOne())
             {
-              x = nm->mkNode(INTS_DIVISION_TOTAL, x, coeff);
+              x = nm->mkNode(Kind::INTS_DIVISION_TOTAL, x, coeff);
             }
             if (nc.getConst<Rational>().sgn() < 0)
             {
-              x = nm->mkNode(NEG, x);
+              x = nm->mkNode(Kind::NEG, x);
             }
           }
           else
           {
             Node coeff = nm->mkConstReal(Rational(1) / nc.getConst<Rational>());
-            x = nm->mkNode(MULT, x, coeff);
+            x = nm->mkNode(Kind::MULT, x, coeff);
           }
         }
       }
