@@ -240,10 +240,14 @@ void Def::simplify(FullModelChecker * mc, FirstOrderModelFmc * m) {
       }
     }
     if( !last_all_stars ){
-      Trace("fmc-cover-simplify") << "Need to modify last entry to be all stars." << std::endl;
-      Trace("fmc-cover-simplify") << "Before: " << std::endl;
-      debugPrint("fmc-cover-simplify",Node::null(), mc);
-      Trace("fmc-cover-simplify") << std::endl;
+      if (TraceIsOn("fmc-cover-simplify"))
+      {
+        Trace("fmc-cover-simplify")
+            << "Need to modify last entry to be all stars." << std::endl;
+        Trace("fmc-cover-simplify") << "Before: " << std::endl;
+        debugPrint("fmc-cover-simplify", Node::null(), mc);
+        Trace("fmc-cover-simplify") << std::endl;
+      }
       std::vector< Node > cond;
       cond.insert( cond.end(), d_cond.begin(), d_cond.end() );
       d_cond.clear();
@@ -258,16 +262,20 @@ void Def::simplify(FullModelChecker * mc, FirstOrderModelFmc * m) {
       for( unsigned j=0; j< cc.getNumChildren(); j++){
         nc.push_back(m->getStar(cc[j].getType()));
       }
-      cond[cond.size()-1] = NodeManager::currentNM()->mkNode( APPLY_UF, nc );
+      cond[cond.size() - 1] =
+          NodeManager::currentNM()->mkNode(Kind::APPLY_UF, nc);
       //re-add the entries
       for (unsigned i=0; i<cond.size(); i++) {
         addEntry(m, cond[i], value[i]);
       }
       Trace("fmc-cover-simplify") << "Finished re-adding entries." << std::endl;
       basic_simplify( m );
-      Trace("fmc-cover-simplify") << "After: " << std::endl;
-      debugPrint("fmc-cover-simplify",Node::null(), mc);
-      Trace("fmc-cover-simplify") << std::endl;
+      if (TraceIsOn("fmc-cover-simplify"))
+      {
+        Trace("fmc-cover-simplify") << "After: " << std::endl;
+        debugPrint("fmc-cover-simplify", Node::null(), mc);
+        Trace("fmc-cover-simplify") << std::endl;
+      }
     }
   }
   Trace("fmc-simplify") << "finish simplify, #cond = " << d_cond.size() << std::endl;
@@ -361,6 +369,12 @@ bool FullModelChecker::processBuildModel(TheoryModel* m){
     // nothing to do if no functions
     return true;
   }
+  // if higher-order, we must use the standard assignment method
+  if (logicInfo().isHigherOrder())
+  {
+    TheoryEngineModelBuilder::assignFunctions(m);
+    return true;
+  }
   FirstOrderModelFmc* fm = d_fm.get();
   Trace("fmc") << "---Full Model Check reset() " << std::endl;
   d_quant_models.clear();
@@ -484,7 +498,7 @@ bool FullModelChecker::processBuildModel(TheoryModel* m){
         }
         entry_children.push_back(ri);
       }
-      Node n = NodeManager::currentNM()->mkNode( APPLY_UF, children );
+      Node n = NodeManager::currentNM()->mkNode(Kind::APPLY_UF, children);
       Node nv = fm->getRepresentative( v );
       Trace("fmc-model-debug")
           << "Representative of " << v << " is " << nv << std::endl;
@@ -492,7 +506,7 @@ bool FullModelChecker::processBuildModel(TheoryModel* m){
         Trace("fmc-warn") << "Warning : model for " << op << " has non-constant value in model " << nv << std::endl;
       }
       Node en = hasNonStar ? n
-                           : NodeManager::currentNM()->mkNode(APPLY_UF,
+                           : NodeManager::currentNM()->mkNode(Kind::APPLY_UF,
                                                               entry_children);
       if( std::find(conds.begin(), conds.end(), n )==conds.end() ){
         Trace("fmc-model-debug") << "- add " << n << " -> " << nv << " (entry is " << en << ")" << std::endl;
@@ -520,15 +534,21 @@ bool FullModelChecker::processBuildModel(TheoryModel* m){
       fm->d_models[op]->addEntry(fm, entry_conds[indices[i]], values[indices[i]]);
     }
 
-    Trace("fmc-model-simplify") << "Before simplification : " << std::endl;
-    fm->d_models[op]->debugPrint("fmc-model-simplify", op, this);
-    Trace("fmc-model-simplify") << std::endl;
+    if (TraceIsOn("fmc-model-simplify"))
+    {
+      Trace("fmc-model-simplify") << "Before simplification : " << std::endl;
+      fm->d_models[op]->debugPrint("fmc-model-simplify", op, this);
+      Trace("fmc-model-simplify") << std::endl;
+    }
 
     Trace("fmc-model-simplify") << "Simplifying " << op << "..." << std::endl;
     fm->d_models[op]->simplify( this, fm );
 
-    fm->d_models[op]->debugPrint("fmc-model", op, this);
-    Trace("fmc-model") << std::endl;
+    if (TraceIsOn("fmc-model"))
+    {
+      fm->d_models[op]->debugPrint("fmc-model", op, this);
+      Trace("fmc-model") << std::endl;
+    }
 
     //for debugging
     /*
@@ -556,6 +576,7 @@ bool FullModelChecker::processBuildModel(TheoryModel* m){
     if (!m->hasAssignedFunctionDefinition(it->first))
     {
       Node f_def = getFunctionValue(fm, it->first, "$x");
+      Trace("model-builder-debug") << "...assign via fmc" << std::endl;
       m->assignFunctionDefinition(it->first, f_def);
     }
   }
@@ -660,10 +681,14 @@ int FullModelChecker::doExhaustiveInstantiation( FirstOrderModel * fm, Node f, i
     // model check the quantifier
     doCheck(fmfmc, f, d_quant_models[f], f[1]);
     std::vector<Node>& mcond = d_quant_models[f].d_cond;
-    Trace("fmc") << "Definition for quantifier " << f << " is : " << std::endl;
     Assert(!mcond.empty());
-    d_quant_models[f].debugPrint("fmc", Node::null(), this);
-    Trace("fmc") << std::endl;
+    if (TraceIsOn("fmc"))
+    {
+      Trace("fmc") << "Definition for quantifier " << f
+                   << " is : " << std::endl;
+      d_quant_models[f].debugPrint("fmc", Node::null(), this);
+      Trace("fmc") << std::endl;
+    }
 
     // consider all entries going to non-true
     Instantiate* instq = d_qim.getInstantiate();
@@ -862,9 +887,12 @@ bool FullModelChecker::exhaustiveInstantiate(FirstOrderModelFmc* fm,
                                              Node f,
                                              Node c)
 {
-  Trace("fmc-exh") << "----Exhaustive instantiate based on " << c << " ";
-  debugPrintCond("fmc-exh", c, true);
-  Trace("fmc-exh")<< std::endl;
+  if (TraceIsOn("fmc-exh"))
+  {
+    Trace("fmc-exh") << "----Exhaustive instantiate based on " << c << " ";
+    debugPrintCond("fmc-exh", c, true);
+    Trace("fmc-exh") << std::endl;
+  }
   QuantifiersBoundInference& qbi = d_qreg.getQuantifiersBoundInference();
   RepBoundFmcEntry rbfe(d_env, qbi, d_qstate, d_treg, f, c, d_fm.get());
   RepSetIterator riter(fm->getRepSet(), &rbfe);
@@ -890,8 +918,11 @@ bool FullModelChecker::exhaustiveInstantiate(FirstOrderModelFmc* fm,
         // constants do not appear in instantiations.
         Node rr = riter.getCurrentTerm(i, !tn.isClosedEnumerable());
         Node r = fm->getRepresentative(rr);
-        debugPrint("fmc-exh-debug", r);
-        Trace("fmc-exh-debug") << " (term : " << rr << ")";
+        if (TraceIsOn("fmc-exh-debug"))
+        {
+          debugPrint("fmc-exh-debug", r);
+          Trace("fmc-exh-debug") << " (term : " << rr << ")";
+        }
         ev_inst.push_back( r );
         inst.push_back( rr );
       }
@@ -950,16 +981,20 @@ void FullModelChecker::doCheck(FirstOrderModelFmc * fm, Node f, Def & d, Node n
   if( n.hasAttribute(BoundIntLitAttribute()) ){
     Trace("fmc-debug") << "It is a bounding literal, polarity = " << n.getAttribute(BoundIntLitAttribute()) << std::endl;
     d.addEntry(fm, mkCondDefault(fm, f), n.getAttribute(BoundIntLitAttribute())==1 ? d_false : d_true );
-  }else if( n.getKind() == kind::BOUND_VARIABLE ){
+  }
+  else if (n.getKind() == Kind::BOUND_VARIABLE)
+  {
     Trace("fmc-debug") << "Add default entry..." << std::endl;
     d.addEntry(fm, mkCondDefault(fm, f), n);
   }
-  else if( n.getKind() == kind::NOT ){
+  else if (n.getKind() == Kind::NOT)
+  {
     //just do directly
     doCheck( fm, f, d, n[0] );
     doNegate( d );
   }
-  else if( n.getKind() == kind::FORALL ){
+  else if (n.getKind() == Kind::FORALL)
+  {
     d.addEntry(fm, mkCondDefault(fm, f), Node::null());
   }
   else if( n.getType().isArray() ){
@@ -994,12 +1029,14 @@ void FullModelChecker::doCheck(FirstOrderModelFmc * fm, Node f, Def & d, Node n
       Def dc;
       doCheck(fm, f, dc, n[i]);
       children.push_back(dc);
-      if( n[i].getKind() == kind::BOUND_VARIABLE ){
+      if (n[i].getKind() == Kind::BOUND_VARIABLE)
+      {
         var_ch.push_back(i);
       }
     }
 
-    if( n.getKind()==APPLY_UF ){
+    if (n.getKind() == Kind::APPLY_UF)
+    {
       Trace("fmc-debug") << "Do uninterpreted compose " << n << std::endl;
       //uninterpreted compose
       doUninterpretedCompose( fm, f, d, n.getOperator(), children );
@@ -1013,9 +1050,12 @@ void FullModelChecker::doCheck(FirstOrderModelFmc * fm, Node f, Def & d, Node n
       std::vector< Node > val;
       doUninterpretedCompose(fm, f, d, children[0], children2, 0, cond, val );
       */
-    } else {
+    }
+    else
+    {
       if( !var_ch.empty() ){
-        if( n.getKind()==EQUAL && !n[0].getType().isBoolean() ){
+        if (n.getKind() == Kind::EQUAL && !n[0].getType().isBoolean())
+        {
           if( var_ch.size()==2 ){
             Trace("fmc-debug") << "Do variable equality " << n << std::endl;
             doVariableEquality( fm, f, d, n );
@@ -1023,7 +1063,9 @@ void FullModelChecker::doCheck(FirstOrderModelFmc * fm, Node f, Def & d, Node n
             Trace("fmc-debug") << "Do variable relation " << n << std::endl;
             doVariableRelation( fm, f, d, var_ch[0]==0 ? children[1] : children[0], var_ch[0]==0 ? n[0] : n[1] );
           }
-        }else{
+        }
+        else
+        {
           Trace("fmc-warn") << "Don't know how to check " << n << std::endl;
           d.addEntry(fm, mkCondDefault(fm, f), Node::null());
         }
@@ -1036,14 +1078,20 @@ void FullModelChecker::doCheck(FirstOrderModelFmc * fm, Node f, Def & d, Node n
         doInterpretedCompose( fm, f, d, n, children, 0, cond, val );
       }
     }
-    Trace("fmc-debug") << "Simplify the definition..." << std::endl;
-    d.debugPrint("fmc-debug", Node::null(), this);
+    if (TraceIsOn("fmc-debug"))
+    {
+      Trace("fmc-debug") << "Simplify the definition..." << std::endl;
+      d.debugPrint("fmc-debug", Node::null(), this);
+    }
     d.simplify(this, fm);
     Trace("fmc-debug") << "Done simplifying" << std::endl;
   }
-  Trace("fmc-debug") << "Definition for " << n << " is : " << std::endl;
-  d.debugPrint("fmc-debug", Node::null(), this);
-  Trace("fmc-debug") << std::endl;
+  if (TraceIsOn("fmc-debug"))
+  {
+    Trace("fmc-debug") << "Definition for " << n << " is : " << std::endl;
+    d.debugPrint("fmc-debug", Node::null(), this);
+    Trace("fmc-debug") << std::endl;
+  }
 }
 
 void FullModelChecker::doNegate( Def & dc ) {
@@ -1120,9 +1168,12 @@ void FullModelChecker::doVariableRelation( FirstOrderModelFmc * fm, Node f, Def
 }
 
 void FullModelChecker::doUninterpretedCompose( FirstOrderModelFmc * fm, Node f, Def & d, Node op, std::vector< Def > & dc ) {
-  Trace("fmc-uf-debug") << "Definition : " << std::endl;
-  fm->d_models[op]->debugPrint("fmc-uf-debug", op, this);
-  Trace("fmc-uf-debug") << std::endl;
+  if (TraceIsOn("fmc-uf-debug"))
+  {
+    Trace("fmc-uf-debug") << "Definition : " << std::endl;
+    fm->d_models[op]->debugPrint("fmc-uf-debug", op, this);
+    Trace("fmc-uf-debug") << std::endl;
+  }
 
   std::vector< Node > cond;
   mkCondDefaultVec(fm, f, cond);
@@ -1133,12 +1184,16 @@ void FullModelChecker::doUninterpretedCompose( FirstOrderModelFmc * fm, Node f,
 void FullModelChecker::doUninterpretedCompose( FirstOrderModelFmc * fm, Node f, Def & d,
                                                Def & df, std::vector< Def > & dc, int index,
                                                std::vector< Node > & cond, std::vector<Node> & val ) {
-  Trace("fmc-uf-process") << "process at " << index << std::endl;
-  for( unsigned i=1; i<cond.size(); i++) {
-    debugPrint("fmc-uf-process", cond[i], true);
-    Trace("fmc-uf-process") << " ";
+  if (TraceIsOn("fmc-uf-process"))
+  {
+    Trace("fmc-uf-process") << "process at " << index << std::endl;
+    for (unsigned i = 1; i < cond.size(); i++)
+    {
+      debugPrint("fmc-uf-process", cond[i], true);
+      Trace("fmc-uf-process") << " ";
+    }
+    Trace("fmc-uf-process") << std::endl;
   }
-  Trace("fmc-uf-process") << std::endl;
   if (index==(int)dc.size()) {
     //we have an entry, now do actual compose
     std::map< int, Node > entries;
@@ -1177,12 +1232,17 @@ void FullModelChecker::doUninterpretedCompose2( FirstOrderModelFmc * fm, Node f,
                                                 std::map< int, Node > & entries, int index,
                                                 std::vector< Node > & cond, std::vector< Node > & val,
                                                 EntryTrie & curr ) {
-  Trace("fmc-uf-process") << "compose " << index << " / " << val.size() << std::endl;
-  for( unsigned i=1; i<cond.size(); i++) {
-    debugPrint("fmc-uf-process", cond[i], true);
-    Trace("fmc-uf-process") << " ";
+  if (TraceIsOn("fmc-uf-process"))
+  {
+    Trace("fmc-uf-process")
+        << "compose " << index << " / " << val.size() << std::endl;
+    for (unsigned i = 1; i < cond.size(); i++)
+    {
+      debugPrint("fmc-uf-process", cond[i], true);
+      Trace("fmc-uf-process") << " ";
+    }
+    Trace("fmc-uf-process") << std::endl;
   }
-  Trace("fmc-uf-process") << std::endl;
   if (index==(int)val.size()) {
     Node c = mkCond(cond);
     Trace("fmc-uf-entry") << "Entry : " << c << " -> index[" << curr.d_data << "]" << std::endl;
@@ -1191,7 +1251,8 @@ void FullModelChecker::doUninterpretedCompose2( FirstOrderModelFmc * fm, Node f,
     Node v = val[index];
     Trace("fmc-uf-process") << "Process " << v << std::endl;
     bool bind_var = false;
-    if( !v.isNull() && v.getKind()==kind::BOUND_VARIABLE ){
+    if (!v.isNull() && v.getKind() == Kind::BOUND_VARIABLE)
+    {
       int j = fm->getVariableId(f, v);
       Trace("fmc-uf-process") << v << " is variable #" << j << std::endl;
       if (!fm->isStar(cond[j + 1]))
@@ -1237,12 +1298,17 @@ void FullModelChecker::doUninterpretedCompose2( FirstOrderModelFmc * fm, Node f,
 void FullModelChecker::doInterpretedCompose( FirstOrderModelFmc * fm, Node f, Def & d, Node n,
                                              std::vector< Def > & dc, int index,
                                              std::vector< Node > & cond, std::vector<Node> & val ) {
-  Trace("fmc-if-process") << "int compose " << index << " / " << dc.size() << std::endl;
-  for( unsigned i=1; i<cond.size(); i++) {
-    debugPrint("fmc-if-process", cond[i], true);
-    Trace("fmc-if-process") << " ";
+  if (TraceIsOn("fmc-if-process"))
+  {
+    Trace("fmc-if-process")
+        << "int compose " << index << " / " << dc.size() << std::endl;
+    for (unsigned i = 1; i < cond.size(); i++)
+    {
+      debugPrint("fmc-if-process", cond[i], true);
+      Trace("fmc-if-process") << " ";
+    }
+    Trace("fmc-if-process") << std::endl;
   }
-  Trace("fmc-if-process") << std::endl;
   if ( index==(int)dc.size() ){
     Node c = mkCond(cond);
     Node v = evaluateInterpreted(n, val);
@@ -1258,8 +1324,10 @@ void FullModelChecker::doInterpretedCompose( FirstOrderModelFmc * fm, Node f, De
           bool process = true;
           if (vtn.isBoolean()) {
             //short circuit
-            if( (n.getKind()==OR && dc[index].d_value[i]==d_true) ||
-                (n.getKind()==AND && dc[index].d_value[i]==d_false) ){
+            if ((n.getKind() == Kind::OR && dc[index].d_value[i] == d_true)
+                || (n.getKind() == Kind::AND
+                    && dc[index].d_value[i] == d_false))
+            {
               Node c = mkCond(new_cond);
               d.addEntry(fm, c, dc[index].d_value[i]);
               process = false;
@@ -1308,7 +1376,7 @@ bool FullModelChecker::doMeet( FirstOrderModelFmc * fm, std::vector< Node > & co
 
 Node FullModelChecker::mkCond(const std::vector<Node>& cond)
 {
-  return NodeManager::currentNM()->mkNode(APPLY_UF, cond);
+  return NodeManager::currentNM()->mkNode(Kind::APPLY_UF, cond);
 }
 
 Node FullModelChecker::mkCondDefault( FirstOrderModelFmc * fm, Node f) {
@@ -1336,13 +1404,16 @@ void FullModelChecker::mkCondVec( Node n, std::vector< Node > & cond ) {
 }
 
 Node FullModelChecker::evaluateInterpreted( Node n, std::vector< Node > & vals ) {
-  if( n.getKind()==EQUAL && !n[0].getType().isBoolean() ){
+  if (n.getKind() == Kind::EQUAL && !n[0].getType().isBoolean())
+  {
     if (!vals[0].isNull() && !vals[1].isNull()) {
       return vals[0]==vals[1] ? d_true : d_false;
     }else{
       return Node::null();
     }
-  }else if( n.getKind()==ITE ){
+  }
+  else if (n.getKind() == Kind::ITE)
+  {
     if( vals[0]==d_true ){
       return vals[1];
     }else if( vals[0]==d_false ){
@@ -1350,17 +1421,25 @@ Node FullModelChecker::evaluateInterpreted( Node n, std::vector< Node > & vals )
     }else{
       return vals[1]==vals[2] ? vals[1] : Node::null();
     }
-  }else if( n.getKind()==AND || n.getKind()==OR ){
+  }
+  else if (n.getKind() == Kind::AND || n.getKind() == Kind::OR)
+  {
     bool isNull = false;
     for (unsigned i=0; i<vals.size(); i++) {
-      if((vals[i]==d_true && n.getKind()==OR) || (vals[i]==d_false && n.getKind()==AND)) {
+      if ((vals[i] == d_true && n.getKind() == Kind::OR)
+          || (vals[i] == d_false && n.getKind() == Kind::AND))
+      {
         return vals[i];
-      }else if( vals[i].isNull() ){
+      }
+      else if (vals[i].isNull())
+      {
         isNull = true;
       }
     }
     return isNull ? Node::null() : vals[0];
-  }else{
+  }
+  else
+  {
     std::vector<Node> children;
     if( n.getMetaKind() == kind::metakind::PARAMETERIZED ){
       children.push_back( n.getOperator() );
