@@ -18,6 +18,7 @@
 #ifndef CVC5__THEORY__QUANTIFIERS__ORACLE_ENGINE_H
 #define CVC5__THEORY__QUANTIFIERS__ORACLE_ENGINE_H
 
+#include "theory/decision_strategy.h"
 #include "theory/quantifiers/oracle_checker.h"
 #include "theory/quantifiers/quant_module.h"
 
@@ -111,6 +112,16 @@ class OracleEngine : public QuantifiersModule
    * oracle interface quantified formulas?
    */
   bool d_consistencyCheckPassed;
+  /**
+   * A decision strategy that prefers equating arguments of oracles to
+   * values that we have already evaluated the oracle on. For example, if
+   * we have an application (f a) of oracle function f, then if a=5 in one
+   * model, we may generate the lemma (=> (= a 5) (= (f a) 10)), where 10 is
+   * result of calling f on 5. This decision strategy will henceforth decide
+   * (= a 5) -> true. This ensures that we don't invoke f for evaluating (f a)
+   * again until we are sure that (= a 5) cannot be made true.
+   */
+  DecisionStrategyVector d_dstrat;
 };
 
 }  // namespace quantifiers
