@@ -27,7 +27,8 @@ QuantifiersState::QuantifiersState(Env& env,
                                    Valuation val,
                                    const LogicInfo& logicInfo)
     : TheoryState(env, val),
-      d_ierCounterc(env.getContext()),
+      d_ierCounterc(context()),
+      d_conflictInst(context()),
       d_logicInfo(logicInfo),
       d_statistics(statisticsRegistry())
 {
@@ -136,6 +137,8 @@ const LogicInfo& QuantifiersState::getLogicInfo() const { return d_logicInfo; }
 
 QuantifiersStatistics& QuantifiersState::getStats() { return d_statistics; }
 
+void QuantifiersState::notifyConflictingInst() { d_conflictInst = true; }
+
 }  // namespace quantifiers
 }  // namespace theory
 }  // namespace cvc5::internal
