@@ -67,8 +67,8 @@ bool SolutionFilterStrength::addTerm(Node n, std::vector<Node>& filtered)
   {
     curr = d_curr_sols.size() == 1
                ? d_curr_sols[0]
-               : nm->mkNode(d_isStrong ? OR : AND, d_curr_sols);
-    Node imp = nm->mkNode(AND, basen.negate(), curr);
+               : nm->mkNode(d_isStrong ? Kind::OR : Kind::AND, d_curr_sols);
+    Node imp = nm->mkNode(Kind::AND, basen.negate(), curr);
     Trace("sygus-sol-implied")
         << "  implies: check subsumed (strong=" << d_isStrong << ") " << imp
         << "..." << std::endl;
@@ -89,7 +89,7 @@ bool SolutionFilterStrength::addTerm(Node n, std::vector<Node>& filtered)
     std::vector<Node> nsubsume;
     for (const Node& s : d_curr_sols)
     {
-      Node imp = nm->mkNode(AND, s.negate(), basen);
+      Node imp = nm->mkNode(Kind::AND, s.negate(), basen);
       Trace("sygus-sol-implied")
           << "  implies: check subsuming " << imp << "..." << std::endl;
       // check the satisfiability query
