@@ -239,8 +239,7 @@ bool Cegis::addEvalLemmas(const std::vector<Node>& candidates,
   // we only do evaluation unfolding for passive enumerators
   bool doEvalUnfold = (doGen
                        && options().quantifiers.sygusEvalUnfoldMode
-                              != options::SygusEvalUnfoldMode::NONE)
-                      || d_usingSymCons;
+                              != options::SygusEvalUnfoldMode::NONE);
   if (doEvalUnfold)
   {
     Trace("sygus-engine") << "  *** Do evaluation unfolding..." << std::endl;
@@ -328,7 +327,7 @@ bool Cegis::constructCandidates(const std::vector<Node>& enums,
         break;
       }
     }
-    Trace("cegis") << "...must repair is: " << mustRepair << std::endl;
+    Trace("cegis-debug") << "must repair is: " << mustRepair << std::endl;
     // if the solution contains a subterm that must be repaired
     if (mustRepair)
     {
@@ -337,6 +336,7 @@ bool Cegis::constructCandidates(const std::vector<Node>& enums,
       // try to solve entire problem?
       if (src->repairSolution(candidates, fail_cvs, candidate_values))
       {
+        Trace("cegis") << "...solution is repaired" << std::endl;
         return true;
       }
       Node rl = getRefinementLemmaFormula();
@@ -360,6 +360,8 @@ bool Cegis::constructCandidates(const std::vector<Node>& enums,
           Kind::OR, d_parent->getConjecture().negate(), expn.negate());
       d_qim.addPendingLemma(
           expn, InferenceId::QUANTIFIERS_SYGUS_REPAIR_CONST_EXCLUDE);
+      Trace("cegis") << "...solution was processed via repair, success = "
+                     << ret << std::endl;
       return ret;
     }
   }
@@ -371,6 +373,7 @@ bool Cegis::constructCandidates(const std::vector<Node>& enums,
   if (!processConstructCandidates(
           enums, enum_values, candidates, candidate_values, !addedEvalLemmas))
   {
+    Trace("cegis") << "...construct candidates failed" << std::endl;
     return false;
   }
 
@@ -387,6 +390,7 @@ bool Cegis::constructCandidates(const std::vector<Node>& enums,
           enums, enum_values, candidates, candidate_values);
     }
   }
+  Trace("cegis") << "...success" << std::endl;
   return true;
 }
 
@@ -598,7 +602,7 @@ bool Cegis::getRefinementEvalLemmas(const std::vector<Node>& vs,
         std::vector<Node> msu;
         std::vector<Node> mexp;
         msu.insert(msu.end(), ms.begin(), ms.end());
-        std::map<TypeNode, int> var_count;
+        std::map<TypeNode, size_t> var_count;
         for (unsigned k = 0; k < vs.size(); k++)
         {
           vsit.setUpdatedTerm(msu[k]);
