@@ -20,6 +20,7 @@
 
 #include <map>
 
+#include "expr/subs.h"
 #include "smt/env_obj.h"
 #include "theory/quantifiers/sygus/sygus_module.h"
 #include "theory/quantifiers/sygus_sampler.h"
@@ -234,6 +235,14 @@ class Cegis : public SygusModule
    */
   bool d_usingSymCons;
   //---------------------------------end for symbolic constructors
+  /**
+   * Subsitution for evaluation unfold, which maps functions-to-synthesize
+   * with lambdas in terms of their deep embeddings. For example, if d_f is the
+   * deep embedding of function to synthesize f with argument list
+   * ((x Int) (y Int)), then d_euSubs maps:
+   *   f -> (lambda ((x Int) (y Int)) (DT_SYGUS_EVAL_UNFOLD d_f x y)).
+   */
+  Subs d_euSubs;
 };
 
 }  // namespace quantifiers
