@@ -566,7 +566,7 @@ void SygusEnumerator::initializeTermCache(TypeNode tn)
 
 SygusEnumerator::TermEnum* SygusEnumerator::getMasterEnumForType(TypeNode tn)
 {
-  if (tn.isDatatype() && tn.getDType().isSygus())
+  if (tn.isSygusDatatype())
   {
     std::map<TypeNode, TermEnumMaster>::iterator it = d_masterEnum.find(tn);
     if (it != d_masterEnum.end())
@@ -626,7 +626,6 @@ bool SygusEnumerator::TermEnumMaster::initialize(SygusEnumerator* se,
                                                  TypeNode tn)
 {
   Trace("sygus-enum-debug") << "master(" << tn << "): init...\n";
-  d_tds = se->d_tds;
   d_se = se;
   d_tn = tn;
 
@@ -722,8 +721,7 @@ bool SygusEnumerator::TermEnumMaster::incrementInternal()
   // If we are enumerating shapes, the first enumerated term is a free variable.
   if (d_enumShapes && !d_enumShapesInit)
   {
-    Assert(d_tds != nullptr);
-    Node fv = d_tds->getFreeVar(d_tn, 0);
+    Node fv = d_enumShapesFv.getFreeVar(d_tn, 0);
     d_enumShapesInit = true;
     d_currTermSet = true;
     d_currTerm = fv;
@@ -1046,7 +1044,7 @@ void SygusEnumerator::TermEnumMaster::childrenToShape(
     // don't need to convert constants and unary applications
     return;
   }
-  std::map<TypeNode, int> vcounter;
+  std::map<TypeNode, size_t> vcounter;
   // Buffered child, so that we only compute vcounter if there are more than
   // one children with free variables, since otherwise there is no change.
   // For example, if we are given { C, (+ x1 x2), 1 }, we buffer child (+ x1 x2)
@@ -1087,9 +1085,8 @@ void SygusEnumerator::TermEnumMaster::childrenToShape(
 }
 
 Node SygusEnumerator::TermEnumMaster::convertShape(
-    Node n, std::map<TypeNode, int>& vcounter)
+    Node n, std::map<TypeNode, size_t>& vcounter)
 {
-  Assert(d_tds != nullptr);
   NodeManager* nm = NodeManager::currentNM();
   std::unordered_map<TNode, Node> visited;
   std::unordered_map<TNode, Node>::iterator it;
@@ -1107,7 +1104,7 @@ Node SygusEnumerator::TermEnumMaster::convertShape(
       if (cur.isVar())
       {
         // do the conversion
-        visited[cur] = d_tds->getFreeVarInc(cur.getType(), vcounter);
+        visited[cur] = d_enumShapesFv.getFreeVarInc(cur.getType(), vcounter);
       }
       else if (!expr::hasBoundVar(cur))
       {
@@ -1207,8 +1204,7 @@ bool SygusEnumerator::TermEnumMasterFv::initialize(SygusEnumerator* se,
 
 Node SygusEnumerator::TermEnumMasterFv::getCurrent()
 {
-  Assert(d_se->d_tds != nullptr);
-  Node ret = d_se->d_tds->getFreeVar(d_tn, d_currSize);
+  Node ret = d_fv.getFreeVar(d_tn, d_currSize);
   Trace("sygus-enum-debug2") << "master_fv(" << d_tn << "): mk " << ret
                              << std::endl;
   return ret;
