@@ -21,6 +21,7 @@
 #include <map>
 #include <unordered_set>
 
+#include "expr/free_var_cache.h"
 #include "expr/node.h"
 #include "expr/type_node.h"
 #include "theory/quantifiers/sygus/enum_val_generator.h"
@@ -60,9 +61,8 @@ class SygusEnumerator : public EnumValGenerator
  public:
   /**
    * @param env Reference to the environment
-   * @param tds Pointer to the term database, required if enumShapes or
-   * enumAnyConstHoles is true, or if we want to include symmetry breaking from
-   * lemmas stored in the sygus term database,
+   * @param tds Pointer to the term database, required if we want to include
+   * symmetry breaking from lemmas stored in the sygus term database,
    * @param sec Pointer to the callback, required e.g. if we wish to do
    * conjecture-specific symmetry breaking
    * @param s Pointer to the statistics
@@ -378,12 +378,12 @@ class SygusEnumerator : public EnumValGenerator
     bool increment() override;
 
    private:
-    /** pointer to term database sygus */
-    TermDbSygus* d_tds;
     /** are we enumerating shapes? */
     bool d_enumShapes;
     /** have we initialized the shape enumeration? */
     bool d_enumShapesInit;
+    /** A free variable cache */
+    FreeVarCache d_enumShapesFv;
     /** are we currently inside a increment() call? */
     bool d_isIncrementing;
     /** cache for getCurrent() */
@@ -449,7 +449,7 @@ class SygusEnumerator : public EnumValGenerator
      * vcounter is { Int -> 7 }, then (+ x1 x2) is converted to (+ x7 x8) and
      * vouncter is updated to { Int -> 9 }.
      */
-    Node convertShape(Node n, std::map<TypeNode, int>& vcounter);
+    Node convertShape(Node n, std::map<TypeNode, size_t>& vcounter);
   };
   /** an interpreted value enumerator
    *
@@ -498,6 +498,10 @@ class SygusEnumerator : public EnumValGenerator
     Node getCurrent() override;
     /** increment the enumerator */
     bool increment() override;
+
+   private:
+    /** A free variable cache */
+    FreeVarCache d_fv;
   };
   /** the master enumerator for each sygus type */
   std::map<TypeNode, TermEnumMaster> d_masterEnum;
