@@ -23,7 +23,7 @@
 #include "options/quantifiers_options.h"
 #include "theory/datatypes/theory_datatypes_utils.h"
 #include "theory/quantifiers/cegqi/ceg_instantiator.h"
-#include "theory/quantifiers/sygus/sygus_grammar_cons_new.h"
+#include "theory/quantifiers/sygus/sygus_grammar_cons.h"
 #include "theory/quantifiers/sygus/sygus_grammar_red.h"
 #include "theory/quantifiers/sygus/term_database_sygus.h"
 #include "theory/quantifiers/term_util.h"
@@ -147,7 +147,8 @@ void SygusGrammarNorm::TransfDrop::buildType(SygusGrammarNorm* sygus_norm,
 bool SygusGrammarNorm::TransfChain::isChainable(TypeNode tn, Node op)
 {
   /* Checks whether operator occurs chainable for its type */
-  if (tn.isInteger() && NodeManager::currentNM()->operatorToKind(op) == ADD)
+  if (tn.isInteger()
+      && NodeManager::currentNM()->operatorToKind(op) == Kind::ADD)
   {
     return true;
   }
@@ -159,7 +160,8 @@ bool SygusGrammarNorm::TransfChain::isChainable(TypeNode tn, Node op)
    function should realize that it is chainable for integers */
 bool SygusGrammarNorm::TransfChain::isId(TypeNode tn, Node op, Node n)
 {
-  if (tn.isInteger() && NodeManager::currentNM()->operatorToKind(op) == ADD
+  if (tn.isInteger()
+      && NodeManager::currentNM()->operatorToKind(op) == Kind::ADD
       && n == TermUtil::mkTypeValue(tn, 0))
   {
     return true;
@@ -231,7 +233,8 @@ void SygusGrammarNorm::TransfChain::buildType(SygusGrammarNorm* sygus_norm,
     std::vector<TypeNode> ctypesp;
     ctypesp.push_back(t);
     ctypesp.push_back(to.d_unres_tn);
-    to.d_sdt.addConstructor(nm->operatorOf(ADD), kindToString(ADD), ctypesp);
+    to.d_sdt.addConstructor(
+        nm->operatorOf(Kind::ADD), kindToString(Kind::ADD), ctypesp);
     Trace("sygus-grammar-normalize-chain")
         << "\tAdding ADD to " << to.d_unres_tn << " with arg types "
         << to.d_unres_tn << " and " << t << "\n";
@@ -318,9 +321,10 @@ std::unique_ptr<SygusGrammarNorm::Transf> SygusGrammarNorm::inferTransf(
     Assert(op_pos[i] < dt.getNumConstructors());
     Node sop = dt[op_pos[i]].getSygusOp();
     /* Collects a chainable operator such as ADD */
-    if (sop.getKind() == BUILTIN && TransfChain::isChainable(sygus_tn, sop))
+    if (sop.getKind() == Kind::BUILTIN
+        && TransfChain::isChainable(sygus_tn, sop))
     {
-      Assert(nm->operatorToKind(sop) == ADD);
+      Assert(nm->operatorToKind(sop) == Kind::ADD);
       /* TODO #1304: be robust for this case */
       /* For now only transforms applications whose arguments have the same type
        * as the root */
@@ -338,7 +342,7 @@ std::unique_ptr<SygusGrammarNorm::Transf> SygusGrammarNorm::inferTransf(
       if (!same_type_plus)
       {
         Trace("sygus-grammar-normalize-infer")
-            << "\tFor OP " << ADD << " did not collecting sop " << sop
+            << "\tFor OP " << Kind::ADD << " did not collecting sop " << sop
             << " in position " << op_pos[i] << "\n";
         continue;
       }
@@ -351,7 +355,7 @@ std::unique_ptr<SygusGrammarNorm::Transf> SygusGrammarNorm::inferTransf(
     }
     /* TODO #1304: check this for each operator */
     /* Collects elements that are not the identity (e.g. 0 is the id of ADD) */
-    if (!TransfChain::isId(sygus_tn, nm->operatorOf(ADD), sop))
+    if (!TransfChain::isId(sygus_tn, nm->operatorOf(Kind::ADD), sop))
     {
       Trace("sygus-grammar-normalize-infer")
           << "\tCollecting for NON_ID_ELEMS the sop " << sop
