@@ -58,7 +58,8 @@ void SygusRedundantCons::initialize(TermDbSygus* tds, TypeNode tn)
     d_gen_terms[i] = g;
     // is the operator a lambda of the form (lambda x1...xn. f(x1...xn))?
     bool lamInOrder = false;
-    if (sop.getKind() == LAMBDA && sop[0].getNumChildren() == sop[1].getNumChildren())
+    if (sop.getKind() == Kind::LAMBDA
+        && sop[0].getNumChildren() == sop[1].getNumChildren())
     {
       Assert(g.getNumChildren()==sop[0].getNumChildren());
       lamInOrder = true;
