@@ -164,7 +164,7 @@ Node SygusRandomEnumerator::incrementH()
     // We may have already generated a sygus term equivalent to the one we are
     // generating now. In that case, pick the smaller term of the two. This
     // operation allows us to generate more refined terms over time.
-    groundTerm[currSkolem] = getMin(nm->mkNode(kind::APPLY_CONSTRUCTOR, args));
+    groundTerm[currSkolem] = getMin(nm->mkNode(Kind::APPLY_CONSTRUCTOR, args));
   }
 
   return groundTerm[mainSkolem];
