@@ -31,6 +31,7 @@ class LogicInfo;
 namespace theory {
 namespace quantifiers {
 
+class QuantifiersInferenceManager;
 class TermDbSygus;
 
 /** SygusRepairConst
@@ -51,7 +52,9 @@ class TermDbSygus;
 class SygusRepairConst : protected EnvObj
 {
  public:
-  SygusRepairConst(Env& env, TermDbSygus* tds);
+  SygusRepairConst(Env& env,
+                   QuantifiersInferenceManager& qim,
+                   TermDbSygus* tds);
   ~SygusRepairConst() {}
   /** initialize
    *
@@ -74,25 +77,21 @@ class SygusRepairConst : protected EnvObj
    * Moreover, it is the case that
    *    repair_cv[j] != candidate_values[j], for at least one j.
    * We always consider applications of the "any constant" constructors in
-   * candidate_values to be repairable. In addition, if the flag
-   * useConstantsAsHoles is true, we consider all constants whose (sygus) type
-   * admit alls constants to be repairable.
+   * candidate_values to be repairable.
    * The repaired solution has the property that it satisfies the synthesis
    * conjecture whose body is given by sygusBody.
    */
   bool repairSolution(Node sygusBody,
                       const std::vector<Node>& candidates,
                       const std::vector<Node>& candidate_values,
-                      std::vector<Node>& repair_cv,
-                      bool useConstantsAsHoles = false);
+                      std::vector<Node>& repair_cv);
   /**
    * Same as above, but where sygusBody is the body (base_inst) provided to the
    * call to initialize of this class.
    */
   bool repairSolution(const std::vector<Node>& candidates,
                       const std::vector<Node>& candidate_values,
-                      std::vector<Node>& repair_cv,
-                      bool useConstantsAsHoles = false);
+                      std::vector<Node>& repair_cv);
   /**
    * Return whether this module has the possibility to repair solutions. This is
    * true if this module has been initialized, and at least one candidate has
@@ -108,6 +107,8 @@ class SygusRepairConst : protected EnvObj
   static bool mustRepair(Node n);
 
  private:
+  /** Reference to the quantifiers inference manager */
+  QuantifiersInferenceManager& d_qim;
   /** pointer to the sygus term database of d_qe */
   TermDbSygus* d_tds;
   /**
@@ -121,12 +122,10 @@ class SygusRepairConst : protected EnvObj
    * this class is a no-op.
    */
   bool d_allow_constant_grammar;
-  /** map from skeleton variables to first-order variables */
-  std::map<Node, Node> d_sk_to_fo;
-  /** reverse map of d_sk_to_fo */
-  std::map<Node, Node> d_fo_to_sk;
   /** a cache of satisfiability queries of the form [***] above we have tried */
   std::unordered_set<Node> d_queries;
+  /** The queries that were unsat */
+  std::unordered_set<Node> d_unsatQueries;
   /**
    * Register information for sygus type tn, tprocessed stores the set of
    * already registered types.
@@ -135,11 +134,9 @@ class SygusRepairConst : protected EnvObj
   /** is repairable?
    *
    * This returns true if n can be repaired by this class. In particular, we
-   * return true if n is an "any constant" constructor, or it is a constructor
-   * for a constant in a type that allows all constants and useConstantsAsHoles
-   * is true.
+   * return true if n is an "any constant" constructor.
    */
-  static bool isRepairable(Node n, bool useConstantsAsHoles);
+  static bool isRepairable(Node n);
   /** get skeleton
    *
    * Returns a skeleton for sygus datatype value n, where the subterms of n that
@@ -148,14 +145,11 @@ class SygusRepairConst : protected EnvObj
    * replacement are taken from TermDbSygus, where we track indices
    * in free_var_count. Variables we introduce in this way are added to sk_vars.
    * The mapping sk_vars_to_subs contains entries v -> c, where v is a
-   * variable in sk_vars, and c is the term in n that it replaced. The flag
-   * useConstantsAsHoles affects which terms we consider to be repairable.
+   * variable in sk_vars, and c is the term in n that it replaced.
    */
   Node getSkeleton(Node n,
-                   std::map<TypeNode, int>& free_var_count,
-                   std::vector<Node>& sk_vars,
-                   std::map<Node, Node>& sk_vars_to_subs,
-                   bool useConstantsAsHoles);
+                   std::map<TypeNode, size_t>& free_var_count,
+                   std::vector<Node>& sk_vars);
   /** get first-order query
    *
    * This function returns a formula that is equivalent to the negation of the
@@ -169,46 +163,6 @@ class SygusRepairConst : protected EnvObj
                   const std::vector<Node>& candidates,
                   const std::vector<Node>& candidate_skeletons,
                   const std::vector<Node>& sk_vars);
-  /** fit to logic
-   *
-   * This function ensures that a query of the form [***] above fits the given
-   * logic. In our approach for constant repair, replacing constants by
-   * variables may introduce e.g. non-linearity. If non-linear arithmetic is
-   * not enabled, we must undo some of the variables we introduced when
-   * inferring candidate skeletons.
-   *
-   * body is the (sygus) form of the original synthesis conjecture we are
-   * considering in this call.
-   *
-   * This function may remove variables from sk_vars and the map
-   * sk_vars_to_subs. The skeletons candidate_skeletons are obtained by
-   * getSkeleton(...) on the resulting vectors. If this function returns a
-   * non-null node n', then n' is getFoQuery(...) on the resulting vectors, and
-   * n' is in the given logic. The function may return null if it is not
-   * possible to find a n' of this form.
-   *
-   * It uses the function below to choose which variables to remove from
-   * sk_vars.
-   */
-  Node fitToLogic(Node body,
-                  const LogicInfo& logic,
-                  Node n,
-                  const std::vector<Node>& candidates,
-                  std::vector<Node>& candidate_skeletons,
-                  std::vector<Node>& sk_vars,
-                  std::map<Node, Node>& sk_vars_to_subs);
-  /** get fit to logic exclusion variable
-   *
-   * If n is not in the given logic, then this method either returns false,
-   * or returns true and sets exvar to some variable in the domain of
-   * d_fo_to_sk, that must be replaced by a constant for n to be in the given
-   * logic. For example, for logic linear arithemic, for input:
-   *    x * y = 5
-   * where x is in the domain of d_fo_to_sk, this function returns true and sets
-   * exvar to x.
-   * If n is in the given logic, this method returns true.
-   */
-  bool getFitToLogicExcludeVar(const LogicInfo& logic, Node n, Node& exvar);
 };
 
 }  // namespace quantifiers
