@@ -43,31 +43,24 @@ TermDb::TermDb(Env& env, QuantifiersState& qs, QuantifiersRegistry& qr)
       d_qstate(qs),
       d_qim(nullptr),
       d_qreg(qr),
-      d_termsContext(),
-      d_termsContextUse(options().quantifiers.termDbCd ? context()
-                                                       : &d_termsContext),
-      d_processed(d_termsContextUse),
-      d_typeMap(d_termsContextUse),
-      d_ops(d_termsContextUse),
-      d_opMap(d_termsContextUse),
+      d_processed(context()),
+      d_typeMap(context()),
+      d_ops(context()),
+      d_opMap(context()),
       d_inactive_map(context())
 {
-  d_consistent_ee = true;
   d_true = NodeManager::currentNM()->mkConst(true);
   d_false = NodeManager::currentNM()->mkConst(false);
-  if (!options().quantifiers.termDbCd)
-  {
-    // when not maintaining terms in a context-dependent manner, we clear during
-    // each presolve, which requires maintaining a single outermost level
-    d_termsContext.push();
-  }
 }
 
 TermDb::~TermDb(){
 
 }
 
-void TermDb::finishInit(QuantifiersInferenceManager* qim) { d_qim = qim; }
+void TermDb::finishInit(QuantifiersInferenceManager* qim)
+{
+  d_qim = qim;
+}
 
 void TermDb::registerQuantifier( Node q ) {
   Assert(q[0].getNumChildren() == d_qreg.getNumInstantiationConstants(q));
@@ -188,11 +181,13 @@ Node TermDb::getMatchOperator(TNode n)
 {
   Kind k = n.getKind();
   //datatype operators may be parametric, always assume they are
-  if (k == SELECT || k == STORE || k == SET_UNION || k == SET_INTER
-      || k == SET_SUBSET || k == SET_MINUS || k == SET_MEMBER
-      || k == SET_SINGLETON || k == APPLY_SELECTOR || k == APPLY_TESTER
-      || k == SEP_PTO || k == HO_APPLY || k == SEQ_NTH || k == STRING_LENGTH
-      || k == BITVECTOR_TO_NAT || k == INT_TO_BITVECTOR)
+  if (k == Kind::SELECT || k == Kind::STORE || k == Kind::SET_UNION
+      || k == Kind::SET_INTER || k == Kind::SET_SUBSET || k == Kind::SET_MINUS
+      || k == Kind::SET_MEMBER || k == Kind::SET_SINGLETON
+      || k == Kind::APPLY_SELECTOR || k == Kind::APPLY_TESTER
+      || k == Kind::SEP_PTO || k == Kind::HO_APPLY || k == Kind::SEQ_NTH
+      || k == Kind::STRING_LENGTH || k == Kind::BITVECTOR_TO_NAT
+      || k == Kind::INT_TO_BITVECTOR)
   {
     //since it is parametric, use a particular one as op
     TypeNode tn = n[0].getType();
@@ -230,11 +225,10 @@ void TermDb::addTerm(Node n)
     DbList* dlt = getOrMkDbListForType(n.getType());
     dlt->d_list.push_back(n);
     // if this is an atomic trigger, consider adding it
-    if (inst::TriggerTermInfo::isAtomicTrigger(n))
+    Node op = getMatchOperator(n);
+    if (!op.isNull())
     {
       Trace("term-db") << "register term in db " << n << std::endl;
-
-      Node op = getMatchOperator(n);
       Trace("term-db-debug") << "  match operator is : " << op << std::endl;
       DbList* dlo = getOrMkDbListForOp(op);
       dlo->d_list.push_back(n);
@@ -262,7 +256,7 @@ DbList* TermDb::getOrMkDbListForType(TypeNode tn)
   {
     return it->second.get();
   }
-  std::shared_ptr<DbList> dl = std::make_shared<DbList>(d_termsContextUse);
+  std::shared_ptr<DbList> dl = std::make_shared<DbList>(context());
   d_typeMap.insert(tn, dl);
   return dl.get();
 }
@@ -274,9 +268,9 @@ DbList* TermDb::getOrMkDbListForOp(TNode op)
   {
     return it->second.get();
   }
-  std::shared_ptr<DbList> dl = std::make_shared<DbList>(d_termsContextUse);
+  std::shared_ptr<DbList> dl = std::make_shared<DbList>(context());
   d_opMap.insert(op, dl);
-  Assert(op.getKind() != BOUND_VARIABLE);
+  Assert(op.getKind() != Kind::BOUND_VARIABLE);
   d_ops.push_back(op);
   return dl.get();
 }
@@ -402,7 +396,8 @@ void TermDb::computeUfTerms( TNode f ) {
         {
           if (at[k] != n[k])
           {
-            lits.push_back(nm->mkNode(EQUAL, at[k], n[k]).negate());
+            lits.push_back(nm->mkNode(Kind::EQUAL, at[k], n[k]).negate());
+            Assert(d_qstate.areEqual(at[k], n[k]));
           }
         }
         Node lem = nm->mkOr(lits);
@@ -420,7 +415,6 @@ void TermDb::computeUfTerms( TNode f ) {
         }
         d_qim->addPendingLemma(lem, InferenceId::QUANTIFIERS_TDB_DEQ_CONG);
         d_qstate.notifyInConflict();
-        d_consistent_ee = false;
         return;
       }
       nonCongruentCount++;
@@ -553,12 +547,6 @@ Node TermDb::getEligibleTermInEqc( TNode r ) {
   }
 }
 
-bool TermDb::resetInternal(Theory::Effort e)
-{
-  // do nothing
-  return true;
-}
-
 bool TermDb::finishResetInternal(Theory::Effort e)
 {
   // do nothing
@@ -585,13 +573,7 @@ void TermDb::setHasTerm( Node n ) {
   }
 }
 
-void TermDb::presolve() {
-  if (options().base.incrementalSolving && !options().quantifiers.termDbCd)
-  {
-    d_termsContext.pop();
-    d_termsContext.push();
-  }
-}
+void TermDb::presolve() {}
 
 bool TermDb::reset( Theory::Effort effort ){
   d_op_nonred_count.clear();
@@ -599,16 +581,10 @@ bool TermDb::reset( Theory::Effort effort ){
   d_func_map_trie.clear();
   d_func_map_eqc_trie.clear();
   d_fmapRelDom.clear();
-  d_consistent_ee = true;
 
   eq::EqualityEngine* ee = d_qstate.getEqualityEngine();
 
   Assert(ee->consistent());
-  // if higher-order, add equalities for the purification terms now
-  if (!resetInternal(effort))
-  {
-    return false;
-  }
 
   //compute has map
   if (options().quantifiers.termDbMode == options::TermDbMode::RELEVANT)
