@@ -48,9 +48,12 @@ Node TermUtil::getRemoveQuantifiers2( Node n, std::map< Node, Node >& visited )
     return it->second;
   }else{
     Node ret = n;
-    if( n.getKind()==FORALL ){
+    if (n.getKind() == Kind::FORALL)
+    {
       ret = getRemoveQuantifiers2( n[1], visited );
-    }else if( n.getNumChildren()>0 ){
+    }
+    else if (n.getNumChildren() > 0)
+    {
       std::vector< Node > children;
       bool childrenChanged = false;
       for( unsigned i=0; i<n.getNumChildren(); i++ ){
@@ -103,9 +106,12 @@ bool TermUtil::hasInstConstAttr(Node n)
 Node TermUtil::getBoundVarAttr( Node n ) {
   if (!n.hasAttribute(BoundVarAttribute()) ){
     Node bv;
-    if( n.getKind()==BOUND_VARIABLE ){
+    if (n.getKind() == Kind::BOUND_VARIABLE)
+    {
       bv = n;
-    }else{
+    }
+    else
+    {
       for( unsigned i=0; i<n.getNumChildren(); i++ ){
         bv = getBoundVarAttr(n[i]);
         if( !bv.isNull() ){
@@ -131,17 +137,17 @@ Node TermUtil::getRemoveQuantifiers( Node n ) {
 
 void TermUtil::computeInstConstContains(Node n, std::vector<Node>& ics)
 {
-  computeVarContainsInternal(n, INST_CONSTANT, ics);
+  computeVarContainsInternal(n, Kind::INST_CONSTANT, ics);
 }
 
 void TermUtil::computeVarContains(Node n, std::vector<Node>& vars)
 {
-  computeVarContainsInternal(n, BOUND_VARIABLE, vars);
+  computeVarContainsInternal(n, Kind::BOUND_VARIABLE, vars);
 }
 
 void TermUtil::computeQuantContains(Node n, std::vector<Node>& quants)
 {
-  computeVarContainsInternal(n, FORALL, quants);
+  computeVarContainsInternal(n, Kind::FORALL, quants);
 }
 
 void TermUtil::computeVarContainsInternal(Node n,
@@ -224,21 +230,21 @@ bool TermUtil::containsUninterpretedConstant( Node n ) {
   }
   bool ret = false;
   Kind k = n.getKind();
-  if (k == UNINTERPRETED_SORT_VALUE)
+  if (k == Kind::UNINTERPRETED_SORT_VALUE)
   {
     Assert(n.getType().isUninterpretedSort());
     ret = true;
   }
-  else if (k == STORE_ALL)
+  else if (k == Kind::STORE_ALL)
   {
     ret = containsUninterpretedConstant(n.getConst<ArrayStoreAll>().getValue());
   }
-  else if (k == FUNCTION_ARRAY_CONST)
+  else if (k == Kind::FUNCTION_ARRAY_CONST)
   {
     ret = containsUninterpretedConstant(
         n.getConst<FunctionArrayConst>().getArrayValue());
   }
-  else if (k == CONST_SEQUENCE)
+  else if (k == Kind::CONST_SEQUENCE)
   {
     const std::vector<Node>& charVec = n.getConst<Sequence>().getVec();
     for (const Node& nc : charVec)
@@ -270,13 +276,14 @@ Node TermUtil::simpleNegate(Node n)
 {
   Assert(n.getType().isBoolean());
   NodeManager* nm = NodeManager::currentNM();
-  if( n.getKind()==OR || n.getKind()==AND ){
+  if (n.getKind() == Kind::OR || n.getKind() == Kind::AND)
+  {
     std::vector< Node > children;
     for (const Node& cn : n)
     {
       children.push_back(simpleNegate(cn));
     }
-    return nm->mkNode(n.getKind() == OR ? AND : OR, children);
+    return nm->mkNode(n.getKind() == Kind::OR ? Kind::AND : Kind::OR, children);
   }
   else if (n.isConst())
   {
@@ -296,54 +303,62 @@ Node TermUtil::mkNegate(Kind notk, Node n)
 
 bool TermUtil::isNegate(Kind k)
 {
-  return k == NOT || k == BITVECTOR_NOT || k == BITVECTOR_NEG || k == NEG;
+  return k == Kind::NOT || k == Kind::BITVECTOR_NOT || k == Kind::BITVECTOR_NEG
+         || k == Kind::NEG;
 }
 
 bool TermUtil::isAssoc(Kind k, bool reqNAry)
 {
   if (reqNAry)
   {
-    if (k == SET_UNION || k == SET_INTER)
+    if (k == Kind::SET_UNION || k == Kind::SET_INTER)
     {
       return false;
     }
   }
-  return k == ADD || k == MULT || k == NONLINEAR_MULT || k == AND || k == OR
-         || k == XOR || k == BITVECTOR_ADD || k == BITVECTOR_MULT
-         || k == BITVECTOR_AND || k == BITVECTOR_OR || k == BITVECTOR_XOR
-         || k == BITVECTOR_XNOR || k == BITVECTOR_CONCAT || k == STRING_CONCAT
-         || k == SET_UNION || k == SET_INTER || k == RELATION_JOIN
-         || k == RELATION_PRODUCT || k == SEP_STAR;
+  return k == Kind::ADD || k == Kind::MULT || k == Kind::NONLINEAR_MULT
+         || k == Kind::AND || k == Kind::OR || k == Kind::XOR
+         || k == Kind::BITVECTOR_ADD || k == Kind::BITVECTOR_MULT
+         || k == Kind::BITVECTOR_AND || k == Kind::BITVECTOR_OR
+         || k == Kind::BITVECTOR_XOR || k == Kind::BITVECTOR_XNOR
+         || k == Kind::BITVECTOR_CONCAT || k == Kind::STRING_CONCAT
+         || k == Kind::SET_UNION || k == Kind::SET_INTER
+         || k == Kind::RELATION_JOIN || k == Kind::RELATION_PRODUCT
+         || k == Kind::SEP_STAR;
 }
 
 bool TermUtil::isComm(Kind k, bool reqNAry)
 {
   if (reqNAry)
   {
-    if (k == SET_UNION || k == SET_INTER)
+    if (k == Kind::SET_UNION || k == Kind::SET_INTER)
     {
       return false;
     }
   }
-  return k == EQUAL || k == ADD || k == MULT || k == NONLINEAR_MULT || k == AND
-         || k == OR || k == XOR || k == BITVECTOR_ADD || k == BITVECTOR_MULT
-         || k == BITVECTOR_AND || k == BITVECTOR_OR || k == BITVECTOR_XOR
-         || k == BITVECTOR_XNOR || k == SET_UNION || k == SET_INTER
-         || k == SEP_STAR;
+  return k == Kind::EQUAL || k == Kind::ADD || k == Kind::MULT
+         || k == Kind::NONLINEAR_MULT || k == Kind::AND || k == Kind::OR
+         || k == Kind::XOR || k == Kind::BITVECTOR_ADD
+         || k == Kind::BITVECTOR_MULT || k == Kind::BITVECTOR_AND
+         || k == Kind::BITVECTOR_OR || k == Kind::BITVECTOR_XOR
+         || k == Kind::BITVECTOR_XNOR || k == Kind::SET_UNION
+         || k == Kind::SET_INTER || k == Kind::SEP_STAR;
 }
 
 bool TermUtil::isNonAdditive( Kind k ) {
-  return k==AND || k==OR || k==BITVECTOR_AND || k==BITVECTOR_OR;
+  return k == Kind::AND || k == Kind::OR || k == Kind::BITVECTOR_AND
+         || k == Kind::BITVECTOR_OR;
 }
 
 bool TermUtil::isBoolConnective( Kind k ) {
-  return k==OR || k==AND || k==EQUAL || k==ITE || k==FORALL || k==NOT || k==SEP_STAR;
+  return k == Kind::OR || k == Kind::AND || k == Kind::EQUAL || k == Kind::ITE
+         || k == Kind::FORALL || k == Kind::NOT || k == Kind::SEP_STAR;
 }
 
 bool TermUtil::isBoolConnectiveTerm( TNode n ) {
-  return isBoolConnective( n.getKind() ) &&
-         ( n.getKind()!=EQUAL || n[0].getType().isBoolean() ) && 
-         ( n.getKind()!=ITE || n.getType().isBoolean() );
+  return isBoolConnective(n.getKind())
+         && (n.getKind() != Kind::EQUAL || n[0].getType().isBoolean())
+         && (n.getKind() != Kind::ITE || n.getType().isBoolean());
 }
 
 Node TermUtil::mkTypeValue(TypeNode tn, int32_t val)
@@ -424,34 +439,34 @@ Node TermUtil::mkTypeConst(TypeNode tn, bool pol)
 
 bool TermUtil::isAntisymmetric(Kind k, Kind& dk)
 {
-  if (k == GT)
+  if (k == Kind::GT)
   {
-    dk = LT;
+    dk = Kind::LT;
     return true;
   }
-  else if (k == GEQ)
+  else if (k == Kind::GEQ)
   {
-    dk = LEQ;
+    dk = Kind::LEQ;
     return true;
   }
-  else if (k == BITVECTOR_UGT)
+  else if (k == Kind::BITVECTOR_UGT)
   {
-    dk = BITVECTOR_ULT;
+    dk = Kind::BITVECTOR_ULT;
     return true;
   }
-  else if (k == BITVECTOR_UGE)
+  else if (k == Kind::BITVECTOR_UGE)
   {
-    dk = BITVECTOR_ULE;
+    dk = Kind::BITVECTOR_ULE;
     return true;
   }
-  else if (k == BITVECTOR_SGT)
+  else if (k == Kind::BITVECTOR_SGT)
   {
-    dk = BITVECTOR_SLT;
+    dk = Kind::BITVECTOR_SLT;
     return true;
   }
-  else if (k == BITVECTOR_SGE)
+  else if (k == Kind::BITVECTOR_SGE)
   {
-    dk = BITVECTOR_SLE;
+    dk = Kind::BITVECTOR_SLE;
     return true;
   }
   return false;
@@ -465,37 +480,37 @@ bool TermUtil::isIdempotentArg(Node n, Kind ik, int arg)
   TypeNode tn = n.getType();
   if (n == mkTypeValue(tn, 0))
   {
-    if (ik == ADD || ik == OR || ik == XOR || ik == BITVECTOR_ADD
-        || ik == BITVECTOR_OR || ik == BITVECTOR_XOR || ik == STRING_CONCAT)
+    if (ik == Kind::ADD || ik == Kind::OR || ik == Kind::XOR
+        || ik == Kind::BITVECTOR_ADD || ik == Kind::BITVECTOR_OR
+        || ik == Kind::BITVECTOR_XOR || ik == Kind::STRING_CONCAT)
     {
       return true;
     }
-    else if (ik == SUB || ik == BITVECTOR_SHL || ik == BITVECTOR_LSHR
-             || ik == BITVECTOR_ASHR || ik == BITVECTOR_SUB
-             || ik == BITVECTOR_UREM)
+    else if (ik == Kind::SUB || ik == Kind::BITVECTOR_SHL
+             || ik == Kind::BITVECTOR_LSHR || ik == Kind::BITVECTOR_ASHR
+             || ik == Kind::BITVECTOR_SUB || ik == Kind::BITVECTOR_UREM)
     {
       return arg == 1;
     }
   }
   else if (n == mkTypeValue(tn, 1))
   {
-    if (ik == MULT || ik == BITVECTOR_MULT)
+    if (ik == Kind::MULT || ik == Kind::BITVECTOR_MULT)
     {
       return true;
     }
-    else if (ik == DIVISION || ik == DIVISION_TOTAL || ik == INTS_DIVISION
-             || ik == INTS_DIVISION_TOTAL
-             || ik == INTS_MODULUS
-             || ik == INTS_MODULUS_TOTAL
-             || ik == BITVECTOR_UDIV
-             || ik == BITVECTOR_SDIV)
+    else if (ik == Kind::DIVISION || ik == Kind::DIVISION_TOTAL
+             || ik == Kind::INTS_DIVISION || ik == Kind::INTS_DIVISION_TOTAL
+             || ik == Kind::INTS_MODULUS || ik == Kind::INTS_MODULUS_TOTAL
+             || ik == Kind::BITVECTOR_UDIV || ik == Kind::BITVECTOR_SDIV)
     {
       return arg == 1;
     }
   }
   else if (n == mkTypeMaxValue(tn))
   {
-    if (ik == EQUAL || ik == BITVECTOR_AND || ik == BITVECTOR_XNOR)
+    if (ik == Kind::EQUAL || ik == Kind::BITVECTOR_AND
+        || ik == Kind::BITVECTOR_XNOR)
     {
       return true;
     }
@@ -508,19 +523,20 @@ Node TermUtil::isSingularArg(Node n, Kind ik, unsigned arg)
   TypeNode tn = n.getType();
   if (n == mkTypeValue(tn, 0))
   {
-    if (ik == AND || ik == MULT || ik == BITVECTOR_AND || ik == BITVECTOR_MULT)
+    if (ik == Kind::AND || ik == Kind::MULT || ik == Kind::BITVECTOR_AND
+        || ik == Kind::BITVECTOR_MULT)
     {
       return n;
     }
-    else if (ik == BITVECTOR_SHL || ik == BITVECTOR_LSHR || ik == BITVECTOR_ASHR
-             || ik == BITVECTOR_UREM)
+    else if (ik == Kind::BITVECTOR_SHL || ik == Kind::BITVECTOR_LSHR
+             || ik == Kind::BITVECTOR_ASHR || ik == Kind::BITVECTOR_UREM)
     {
       if (arg == 0)
       {
         return n;
       }
     }
-    else if (ik == BITVECTOR_UDIV || ik == BITVECTOR_SDIV)
+    else if (ik == Kind::BITVECTOR_UDIV || ik == Kind::BITVECTOR_SDIV)
     {
       if (arg == 0)
       {
@@ -531,17 +547,16 @@ Node TermUtil::isSingularArg(Node n, Kind ik, unsigned arg)
         return mkTypeMaxValue(tn);
       }
     }
-    else if (ik == DIVISION || ik == DIVISION_TOTAL || ik == INTS_DIVISION
-             || ik == INTS_DIVISION_TOTAL
-             || ik == INTS_MODULUS
-             || ik == INTS_MODULUS_TOTAL)
+    else if (ik == Kind::DIVISION || ik == Kind::DIVISION_TOTAL
+             || ik == Kind::INTS_DIVISION || ik == Kind::INTS_DIVISION_TOTAL
+             || ik == Kind::INTS_MODULUS || ik == Kind::INTS_MODULUS_TOTAL)
     {
       if (arg == 0)
       {
         return n;
       }
     }
-    else if (ik == STRING_SUBSTR)
+    else if (ik == Kind::STRING_SUBSTR)
     {
       if (arg == 0)
       {
@@ -552,7 +567,7 @@ Node TermUtil::isSingularArg(Node n, Kind ik, unsigned arg)
         return mkTypeValue(NodeManager::currentNM()->stringType(), 0);
       }
     }
-    else if (ik == STRING_INDEXOF)
+    else if (ik == Kind::STRING_INDEXOF)
     {
       if (arg == 0 || arg == 1)
       {
@@ -562,14 +577,14 @@ Node TermUtil::isSingularArg(Node n, Kind ik, unsigned arg)
   }
   else if (n == mkTypeValue(tn, 1))
   {
-    if (ik == BITVECTOR_UREM)
+    if (ik == Kind::BITVECTOR_UREM)
     {
       return mkTypeValue(tn, 0);
     }
   }
   else if (n == mkTypeMaxValue(tn))
   {
-    if (ik == OR || ik == BITVECTOR_OR)
+    if (ik == Kind::OR || ik == Kind::BITVECTOR_OR)
     {
       return n;
     }
@@ -579,11 +594,11 @@ Node TermUtil::isSingularArg(Node n, Kind ik, unsigned arg)
     if (n.getType().isInteger() && n.getConst<Rational>().sgn() < 0)
     {
       // negative arguments
-      if (ik == STRING_SUBSTR || ik == STRING_CHARAT)
+      if (ik == Kind::STRING_SUBSTR || ik == Kind::STRING_CHARAT)
       {
         return mkTypeValue(NodeManager::currentNM()->stringType(), 0);
       }
-      else if (ik == STRING_INDEXOF)
+      else if (ik == Kind::STRING_INDEXOF)
       {
         Assert(arg == 2);
         return mkTypeValue(NodeManager::currentNM()->integerType(), -1);
@@ -595,25 +610,25 @@ Node TermUtil::isSingularArg(Node n, Kind ik, unsigned arg)
 
 bool TermUtil::hasOffsetArg(Kind ik, int arg, int& offset, Kind& ok)
 {
-  if (ik == LT)
+  if (ik == Kind::LT)
   {
     Assert(arg == 0 || arg == 1);
     offset = arg == 0 ? 1 : -1;
-    ok = LEQ;
+    ok = Kind::LEQ;
     return true;
   }
-  else if (ik == BITVECTOR_ULT)
+  else if (ik == Kind::BITVECTOR_ULT)
   {
     Assert(arg == 0 || arg == 1);
     offset = arg == 0 ? 1 : -1;
-    ok = BITVECTOR_ULE;
+    ok = Kind::BITVECTOR_ULE;
     return true;
   }
-  else if (ik == BITVECTOR_SLT)
+  else if (ik == Kind::BITVECTOR_SLT)
   {
     Assert(arg == 0 || arg == 1);
     offset = arg == 0 ? 1 : -1;
-    ok = BITVECTOR_SLE;
+    ok = Kind::BITVECTOR_SLE;
     return true;
   }
   return false;
