@@ -35,24 +35,34 @@ TypeNode QuantifierTypeRule::computeType(NodeManager* nodeManager,
          && n.getNumChildren() > 0);
   if (check)
   {
-    if (n[0].getType(check) != nodeManager->boundVarListType())
+    // bound variable lists, etc. cannot be abstracted
+    if (n[0].getTypeOrNull() != nodeManager->boundVarListType())
     {
-      throw TypeCheckingExceptionPrivate(
-          n, "first argument of quantifier is not bound var list");
+      if (errOut)
+      {
+        (*errOut) << "first argument of quantifier is not bound var list";
+      }
+      return TypeNode::null();
     }
-    if (n[1].getType(check) != nodeManager->booleanType())
+    TypeNode bodyType = n[1].getTypeOrNull();
+    if (!bodyType.isBoolean() && !bodyType.isFullyAbstract())
     {
-      throw TypeCheckingExceptionPrivate(n,
-                                         "body of quantifier is not boolean");
+      if (errOut)
+      {
+        (*errOut) << "body of quantifier is not boolean";
+      }
+      return TypeNode::null();
     }
     if (n.getNumChildren() == 3)
     {
-      if (n[2].getType(check) != nodeManager->instPatternListType())
+      if (n[2].getTypeOrNull() != nodeManager->instPatternListType())
       {
-        throw TypeCheckingExceptionPrivate(
-            n,
-            "third argument of quantifier is not instantiation "
-            "pattern list");
+        if (errOut)
+        {
+          (*errOut) << "third argument of quantifier is not instantiation "
+                       "pattern list";
+        }
+        return TypeNode::null();
       }
       for (const Node& p : n[2])
       {
@@ -63,10 +73,13 @@ TypeNode QuantifierTypeRule::computeType(NodeManager* nodeManager,
         if (!InstStrategyPool::hasProductSemantics(n, p)
             && !InstStrategyPool::hasTupleSemantics(n, p))
         {
-          throw TypeCheckingExceptionPrivate(
-              n,
-              "Pool annotation does not match the types of the variables of "
-              "the quantified formula.");
+          if (errOut)
+          {
+            (*errOut)
+                << "expected number of arguments to pool to be the same as the "
+                   "number of bound variables of the quantified formula";
+          }
+          return TypeNode::null();
         }
       }
     }
@@ -87,12 +100,15 @@ TypeNode QuantifierBoundVarListTypeRule::computeType(NodeManager* nodeManager,
   Assert(n.getKind() == Kind::BOUND_VAR_LIST);
   if (check)
   {
-    for (int i = 0; i < (int)n.getNumChildren(); i++)
+    for (const Node& nc : n)
     {
-      if (n[i].getKind() != Kind::BOUND_VARIABLE)
+      if (nc.getKind() != Kind::BOUND_VARIABLE)
       {
-        throw TypeCheckingExceptionPrivate(
-            n, "argument of bound var list is not bound variable");
+        if (errOut)
+        {
+          (*errOut) << "argument of bound var list is not bound variable";
+        }
+        return TypeNode::null();
       }
     }
   }
@@ -111,14 +127,17 @@ TypeNode QuantifierInstPatternTypeRule::computeType(NodeManager* nodeManager,
   Assert(n.getKind() == Kind::INST_PATTERN);
   if (check)
   {
-    TypeNode tn = n[0].getType(check);
+    TypeNode tn = n[0].getTypeOrNull();
     // this check catches the common mistake writing :pattern (f x) instead of
     // :pattern ((f x))
     if (n[0].isVar() && n[0].getKind() != Kind::BOUND_VARIABLE
         && tn.isFunction())
     {
-      throw TypeCheckingExceptionPrivate(
-          n[0], "Pattern must be a list of fully-applied terms.");
+      if (errOut)
+      {
+        (*errOut) << "Pattern must be a list of fully-applied terms.";
+      }
+      return TypeNode::null();
     }
   }
   return nodeManager->instPatternType();
@@ -153,7 +172,7 @@ TypeNode QuantifierAnnotationTypeRule::computeType(NodeManager* nodeManager,
       // arguments must have set types
       for (const Node& nn : n)
       {
-        if (!nn.getType().isSet())
+        if (!nn.getTypeOrNull().isSet())
         {
           throw TypeCheckingExceptionPrivate(n, "Expecting a set as argument.");
         }
@@ -161,16 +180,19 @@ TypeNode QuantifierAnnotationTypeRule::computeType(NodeManager* nodeManager,
     }
     else if (k == Kind::INST_ADD_TO_POOL || k == Kind::SKOLEM_ADD_TO_POOL)
     {
-      TypeNode tn = n[0].getType();
-      TypeNode tn1 = n[1].getType();
+      TypeNode tn = n[0].getTypeOrNull();
+      TypeNode tn1 = n[1].getTypeOrNull();
       if (!tn1.isSet())
       {
         throw TypeCheckingExceptionPrivate(n, "Expecting a set as argument.");
       }
       if (tn1.getSetElementType() != tn)
       {
-        throw TypeCheckingExceptionPrivate(
-            n, "Type of term must match the element type of the pool.");
+        if (errOut)
+        {
+          (*errOut) << "Expecting a keyword at the head of INST_ATTRIBUTE.";
+        }
+        return TypeNode::null();
       }
     }
   }
@@ -195,15 +217,18 @@ TypeNode QuantifierInstPatternListTypeRule::computeType(
           && k != Kind::INST_ATTRIBUTE && k != Kind::INST_POOL
           && k != Kind::INST_ADD_TO_POOL && k != Kind::SKOLEM_ADD_TO_POOL)
       {
-        throw TypeCheckingExceptionPrivate(
-            n,
-            "argument of inst pattern list is not a legal quantifiers "
-            "annotation");
+        if (errOut)
+        {
+          (*errOut) << "argument of inst pattern list is not a legal "
+                       "quantifiers annotation";
+        }
+        return TypeNode::null();
       }
     }
   }
   return nodeManager->instPatternListType();
 }
+
 TypeNode QuantifierOracleFormulaGenTypeRule::preComputeType(NodeManager* nm,
                                                             TNode n)
 {
@@ -215,15 +240,21 @@ TypeNode QuantifierOracleFormulaGenTypeRule::computeType(
   Assert(n.getKind() == Kind::ORACLE_FORMULA_GEN);
   if (check)
   {
-    if (!n[0].getType().isBoolean())
+    if (!n[0].getTypeOrNull().isBoolean())
     {
-      throw TypeCheckingExceptionPrivate(
-          n, "expected Boolean for oracle interface assumption");
+      if (errOut)
+      {
+        (*errOut) << "expected Boolean for oracle interface assumption";
+      }
+      return TypeNode::null();
     }
-    if (!n[1].getType().isBoolean())
+    if (!n[1].getTypeOrNull().isBoolean())
     {
-      throw TypeCheckingExceptionPrivate(
-          n, "expected Boolean for oracle interface constraint");
+      if (errOut)
+      {
+        (*errOut) << "expected Boolean for oracle interface constraint";
+      }
+      return TypeNode::null();
     }
   }
   return nodeManager->booleanType();
