@@ -1,10 +1,10 @@
 /******************************************************************************
  * Top contributors (to current version):
- *   Andrew Reynolds, Aina Niemetz, Tim King
+ *   Andrew Reynolds, Tim King, Aina Niemetz
  *
  * This file is part of the cvc5 project.
  *
- * Copyright (c) 2009-2022 by the authors listed in the file AUTHORS
+ * Copyright (c) 2009-2023 by the authors listed in the file AUTHORS
  * in the top-level source directory and their institutional affiliations.
  * All rights reserved.  See the file COPYING in the top-level source
  * directory for licensing information.
@@ -38,6 +38,8 @@ namespace quantifiers {
  */
 struct QuantifierTypeRule
 {
+  static TypeNode preComputeType(NodeManager* nm, TNode n);
+
   static TypeNode computeType(NodeManager* nodeManager,
                               TNode n,
                               bool check,
@@ -50,6 +52,8 @@ struct QuantifierTypeRule
  */
 struct QuantifierBoundVarListTypeRule
 {
+  static TypeNode preComputeType(NodeManager* nm, TNode n);
+
   static TypeNode computeType(NodeManager* nodeManager,
                               TNode n,
                               bool check,
@@ -63,6 +67,8 @@ struct QuantifierBoundVarListTypeRule
  */
 struct QuantifierInstPatternTypeRule
 {
+  static TypeNode preComputeType(NodeManager* nm, TNode n);
+
   static TypeNode computeType(NodeManager* nodeManager,
                               TNode n,
                               bool check,
@@ -78,6 +84,8 @@ struct QuantifierInstPatternTypeRule
  */
 struct QuantifierAnnotationTypeRule
 {
+  static TypeNode preComputeType(NodeManager* nm, TNode n);
+
   static TypeNode computeType(NodeManager* nodeManager,
                               TNode n,
                               bool check,
@@ -91,6 +99,8 @@ struct QuantifierAnnotationTypeRule
  */
 struct QuantifierInstPatternListTypeRule
 {
+  static TypeNode preComputeType(NodeManager* nm, TNode n);
+
   static TypeNode computeType(NodeManager* nodeManager,
                               TNode n,
                               bool check,
@@ -104,6 +114,8 @@ struct QuantifierInstPatternListTypeRule
  */
 struct QuantifierOracleFormulaGenTypeRule
 {
+  static TypeNode preComputeType(NodeManager* nm, TNode n);
+
   static TypeNode computeType(NodeManager* nodeManager,
                               TNode n,
                               bool check,
