@@ -62,7 +62,7 @@ void CardinalityExtension::reset()
 void CardinalityExtension::registerTerm(Node n)
 {
   Trace("sets-card-debug") << "Register term : " << n << std::endl;
-  Assert(n.getKind() == SET_CARD);
+  Assert(n.getKind() == Kind::SET_CARD);
   TypeNode tnc = n[0].getType().getSetElementType();
   d_t_card_enabled[tnc] = true;
   Node r = d_state.getRepresentative(n[0]);
@@ -136,8 +136,8 @@ void CardinalityExtension::checkCardinalityExtended(TypeNode& t)
   {
     Node typeCardinality =
         nm->mkConstInt(Rational(card.getFiniteCardinality()));
-    Node cardUniv = nm->mkNode(kind::SET_CARD, proxy);
-    Node leq = nm->mkNode(kind::LEQ, cardUniv, typeCardinality);
+    Node cardUniv = nm->mkNode(Kind::SET_CARD, proxy);
+    Node leq = nm->mkNode(Kind::LEQ, cardUniv, typeCardinality);
 
     // (=> true (<= (card (as univset t)) cardUniv)
     if (!d_state.isEntailed(leq, true))
@@ -161,7 +161,7 @@ void CardinalityExtension::checkCardinalityExtended(TypeNode& t)
       }
 
       // (=> true (subset representative (as univset t))
-      Node subset = nm->mkNode(kind::SET_SUBSET, variable, proxy);
+      Node subset = nm->mkNode(Kind::SET_SUBSET, variable, proxy);
       // subset terms are rewritten as union terms: (subset A B) implies (=
       // (union A B) B)
       subset = rewrite(subset);
@@ -177,11 +177,11 @@ void CardinalityExtension::checkCardinalityExtended(TypeNode& t)
 
       for (const auto& negativeMember : negativeMembers)
       {
-        Node member = nm->mkNode(SET_MEMBER, negativeMember.first, univ);
+        Node member = nm->mkNode(Kind::SET_MEMBER, negativeMember.first, univ);
         // negativeMember.second is the reason for the negative membership and
         // has kind SET_MEMBER. So we specify the negation as the reason for the
         // negative membership lemma
-        Node notMember = nm->mkNode(NOT, negativeMember.second);
+        Node notMember = nm->mkNode(Kind::NOT, negativeMember.second);
         // (=>
         //    (not (member negativeMember representative)))
         //    (member negativeMember (as univset t)))
@@ -242,9 +242,9 @@ void CardinalityExtension::checkRegister()
       if (!d_state.isCongruent(n))
       {
         // if setminus, do for intersection instead
-        if (n.getKind() == SET_MINUS)
+        if (n.getKind() == Kind::SET_MINUS)
         {
-          n = rewrite(nm->mkNode(SET_INTER, n[0], n[1]));
+          n = rewrite(nm->mkNode(Kind::SET_INTER, n[0], n[1]));
         }
         registerCardinalityTerm(n);
       }
@@ -270,14 +270,14 @@ void CardinalityExtension::registerCardinalityTerm(Node n)
   NodeManager* nm = NodeManager::currentNM();
   Trace("sets-card") << "Cardinality lemmas for " << n << " : " << std::endl;
   std::vector<Node> cterms;
-  if (n.getKind() == SET_INTER)
+  if (n.getKind() == Kind::SET_INTER)
   {
     for (unsigned e = 0; e < 2; e++)
     {
-      Node s = nm->mkNode(SET_MINUS, n[e], n[1 - e]);
+      Node s = nm->mkNode(Kind::SET_MINUS, n[e], n[1 - e]);
       cterms.push_back(s);
     }
-    Node pos_lem = nm->mkNode(GEQ, nm->mkNode(SET_CARD, n), d_zero);
+    Node pos_lem = nm->mkNode(Kind::GEQ, nm->mkNode(Kind::SET_CARD, n), d_zero);
     d_im.assertInference(
         pos_lem, InferenceId::SETS_CARD_POSITIVE, d_emp_exp, 1);
   }
@@ -289,13 +289,15 @@ void CardinalityExtension::registerCardinalityTerm(Node n)
   {
     Node nn = cterms[k];
     Node nk = d_treg.getProxy(nn);
-    Node pos_lem = nm->mkNode(GEQ, nm->mkNode(SET_CARD, nk), d_zero);
+    Node pos_lem =
+        nm->mkNode(Kind::GEQ, nm->mkNode(Kind::SET_CARD, nk), d_zero);
     d_im.assertInference(
         pos_lem, InferenceId::SETS_CARD_POSITIVE, d_emp_exp, 1);
     if (nn != nk)
     {
-      Node lem =
-          nm->mkNode(EQUAL, nm->mkNode(SET_CARD, nk), nm->mkNode(SET_CARD, nn));
+      Node lem = nm->mkNode(Kind::EQUAL,
+                            nm->mkNode(Kind::SET_CARD, nk),
+                            nm->mkNode(Kind::SET_CARD, nn));
       lem = rewrite(lem);
       Trace("sets-card") << "  " << k << " : " << lem << std::endl;
       d_im.assertInference(lem, InferenceId::SETS_CARD_EQUAL, d_emp_exp, 1);
@@ -351,7 +353,7 @@ void CardinalityExtension::checkCardCyclesRec(Node eqc,
           conc.push_back(eqc.eqNode(cc));
         }
       }
-      Node fact = conc.size() == 1 ? conc[0] : nm->mkNode(AND, conc);
+      Node fact = conc.size() == 1 ? conc[0] : nm->mkNode(Kind::AND, conc);
       Trace("sets-cycle-debug")
           << "CYCLE: " << fact << " from " << exp << std::endl;
       d_im.assertInference(fact, InferenceId::SETS_CARD_CYCLE, exp);
@@ -383,7 +385,7 @@ void CardinalityExtension::checkCardCyclesRec(Node eqc,
   for (const Node& n : nvsets)
   {
     Kind nk = n.getKind();
-    if (nk != SET_INTER && nk != SET_MINUS)
+    if (nk != Kind::SET_INTER && nk != Kind::SET_MINUS)
     {
       continue;
     }
@@ -399,26 +401,26 @@ void CardinalityExtension::checkCardCyclesRec(Node eqc,
     // accurate. However, it may lead to issues if the rewritten form of a
     // node leads to unexpected relationships in the graph. To avoid this,
     // we ensure that universe is not a child of a set in the assertions above.
-    if (n.getKind() == SET_INTER)
+    if (n.getKind() == Kind::SET_INTER)
     {
       d_localBase[n] = n;
       for (unsigned e = 0; e < 2; e++)
       {
-        Node sm = rewrite(nm->mkNode(SET_MINUS, n[e], n[1 - e]));
+        Node sm = rewrite(nm->mkNode(Kind::SET_MINUS, n[e], n[1 - e]));
         sib.push_back(sm);
       }
       true_sib = 2;
     }
     else
     {
-      Node si = rewrite(nm->mkNode(SET_INTER, n[0], n[1]));
+      Node si = rewrite(nm->mkNode(Kind::SET_INTER, n[0], n[1]));
       sib.push_back(si);
       d_localBase[n] = si;
-      Node osm = rewrite(nm->mkNode(SET_MINUS, n[1], n[0]));
+      Node osm = rewrite(nm->mkNode(Kind::SET_MINUS, n[1], n[0]));
       sib.push_back(osm);
       true_sib = 1;
     }
-    Node u = rewrite(nm->mkNode(SET_UNION, n[0], n[1]));
+    Node u = rewrite(nm->mkNode(Kind::SET_UNION, n[0], n[1]));
     if (!d_state.hasTerm(u))
     {
       u = Node::null();
@@ -500,7 +502,7 @@ void CardinalityExtension::checkCardCyclesRec(Node eqc,
                 << "Sibling " << sib[si] << " is already empty." << std::endl;
           }
         }
-        if (!is_union && nk == SET_INTER && !u.isNull())
+        if (!is_union && nk == Kind::SET_INTER && !u.isNull())
         {
           // union is equal to other parent
           if (!d_state.areEqual(u, n[1 - e]))
@@ -544,7 +546,8 @@ void CardinalityExtension::checkCardCyclesRec(Node eqc,
         d_state.addEqualityToExp(cpk, eqccSingleton, exps);
         if (d_state.areDisequal(n, emp_set))
         {
-          exps.push_back(n.eqNode(emp_set).negate());
+          // ensure we can explain the disequality
+          d_state.explainDisequal(n, emp_set, exps);
           eq_parent = true;
         }
         else
@@ -588,7 +591,7 @@ void CardinalityExtension::checkCardCyclesRec(Node eqc,
                               << " are equal, ids = " << card_parent_ids[l]
                               << " " << card_parent_ids[k] << std::endl;
           dup = true;
-          if (n.getKind() != SET_INTER)
+          if (n.getKind() != Kind::SET_INTER)
           {
             continue;
           }
@@ -846,7 +849,7 @@ void CardinalityExtension::checkNormalForm(Node eqc,
                 Node r1 = e == 0 ? o0 : o1;
                 Node r2 = e == 0 ? o1 : o0;
                 // check if their intersection exists modulo equality
-                Node r1r2i = d_state.getBinaryOpTerm(SET_INTER, r1, r2);
+                Node r1r2i = d_state.getBinaryOpTerm(Kind::SET_INTER, r1, r2);
                 if (!r1r2i.isNull())
                 {
                   Trace("sets-nf-debug")
@@ -867,7 +870,7 @@ void CardinalityExtension::checkNormalForm(Node eqc,
                 Assert(o0 != o1);
                 Node kca = d_treg.getProxy(o0);
                 Node kcb = d_treg.getProxy(o1);
-                Node intro = rewrite(nm->mkNode(SET_INTER, kca, kcb));
+                Node intro = rewrite(nm->mkNode(Kind::SET_INTER, kca, kcb));
                 Trace("sets-nf") << "   Intro split : " << o0 << " against " << o1
                                 << ", term is " << intro << std::endl;
                 intro_sets.push_back(intro);
@@ -999,22 +1002,22 @@ void CardinalityExtension::checkMinCard()
     }
     else
     {
-      cardTerm = nm->mkNode(SET_CARD, eqc);
+      cardTerm = nm->mkNode(Kind::SET_CARD, eqc);
     }
     for (const std::pair<const Node, Node>& itmm : pmemsE)
     {
       members.push_back(itmm.first);
-      exp.push_back(nm->mkNode(SET_MEMBER, itmm.first, cardTerm[0]));
+      exp.push_back(nm->mkNode(Kind::SET_MEMBER, itmm.first, cardTerm[0]));
     }
     if (members.size() > 1)
     {
-      exp.push_back(nm->mkNode(DISTINCT, members));
+      exp.push_back(nm->mkNode(Kind::DISTINCT, members));
     }
     if (!members.empty())
     {
-      Node conc =
-          nm->mkNode(GEQ, cardTerm, nm->mkConstInt(Rational(members.size())));
-      Node expn = exp.size() == 1 ? exp[0] : nm->mkNode(AND, exp);
+      Node conc = nm->mkNode(
+          Kind::GEQ, cardTerm, nm->mkConstInt(Rational(members.size())));
+      Node expn = exp.size() == 1 ? exp[0] : nm->mkNode(Kind::AND, exp);
       d_im.assertInference(conc, InferenceId::SETS_CARD_MINIMAL, expn, 1);
     }
   }
@@ -1081,7 +1084,7 @@ void CardinalityExtension::mkModelValueElementsFor(
           // the current members of this finite type.
 
           Node slack = sm->mkDummySkolem("slack", elementType);
-          Node singleton = nm->mkNode(SET_SINGLETON, slack);
+          Node singleton = nm->mkNode(Kind::SET_SINGLETON, slack);
           els.push_back(singleton);
           d_finite_type_slack_elements[elementType].push_back(slack);
           Trace("sets-model") << "Added slack element " << slack << " to set "
@@ -1089,7 +1092,7 @@ void CardinalityExtension::mkModelValueElementsFor(
         }
         else
         {
-          els.push_back(nm->mkNode(SET_SINGLETON,
+          els.push_back(nm->mkNode(Kind::SET_SINGLETON,
                                    sm->mkDummySkolem("msde", elementType)));
         }
       }
