@@ -90,7 +90,7 @@ SetEnumerator& SetEnumerator::operator++()
     // get a new element and return it as a singleton set
     Node element = *d_elementEnumerator;
     d_elementsSoFar.push_back(element);
-    d_currentSet = d_nodeManager->mkNode(kind::SET_SINGLETON, element);
+    d_currentSet = d_nodeManager->mkNode(Kind::SET_SINGLETON, element);
     d_elementEnumerator++;
   }
   else
