@@ -89,7 +89,7 @@ void CodePointSolver::checkCodes()
       }
       codeArg = ei->d_codeTerm.get();
     }
-    Node vc = nm->mkNode(kind::STRING_TO_CODE, codeArg);
+    Node vc = nm->mkNode(Kind::STRING_TO_CODE, codeArg);
     // only relevant for injectivity if not already equal to negative one
     if (d_state.areEqual(vc, d_negOne))
     {
@@ -138,7 +138,7 @@ void CodePointSolver::checkCodes()
     Node deq = c[0].eqNode(c[1]).negate();
     Node eqn = c[0][0].eqNode(c[1][0]);
     // str.code(x)==-1 V str.code(x)!=str.code(y) V x==y
-    Node inj_lem = nm->mkNode(kind::OR, eq_no, deq, eqn);
+    Node inj_lem = nm->mkNode(Kind::OR, eq_no, deq, eqn);
     deq = rewrite(deq);
     d_im.addPendingPhaseRequirement(deq, false);
     std::vector<Node> emptyVec;
