@@ -229,11 +229,13 @@ void ExtfSolver::doReduction(Node n, int pol)
     else
     {
       InferInfo ii(InferenceId::STRINGS_REDUCTION);
+      // ensure that we are called to process the side effects
+      ii.d_sim = this;
       ii.d_conc = nnlem;
       d_im.sendInference(ii, true);
       Trace("strings-extf-debug")
           << "  resolve extf : " << n << " based on reduction." << std::endl;
-      d_reduced.insert(nn);
+      d_reductionWaitingMap[nnlem] = nn;
     }
   }
 }
@@ -818,6 +820,25 @@ bool StringsExtfCallback::getCurrentSubstitution(
   return true;
 }
 
+void ExtfSolver::processFact(InferInfo& ii, ProofGenerator*& pg)
+{
+  // process it with the inference manager
+  d_im.processFact(ii, pg);
+}
+
+TrustNode ExtfSolver::processLemma(InferInfo& ii, LemmaProperty& p)
+{
+  // if this was the reduction lemma for a term, mark it reduced now
+  std::map<Node, Node>::iterator it = d_reductionWaitingMap.find(ii.d_conc);
+  if (it != d_reductionWaitingMap.end())
+  {
+    d_reduced.insert(it->second);
+    d_reductionWaitingMap.erase(it);
+  }
+  // now process it with the inference manager
+  return d_im.processLemma(ii, p);
+}
+
 std::string ExtfSolver::debugPrintModel()
 {
   std::stringstream ss;
