@@ -36,7 +36,7 @@ Node InferInfo::processFact(std::vector<Node>& exp, ProofGenerator*& pg)
 {
   for (const Node& ec : d_premises)
   {
-    utils::flattenOp(kind::AND, ec, exp);
+    utils::flattenOp(Kind::AND, ec, exp);
   }
   d_sim->processFact(*this, pg);
   return d_conc;
@@ -57,7 +57,7 @@ bool InferInfo::isConflict() const
 bool InferInfo::isFact() const
 {
   Assert(!d_conc.isNull());
-  TNode atom = d_conc.getKind() == kind::NOT ? d_conc[0] : d_conc;
+  TNode atom = d_conc.getKind() == Kind::NOT ? d_conc[0] : d_conc;
   // we could process inferences with conjunctive conclusions as facts, where
   // the explanation is copied. However, for simplicity, we always send these
   // as lemmas. This case happens very infrequently.
