@@ -434,6 +434,7 @@ void InferProofCons::convert(InferenceId infer,
         std::vector<Node> childrenC;
         childrenC.push_back(mainEqCeq);
         // if it is between sequences, we require the explicit disequality
+        ProofRule r = ProofRule::CONCAT_CONFLICT;
         if (mainEqCeq[0].getType().isSequence())
         {
           Assert(t0.isConst() && s0.isConst());
@@ -442,11 +443,11 @@ void InferProofCons::convert(InferenceId infer,
           psb.addStep(ProofRule::MACRO_SR_PRED_INTRO, {}, {deq}, deq);
           Assert(!deq.isNull());
           childrenC.push_back(deq);
+          r = ProofRule::CONCAT_CONFLICT_DEQ;
         }
         std::vector<Node> argsC;
         argsC.push_back(nodeIsRev);
-        Node conflict =
-            psb.tryStep(ProofRule::CONCAT_CONFLICT, childrenC, argsC);
+        Node conflict = psb.tryStep(r, childrenC, argsC);
         if (conflict == conc)
         {
           useBuffer = true;
