@@ -38,7 +38,7 @@ class StringProofRuleChecker : public ProofRuleChecker
 
  protected:
   /** Return the conclusion of the given proof step, or null if it is invalid */
-  Node checkInternal(PfRule id,
+  Node checkInternal(ProofRule id,
                      const std::vector<Node>& children,
                      const std::vector<Node>& args) override;
   /** cardinality of the alphabet, which impacts certain inferences */
