@@ -59,12 +59,12 @@ RegExpElimination::RegExpElimination(Env& env, bool isAgg, context::Context* c)
 
 Node RegExpElimination::eliminate(Node atom, bool isAgg)
 {
-  Assert(atom.getKind() == STRING_IN_REGEXP);
-  if (atom[1].getKind() == REGEXP_CONCAT)
+  Assert(atom.getKind() == Kind::STRING_IN_REGEXP);
+  if (atom[1].getKind() == Kind::REGEXP_CONCAT)
   {
     return eliminateConcat(atom, isAgg);
   }
-  else if (atom[1].getKind() == REGEXP_STAR)
+  else if (atom[1].getKind() == Kind::REGEXP_STAR)
   {
     return eliminateStar(atom, isAgg);
   }
@@ -83,7 +83,7 @@ TrustNode RegExpElimination::eliminateTrusted(Node atom)
       Node eq = atom.eqNode(eatom);
       Node aggn = NodeManager::currentNM()->mkConst(d_isAggressive);
       std::shared_ptr<ProofNode> pn =
-          pnm->mkNode(PfRule::RE_ELIM, {}, {atom, aggn}, eq);
+          pnm->mkNode(ProofRule::RE_ELIM, {}, {atom, aggn}, eq);
       d_epg->setProofFor(eq, pn);
       return TrustNode::mkTrustRewrite(atom, eatom, d_epg.get());
     }
@@ -97,7 +97,7 @@ Node RegExpElimination::eliminateConcat(Node atom, bool isAgg)
   NodeManager* nm = NodeManager::currentNM();
   BoundVarManager* bvm = nm->getBoundVarManager();
   Node x = atom[0];
-  Node lenx = nm->mkNode(STRING_LENGTH, x);
+  Node lenx = nm->mkNode(Kind::STRING_LENGTH, x);
   Node re = atom[1];
   Node zero = nm->mkConstInt(Rational(0));
   std::vector<Node> children;
@@ -121,8 +121,8 @@ Node RegExpElimination::eliminateConcat(Node atom, bool isAgg)
     Node fl = RegExpEntail::getFixedLengthForRegexp(c);
     if (fl.isNull())
     {
-      if (!hasPivotIndex && c.getKind() == REGEXP_STAR
-          && c[0].getKind() == REGEXP_ALLCHAR)
+      if (!hasPivotIndex && c.getKind() == Kind::REGEXP_STAR
+          && c[0].getKind() == Kind::REGEXP_ALLCHAR)
       {
         hasPivotIndex = true;
         pivotIndex = i;
@@ -144,14 +144,15 @@ Node RegExpElimination::eliminateConcat(Node atom, bool isAgg)
     }
   }
   Node lenSum = childLengths.size() > 1
-                    ? nm->mkNode(ADD, childLengths)
+                    ? nm->mkNode(Kind::ADD, childLengths)
                     : (childLengths.empty() ? zero : childLengths[0]);
   // if we have a fixed length
   if (hasFixedLength)
   {
     Assert(re.getNumChildren() == children.size());
     std::vector<Node> conc;
-    conc.push_back(nm->mkNode(hasPivotIndex ? GEQ : EQUAL, lenx, lenSum));
+    conc.push_back(
+        nm->mkNode(hasPivotIndex ? Kind::GEQ : Kind::EQUAL, lenx, lenSum));
     Node currEnd = zero;
     for (unsigned i = 0, size = childLengths.size(); i < size; i++)
     {
@@ -159,24 +160,25 @@ Node RegExpElimination::eliminateConcat(Node atom, bool isAgg)
       {
         Node ppSum = childLengthsPostPivot.size() == 1
                          ? childLengthsPostPivot[0]
-                         : nm->mkNode(ADD, childLengthsPostPivot);
-        currEnd = nm->mkNode(SUB, lenx, ppSum);
+                         : nm->mkNode(Kind::ADD, childLengthsPostPivot);
+        currEnd = nm->mkNode(Kind::SUB, lenx, ppSum);
       }
       else
       {
-        Node curr = nm->mkNode(STRING_SUBSTR, x, currEnd, childLengths[i]);
+        Node curr =
+            nm->mkNode(Kind::STRING_SUBSTR, x, currEnd, childLengths[i]);
         // We do not need to include memberships of the form
         //   (str.substr x n 1) in re.allchar
         // since we know that by construction, n < len( x ).
-        if (re[i].getKind() != REGEXP_ALLCHAR)
+        if (re[i].getKind() != Kind::REGEXP_ALLCHAR)
         {
-          Node currMem = nm->mkNode(STRING_IN_REGEXP, curr, re[i]);
+          Node currMem = nm->mkNode(Kind::STRING_IN_REGEXP, curr, re[i]);
           conc.push_back(currMem);
         }
-        currEnd = nm->mkNode(ADD, currEnd, childLengths[i]);
+        currEnd = nm->mkNode(Kind::ADD, currEnd, childLengths[i]);
       }
     }
-    Node res = nm->mkNode(AND, conc);
+    Node res = nm->mkNode(Kind::AND, conc);
     // For example:
     //   x in re.++(re.union(re.range("A", "J"), re.range("N", "Z")), "AB") -->
     //   len( x ) = 3 ^
@@ -204,7 +206,7 @@ Node RegExpElimination::eliminateConcat(Node atom, bool isAgg)
   {
     Trace("re-elim-debug") << "  " << c << std::endl;
     onlySigmasAndConsts = false;
-    if (c.getKind() == STRING_TO_REGEXP)
+    if (c.getKind() == Kind::STRING_TO_REGEXP)
     {
       onlySigmasAndConsts = true;
       sep_children.push_back(c[0]);
@@ -212,13 +214,14 @@ Node RegExpElimination::eliminateConcat(Node atom, bool isAgg)
       gap_minsize.push_back(0);
       gap_exact.push_back(true);
     }
-    else if (c.getKind() == REGEXP_STAR && c[0].getKind() == REGEXP_ALLCHAR)
+    else if (c.getKind() == Kind::REGEXP_STAR
+             && c[0].getKind() == Kind::REGEXP_ALLCHAR)
     {
       // found a gap of any size
       onlySigmasAndConsts = true;
       gap_exact[gap_exact.size() - 1] = false;
     }
-    else if (c.getKind() == REGEXP_ALLCHAR)
+    else if (c.getKind() == Kind::REGEXP_ALLCHAR)
     {
       // add one to the minimum size of the gap
       onlySigmasAndConsts = true;
@@ -252,19 +255,19 @@ Node RegExpElimination::eliminateConcat(Node atom, bool isAgg)
       if (gap_minsize[i] > 0)
       {
         // the gap to this child is at least gap_minsize[i]
-        prev_end =
-            nm->mkNode(ADD, prev_end, nm->mkConstInt(Rational(gap_minsize[i])));
+        prev_end = nm->mkNode(
+            Kind::ADD, prev_end, nm->mkConstInt(Rational(gap_minsize[i])));
       }
       prev_ends.push_back(prev_end);
       Node sc = sep_children[i];
-      Node lensc = nm->mkNode(STRING_LENGTH, sc);
+      Node lensc = nm->mkNode(Kind::STRING_LENGTH, sc);
       if (gap_exact[i])
       {
         // if the gap is exact, it is a substring constraint
         Node curr = prev_end;
-        Node ss = nm->mkNode(STRING_SUBSTR, x, curr, lensc);
+        Node ss = nm->mkNode(Kind::STRING_SUBSTR, x, curr, lensc);
         conj.push_back(ss.eqNode(sc));
-        prev_end = nm->mkNode(ADD, curr, lensc);
+        prev_end = nm->mkNode(Kind::ADD, curr, lensc);
       }
       else
       {
@@ -284,12 +287,12 @@ Node RegExpElimination::eliminateConcat(Node atom, bool isAgg)
           Node k =
               bvm->mkBoundVar<ReElimConcatIndexAttribute>(cacheVal, intType);
           non_greedy_find_vars.push_back(k);
-          prev_end = nm->mkNode(ADD, prev_end, k);
+          prev_end = nm->mkNode(Kind::ADD, prev_end, k);
         }
-        Node curr = nm->mkNode(STRING_INDEXOF, x, sc, prev_end);
+        Node curr = nm->mkNode(Kind::STRING_INDEXOF, x, sc, prev_end);
         Node idofFind = curr.eqNode(nm->mkConstInt(Rational(-1))).negate();
         conj.push_back(idofFind);
-        prev_end = nm->mkNode(ADD, curr, lensc);
+        prev_end = nm->mkNode(Kind::ADD, curr, lensc);
       }
     }
 
@@ -311,9 +314,10 @@ Node RegExpElimination::eliminateConcat(Node atom, bool isAgg)
         //     x in (re.++ "A" (re.* _) "B" _ _) --->
         //        ... ^ "B" = substr( x, len( x ) - 3, 1 )  ^ ...
         Node sc = sep_children.back();
-        Node lenSc = nm->mkNode(STRING_LENGTH, sc);
-        Node loc = nm->mkNode(SUB, lenx, nm->mkNode(ADD, lenSc, cEnd));
-        Node scc = sc.eqNode(nm->mkNode(STRING_SUBSTR, x, loc, lenSc));
+        Node lenSc = nm->mkNode(Kind::STRING_LENGTH, sc);
+        Node loc =
+            nm->mkNode(Kind::SUB, lenx, nm->mkNode(Kind::ADD, lenSc, cEnd));
+        Node scc = sc.eqNode(nm->mkNode(Kind::STRING_SUBSTR, x, loc, lenSc));
         // We also must ensure that we fit. This constraint is necessary in
         // addition to the constraint above. Take this example:
         //     x in (re.++ "A" _ (re.* _) "B" _) --->
@@ -338,9 +342,10 @@ Node RegExpElimination::eliminateConcat(Node atom, bool isAgg)
         // above says that the "B" we find at end-2 can be found >=1 after
         // the "A".
         conj.pop_back();
-        Node fit = nm->mkNode(gap_exact[sep_children.size() - 1] ? EQUAL : LEQ,
-                              prev_ends.back(),
-                              loc);
+        Node fit = nm->mkNode(
+            gap_exact[sep_children.size() - 1] ? Kind::EQUAL : Kind::LEQ,
+            prev_ends.back(),
+            loc);
 
         conj.push_back(scc);
         conj.push_back(fit);
@@ -352,7 +357,8 @@ Node RegExpElimination::eliminateConcat(Node atom, bool isAgg)
         // For example:
         //     x in (re.++ "A" (re.* _) "B" _ _ (re.* _)) --->
         //        ... ^ indexof( x, "B", 1 ) + 2 <= len( x )
-        Node fit = nm->mkNode(LEQ, nm->mkNode(ADD, prev_end, cEnd), lenx);
+        Node fit =
+            nm->mkNode(Kind::LEQ, nm->mkNode(Kind::ADD, prev_end, cEnd), lenx);
         conj.push_back(fit);
       }
       Node res = nm->mkAnd(conj);
@@ -362,17 +368,18 @@ Node RegExpElimination::eliminateConcat(Node atom, bool isAgg)
         std::vector<Node> children2;
         for (const Node& v : non_greedy_find_vars)
         {
-          Node bound = nm->mkNode(
-              AND, nm->mkNode(LEQ, zero, v), nm->mkNode(LT, v, lenx));
+          Node bound = nm->mkNode(Kind::AND,
+                                  nm->mkNode(Kind::LEQ, zero, v),
+                                  nm->mkNode(Kind::LT, v, lenx));
           children2.push_back(bound);
         }
         children2.push_back(res);
-        Node body = nm->mkNode(AND, children2);
-        Node bvl = nm->mkNode(BOUND_VAR_LIST, non_greedy_find_vars);
+        Node body = nm->mkNode(Kind::AND, children2);
+        Node bvl = nm->mkNode(Kind::BOUND_VAR_LIST, non_greedy_find_vars);
         res = utils::mkForallInternal(bvl, body.negate()).negate();
       }
       // must also give a minimum length requirement
-      res = nm->mkNode(AND, res, nm->mkNode(GEQ, lenx, lenSum));
+      res = nm->mkNode(Kind::AND, res, nm->mkNode(Kind::GEQ, lenx, lenSum));
       // Examples of this elimination:
       //   x in (re.++ "A" (re.* _) "B" (re.* _)) --->
       //     substr(x,0,1)="A" ^ indexof(x,"B",1)!=-1
@@ -410,13 +417,14 @@ Node RegExpElimination::eliminateConcat(Node atom, bool isAgg)
   {
     unsigned index = r == 0 ? 0 : nchildren - 1;
     Node c = children[index];
-    if (c.getKind() == STRING_TO_REGEXP)
+    if (c.getKind() == Kind::STRING_TO_REGEXP)
     {
-      Assert(children[index + (r == 0 ? 1 : -1)].getKind() != STRING_TO_REGEXP);
+      Assert(children[index + (r == 0 ? 1 : -1)].getKind()
+             != Kind::STRING_TO_REGEXP);
       Node s = c[0];
-      Node lens = nm->mkNode(STRING_LENGTH, s);
-      Node sss = r == 0 ? zero : nm->mkNode(SUB, lenx, lens);
-      Node ss = nm->mkNode(STRING_SUBSTR, x, sss, lens);
+      Node lens = nm->mkNode(Kind::STRING_LENGTH, s);
+      Node sss = r == 0 ? zero : nm->mkNode(Kind::SUB, lenx, lens);
+      Node ss = nm->mkNode(Kind::STRING_SUBSTR, x, sss, lens);
       sConstraints.push_back(ss.eqNode(s));
       if (r == 0)
       {
@@ -425,10 +433,10 @@ Node RegExpElimination::eliminateConcat(Node atom, bool isAgg)
       else if (r == 1 && sConstraints.size() == 2)
       {
         // first and last children cannot overlap
-        Node bound = nm->mkNode(GEQ, sss, sStartIndex);
+        Node bound = nm->mkNode(Kind::GEQ, sss, sStartIndex);
         sConstraints.push_back(bound);
       }
-      sLength = nm->mkNode(SUB, sLength, lens);
+      sLength = nm->mkNode(Kind::SUB, sLength, lens);
     }
     if (r == 1 && !sConstraints.empty())
     {
@@ -438,18 +446,18 @@ Node RegExpElimination::eliminateConcat(Node atom, bool isAgg)
         rexpElimChildren.push_back(children[i]);
       }
     }
-    if (c.getKind() != STRING_TO_REGEXP)
+    if (c.getKind() != Kind::STRING_TO_REGEXP)
     {
       rexpElimChildren.push_back(c);
     }
   }
   if (!sConstraints.empty())
   {
-    Node ss = nm->mkNode(STRING_SUBSTR, x, sStartIndex, sLength);
+    Node ss = nm->mkNode(Kind::STRING_SUBSTR, x, sStartIndex, sLength);
     Assert(!rexpElimChildren.empty());
     Node regElim = utils::mkConcat(rexpElimChildren, nm->regExpType());
-    sConstraints.push_back(nm->mkNode(STRING_IN_REGEXP, ss, regElim));
-    Node ret = nm->mkNode(AND, sConstraints);
+    sConstraints.push_back(nm->mkNode(Kind::STRING_IN_REGEXP, ss, regElim));
+    Node ret = nm->mkNode(Kind::AND, sConstraints);
     // e.g.
     // x in re.++( "A", R ) ---> substr(x,0,1)="A" ^ substr(x,1,len(x)-1) in R
     return returnElim(atom, ret, "concat-splice");
@@ -457,10 +465,10 @@ Node RegExpElimination::eliminateConcat(Node atom, bool isAgg)
   Assert(nchildren > 1);
   for (unsigned i = 0; i < nchildren; i++)
   {
-    if (children[i].getKind() == STRING_TO_REGEXP)
+    if (children[i].getKind() == Kind::STRING_TO_REGEXP)
     {
       Node s = children[i][0];
-      Node lens = nm->mkNode(STRING_LENGTH, s);
+      Node lens = nm->mkNode(Kind::STRING_LENGTH, s);
       // there exists an index in this string such that the substring is this
       Node k;
       std::vector<Node> echildren;
@@ -470,7 +478,7 @@ Node RegExpElimination::eliminateConcat(Node atom, bool isAgg)
       }
       else if (i + 1 == nchildren)
       {
-        k = nm->mkNode(SUB, lenx, lens);
+        k = nm->mkNode(Kind::SUB, lenx, lens);
       }
       else
       {
@@ -478,21 +486,23 @@ Node RegExpElimination::eliminateConcat(Node atom, bool isAgg)
             BoundVarManager::getCacheValue(atom, nm->mkConstInt(Rational(i)));
         TypeNode intType = nm->integerType();
         k = bvm->mkBoundVar<ReElimConcatIndexAttribute>(cacheVal, intType);
-        Node bound =
-            nm->mkNode(AND,
-                       nm->mkNode(LEQ, zero, k),
-                       nm->mkNode(LEQ, k, nm->mkNode(SUB, lenx, lens)));
+        Node bound = nm->mkNode(
+            Kind::AND,
+            nm->mkNode(Kind::LEQ, zero, k),
+            nm->mkNode(Kind::LEQ, k, nm->mkNode(Kind::SUB, lenx, lens)));
         echildren.push_back(bound);
       }
-      Node substrEq = nm->mkNode(STRING_SUBSTR, x, k, lens).eqNode(s);
+      Node substrEq = nm->mkNode(Kind::STRING_SUBSTR, x, k, lens).eqNode(s);
       echildren.push_back(substrEq);
       if (i > 0)
       {
         std::vector<Node> rprefix;
         rprefix.insert(rprefix.end(), children.begin(), children.begin() + i);
         Node rpn = utils::mkConcat(rprefix, nm->regExpType());
-        Node substrPrefix = nm->mkNode(
-            STRING_IN_REGEXP, nm->mkNode(STRING_SUBSTR, x, zero, k), rpn);
+        Node substrPrefix =
+            nm->mkNode(Kind::STRING_IN_REGEXP,
+                       nm->mkNode(Kind::STRING_SUBSTR, x, zero, k),
+                       rpn);
         echildren.push_back(substrPrefix);
       }
       if (i + 1 < nchildren)
@@ -500,17 +510,18 @@ Node RegExpElimination::eliminateConcat(Node atom, bool isAgg)
         std::vector<Node> rsuffix;
         rsuffix.insert(rsuffix.end(), children.begin() + i + 1, children.end());
         Node rps = utils::mkConcat(rsuffix, nm->regExpType());
-        Node ks = nm->mkNode(ADD, k, lens);
+        Node ks = nm->mkNode(Kind::ADD, k, lens);
         Node substrSuffix = nm->mkNode(
-            STRING_IN_REGEXP,
-            nm->mkNode(STRING_SUBSTR, x, ks, nm->mkNode(SUB, lenx, ks)),
+            Kind::STRING_IN_REGEXP,
+            nm->mkNode(
+                Kind::STRING_SUBSTR, x, ks, nm->mkNode(Kind::SUB, lenx, ks)),
             rps);
         echildren.push_back(substrSuffix);
       }
-      Node body = nm->mkNode(AND, echildren);
-      if (k.getKind() == BOUND_VARIABLE)
+      Node body = nm->mkNode(Kind::AND, echildren);
+      if (k.getKind() == Kind::BOUND_VARIABLE)
       {
-        Node bvl = nm->mkNode(BOUND_VAR_LIST, k);
+        Node bvl = nm->mkNode(Kind::BOUND_VAR_LIST, k);
         body = utils::mkForallInternal(bvl, body.negate()).negate();
       }
       // e.g. x in re.++( R1, "AB", R2 ) --->
@@ -536,14 +547,14 @@ Node RegExpElimination::eliminateStar(Node atom, bool isAgg)
   NodeManager* nm = NodeManager::currentNM();
   BoundVarManager* bvm = nm->getBoundVarManager();
   Node x = atom[0];
-  Node lenx = nm->mkNode(STRING_LENGTH, x);
+  Node lenx = nm->mkNode(Kind::STRING_LENGTH, x);
   Node re = atom[1];
   Node zero = nm->mkConstInt(Rational(0));
   // for regular expression star,
   // if the period is a fixed constant, we can turn it into a bounded
   // quantifier
   std::vector<Node> disj;
-  if (re[0].getKind() == REGEXP_UNION)
+  if (re[0].getKind() == Kind::REGEXP_UNION)
   {
     for (const Node& r : re[0])
     {
@@ -559,16 +570,16 @@ Node RegExpElimination::eliminateStar(Node atom, bool isAgg)
   TypeNode intType = nm->integerType();
   Node index = bvm->mkBoundVar<ReElimStarIndexAttribute>(atom, intType);
   Node substr_ch =
-      nm->mkNode(STRING_SUBSTR, x, index, nm->mkConstInt(Rational(1)));
+      nm->mkNode(Kind::STRING_SUBSTR, x, index, nm->mkConstInt(Rational(1)));
   // handle the case where it is purely characters
   for (const Node& r : disj)
   {
-    Assert(r.getKind() != REGEXP_UNION);
-    Assert(r.getKind() != REGEXP_ALLCHAR);
+    Assert(r.getKind() != Kind::REGEXP_UNION);
+    Assert(r.getKind() != Kind::REGEXP_ALLCHAR);
     lenOnePeriod = false;
     // lenOnePeriod is true if this regular expression is a single character
     // regular expression
-    if (r.getKind() == STRING_TO_REGEXP)
+    if (r.getKind() == Kind::STRING_TO_REGEXP)
     {
       Node s = r[0];
       if (s.isConst() && s.getConst<String>().size() == 1)
@@ -576,7 +587,7 @@ Node RegExpElimination::eliminateStar(Node atom, bool isAgg)
         lenOnePeriod = true;
       }
     }
-    else if (r.getKind() == REGEXP_RANGE)
+    else if (r.getKind() == Kind::REGEXP_RANGE)
     {
       lenOnePeriod = true;
     }
@@ -586,19 +597,21 @@ Node RegExpElimination::eliminateStar(Node atom, bool isAgg)
     }
     else
     {
-      Node regexp_ch = nm->mkNode(STRING_IN_REGEXP, substr_ch, r);
+      Node regexp_ch = nm->mkNode(Kind::STRING_IN_REGEXP, substr_ch, r);
       char_constraints.push_back(regexp_ch);
     }
   }
   if (lenOnePeriod)
   {
     Assert(!char_constraints.empty());
-    Node bound = nm->mkNode(
-        AND, nm->mkNode(LEQ, zero, index), nm->mkNode(LT, index, lenx));
-    Node conc = char_constraints.size() == 1 ? char_constraints[0]
-                                             : nm->mkNode(OR, char_constraints);
-    Node body = nm->mkNode(OR, bound.negate(), conc);
-    Node bvl = nm->mkNode(BOUND_VAR_LIST, index);
+    Node bound = nm->mkNode(Kind::AND,
+                            nm->mkNode(Kind::LEQ, zero, index),
+                            nm->mkNode(Kind::LT, index, lenx));
+    Node conc = char_constraints.size() == 1
+                    ? char_constraints[0]
+                    : nm->mkNode(Kind::OR, char_constraints);
+    Node body = nm->mkNode(Kind::OR, bound.negate(), conc);
+    Node bvl = nm->mkNode(Kind::BOUND_VAR_LIST, index);
     Node res = utils::mkForallInternal(bvl, body);
     // e.g.
     //   x in (re.* (re.union "A" "B" )) --->
@@ -609,7 +622,7 @@ Node RegExpElimination::eliminateStar(Node atom, bool isAgg)
   if (disj.size() == 1)
   {
     Node r = disj[0];
-    if (r.getKind() == STRING_TO_REGEXP)
+    if (r.getKind() == Kind::STRING_TO_REGEXP)
     {
       Node s = r[0];
       if (s.isConst())
@@ -619,17 +632,23 @@ Node RegExpElimination::eliminateStar(Node atom, bool isAgg)
         std::vector<Node> conj;
         // lens is a positive constant, so it is safe to use total div/mod here.
         Node bound = nm->mkNode(
-            AND,
-            nm->mkNode(LEQ, zero, index),
-            nm->mkNode(LT, index, nm->mkNode(INTS_DIVISION_TOTAL, lenx, lens)));
-        Node conc =
-            nm->mkNode(STRING_SUBSTR, x, nm->mkNode(MULT, index, lens), lens)
-                .eqNode(s);
-        Node body = nm->mkNode(OR, bound.negate(), conc);
-        Node bvl = nm->mkNode(BOUND_VAR_LIST, index);
+            Kind::AND,
+            nm->mkNode(Kind::LEQ, zero, index),
+            nm->mkNode(Kind::LT,
+                       index,
+                       nm->mkNode(Kind::INTS_DIVISION_TOTAL, lenx, lens)));
+        Node conc = nm->mkNode(Kind::STRING_SUBSTR,
+                               x,
+                               nm->mkNode(Kind::MULT, index, lens),
+                               lens)
+                        .eqNode(s);
+        Node body = nm->mkNode(Kind::OR, bound.negate(), conc);
+        Node bvl = nm->mkNode(Kind::BOUND_VAR_LIST, index);
         Node res = utils::mkForallInternal(bvl, body);
         res = nm->mkNode(
-            AND, nm->mkNode(INTS_MODULUS_TOTAL, lenx, lens).eqNode(zero), res);
+            Kind::AND,
+            nm->mkNode(Kind::INTS_MODULUS_TOTAL, lenx, lens).eqNode(zero),
+            res);
         // e.g.
         //    x in ("abc")* --->
         //    forall k. 0 <= k < (len( x ) div 3) => substr(x,3*k,3) = "abc" ^
