@@ -46,7 +46,7 @@ RegExpSolver::RegExpSolver(Env& env,
       d_regexp_opr(env, tr.getSkolemCache())
 {
   d_emptyString = NodeManager::currentNM()->mkConst(cvc5::internal::String(""));
-  d_emptyRegexp = NodeManager::currentNM()->mkNode(REGEXP_NONE);
+  d_emptyRegexp = NodeManager::currentNM()->mkNode(Kind::REGEXP_NONE);
   d_true = NodeManager::currentNM()->mkConst(true);
   d_false = NodeManager::currentNM()->mkConst(false);
 }
@@ -80,7 +80,7 @@ std::map<Node, std::vector<Node>> RegExpSolver::computeAssertions(Kind k) const
 
 void RegExpSolver::computeAssertedMemberships()
 {
-  d_assertedMems = computeAssertions(STRING_IN_REGEXP);
+  d_assertedMems = computeAssertions(Kind::STRING_IN_REGEXP);
 }
 
 void RegExpSolver::checkMemberships(Theory::Effort e)
@@ -142,11 +142,11 @@ void RegExpSolver::checkMembershipsEager()
     return;
   }
   // eagerly reduce positive membership into re.++
-  std::vector<Node> mems = d_esolver.getActive(STRING_IN_REGEXP);
+  std::vector<Node> mems = d_esolver.getActive(Kind::STRING_IN_REGEXP);
   for (const Node& n : mems)
   {
-    Assert(n.getKind() == STRING_IN_REGEXP);
-    if (n[1].getKind() != REGEXP_CONCAT)
+    Assert(n.getKind() == Kind::STRING_IN_REGEXP);
+    if (n[1].getKind() != Kind::REGEXP_CONCAT)
     {
       // not a membership into concatenation
       continue;
@@ -211,7 +211,7 @@ void RegExpSolver::checkUnfold(Theory::Effort e)
     {
       Node assertion = mp.first;
       Node rep = mp.second;
-      bool polarity = assertion.getKind() != NOT;
+      bool polarity = assertion.getKind() != Kind::NOT;
       if (polarity != checkPol)
       {
         continue;
@@ -278,9 +278,9 @@ void RegExpSolver::checkUnfold(Theory::Effort e)
 bool RegExpSolver::doUnfold(const Node& assertion)
 {
   bool ret = false;
-  bool polarity = assertion.getKind() != NOT;
+  bool polarity = assertion.getKind() != Kind::NOT;
   Node atom = polarity ? assertion : assertion[0];
-  Assert(atom.getKind() == STRING_IN_REGEXP);
+  Assert(atom.getKind() == Kind::STRING_IN_REGEXP);
   Trace("strings-regexp") << "Simplify on " << atom << std::endl;
   Node conc = d_regexp_opr.simplify(atom, polarity);
   Trace("strings-regexp") << "...finished, got " << conc << std::endl;
@@ -291,7 +291,7 @@ bool RegExpSolver::doUnfold(const Node& assertion)
     std::vector<Node> noExplain;
     iexp.push_back(assertion);
     noExplain.push_back(assertion);
-    Assert(atom.getKind() == STRING_IN_REGEXP);
+    Assert(atom.getKind() == Kind::STRING_IN_REGEXP);
     if (polarity)
     {
       d_statistics.d_regexpUnfoldingsPos << atom[1].getKind();
@@ -322,7 +322,7 @@ bool RegExpSolver::checkEqcInclusion(std::vector<Node>& mems)
 
   for (const Node& m1 : mems)
   {
-    bool m1Neg = m1.getKind() == NOT;
+    bool m1Neg = m1.getKind() == Kind::NOT;
     Node m1Lit = m1Neg ? m1[0] : m1;
 
     if (remove.find(m1) != remove.end())
@@ -338,7 +338,7 @@ bool RegExpSolver::checkEqcInclusion(std::vector<Node>& mems)
         continue;
       }
 
-      bool m2Neg = m2.getKind() == NOT;
+      bool m2Neg = m2.getKind() == Kind::NOT;
       Node m2Lit = m2Neg ? m2[0] : m2;
 
       if (m1Neg == m2Neg)
@@ -440,10 +440,11 @@ bool RegExpSolver::checkEqcIntersect(const std::vector<Node>& mems)
   NodeManager* nm = NodeManager::currentNM();
   for (const Node& m : mems)
   {
-    if (m.getKind() != STRING_IN_REGEXP)
+    if (m.getKind() != Kind::STRING_IN_REGEXP)
     {
       // do not do negative
-      Assert(m.getKind() == NOT && m[0].getKind() == STRING_IN_REGEXP);
+      Assert(m.getKind() == Kind::NOT
+             && m[0].getKind() == Kind::STRING_IN_REGEXP);
       continue;
     }
     RegExpConstType rct = d_regexp_opr.getRegExpConstType(m[1]);
@@ -496,7 +497,7 @@ bool RegExpSolver::checkEqcIntersect(const std::vector<Node>& mems)
       return false;
     }
     // rewrite to ensure the equality checks below are precise
-    Node mres = nm->mkNode(STRING_IN_REGEXP, mi[0], resR);
+    Node mres = nm->mkNode(Kind::STRING_IN_REGEXP, mi[0], resR);
     Node mresr = rewrite(mres);
     if (mresr == mi)
     {
@@ -593,7 +594,7 @@ cvc5::internal::String RegExpSolver::getHeadConst(Node x)
   {
     return x.getConst<String>();
   }
-  else if (x.getKind() == STRING_CONCAT)
+  else if (x.getKind() == Kind::STRING_CONCAT)
   {
     if (x[0].isConst())
     {
@@ -644,7 +645,7 @@ bool RegExpSolver::deriveRegExp(Node x,
       }
       else
       {
-        Assert(x.getKind() == STRING_CONCAT);
+        Assert(x.getKind() == Kind::STRING_CONCAT);
         std::vector<Node> vec_nodes;
         for (unsigned int i = 1; i < x.getNumChildren(); ++i)
         {
@@ -652,7 +653,8 @@ bool RegExpSolver::deriveRegExp(Node x,
         }
         Node left = utils::mkConcat(vec_nodes, x.getType());
         left = rewrite(left);
-        conc = NodeManager::currentNM()->mkNode(STRING_IN_REGEXP, left, dc);
+        conc =
+            NodeManager::currentNM()->mkNode(Kind::STRING_IN_REGEXP, left, dc);
       }
     }
     std::vector<Node> iexp = ant;
@@ -670,26 +672,26 @@ Node RegExpSolver::getNormalSymRegExp(Node r, std::vector<Node>& nf_exp)
   Node ret = r;
   switch (r.getKind())
   {
-    case REGEXP_NONE:
-    case REGEXP_ALLCHAR:
-    case REGEXP_RANGE: break;
-    case STRING_TO_REGEXP:
+    case Kind::REGEXP_NONE:
+    case Kind::REGEXP_ALLCHAR:
+    case Kind::REGEXP_RANGE: break;
+    case Kind::STRING_TO_REGEXP:
     {
       if (!r[0].isConst())
       {
         Node tmp = d_csolver.getNormalString(r[0], nf_exp);
         if (tmp != r[0])
         {
-          ret = NodeManager::currentNM()->mkNode(STRING_TO_REGEXP, tmp);
+          ret = NodeManager::currentNM()->mkNode(Kind::STRING_TO_REGEXP, tmp);
         }
       }
       break;
     }
-    case REGEXP_CONCAT:
-    case REGEXP_UNION:
-    case REGEXP_INTER:
-    case REGEXP_STAR:
-    case REGEXP_COMPLEMENT:
+    case Kind::REGEXP_CONCAT:
+    case Kind::REGEXP_UNION:
+    case Kind::REGEXP_INTER:
+    case Kind::REGEXP_STAR:
+    case Kind::REGEXP_COMPLEMENT:
     {
       std::vector<Node> vec_nodes;
       for (const Node& cr : r)
@@ -717,7 +719,7 @@ void RegExpSolver::checkEvaluations()
     Node rep = mr.first;
     for (const Node& assertion : mr.second)
     {
-      bool polarity = assertion.getKind() != NOT;
+      bool polarity = assertion.getKind() != Kind::NOT;
       Node atom = polarity ? assertion : assertion[0];
       Trace("strings-regexp")
           << "We have regular expression assertion : " << assertion
@@ -760,7 +762,7 @@ void RegExpSolver::checkEvaluations()
                                    << nx << " IN " << r << std::endl;
 
         // We rewrite the membership nx IN r.
-        Node tmp = rewrite(nm->mkNode(STRING_IN_REGEXP, nx, r));
+        Node tmp = rewrite(nm->mkNode(Kind::STRING_IN_REGEXP, nx, r));
         Trace("strings-regexp-nf") << "Simplifies to " << tmp << std::endl;
         if (tmp.isConst())
         {
