@@ -82,73 +82,74 @@ Node TermRegistry::eagerReduce(Node t, SkolemCache* sc, uint32_t alphaCard)
   NodeManager* nm = NodeManager::currentNM();
   Node lemma;
   Kind tk = t.getKind();
-  if (tk == STRING_TO_CODE)
+  if (tk == Kind::STRING_TO_CODE)
   {
     // ite( str.len(s)==1, 0 <= str.code(s) < |A|, str.code(s)=-1 )
-    Node len = nm->mkNode(STRING_LENGTH, t[0]);
+    Node len = nm->mkNode(Kind::STRING_LENGTH, t[0]);
     Node code_len = len.eqNode(nm->mkConstInt(Rational(1)));
     Node code_eq_neg1 = t.eqNode(nm->mkConstInt(Rational(-1)));
     Node code_range = utils::mkCodeRange(t, alphaCard);
-    lemma = nm->mkNode(ITE, code_len, code_range, code_eq_neg1);
+    lemma = nm->mkNode(Kind::ITE, code_len, code_range, code_eq_neg1);
   }
-  else if (tk == SEQ_NTH)
+  else if (tk == Kind::SEQ_NTH)
   {
     if (t[0].getType().isString())
     {
       Node s = t[0];
       Node n = t[1];
       // start point is greater than or equal zero
-      Node c1 = nm->mkNode(GEQ, n, nm->mkConstInt(0));
+      Node c1 = nm->mkNode(Kind::GEQ, n, nm->mkConstInt(0));
       // start point is less than end of string
-      Node c2 = nm->mkNode(GT, nm->mkNode(STRING_LENGTH, s), n);
+      Node c2 = nm->mkNode(Kind::GT, nm->mkNode(Kind::STRING_LENGTH, s), n);
       // check whether this application of seq.nth is defined.
-      Node cond = nm->mkNode(AND, c1, c2);
+      Node cond = nm->mkNode(Kind::AND, c1, c2);
       Node code_range = utils::mkCodeRange(t, alphaCard);
       // the lemma for `seq.nth`
-      lemma = nm->mkNode(ITE, cond, code_range, t.eqNode(nm->mkConstInt(Rational(-1))));
+      lemma = nm->mkNode(
+          Kind::ITE, cond, code_range, t.eqNode(nm->mkConstInt(Rational(-1))));
       // IF: n >=0 AND n < len( s )
       // THEN: 0 <= (seq.nth s n) < |A|
       // ELSE: (seq.nth s n) = -1
     }
   }
-  else if (tk == STRING_INDEXOF || tk == STRING_INDEXOF_RE)
+  else if (tk == Kind::STRING_INDEXOF || tk == Kind::STRING_INDEXOF_RE)
   {
     // (and
     //   (or (= (f x y n) (- 1)) (>= (f x y n) n))
     //   (<= (f x y n) (str.len x)))
     //
     // where f in { str.indexof, str.indexof_re }
-    Node l = nm->mkNode(STRING_LENGTH, t[0]);
-    lemma = nm->mkNode(AND,
-                       nm->mkNode(OR,
+    Node l = nm->mkNode(Kind::STRING_LENGTH, t[0]);
+    lemma = nm->mkNode(Kind::AND,
+                       nm->mkNode(Kind::OR,
                                   t.eqNode(nm->mkConstInt(Rational(-1))),
-                                  nm->mkNode(GEQ, t, t[2])),
-                       nm->mkNode(LEQ, t, l));
+                                  nm->mkNode(Kind::GEQ, t, t[2])),
+                       nm->mkNode(Kind::LEQ, t, l));
   }
-  else if (tk == STRING_STOI)
+  else if (tk == Kind::STRING_STOI)
   {
     // (>= (str.to_int x) (- 1))
-    lemma = nm->mkNode(GEQ, t, nm->mkConstInt(Rational(-1)));
+    lemma = nm->mkNode(Kind::GEQ, t, nm->mkConstInt(Rational(-1)));
   }
-  else if (tk == STRING_CONTAINS)
+  else if (tk == Kind::STRING_CONTAINS)
   {
     // ite( (str.contains s r), (= s (str.++ sk1 r sk2)), (not (= s r)))
     Node sk1 =
         sc->mkSkolemCached(t[0], t[1], SkolemCache::SK_FIRST_CTN_PRE, "sc1");
     Node sk2 =
         sc->mkSkolemCached(t[0], t[1], SkolemCache::SK_FIRST_CTN_POST, "sc2");
-    lemma = t[0].eqNode(nm->mkNode(STRING_CONCAT, sk1, t[1], sk2));
-    lemma = nm->mkNode(ITE, t, lemma, t[0].eqNode(t[1]).notNode());
+    lemma = t[0].eqNode(nm->mkNode(Kind::STRING_CONCAT, sk1, t[1], sk2));
+    lemma = nm->mkNode(Kind::ITE, t, lemma, t[0].eqNode(t[1]).notNode());
   }
-  else if (tk == STRING_IN_REGEXP)
+  else if (tk == Kind::STRING_IN_REGEXP)
   {
     // for (str.in_re t R), if R has a fixed length L, then we infer the lemma:
     // (str.in_re t R) => (= (str.len t) L).
     Node len = RegExpEntail::getFixedLengthForRegexp(t[1]);
     if (!len.isNull())
     {
-      lemma =
-          nm->mkNode(IMPLIES, t, nm->mkNode(STRING_LENGTH, t[0]).eqNode(len));
+      lemma = nm->mkNode(
+          Kind::IMPLIES, t, nm->mkNode(Kind::STRING_LENGTH, t[0]).eqNode(len));
     }
   }
   return lemma;
@@ -159,13 +160,13 @@ Node TermRegistry::lengthPositive(Node t)
   NodeManager* nm = NodeManager::currentNM();
   Node zero = nm->mkConstInt(Rational(0));
   Node emp = Word::mkEmptyWord(t.getType());
-  Node tlen = nm->mkNode(STRING_LENGTH, t);
+  Node tlen = nm->mkNode(Kind::STRING_LENGTH, t);
   Node tlenEqZero = tlen.eqNode(zero);
   Node tEqEmp = t.eqNode(emp);
-  Node caseEmpty = nm->mkNode(AND, tlenEqZero, tEqEmp);
-  Node caseNEmpty = nm->mkNode(GT, tlen, zero);
+  Node caseEmpty = nm->mkNode(Kind::AND, tlenEqZero, tEqEmp);
+  Node caseNEmpty = nm->mkNode(Kind::GT, tlen, zero);
   // (or (and (= (str.len t) 0) (= t "")) (> (str.len t) 0))
-  return nm->mkNode(OR, caseEmpty, caseNEmpty);
+  return nm->mkNode(Kind::OR, caseEmpty, caseNEmpty);
 }
 
 void TermRegistry::preRegisterTerm(TNode n)
@@ -180,15 +181,15 @@ void TermRegistry::preRegisterTerm(TNode n)
       << "TheoryString::preregister : " << n << std::endl;
   // check for logic exceptions
   Kind k = n.getKind();
-  if (k == STRING_IN_REGEXP)
+  if (k == Kind::STRING_IN_REGEXP)
   {
     d_im->preferPhase(n, true);
   }
-  else if (k == STRING_TO_CODE)
+  else if (k == Kind::STRING_TO_CODE)
   {
     d_hasStrCode = true;
   }
-  else if (k == SEQ_NTH || k == STRING_UPDATE)
+  else if (k == Kind::SEQ_NTH || k == Kind::STRING_UPDATE)
   {
     d_hasSeqUpdate = true;
   }
@@ -207,7 +208,8 @@ void TermRegistry::preRegisterTerm(TNode n)
   if (tn.isBoolean())
   {
     // All kinds that we do congruence over that may return a Boolean go here
-    if (k == STRING_CONTAINS || k == STRING_LEQ || k == SEQ_NTH || k == EQUAL)
+    if (k == Kind::STRING_CONTAINS || k == Kind::STRING_LEQ
+        || k == Kind::SEQ_NTH || k == Kind::EQUAL)
     {
       // Get triggered for both equal and dis-equal
       d_state.addEqualityEngineTriggerPredicate(n);
@@ -227,8 +229,8 @@ void TermRegistry::preRegisterTerm(TNode n)
   // their arguments have string type and do not introduce any shared
   // terms.
   if (n.hasOperator() && ee->isFunctionKind(k)
-      && kindToTheoryId(k) == THEORY_STRINGS && k != STRING_CONCAT
-      && k != STRING_IN_REGEXP)
+      && kindToTheoryId(k) == THEORY_STRINGS && k != Kind::STRING_CONCAT
+      && k != Kind::STRING_IN_REGEXP)
   {
     d_functionsTerms.push_back(n);
   }
@@ -251,7 +253,7 @@ void TermRegistry::registerSubterms(Node n)
       registerTermInternal(cur);
       Kind k = cur.getKind();
       // only traverse beneath operators belonging to strings
-      if (k==EQUAL || theory::kindToTheoryId(k)==THEORY_STRINGS)
+      if (k == Kind::EQUAL || theory::kindToTheoryId(k) == THEORY_STRINGS)
       {
         // strings does not have any closure kinds
         Assert (!cur.isClosure());
@@ -291,11 +293,11 @@ void TermRegistry::registerTermInternal(Node n)
     // we don't send out eager reduction lemma for str.contains currently
     bool doEagerReduce = true;
     Kind k = n.getKind();
-    if (k == STRING_CONTAINS)
+    if (k == Kind::STRING_CONTAINS)
     {
       doEagerReduce = false;
     }
-    else if (k == STRING_TO_CODE)
+    else if (k == Kind::STRING_TO_CODE)
     {
       // code for proxy are implied
       Node c = SkolemManager::getOriginalForm(n[0]);
@@ -310,7 +312,7 @@ void TermRegistry::registerTermInternal(Node n)
         if (d_epg != nullptr)
         {
           regTermLem = d_epg->mkTrustNode(
-              eagerRedLemma, PfRule::STRING_EAGER_REDUCTION, {}, {n});
+              eagerRedLemma, ProofRule::STRING_EAGER_REDUCTION, {}, {n});
         }
         else
         {
@@ -354,9 +356,9 @@ TrustNode TermRegistry::getRegisterTermLemma(Node n)
   //  for variables, split on empty vs positive length
   //  for concat/const/replace, introduce proxy var and state length relation
   Node lsum;
-  if (n.getKind() != STRING_CONCAT && !n.isConst())
+  if (n.getKind() != Kind::STRING_CONCAT && !n.isConst())
   {
-    Node lsumb = nm->mkNode(STRING_LENGTH, n);
+    Node lsumb = nm->mkNode(Kind::STRING_LENGTH, n);
     lsum = rewrite(lsumb);
     // can register length term if it does not rewrite
     if (lsum == lsumb)
@@ -371,13 +373,13 @@ TrustNode TermRegistry::getRegisterTermLemma(Node n)
   // If we are introducing a proxy for a constant or concat term, we do not
   // need to send lemmas about its length, since its length is already
   // implied.
-  if (n.isConst() || n.getKind() == STRING_CONCAT)
+  if (n.isConst() || n.getKind() == Kind::STRING_CONCAT)
   {
     // do not send length lemma for sk.
     registerTermAtomic(sk, LENGTH_IGNORE);
   }
-  Node skl = nm->mkNode(STRING_LENGTH, sk);
-  if (n.getKind() == STRING_CONCAT)
+  Node skl = nm->mkNode(Kind::STRING_LENGTH, sk);
+  if (n.getKind() == Kind::STRING_CONCAT)
   {
     std::vector<Node> nodeVec;
     NodeNodeMap::const_iterator itl;
@@ -390,11 +392,11 @@ TrustNode TermRegistry::getRegisterTermLemma(Node n)
       }
       else
       {
-        Node lni = nm->mkNode(STRING_LENGTH, nc);
+        Node lni = nm->mkNode(Kind::STRING_LENGTH, nc);
         nodeVec.push_back(lni);
       }
     }
-    lsum = nm->mkNode(ADD, nodeVec);
+    lsum = nm->mkNode(Kind::ADD, nodeVec);
     lsum = rewrite(lsum);
   }
   else if (n.isConst())
@@ -405,12 +407,12 @@ TrustNode TermRegistry::getRegisterTermLemma(Node n)
   d_proxyVarToLength[sk] = lsum;
   Node ceq = rewrite(skl.eqNode(lsum));
 
-  Node ret = nm->mkNode(AND, eq, ceq);
+  Node ret = nm->mkNode(Kind::AND, eq, ceq);
 
   // it is a simple rewrite to justify this
   if (d_epg != nullptr)
   {
-    return d_epg->mkTrustNode(ret, PfRule::MACRO_SR_PRED_INTRO, {}, {ret});
+    return d_epg->mkTrustNode(ret, ProofRule::MACRO_SR_PRED_INTRO, {}, {ret});
   }
   return TrustNode::mkTrustLemma(ret, nullptr);
 }
@@ -462,12 +464,13 @@ bool TermRegistry::hasSeqUpdate() const { return d_hasSeqUpdate; }
 
 bool TermRegistry::isHandledUpdateOrSubstr(Node n)
 {
-  Assert(n.getKind() == STRING_UPDATE || n.getKind() == STRING_SUBSTR);
+  Assert(n.getKind() == Kind::STRING_UPDATE
+         || n.getKind() == Kind::STRING_SUBSTR);
   NodeManager* nm = NodeManager::currentNM();
   Node lenN = n[2];
-  if (n.getKind() == STRING_UPDATE)
+  if (n.getKind() == Kind::STRING_UPDATE)
   {
-    lenN = nm->mkNode(STRING_LENGTH, n[2]);
+    lenN = nm->mkNode(Kind::STRING_LENGTH, n[2]);
   }
   Node one = nm->mkConstInt(Rational(1));
   return d_aent.checkEq(lenN, one);
@@ -475,7 +478,7 @@ bool TermRegistry::isHandledUpdateOrSubstr(Node n)
 
 Node TermRegistry::getUpdateBase(Node n)
 {
-  while (n.getKind() == STRING_UPDATE)
+  while (n.getKind() == Kind::STRING_UPDATE)
   {
     n = n[0];
   }
@@ -494,13 +497,13 @@ TrustNode TermRegistry::getRegisterTermAtomicLemma(
   }
   Assert(n.getType().isStringLike());
   NodeManager* nm = NodeManager::currentNM();
-  Node n_len = nm->mkNode(kind::STRING_LENGTH, n);
+  Node n_len = nm->mkNode(Kind::STRING_LENGTH, n);
   Node emp = Word::mkEmptyWord(n.getType());
   if (s == LENGTH_GEQ_ONE)
   {
     Node neq_empty = n.eqNode(emp).negate();
-    Node len_n_gt_z = nm->mkNode(GT, n_len, d_zero);
-    Node len_geq_one = nm->mkNode(AND, neq_empty, len_n_gt_z);
+    Node len_n_gt_z = nm->mkNode(Kind::GT, n_len, d_zero);
+    Node len_geq_one = nm->mkNode(Kind::AND, neq_empty, len_n_gt_z);
     Trace("strings-lemma") << "Strings::Lemma SK-GEQ-ONE : " << len_geq_one
                            << std::endl;
     Trace("strings-assert") << "(assert " << len_geq_one << ")" << std::endl;
@@ -522,7 +525,7 @@ TrustNode TermRegistry::getRegisterTermAtomicLemma(
   // split whether the string is empty
   Node n_len_eq_z = n_len.eqNode(d_zero);
   Node n_len_eq_z_2 = n.eqNode(emp);
-  Node case_empty = nm->mkNode(AND, n_len_eq_z, n_len_eq_z_2);
+  Node case_empty = nm->mkNode(Kind::AND, n_len_eq_z, n_len_eq_z_2);
   Node case_emptyr = rewrite(case_empty);
   if (!case_emptyr.isConst())
   {
@@ -546,7 +549,7 @@ TrustNode TermRegistry::getRegisterTermAtomicLemma(
 
   if (d_epg != nullptr)
   {
-    return d_epg->mkTrustNode(lenLemma, PfRule::STRING_LENGTH_POS, {}, {n});
+    return d_epg->mkTrustNode(lenLemma, ProofRule::STRING_LENGTH_POS, {}, {n});
   }
   return TrustNode::mkTrustLemma(lenLemma, nullptr);
 }
@@ -619,7 +622,7 @@ Node TermRegistry::ensureProxyVariableFor(Node n)
 
 void TermRegistry::removeProxyEqs(Node n, std::vector<Node>& unproc) const
 {
-  if (n.getKind() == AND)
+  if (n.getKind() == Kind::AND)
   {
     for (const Node& nc : n)
     {
@@ -629,7 +632,7 @@ void TermRegistry::removeProxyEqs(Node n, std::vector<Node>& unproc) const
   }
   Trace("strings-subs-proxy") << "Input : " << n << std::endl;
   Node ns = rewrite(n);
-  if (ns.getKind() == EQUAL)
+  if (ns.getKind() == Kind::EQUAL)
   {
     for (size_t i = 0; i < 2; i++)
     {
@@ -676,12 +679,13 @@ const std::set<Node>& TermRegistry::getRelevantTermSet() const
 
 Node TermRegistry::mkNConcat(Node n1, Node n2) const
 {
-  return rewrite(NodeManager::currentNM()->mkNode(STRING_CONCAT, n1, n2));
+  return rewrite(NodeManager::currentNM()->mkNode(Kind::STRING_CONCAT, n1, n2));
 }
 
 Node TermRegistry::mkNConcat(Node n1, Node n2, Node n3) const
 {
-  return rewrite(NodeManager::currentNM()->mkNode(STRING_CONCAT, n1, n2, n3));
+  return rewrite(
+      NodeManager::currentNM()->mkNode(Kind::STRING_CONCAT, n1, n2, n3));
 }
 
 Node TermRegistry::mkNConcat(const std::vector<Node>& c, TypeNode tn) const
