@@ -826,8 +826,8 @@ Node TheoryStrings::mkSkeletonFromBase(Node r,
     for (size_t i = currIndex; i < nextIndex; i++)
     {
       cacheVals[1] = nm->mkConstInt(Rational(i));
-      Node kv = sm->mkSkolemFunction(
-          SkolemFunId::SEQ_MODEL_BASE_ELEMENT, etn, cacheVals);
+      Node kv = sm->mkInternalSkolemFunction(
+          InternalSkolemFunId::SEQ_MODEL_BASE_ELEMENT, etn, cacheVals);
       skChildren.push_back(utils::mkUnit(tn, kv));
     }
   }
