@@ -19,7 +19,8 @@
 #define CVC5__THEORY__THEORY_ENGINE_MODULE_H
 
 #include "expr/node.h"
-#include "theory/engine_output_channel.h"
+#include "prop/sat_solver_types.h"
+#include "theory/output_channel.h"
 #include "theory/theory.h"
 
 namespace cvc5::internal {
@@ -50,6 +51,10 @@ class TheoryEngineModule : protected EnvObj
    * presolve, called at the beginning of each check-sat.
    */
   virtual void presolve();
+  /**
+   * postsolve, called at the end of each check-sat.
+   */
+  virtual void postsolve(prop::SatValue result);
   /**
    * check, called at the beginning of a check in TheoryEngine.
    */
@@ -62,26 +67,32 @@ class TheoryEngineModule : protected EnvObj
    * Notify that a lemma was sent
    *
    * @param n The lemma, which has been theory preprocessed
+   * @param id The inference identifier of the lemma
    * @param p The property of the lemma
    * @param skAsserts The skolem assertions for the given lemma
    * @param sks The skolems for each assertion in skAsserts.
    */
   virtual void notifyLemma(TNode n,
-                           theory::LemmaProperty p,
+                           InferenceId id,
+                           LemmaProperty p,
                            const std::vector<Node>& skAsserts,
                            const std::vector<Node>& sks);
   /** Needs candidate model, return true if the method below requires calling */
   virtual bool needsCandidateModel();
   /** Notify that m is a (candidate) model */
   virtual void notifyCandidateModel(TheoryModel* m);
-  /** Get name, for debugging and statistics. */
-  const std::string& getName();
+  /** Get the theory identifier */
+  TheoryId getId() const;
 
  protected:
   /** The output channel, for sending lemmas */
-  EngineOutputChannel d_out;
+  OutputChannel d_out;
   /** The name */
   std::string d_name;
+
+ private:
+  /** Static allocator of theory module identifiers */
+  static size_t d_idCounter;
 };
 
 }  // namespace theory
