@@ -41,13 +41,13 @@ TrustNode TheoryEngineProofGenerator::mkTrustExplain(
     // propagation of false is a conflict
     trn = TrustNode::mkTrustConflict(exp, this);
     p = trn.getProven();
-    Assert(p.getKind() == NOT);
+    Assert(p.getKind() == Kind::NOT);
   }
   else
   {
     trn = TrustNode::mkTrustPropExp(lit, exp, this);
     p = trn.getProven();
-    Assert(p.getKind() == IMPLIES && p.getNumChildren() == 2);
+    Assert(p.getKind() == Kind::IMPLIES && p.getNumChildren() == 2);
   }
   // should not already be proven
   NodeLazyCDProofMap::iterator it = d_proofs.find(p);
@@ -75,12 +75,12 @@ std::shared_ptr<ProofNode> TheoryEngineProofGenerator::getProofFor(Node f)
   // should only ask this generator for proofs of implications, or conflicts
   Node exp;
   Node conclusion;
-  if (f.getKind() == IMPLIES && f.getNumChildren() == 2)
+  if (f.getKind() == Kind::IMPLIES && f.getNumChildren() == 2)
   {
     exp = f[0];
     conclusion = f[1];
   }
-  else if (f.getKind() == NOT)
+  else if (f.getKind() == Kind::NOT)
   {
     exp = f[0];
     conclusion = d_false;
@@ -92,7 +92,7 @@ std::shared_ptr<ProofNode> TheoryEngineProofGenerator::getProofFor(Node f)
     return nullptr;
   }
   // get the assumptions to assume in a scope
-  if (exp.getKind() == AND)
+  if (exp.getKind() == Kind::AND)
   {
     for (const Node& fc : exp)
     {
