@@ -18,8 +18,9 @@
 #include "base/configuration.h"
 #include "options/uf_options.h"
 #include "proof/proof.h"
-#include "proof/proof_node_manager.h"
 #include "proof/proof_checker.h"
+#include "proof/proof_node_algorithm.h"
+#include "proof/proof_node_manager.h"
 
 namespace cvc5::internal {
 namespace theory {
@@ -1082,11 +1083,10 @@ Node EqProof::addToProof(CDProof* p,
     // build constant application (f c1 ... cn) and equality (= (f c1 ... cn) c)
     Kind k = d_node[0].getKind();
     std::vector<Node> cargs;
-    cargs.push_back(ProofRuleChecker::mkKindNode(k));
+    ProofRule rule = expr::getCongRule(d_node[0], cargs);
     if (d_node[0].getMetaKind() == kind::metakind::PARAMETERIZED)
     {
       constChildren.insert(constChildren.begin(), d_node[0].getOperator());
-      cargs.push_back(d_node[0].getOperator());
     }
     Node constApp = NodeManager::currentNM()->mkNode(k, constChildren);
     Node constEquality = constApp.eqNode(d_node[1]);
@@ -1097,10 +1097,10 @@ Node EqProof::addToProof(CDProof* p,
         constEquality, ProofRule::MACRO_SR_PRED_INTRO, {}, {constEquality});
     // build congruence conclusion (= (f t1 ... tn) (f c1 ... cn))
     Node congConclusion = d_node[0].eqNode(constApp);
-    Trace("eqproof-conv") << "EqProof::addToProof: adding  " << ProofRule::CONG
+    Trace("eqproof-conv") << "EqProof::addToProof: adding  " << rule
                           << " step for " << congConclusion << " from "
                           << subChildren << "\n";
-    p->addStep(congConclusion, ProofRule::CONG, {subChildren}, cargs, true);
+    p->addStep(congConclusion, rule, {subChildren}, cargs, true);
     Trace("eqproof-conv") << "EqProof::addToProof: adding  " << ProofRule::TRANS
                           << " step for original conclusion " << d_node << "\n";
     std::vector<Node> transitivityChildren{congConclusion, constEquality};
@@ -1441,16 +1441,19 @@ Node EqProof::addToProof(CDProof* p,
     // Get node of the function operator over which congruence is being
     // applied.
     std::vector<Node> args;
-    args.push_back(ProofRuleChecker::mkKindNode(k));
-    if (kind::metaKindOf(k) == kind::metakind::PARAMETERIZED)
-    {
-      args.push_back(conclusion[0].getOperator());
-    }
+    ProofRule r = expr::getCongRule(d_node[0], args);
     // Add congruence step
-    Trace("eqproof-conv") << "EqProof::addToProof: build cong step of "
-                          << conclusion << " with op " << args[0]
-                          << " and children " << children << "\n";
-    p->addStep(conclusion, ProofRule::CONG, children, args, true);
+    if (TraceIsOn("eqproof-conv"))
+    {
+      Trace("eqproof-conv")
+          << "EqProof::addToProof: build cong step of " << conclusion;
+      if (!args.empty())
+      {
+        Trace("eqproof-conv") << " with op " << args[0];
+      }
+      Trace("eqproof-conv") << " and children " << children << "\n";
+    }
+    p->addStep(conclusion, r, children, args, true);
   }
   // higher-order case
   else
@@ -1459,7 +1462,11 @@ Node EqProof::addToProof(CDProof* p,
     Trace("eqproof-conv") << "EqProof::addToProof: build HO-cong step of "
                           << conclusion << " with children " << children
                           << "\n";
-    p->addStep(conclusion, ProofRule::HO_CONG, children, {}, true);
+    p->addStep(conclusion,
+               ProofRule::HO_CONG,
+               children,
+               {ProofRuleChecker::mkKindNode(Kind::APPLY_UF)},
+               true);
   }
   // If the conclusion of the congruence step changed due to the n-ary handling,
   // we obtained for example (= (f (f t1 t2 t3) t4) (f (f t5 t6) t7)), which is
