@@ -47,11 +47,11 @@ using ArrayToLambdaAttribute = expr::Attribute<ArrayToLambdaTag, Node>;
 Node FunctionConst::toLambda(TNode n)
 {
   Kind nk = n.getKind();
-  if (nk == kind::LAMBDA)
+  if (nk == Kind::LAMBDA)
   {
     return n;
   }
-  else if (nk == kind::FUNCTION_ARRAY_CONST)
+  else if (nk == Kind::FUNCTION_ARRAY_CONST)
   {
     ArrayToLambdaAttribute atla;
     if (n.hasAttribute(atla))
@@ -75,7 +75,7 @@ Node FunctionConst::toLambda(TNode n)
           bvm->mkBoundVar<FunctionBoundVarListAttribute>(cacheVal, argTypes[i]);
       bvs.push_back(v);
     }
-    Node bvl = nm->mkNode(kind::BOUND_VAR_LIST, bvs);
+    Node bvl = nm->mkNode(Kind::BOUND_VAR_LIST, bvs);
     Node lam = getLambdaForArrayRepresentation(avalue, bvl);
     n.setAttribute(atla, lam);
     return lam;
@@ -126,7 +126,7 @@ Node FunctionConst::getLambdaForArrayRepresentationRec(
   if (bvlIndex < bvl.getNumChildren())
   {
     Assert(a.getType().isArray());
-    if (a.getKind() == kind::STORE)
+    if (a.getKind() == Kind::STORE)
     {
       // convert the array recursively
       Node body =
@@ -142,11 +142,11 @@ Node FunctionConst::getLambdaForArrayRepresentationRec(
           Assert(a[1].getType() == bvl[bvlIndex].getType());
           Assert(val.getType() == body.getType());
           Node cond = bvl[bvlIndex].eqNode(a[1]);
-          ret = NodeManager::currentNM()->mkNode(kind::ITE, cond, val, body);
+          ret = NodeManager::currentNM()->mkNode(Kind::ITE, cond, val, body);
         }
       }
     }
-    else if (a.getKind() == kind::STORE_ALL)
+    else if (a.getKind() == Kind::STORE_ALL)
     {
       ArrayStoreAll storeAll = a.getConst<ArrayStoreAll>();
       Node sa = storeAll.getValue();
@@ -174,7 +174,7 @@ Node FunctionConst::getLambdaForArrayRepresentation(TNode a, TNode bvl)
   {
     Trace("builtin-rewrite-debug")
         << "...got lambda body " << body << std::endl;
-    return NodeManager::currentNM()->mkNode(kind::LAMBDA, bvl, body);
+    return NodeManager::currentNM()->mkNode(Kind::LAMBDA, bvl, body);
   }
   Trace("builtin-rewrite-debug") << "...failed to get lambda body" << std::endl;
   return Node::null();
@@ -183,7 +183,7 @@ Node FunctionConst::getLambdaForArrayRepresentation(TNode a, TNode bvl)
 Node FunctionConst::getArrayRepresentationForLambdaRec(TNode n,
                                                        TypeNode retType)
 {
-  Assert(n.getKind() == kind::LAMBDA);
+  Assert(n.getKind() == Kind::LAMBDA);
   NodeManager* nm = NodeManager::currentNM();
   Trace("builtin-rewrite-debug")
       << "Get array representation for : " << n << std::endl;
@@ -198,7 +198,7 @@ Node FunctionConst::getArrayRepresentationForLambdaRec(TNode n,
     {
       args.push_back(n[0][i]);
     }
-    rec_bvl = nm->mkNode(kind::BOUND_VAR_LIST, args);
+    rec_bvl = nm->mkNode(Kind::BOUND_VAR_LIST, args);
   }
 
   Trace("builtin-rewrite-debug2") << "  process body..." << std::endl;
@@ -206,8 +206,8 @@ Node FunctionConst::getArrayRepresentationForLambdaRec(TNode n,
   std::vector<Node> vals;
   Node curr = n[1];
   Kind ck = curr.getKind();
-  while (ck == kind::ITE || ck == kind::OR || ck == kind::AND
-         || ck == kind::EQUAL || ck == kind::NOT || ck == kind::BOUND_VARIABLE)
+  while (ck == Kind::ITE || ck == Kind::OR || ck == Kind::AND
+         || ck == Kind::EQUAL || ck == Kind::NOT || ck == Kind::BOUND_VARIABLE)
   {
     Node index_eq;
     Node curr_val;
@@ -218,7 +218,7 @@ Node FunctionConst::getArrayRepresentationForLambdaRec(TNode n,
     // [1] We infer that the entry has value "curr_val" under condition
     // "index_eq". We set "next" to the node that is the remainder of the
     // function to process.
-    if (ck == kind::ITE)
+    if (ck == Kind::ITE)
     {
       Trace("builtin-rewrite-debug2")
           << "  process condition : " << curr[0] << std::endl;
@@ -226,7 +226,7 @@ Node FunctionConst::getArrayRepresentationForLambdaRec(TNode n,
       curr_val = curr[1];
       next = curr[2];
     }
-    else if (ck == kind::OR || ck == kind::AND)
+    else if (ck == Kind::OR || ck == Kind::AND)
     {
       Trace("builtin-rewrite-debug2")
           << "  process base : " << curr << std::endl;
@@ -245,8 +245,8 @@ Node FunctionConst::getArrayRepresentationForLambdaRec(TNode n,
       //       lambda x. (ite (= x v1) [...] true)
       // thus requiring the rest of the disjunction to be further processed in
       // the then-branch as the current value.
-      bool pol = curr[0].getKind() != kind::NOT;
-      bool inverted = (pol == (ck == kind::AND));
+      bool pol = curr[0].getKind() != Kind::NOT;
+      bool inverted = (pol == (ck == Kind::AND));
       index_eq = pol ? curr[0] : curr[0][0];
       // processed : the value that is determined by the first child of curr
       // remainder : the remaining children of curr
@@ -295,18 +295,18 @@ Node FunctionConst::getArrayRepresentationForLambdaRec(TNode n,
       //  (1) lambda x. (= x v) becomes lambda x. (ite (= x v) true false)
       //  (2) lambda x. x becomes lambda x. (ite (= x true) true false)
       // Note the negateg cases of the bodies above are also handled.
-      bool pol = ck != kind::NOT;
+      bool pol = ck != Kind::NOT;
       index_eq = pol ? curr : curr[0];
       curr_val = nm->mkConst(pol);
       next = nm->mkConst(!pol);
     }
 
     // [2] We ensure that "index_eq" is an equality, if possible.
-    if (index_eq.getKind() != kind::EQUAL)
+    if (index_eq.getKind() != Kind::EQUAL)
     {
-      bool pol = index_eq.getKind() != kind::NOT;
+      bool pol = index_eq.getKind() != Kind::NOT;
       Node indexEqAtom = pol ? index_eq : index_eq[0];
-      if (indexEqAtom.getKind() == kind::BOUND_VARIABLE)
+      if (indexEqAtom.getKind() == Kind::BOUND_VARIABLE)
       {
         if (!indexEqAtom.getType().isBoolean())
         {
@@ -361,7 +361,7 @@ Node FunctionConst::getArrayRepresentationForLambdaRec(TNode n,
     // remaining arguments (rec_bvl).
     if (!rec_bvl.isNull())
     {
-      curr_val = nm->mkNode(kind::LAMBDA, rec_bvl, curr_val);
+      curr_val = nm->mkNode(Kind::LAMBDA, rec_bvl, curr_val);
       Trace("builtin-rewrite-debug") << push;
       Trace("builtin-rewrite-debug2") << push;
       curr_val = getArrayRepresentationForLambdaRec(curr_val, retType);
@@ -397,7 +397,7 @@ Node FunctionConst::getArrayRepresentationForLambdaRec(TNode n,
   }
   if (!rec_bvl.isNull())
   {
-    curr = nm->mkNode(kind::LAMBDA, rec_bvl, curr);
+    curr = nm->mkNode(Kind::LAMBDA, rec_bvl, curr);
     Trace("builtin-rewrite-debug") << push;
     Trace("builtin-rewrite-debug2") << push;
     curr = getArrayRepresentationForLambdaRec(curr, retType);
@@ -430,7 +430,7 @@ Node FunctionConst::getArrayRepresentationForLambdaRec(TNode n,
     {
       size_t ii = (numCond - 1) - i;
       Assert(conds[ii].getType() == first_arg.getType());
-      curr = nm->mkNode(kind::STORE, curr, conds[ii], vals[ii]);
+      curr = nm->mkNode(Kind::STORE, curr, conds[ii], vals[ii]);
       // normalize it using the array rewriter utility, which must be done at
       // each iteration of this loop
       curr = arrays::TheoryArraysRewriter::normalizeConstant(curr);
@@ -448,12 +448,12 @@ Node FunctionConst::getArrayRepresentationForLambdaRec(TNode n,
 Node FunctionConst::toArrayConst(TNode n)
 {
   Kind nk = n.getKind();
-  if (nk == kind::FUNCTION_ARRAY_CONST)
+  if (nk == Kind::FUNCTION_ARRAY_CONST)
   {
     const FunctionArrayConst& fc = n.getConst<FunctionArrayConst>();
     return fc.getArrayValue();
   }
-  else if (nk == kind::LAMBDA)
+  else if (nk == Kind::LAMBDA)
   {
     // must carry the overall return type to deal with cases like (lambda ((x
     // Int) (y Int)) (ite (= x _) 0.5 0.0)), where the inner construction for
