@@ -64,7 +64,7 @@ class EqualityEngine;
  * in a SAT-context dependent manner in a context-dependent (CDProof) object.
  * It furthermore maintains an internal FactProofGenerator class for managing
  * proofs of facts whose steps are explicitly provided (those that are given
- * concrete PfRule, children, and args). Call these "simple facts".
+ * concrete ProofRule, children, and args). Call these "simple facts".
  *
  * Overall, this class is an eager proof generator (theory/proof_generator.h),
  * in that it stores (copies) of proofs for lemmas at the moment they are sent
@@ -107,11 +107,14 @@ class ProofEqEngine : public EagerProofGenerator
    * holds in the equality engine, this method returns false.
    */
   bool assertFact(Node lit,
-                  PfRule id,
+                  ProofRule id,
                   const std::vector<Node>& exp,
                   const std::vector<Node>& args);
   /** Same as above but where exp is (conjunctive) node */
-  bool assertFact(Node lit, PfRule id, Node exp, const std::vector<Node>& args);
+  bool assertFact(Node lit,
+                  ProofRule id,
+                  Node exp,
+                  const std::vector<Node>& args);
   /**
    * Multi-step version of assert fact via a proof step buffer. This method
    * is similar to above, but the justification for lit may have multiple steps.
@@ -171,7 +174,7 @@ class ProofEqEngine : public EagerProofGenerator
    * internally so that this class may respond to a call to
    * ProofGenerator::getProof(...).
    */
-  TrustNode assertConflict(PfRule id,
+  TrustNode assertConflict(ProofRule id,
                            const std::vector<Node>& exp,
                            const std::vector<Node>& args);
   /** Generator version, where pg has a proof of false from assumptions exp */
@@ -215,7 +218,7 @@ class ProofEqEngine : public EagerProofGenerator
    * The formula can be queried via TrustNode::getProven in the standard way.
    */
   TrustNode assertLemma(Node conc,
-                        PfRule id,
+                        ProofRule id,
                         const std::vector<Node>& exp,
                         const std::vector<Node>& noExplain,
                         const std::vector<Node>& args);
