@@ -4,7 +4,7 @@
  *
  * This file is part of the cvc5 project.
  *
- * Copyright (c) 2009-2022 by the authors listed in the file AUTHORS
+ * Copyright (c) 2009-2023 by the authors listed in the file AUTHORS
  * in the top-level source directory and their institutional affiliations.
  * All rights reserved.  See the file COPYING in the top-level source
  * directory for licensing information.
@@ -89,6 +89,7 @@ enum class Resource
   SatConflictStep,
   SygusCheckStep,
   TheoryCheckStep,
+  FindSynthStep,
   Unknown
 };
 
@@ -167,7 +168,7 @@ class ResourceManager
    * Marks the end of a SolverEngine check call, stops the per
    * call timer.
    */
-  void endCall();
+  void refresh();
 
   /**
    * Registers a listener that is notified on a resource out or (per-call)
