@@ -1,10 +1,10 @@
 /******************************************************************************
  * Top contributors (to current version):
- *   Andres Noetzli, Mathias Preiner
+ *   Andres Noetzli, Andrew Reynolds, Mathias Preiner
  *
  * This file is part of the cvc5 project.
  *
- * Copyright (c) 2009-2022 by the authors listed in the file AUTHORS
+ * Copyright (c) 2009-2023 by the authors listed in the file AUTHORS
  * in the top-level source directory and their institutional affiliations.
  * All rights reserved.  See the file COPYING in the top-level source
  * directory for licensing information.
@@ -23,7 +23,6 @@ using namespace cvc5;
 int main(void)
 {
   Solver slv;
-  slv.setOption("sygus-rr-synth-input", "true");
   slv.setOption("strings-exp", "true");
   slv.setOption("sygus-abort-size", "1");
   Sort s1 = slv.mkUninterpretedSort("_u0");
