@@ -4,7 +4,7 @@
  *
  * This file is part of the cvc5 project.
  *
- * Copyright (c) 2009-2022 by the authors listed in the file AUTHORS
+ * Copyright (c) 2009-2023 by the authors listed in the file AUTHORS
  * in the top-level source directory and their institutional affiliations.
  * All rights reserved.  See the file COPYING in the top-level source
  * directory for licensing information.
@@ -25,10 +25,10 @@ class TestApiWhiteOp : public TestApi
 
 TEST_F(TestApiWhiteOp, opFromKind)
 {
-  Op plus(d_solver.getNodeManager(), ADD);
+  Op plus(d_solver.getNodeManager(), Kind::ADD);
   ASSERT_FALSE(plus.isIndexed());
   ASSERT_EQ(0, plus.getNumIndices());
-  ASSERT_EQ(plus, d_solver.mkOp(ADD));
+  ASSERT_EQ(plus, d_solver.mkOp(Kind::ADD));
 }
 }  // namespace test
 }  // namespace cvc5::internal
