@@ -81,10 +81,13 @@ TEST_F(TestApiBlackResult, isUnknown)
 {
   d_solver.setLogic("QF_NIA");
   d_solver.setOption("incremental", "false");
-  d_solver.setOption("solve-int-as-bv", "32");
-  Sort int_sort = d_solver.getIntegerSort();
-  Term x = d_solver.mkConst(int_sort, "x");
-  d_solver.assertFormula(x.eqTerm(x).notTerm());
+  d_solver.setOption("solve-real-as-int", "true");
+  Sort real_sort = d_solver.getRealSort();
+  Term x = d_solver.mkConst(real_sort, "x");
+  d_solver.assertFormula(
+      d_solver.mkTerm(Kind::LT, {d_solver.mkReal("0.0"), x}));
+  d_solver.assertFormula(
+      d_solver.mkTerm(Kind::LT, {x, d_solver.mkReal("1.0")}));
   cvc5::Result res = d_solver.checkSat();
   ASSERT_FALSE(res.isSat());
   ASSERT_TRUE(res.isUnknown());
