@@ -236,6 +236,14 @@ class SortTest
     assertDoesNotThrow(() -> new Sort().isTuple());
   }
 
+  @Test
+  void isNullable()
+  {
+    Sort sort = d_solver.mkNullableSort(d_solver.getRealSort());
+    assertTrue(sort.isNullable());
+    assertDoesNotThrow(() -> new Sort().isNullable());
+  }
+
   @Test
   void isRecord()
   {
@@ -645,6 +653,17 @@ class SortTest
     assertThrows(CVC5ApiException.class, () -> bvSort.getTupleSorts());
   }
 
+  @Test
+  void getNullableElementSort() throws CVC5ApiException
+  {
+    Sort nullableSort = d_solver.mkNullableSort(d_solver.getIntegerSort());
+    assertDoesNotThrow(() -> nullableSort.getNullableElementSort());
+    Sort elementSort = nullableSort.getNullableElementSort();
+    assertEquals(elementSort, d_solver.getIntegerSort());
+    Sort bvSort = d_solver.mkBitVectorSort(32);
+    assertThrows(CVC5ApiException.class, () -> bvSort.getNullableElementSort());
+  }
+
   @Test
   void sortCompare() throws CVC5ApiException
   {
