@@ -4,7 +4,7 @@
 #
 # This file is part of the cvc5 project.
 #
-# Copyright (c) 2009-2022 by the authors listed in the file AUTHORS
+# Copyright (c) 2009-2023 by the authors listed in the file AUTHORS
 # in the top-level source directory and their institutional affiliations.
 # All rights reserved.  See the file COPYING in the top-level source
 # directory for licensing information.
@@ -1009,15 +1009,11 @@ def test_get_rounding_mode_value(solver):
 
 
 def test_get_tuple(solver):
-    s1 = solver.getIntegerSort()
-    s2 = solver.getRealSort()
-    s3 = solver.getStringSort()
-
     t1 = solver.mkInteger(15)
     t2 = solver.mkReal(17, 25)
     t3 = solver.mkString("abc")
 
-    tup = solver.mkTuple([s1, s2, s3], [t1, t2, t3])
+    tup = solver.mkTuple([t1, t2, t3])
 
     assert tup.isTupleValue()
     assert [t1, t2, t3] == tup.getTupleValue()
@@ -1326,6 +1322,34 @@ def test_get_cardinality_constraint(solver):
   with pytest.raises(RuntimeError):
     nullt.isCardinalityConstraint()
 
+def test_get_real_algebraic_number(solver):
+  solver.setOption("produce-models", "true")
+  solver.setLogic("QF_NRA")
+  realsort = solver.getRealSort()
+  x = solver.mkConst(realsort, "x")
+  x2 = solver.mkTerm(Kind.MULT, x, x)
+  two = solver.mkReal(2, 1)
+  eq = solver.mkTerm(Kind.EQUAL, x2, two)
+  solver.assertFormula(eq)
+  # Note that check-sat should only return "sat" if libpoly is enabled.
+  # Otherwise, we do not test the following functionality.
+  if solver.checkSat().isSat():
+    # We find a model for (x*x = 2), where x should be a real algebraic number.
+    # We assert that its defining polynomial is non-null and its lower and
+    # upper bounds are real.
+    vx = solver.getValue(x)
+    assert vx.isRealAlgebraicNumber()
+    y = solver.mkVar(realsort, "y")
+    poly = vx.getRealAlgebraicNumberDefiningPolynomial(y)
+    assert not poly.isNull()
+    lb = vx.getRealAlgebraicNumberLowerBound()
+    assert lb.isRealValue()
+    ub = vx.getRealAlgebraicNumberUpperBound()
+    assert ub.isRealValue()
+    # cannot call with non-variable
+    yc = solver.mkConst(realsort, "y")
+    with pytest.raises(RuntimeError):
+      vx.getRealAlgebraicNumberDefiningPolynomial(yc)
 
 def test_term_scoped_to_string(solver):
     intsort = solver.getIntegerSort()
