@@ -40,8 +40,6 @@
 
 namespace cvc5::internal {
 
-using namespace kind;
-
 namespace test {
 
 namespace {
@@ -197,7 +195,7 @@ TEST_F(TestNodeBlackNode, operator_square)
   // Basic access check
   Node tb = d_nodeManager->mkConst(true);
   Node eb = d_nodeManager->mkConst(false);
-  Node cnd = d_nodeManager->mkNode(XOR, tb, eb);
+  Node cnd = d_nodeManager->mkNode(Kind::XOR, tb, eb);
   Node ite = cnd.iteNode(tb, eb);
 
   ASSERT_EQ(tb, cnd[0]);
@@ -219,7 +217,8 @@ TEST_F(TestNodeBlackNode, operator_assign)
 {
   Node a, b;
   Node c = d_nodeManager->mkNode(
-      NOT, d_skolemManager->mkDummySkolem("c", d_nodeManager->booleanType()));
+      Kind::NOT,
+      d_skolemManager->mkDummySkolem("c", d_nodeManager->booleanType()));
 
   b = c;
   ASSERT_EQ(b, c);
@@ -242,26 +241,26 @@ TEST_F(TestNodeBlackNode, operator_less_than)
   ASSERT_TRUE(a < b || b < a);
   ASSERT_TRUE(!(a < b && b < a));
 
-  Node c = d_nodeManager->mkNode(AND, a, b);
-  Node d = d_nodeManager->mkNode(AND, a, b);
+  Node c = d_nodeManager->mkNode(Kind::AND, a, b);
+  Node d = d_nodeManager->mkNode(Kind::AND, a, b);
 
   ASSERT_FALSE(c < d);
   ASSERT_FALSE(d < c);
 
   // simple test of descending descendant property
   Node child = d_nodeManager->mkConst(true);
-  Node parent = d_nodeManager->mkNode(NOT, child);
+  Node parent = d_nodeManager->mkNode(Kind::NOT, child);
 
   ASSERT_TRUE(child < parent);
 
   // slightly less simple test of DD property
   std::vector<Node> chain;
   const int N = 500;
-  Node curr = d_nodeManager->mkNode(OR, a, b);
+  Node curr = d_nodeManager->mkNode(Kind::OR, a, b);
   chain.push_back(curr);
   for (int i = 0; i < N; ++i)
   {
-    curr = d_nodeManager->mkNode(AND, curr, curr);
+    curr = d_nodeManager->mkNode(Kind::AND, curr, curr);
     chain.push_back(curr);
   }
 
@@ -283,7 +282,7 @@ TEST_F(TestNodeBlackNode, eqNode)
   Node right = d_skolemManager->mkDummySkolem("right", t);
   Node eq = left.eqNode(right);
 
-  ASSERT_EQ(EQUAL, eq.getKind());
+  ASSERT_EQ(Kind::EQUAL, eq.getKind());
   ASSERT_EQ(2, eq.getNumChildren());
 
   ASSERT_EQ(eq[0], left);
@@ -295,7 +294,7 @@ TEST_F(TestNodeBlackNode, notNode)
   Node child = d_nodeManager->mkConst(true);
   Node parent = child.notNode();
 
-  ASSERT_EQ(NOT, parent.getKind());
+  ASSERT_EQ(Kind::NOT, parent.getKind());
   ASSERT_EQ(1, parent.getNumChildren());
 
   ASSERT_EQ(parent[0], child);
@@ -304,10 +303,11 @@ TEST_F(TestNodeBlackNode, notNode)
 TEST_F(TestNodeBlackNode, andNode)
 {
   Node left = d_nodeManager->mkConst(true);
-  Node right = d_nodeManager->mkNode(NOT, (d_nodeManager->mkConst(false)));
+  Node right =
+      d_nodeManager->mkNode(Kind::NOT, (d_nodeManager->mkConst(false)));
   Node eq = left.andNode(right);
 
-  ASSERT_EQ(AND, eq.getKind());
+  ASSERT_EQ(Kind::AND, eq.getKind());
   ASSERT_EQ(2, eq.getNumChildren());
 
   ASSERT_EQ(*(eq.begin()), left);
@@ -317,10 +317,11 @@ TEST_F(TestNodeBlackNode, andNode)
 TEST_F(TestNodeBlackNode, orNode)
 {
   Node left = d_nodeManager->mkConst(true);
-  Node right = d_nodeManager->mkNode(NOT, (d_nodeManager->mkConst(false)));
+  Node right =
+      d_nodeManager->mkNode(Kind::NOT, (d_nodeManager->mkConst(false)));
   Node eq = left.orNode(right);
 
-  ASSERT_EQ(OR, eq.getKind());
+  ASSERT_EQ(Kind::OR, eq.getKind());
   ASSERT_EQ(2, eq.getNumChildren());
 
   ASSERT_EQ(*(eq.begin()), left);
@@ -332,12 +333,13 @@ TEST_F(TestNodeBlackNode, iteNode)
   Node a = d_skolemManager->mkDummySkolem("a", d_nodeManager->booleanType());
   Node b = d_skolemManager->mkDummySkolem("b", d_nodeManager->booleanType());
 
-  Node cnd = d_nodeManager->mkNode(OR, a, b);
+  Node cnd = d_nodeManager->mkNode(Kind::OR, a, b);
   Node thenBranch = d_nodeManager->mkConst(true);
-  Node elseBranch = d_nodeManager->mkNode(NOT, d_nodeManager->mkConst(false));
+  Node elseBranch =
+      d_nodeManager->mkNode(Kind::NOT, d_nodeManager->mkConst(false));
   Node ite = cnd.iteNode(thenBranch, elseBranch);
 
-  ASSERT_EQ(ITE, ite.getKind());
+  ASSERT_EQ(Kind::ITE, ite.getKind());
   ASSERT_EQ(3, ite.getNumChildren());
 
   ASSERT_EQ(*(ite.begin()), cnd);
@@ -348,10 +350,11 @@ TEST_F(TestNodeBlackNode, iteNode)
 TEST_F(TestNodeBlackNode, iffNode)
 {
   Node left = d_nodeManager->mkConst(true);
-  Node right = d_nodeManager->mkNode(NOT, (d_nodeManager->mkConst(false)));
+  Node right =
+      d_nodeManager->mkNode(Kind::NOT, (d_nodeManager->mkConst(false)));
   Node eq = left.eqNode(right);
 
-  ASSERT_EQ(EQUAL, eq.getKind());
+  ASSERT_EQ(Kind::EQUAL, eq.getKind());
   ASSERT_EQ(2, eq.getNumChildren());
 
   ASSERT_EQ(*(eq.begin()), left);
@@ -361,10 +364,11 @@ TEST_F(TestNodeBlackNode, iffNode)
 TEST_F(TestNodeBlackNode, impNode)
 {
   Node left = d_nodeManager->mkConst(true);
-  Node right = d_nodeManager->mkNode(NOT, (d_nodeManager->mkConst(false)));
+  Node right =
+      d_nodeManager->mkNode(Kind::NOT, (d_nodeManager->mkConst(false)));
   Node eq = left.impNode(right);
 
-  ASSERT_EQ(IMPLIES, eq.getKind());
+  ASSERT_EQ(Kind::IMPLIES, eq.getKind());
   ASSERT_EQ(2, eq.getNumChildren());
 
   ASSERT_EQ(*(eq.begin()), left);
@@ -374,10 +378,11 @@ TEST_F(TestNodeBlackNode, impNode)
 TEST_F(TestNodeBlackNode, xorNode)
 {
   Node left = d_nodeManager->mkConst(true);
-  Node right = d_nodeManager->mkNode(NOT, (d_nodeManager->mkConst(false)));
+  Node right =
+      d_nodeManager->mkNode(Kind::NOT, (d_nodeManager->mkConst(false)));
   Node eq = left.xorNode(right);
 
-  ASSERT_EQ(XOR, eq.getKind());
+  ASSERT_EQ(Kind::XOR, eq.getKind());
   ASSERT_EQ(2, eq.getNumChildren());
 
   ASSERT_EQ(*(eq.begin()), left);
@@ -389,20 +394,20 @@ TEST_F(TestNodeBlackNode, getKind)
   Node a = d_skolemManager->mkDummySkolem("a", d_nodeManager->booleanType());
   Node b = d_skolemManager->mkDummySkolem("b", d_nodeManager->booleanType());
 
-  Node n = d_nodeManager->mkNode(NOT, a);
-  ASSERT_EQ(NOT, n.getKind());
+  Node n = d_nodeManager->mkNode(Kind::NOT, a);
+  ASSERT_EQ(Kind::NOT, n.getKind());
 
-  n = d_nodeManager->mkNode(EQUAL, a, b);
-  ASSERT_EQ(EQUAL, n.getKind());
+  n = d_nodeManager->mkNode(Kind::EQUAL, a, b);
+  ASSERT_EQ(Kind::EQUAL, n.getKind());
 
   Node x = d_skolemManager->mkDummySkolem("x", d_nodeManager->realType());
   Node y = d_skolemManager->mkDummySkolem("y", d_nodeManager->realType());
 
-  n = d_nodeManager->mkNode(ADD, x, y);
-  ASSERT_EQ(ADD, n.getKind());
+  n = d_nodeManager->mkNode(Kind::ADD, x, y);
+  ASSERT_EQ(Kind::ADD, n.getKind());
 
-  n = d_nodeManager->mkNode(NEG, x);
-  ASSERT_EQ(NEG, n.getKind());
+  n = d_nodeManager->mkNode(Kind::NEG, x);
+  ASSERT_EQ(Kind::NEG, n.getKind());
 }
 
 TEST_F(TestNodeBlackNode, getOperator)
@@ -413,7 +418,7 @@ TEST_F(TestNodeBlackNode, getOperator)
 
   Node f = d_skolemManager->mkDummySkolem("f", predType);
   Node a = d_skolemManager->mkDummySkolem("a", sort);
-  Node fa = d_nodeManager->mkNode(kind::APPLY_UF, f, a);
+  Node fa = d_nodeManager->mkNode(Kind::APPLY_UF, f, a);
 
   ASSERT_TRUE(fa.hasOperator());
   ASSERT_FALSE(f.hasOperator());
@@ -442,20 +447,20 @@ TEST_F(TestNodeBlackNode, getNumChildren)
   for (uint32_t i = 0; i < 500; ++i)
   {
     uint32_t n = rand() % 1000 + 2;
-    testNaryExpForSize(AND, n);
+    testNaryExpForSize(Kind::AND, n);
   }
 
 #ifdef CVC5_ASSERTIONS
-  ASSERT_DEATH(testNaryExpForSize(AND, 0),
+  ASSERT_DEATH(testNaryExpForSize(Kind::AND, 0),
                "getNumChildren\\(\\) >= "
                "kind::metakind::getMinArityForKind\\(getKind\\(\\)\\)");
-  ASSERT_DEATH(testNaryExpForSize(AND, 1),
+  ASSERT_DEATH(testNaryExpForSize(Kind::AND, 1),
                "getNumChildren\\(\\) >= "
                "kind::metakind::getMinArityForKind\\(getKind\\(\\)\\)");
-  ASSERT_DEATH(testNaryExpForSize(NOT, 0),
+  ASSERT_DEATH(testNaryExpForSize(Kind::NOT, 0),
                "getNumChildren\\(\\) >= "
                "kind::metakind::getMinArityForKind\\(getKind\\(\\)\\)");
-  ASSERT_DEATH(testNaryExpForSize(NOT, 2),
+  ASSERT_DEATH(testNaryExpForSize(Kind::NOT, 2),
                "getNumChildren\\(\\) <= "
                "kind::metakind::getMaxArityForKind\\(getKind\\(\\)\\)");
 #endif /* CVC5_ASSERTIONS */
@@ -467,7 +472,7 @@ TEST_F(TestNodeBlackNode, iterator)
   Node x = d_skolemManager->mkDummySkolem("x", d_nodeManager->booleanType());
   Node y = d_skolemManager->mkDummySkolem("y", d_nodeManager->booleanType());
   Node z = d_skolemManager->mkDummySkolem("z", d_nodeManager->booleanType());
-  Node n = b << x << y << z << kind::AND;
+  Node n = b << x << y << z << Kind::AND;
 
   {  // iterator
     Node::iterator i = n.begin();
@@ -493,7 +498,7 @@ TEST_F(TestNodeBlackNode, const_reverse_iterator)
   Node x = d_skolemManager->mkDummySkolem("x", d_nodeManager->booleanType());
   Node y = d_skolemManager->mkDummySkolem("y", d_nodeManager->booleanType());
   Node z = d_skolemManager->mkDummySkolem("z", d_nodeManager->booleanType());
-  Node n = b << x << y << z << kind::AND;
+  Node n = b << x << y << z << Kind::AND;
 
   {  // same for const iterator
     const Node& c = n;
@@ -512,19 +517,19 @@ TEST_F(TestNodeBlackNode, kinded_iterator)
   Node x = d_skolemManager->mkDummySkolem("x", integerType);
   Node y = d_skolemManager->mkDummySkolem("y", integerType);
   Node z = d_skolemManager->mkDummySkolem("z", integerType);
-  Node plus_x_y_z = d_nodeManager->mkNode(kind::ADD, x, y, z);
-  Node x_minus_y = d_nodeManager->mkNode(kind::SUB, x, y);
+  Node plus_x_y_z = d_nodeManager->mkNode(Kind::ADD, x, y, z);
+  Node x_minus_y = d_nodeManager->mkNode(Kind::SUB, x, y);
 
   {  // iterator
-    Node::kinded_iterator i = plus_x_y_z.begin(ADD);
+    Node::kinded_iterator i = plus_x_y_z.begin(Kind::ADD);
     ASSERT_EQ(*i++, x);
     ASSERT_EQ(*i++, y);
     ASSERT_EQ(*i++, z);
-    ASSERT_TRUE(i == plus_x_y_z.end(ADD));
+    ASSERT_TRUE(i == plus_x_y_z.end(Kind::ADD));
 
-    i = x.begin(ADD);
+    i = x.begin(Kind::ADD);
     ASSERT_EQ(*i++, x);
-    ASSERT_TRUE(i == x.end(ADD));
+    ASSERT_TRUE(i == x.end(Kind::ADD));
   }
 }
 
@@ -540,8 +545,8 @@ TEST_F(TestNodeBlackNode, toString)
       "y", booleanType, "", SkolemManager::SKOLEM_EXACT_NAME);
   Node z = d_skolemManager->mkDummySkolem(
       "z", booleanType, "", SkolemManager::SKOLEM_EXACT_NAME);
-  Node m = NodeBuilder() << w << x << kind::OR;
-  Node n = NodeBuilder() << m << y << z << kind::AND;
+  Node m = NodeBuilder() << w << x << Kind::OR;
+  Node n = NodeBuilder() << m << y << z << Kind::AND;
 
   ASSERT_EQ(n.toString(), "(AND (OR w x) y z)");
 }
@@ -558,9 +563,9 @@ TEST_F(TestNodeBlackNode, toStream)
       "y", booleanType, "", SkolemManager::SKOLEM_EXACT_NAME);
   Node z = d_skolemManager->mkDummySkolem(
       "z", booleanType, "", SkolemManager::SKOLEM_EXACT_NAME);
-  Node m = NodeBuilder() << x << y << kind::OR;
-  Node n = NodeBuilder() << w << m << z << kind::AND;
-  Node o = NodeBuilder() << n << n << kind::XOR;
+  Node m = NodeBuilder() << x << y << Kind::OR;
+  Node n = NodeBuilder() << w << m << z << Kind::AND;
+  Node o = NodeBuilder() << n << n << Kind::XOR;
 
   std::stringstream sstr;
   options::ioutils::applyDagThresh(sstr, 0);
@@ -631,21 +636,21 @@ TEST_F(TestNodeBlackNode, dagifier)
       "f", fnType, "", SkolemManager::SKOLEM_EXACT_NAME);
   Node g = d_skolemManager->mkDummySkolem(
       "g", fnType, "", SkolemManager::SKOLEM_EXACT_NAME);
-  Node fx = d_nodeManager->mkNode(APPLY_UF, f, x);
-  Node fy = d_nodeManager->mkNode(APPLY_UF, f, y);
-  Node gx = d_nodeManager->mkNode(APPLY_UF, g, x);
-  Node gy = d_nodeManager->mkNode(APPLY_UF, g, y);
-  Node fgx = d_nodeManager->mkNode(APPLY_UF, f, gx);
-  Node ffx = d_nodeManager->mkNode(APPLY_UF, f, fx);
-  Node fffx = d_nodeManager->mkNode(APPLY_UF, f, ffx);
-  Node fffx_eq_x = d_nodeManager->mkNode(EQUAL, fffx, x);
-  Node fffx_eq_y = d_nodeManager->mkNode(EQUAL, fffx, y);
-  Node fx_eq_gx = d_nodeManager->mkNode(EQUAL, fx, gx);
-  Node x_eq_y = d_nodeManager->mkNode(EQUAL, x, y);
-  Node fgx_eq_gy = d_nodeManager->mkNode(EQUAL, fgx, gy);
+  Node fx = d_nodeManager->mkNode(Kind::APPLY_UF, f, x);
+  Node fy = d_nodeManager->mkNode(Kind::APPLY_UF, f, y);
+  Node gx = d_nodeManager->mkNode(Kind::APPLY_UF, g, x);
+  Node gy = d_nodeManager->mkNode(Kind::APPLY_UF, g, y);
+  Node fgx = d_nodeManager->mkNode(Kind::APPLY_UF, f, gx);
+  Node ffx = d_nodeManager->mkNode(Kind::APPLY_UF, f, fx);
+  Node fffx = d_nodeManager->mkNode(Kind::APPLY_UF, f, ffx);
+  Node fffx_eq_x = d_nodeManager->mkNode(Kind::EQUAL, fffx, x);
+  Node fffx_eq_y = d_nodeManager->mkNode(Kind::EQUAL, fffx, y);
+  Node fx_eq_gx = d_nodeManager->mkNode(Kind::EQUAL, fx, gx);
+  Node x_eq_y = d_nodeManager->mkNode(Kind::EQUAL, x, y);
+  Node fgx_eq_gy = d_nodeManager->mkNode(Kind::EQUAL, fgx, gy);
 
   Node n = d_nodeManager->mkNode(
-      OR, {fffx_eq_x, fffx_eq_y, fx_eq_gx, x_eq_y, fgx_eq_gy});
+      Kind::OR, {fffx_eq_x, fffx_eq_y, fx_eq_gx, x_eq_y, fgx_eq_gy});
 
   std::stringstream sstr;
   options::ioutils::applyDagThresh(sstr, 0);
@@ -660,7 +665,7 @@ TEST_F(TestNodeBlackNode, for_each_over_nodes_as_node)
 {
   const std::vector<Node> skolems =
       makeNSkolemNodes(d_nodeManager, 3, d_nodeManager->integerType());
-  Node add = d_nodeManager->mkNode(kind::ADD, skolems);
+  Node add = d_nodeManager->mkNode(Kind::ADD, skolems);
   std::vector<Node> children;
   for (Node child : add)
   {
@@ -674,7 +679,7 @@ TEST_F(TestNodeBlackNode, for_each_over_nodes_as_tnode)
 {
   const std::vector<Node> skolems =
       makeNSkolemNodes(d_nodeManager, 3, d_nodeManager->integerType());
-  Node add = d_nodeManager->mkNode(kind::ADD, skolems);
+  Node add = d_nodeManager->mkNode(Kind::ADD, skolems);
   std::vector<TNode> children;
   for (TNode child : add)
   {
@@ -688,7 +693,7 @@ TEST_F(TestNodeBlackNode, for_each_over_tnodes_as_node)
 {
   const std::vector<Node> skolems =
       makeNSkolemNodes(d_nodeManager, 3, d_nodeManager->integerType());
-  Node add_node = d_nodeManager->mkNode(kind::ADD, skolems);
+  Node add_node = d_nodeManager->mkNode(Kind::ADD, skolems);
   TNode add_tnode = add_node;
   std::vector<Node> children;
   for (Node child : add_tnode)
@@ -703,7 +708,7 @@ TEST_F(TestNodeBlackNode, for_each_over_tnodes_as_tnode)
 {
   const std::vector<Node> skolems =
       makeNSkolemNodes(d_nodeManager, 3, d_nodeManager->integerType());
-  Node add_node = d_nodeManager->mkNode(kind::ADD, skolems);
+  Node add_node = d_nodeManager->mkNode(Kind::ADD, skolems);
   TNode add_tnode = add_node;
   std::vector<TNode> children;
   for (TNode child : add_tnode)
@@ -730,25 +735,26 @@ TEST_F(TestNodeBlackNode, isConst)
   Node cons = lcons[0]->getConstructor();
   Node nil = lcons[1]->getConstructor();
   Node x = d_skolemManager->mkDummySkolem("x", d_nodeManager->integerType());
-  Node cons_x_nil =
-      d_nodeManager->mkNode(APPLY_CONSTRUCTOR,
-                            cons,
-                            x,
-                            d_nodeManager->mkNode(APPLY_CONSTRUCTOR, nil));
-  Node cons_1_nil =
-      d_nodeManager->mkNode(APPLY_CONSTRUCTOR,
-                            cons,
-                            d_nodeManager->mkConstInt(Rational(1)),
-                            d_nodeManager->mkNode(APPLY_CONSTRUCTOR, nil));
-  Node cons_1_cons_2_nil = d_nodeManager->mkNode(
-      APPLY_CONSTRUCTOR,
+  Node cons_x_nil = d_nodeManager->mkNode(
+      Kind::APPLY_CONSTRUCTOR,
+      cons,
+      x,
+      d_nodeManager->mkNode(Kind::APPLY_CONSTRUCTOR, nil));
+  Node cons_1_nil = d_nodeManager->mkNode(
+      Kind::APPLY_CONSTRUCTOR,
       cons,
       d_nodeManager->mkConstInt(Rational(1)),
-      d_nodeManager->mkNode(APPLY_CONSTRUCTOR,
-                            cons,
-                            d_nodeManager->mkConstInt(Rational(2)),
-                            d_nodeManager->mkNode(APPLY_CONSTRUCTOR, nil)));
-  ASSERT_TRUE(d_nodeManager->mkNode(APPLY_CONSTRUCTOR, nil).isConst());
+      d_nodeManager->mkNode(Kind::APPLY_CONSTRUCTOR, nil));
+  Node cons_1_cons_2_nil = d_nodeManager->mkNode(
+      Kind::APPLY_CONSTRUCTOR,
+      cons,
+      d_nodeManager->mkConstInt(Rational(1)),
+      d_nodeManager->mkNode(
+          Kind::APPLY_CONSTRUCTOR,
+          cons,
+          d_nodeManager->mkConstInt(Rational(2)),
+          d_nodeManager->mkNode(Kind::APPLY_CONSTRUCTOR, nil)));
+  ASSERT_TRUE(d_nodeManager->mkNode(Kind::APPLY_CONSTRUCTOR, nil).isConst());
   ASSERT_FALSE(cons_x_nil.isConst());
   ASSERT_TRUE(cons_1_nil.isConst());
   ASSERT_TRUE(cons_1_cons_2_nil.isConst());
@@ -760,13 +766,13 @@ TEST_F(TestNodeBlackNode, isConst)
   Node storeAll = d_nodeManager->mkConst(ArrayStoreAll(arrType, zero));
   ASSERT_TRUE(storeAll.isConst());
 
-  Node arr = d_nodeManager->mkNode(STORE, storeAll, zero, zero);
+  Node arr = d_nodeManager->mkNode(Kind::STORE, storeAll, zero, zero);
   ASSERT_FALSE(arr.isConst());
-  arr = d_nodeManager->mkNode(STORE, storeAll, zero, one);
+  arr = d_nodeManager->mkNode(Kind::STORE, storeAll, zero, one);
   ASSERT_TRUE(arr.isConst());
-  Node arr2 = d_nodeManager->mkNode(STORE, arr, one, zero);
+  Node arr2 = d_nodeManager->mkNode(Kind::STORE, arr, one, zero);
   ASSERT_FALSE(arr2.isConst());
-  arr2 = d_nodeManager->mkNode(STORE, arr, zero, one);
+  arr2 = d_nodeManager->mkNode(Kind::STORE, arr, zero, one);
   ASSERT_FALSE(arr2.isConst());
 
   arrType = d_nodeManager->mkArrayType(d_nodeManager->mkBitVectorType(1),
@@ -776,15 +782,15 @@ TEST_F(TestNodeBlackNode, isConst)
   storeAll = d_nodeManager->mkConst(ArrayStoreAll(arrType, zero));
   ASSERT_TRUE(storeAll.isConst());
 
-  arr = d_nodeManager->mkNode(STORE, storeAll, zero, zero);
+  arr = d_nodeManager->mkNode(Kind::STORE, storeAll, zero, zero);
   ASSERT_FALSE(arr.isConst());
-  arr = d_nodeManager->mkNode(STORE, storeAll, zero, one);
+  arr = d_nodeManager->mkNode(Kind::STORE, storeAll, zero, one);
   ASSERT_TRUE(arr.isConst());
-  arr2 = d_nodeManager->mkNode(STORE, arr, one, zero);
+  arr2 = d_nodeManager->mkNode(Kind::STORE, arr, one, zero);
   ASSERT_FALSE(arr2.isConst());
-  arr2 = d_nodeManager->mkNode(STORE, arr, one, one);
+  arr2 = d_nodeManager->mkNode(Kind::STORE, arr, one, one);
   ASSERT_FALSE(arr2.isConst());
-  arr2 = d_nodeManager->mkNode(STORE, arr, zero, one);
+  arr2 = d_nodeManager->mkNode(Kind::STORE, arr, zero, one);
   ASSERT_FALSE(arr2.isConst());
 }
 
@@ -792,7 +798,7 @@ namespace {
 Node level0(NodeManager* nm)
 {
   SkolemManager* sm = nm->getSkolemManager();
-  NodeBuilder nb(kind::AND);
+  NodeBuilder nb(Kind::AND);
   Node x = sm->mkDummySkolem("x", nm->booleanType());
   nb << x;
   nb << x;
