@@ -29,8 +29,6 @@
 
 namespace cvc5::internal {
 
-using namespace kind;
-
 namespace test {
 
 class TestNodeBlackNodeTraversalPostorder : public TestNode
@@ -45,7 +43,7 @@ TEST_F(TestNodeBlackNodeTraversalPostorder, preincrement_iteration)
 {
   const Node tb = d_nodeManager->mkConst(true);
   const Node eb = d_nodeManager->mkConst(false);
-  const Node cnd = d_nodeManager->mkNode(XOR, tb, eb);
+  const Node cnd = d_nodeManager->mkNode(Kind::XOR, tb, eb);
 
   auto traversal = NodeDfsIterable(cnd, VisitOrder::POSTORDER);
   NodeDfsIterator i = traversal.begin();
@@ -66,7 +64,7 @@ TEST_F(TestNodeBlackNodeTraversalPostorder, postincrement_iteration)
 {
   const Node tb = d_nodeManager->mkConst(true);
   const Node eb = d_nodeManager->mkConst(false);
-  const Node cnd = d_nodeManager->mkNode(XOR, tb, eb);
+  const Node cnd = d_nodeManager->mkNode(Kind::XOR, tb, eb);
 
   auto traversal = NodeDfsIterable(cnd, VisitOrder::POSTORDER);
   NodeDfsIterator i = traversal.begin();
@@ -81,7 +79,7 @@ TEST_F(TestNodeBlackNodeTraversalPostorder, postorder_is_default)
 {
   const Node tb = d_nodeManager->mkConst(true);
   const Node eb = d_nodeManager->mkConst(false);
-  const Node cnd = d_nodeManager->mkNode(XOR, tb, eb);
+  const Node cnd = d_nodeManager->mkNode(Kind::XOR, tb, eb);
 
   auto traversal = NodeDfsIterable(cnd);
   NodeDfsIterator i = traversal.begin();
@@ -94,7 +92,7 @@ TEST_F(TestNodeBlackNodeTraversalPostorder, range_for_loop)
 {
   const Node tb = d_nodeManager->mkConst(true);
   const Node eb = d_nodeManager->mkConst(false);
-  const Node cnd = d_nodeManager->mkNode(XOR, tb, eb);
+  const Node cnd = d_nodeManager->mkNode(Kind::XOR, tb, eb);
 
   size_t count = 0;
   for (auto i : NodeDfsIterable(cnd, VisitOrder::POSTORDER))
@@ -108,7 +106,7 @@ TEST_F(TestNodeBlackNodeTraversalPostorder, count_if_with_loop)
 {
   const Node tb = d_nodeManager->mkConst(true);
   const Node eb = d_nodeManager->mkConst(false);
-  const Node cnd = d_nodeManager->mkNode(XOR, tb, eb);
+  const Node cnd = d_nodeManager->mkNode(Kind::XOR, tb, eb);
 
   size_t count = 0;
   for (auto i : NodeDfsIterable(cnd, VisitOrder::POSTORDER))
@@ -125,8 +123,8 @@ TEST_F(TestNodeBlackNodeTraversalPostorder, stl_count_if)
 {
   const Node tb = d_nodeManager->mkConst(true);
   const Node eb = d_nodeManager->mkConst(false);
-  const Node cnd = d_nodeManager->mkNode(XOR, tb, eb);
-  const Node top = d_nodeManager->mkNode(XOR, cnd, cnd);
+  const Node cnd = d_nodeManager->mkNode(Kind::XOR, tb, eb);
+  const Node top = d_nodeManager->mkNode(Kind::XOR, cnd, cnd);
 
   auto traversal = NodeDfsIterable(top, VisitOrder::POSTORDER);
 
@@ -139,8 +137,8 @@ TEST_F(TestNodeBlackNodeTraversalPostorder, stl_copy)
 {
   const Node tb = d_nodeManager->mkConst(true);
   const Node eb = d_nodeManager->mkConst(false);
-  const Node cnd = d_nodeManager->mkNode(XOR, tb, eb);
-  const Node top = d_nodeManager->mkNode(XOR, cnd, cnd);
+  const Node cnd = d_nodeManager->mkNode(Kind::XOR, tb, eb);
+  const Node top = d_nodeManager->mkNode(Kind::XOR, cnd, cnd);
   std::vector<TNode> expected = {tb, eb, cnd, top};
 
   auto traversal = NodeDfsIterable(top, VisitOrder::POSTORDER);
@@ -154,8 +152,8 @@ TEST_F(TestNodeBlackNodeTraversalPostorder, skip_if)
 {
   const Node tb = d_nodeManager->mkConst(true);
   const Node eb = d_nodeManager->mkConst(false);
-  const Node cnd = d_nodeManager->mkNode(XOR, tb, eb);
-  const Node top = d_nodeManager->mkNode(XOR, cnd, cnd);
+  const Node cnd = d_nodeManager->mkNode(Kind::XOR, tb, eb);
+  const Node top = d_nodeManager->mkNode(Kind::XOR, cnd, cnd);
   std::vector<TNode> expected = {top};
 
   auto traversal = NodeDfsIterable(
@@ -170,8 +168,8 @@ TEST_F(TestNodeBlackNodeTraversalPostorder, skip_all)
 {
   const Node tb = d_nodeManager->mkConst(true);
   const Node eb = d_nodeManager->mkConst(false);
-  const Node cnd = d_nodeManager->mkNode(XOR, tb, eb);
-  const Node top = d_nodeManager->mkNode(XOR, cnd, cnd);
+  const Node cnd = d_nodeManager->mkNode(Kind::XOR, tb, eb);
+  const Node top = d_nodeManager->mkNode(Kind::XOR, cnd, cnd);
   std::vector<TNode> expected = {};
 
   auto traversal =
@@ -186,7 +184,7 @@ TEST_F(TestNodeBlackNodeTraversalPreorder, preincrement_iteration)
 {
   const Node tb = d_nodeManager->mkConst(true);
   const Node eb = d_nodeManager->mkConst(false);
-  const Node cnd = d_nodeManager->mkNode(XOR, tb, eb);
+  const Node cnd = d_nodeManager->mkNode(Kind::XOR, tb, eb);
 
   auto traversal = NodeDfsIterable(cnd, VisitOrder::PREORDER);
   NodeDfsIterator i = traversal.begin();
@@ -207,7 +205,7 @@ TEST_F(TestNodeBlackNodeTraversalPreorder, postincrement_iteration)
 {
   const Node tb = d_nodeManager->mkConst(true);
   const Node eb = d_nodeManager->mkConst(false);
-  const Node cnd = d_nodeManager->mkNode(XOR, tb, eb);
+  const Node cnd = d_nodeManager->mkNode(Kind::XOR, tb, eb);
 
   auto traversal = NodeDfsIterable(cnd, VisitOrder::PREORDER);
   NodeDfsIterator i = traversal.begin();
@@ -222,7 +220,7 @@ TEST_F(TestNodeBlackNodeTraversalPreorder, range_for_loop)
 {
   const Node tb = d_nodeManager->mkConst(true);
   const Node eb = d_nodeManager->mkConst(false);
-  const Node cnd = d_nodeManager->mkNode(XOR, tb, eb);
+  const Node cnd = d_nodeManager->mkNode(Kind::XOR, tb, eb);
 
   size_t count = 0;
   for (auto i : NodeDfsIterable(cnd, VisitOrder::PREORDER))
@@ -236,7 +234,7 @@ TEST_F(TestNodeBlackNodeTraversalPreorder, count_if_with_loop)
 {
   const Node tb = d_nodeManager->mkConst(true);
   const Node eb = d_nodeManager->mkConst(false);
-  const Node cnd = d_nodeManager->mkNode(XOR, tb, eb);
+  const Node cnd = d_nodeManager->mkNode(Kind::XOR, tb, eb);
 
   size_t count = 0;
   for (auto i : NodeDfsIterable(cnd, VisitOrder::PREORDER))
@@ -253,8 +251,8 @@ TEST_F(TestNodeBlackNodeTraversalPreorder, stl_count_if)
 {
   const Node tb = d_nodeManager->mkConst(true);
   const Node eb = d_nodeManager->mkConst(false);
-  const Node cnd = d_nodeManager->mkNode(XOR, tb, eb);
-  const Node top = d_nodeManager->mkNode(XOR, cnd, cnd);
+  const Node cnd = d_nodeManager->mkNode(Kind::XOR, tb, eb);
+  const Node top = d_nodeManager->mkNode(Kind::XOR, cnd, cnd);
 
   auto traversal = NodeDfsIterable(top, VisitOrder::PREORDER);
 
@@ -267,8 +265,8 @@ TEST_F(TestNodeBlackNodeTraversalPreorder, stl_copy)
 {
   const Node tb = d_nodeManager->mkConst(true);
   const Node eb = d_nodeManager->mkConst(false);
-  const Node cnd = d_nodeManager->mkNode(XOR, tb, eb);
-  const Node top = d_nodeManager->mkNode(XOR, cnd, cnd);
+  const Node cnd = d_nodeManager->mkNode(Kind::XOR, tb, eb);
+  const Node top = d_nodeManager->mkNode(Kind::XOR, cnd, cnd);
   std::vector<TNode> expected = {top, cnd, tb, eb};
 
   auto traversal = NodeDfsIterable(top, VisitOrder::PREORDER);
@@ -282,8 +280,8 @@ TEST_F(TestNodeBlackNodeTraversalPreorder, skip_if)
 {
   const Node tb = d_nodeManager->mkConst(true);
   const Node eb = d_nodeManager->mkConst(false);
-  const Node cnd = d_nodeManager->mkNode(XOR, tb, eb);
-  const Node top = d_nodeManager->mkNode(XOR, cnd, cnd);
+  const Node cnd = d_nodeManager->mkNode(Kind::XOR, tb, eb);
+  const Node top = d_nodeManager->mkNode(Kind::XOR, cnd, cnd);
   std::vector<TNode> expected = {top, cnd, eb};
 
   auto traversal = NodeDfsIterable(
