@@ -19,7 +19,6 @@
 #include "test_smt.h"
 #include "util/rational.h"
 
-using namespace cvc5::internal::kind;
 using namespace cvc5::internal::preprocessing::passes;
 
 namespace cvc5::internal {
@@ -34,16 +33,16 @@ TEST_F(TestPPWhiteForeignTheoryRewrite, simplify)
   ForeignTheoryRewriter ftr(d_slvEngine->getEnv());
   std::cout << "len(x) >= 0 is simplified to true" << std::endl;
   Node x = d_nodeManager->mkVar("x", d_nodeManager->stringType());
-  Node len_x = d_nodeManager->mkNode(kind::STRING_LENGTH, x);
+  Node len_x = d_nodeManager->mkNode(Kind::STRING_LENGTH, x);
   Node zero = d_nodeManager->mkConstInt(0);
-  Node geq1 = d_nodeManager->mkNode(kind::GEQ, len_x, zero);
+  Node geq1 = d_nodeManager->mkNode(Kind::GEQ, len_x, zero);
   Node tt = d_nodeManager->mkConst<bool>(true);
   Node simplified1 = ftr.foreignRewrite(geq1);
   ASSERT_EQ(simplified1, tt);
 
   std::cout << "len(x) >= n is not simplified to true" << std::endl;
   Node n = d_nodeManager->mkVar("n", d_nodeManager->integerType());
-  Node geq2 = d_nodeManager->mkNode(kind::GEQ, len_x, n);
+  Node geq2 = d_nodeManager->mkNode(Kind::GEQ, len_x, n);
   Node simplified2 = ftr.foreignRewrite(geq2);
   ASSERT_NE(simplified2, tt);
 }
