@@ -25,7 +25,6 @@
 #include "theory/rewriter.h"
 #include "util/rational.h"
 
-using namespace cvc5::internal::kind;
 using namespace cvc5::internal::theory;
 
 namespace cvc5::internal {
@@ -54,7 +53,7 @@ TEST_F(TestTheoryWhiteEvaluator, simple)
       (unsigned int)0b0000000100000101001110111001101000101110011101011011110011100111));
 
   Node t = d_nodeManager->mkNode(
-      kind::ITE, d_nodeManager->mkNode(kind::EQUAL, y, one), x, w);
+      Kind::ITE, d_nodeManager->mkNode(Kind::EQUAL, y, one), x, w);
 
   std::vector<Node> args = {w, x, y, z};
   std::vector<Node> vals = {c1, zero, one, c1};
@@ -80,14 +79,14 @@ TEST_F(TestTheoryWhiteEvaluator, loop)
       64,
       (unsigned int)0b0001111000010111110000110110001101011110111001101100000101010100));
 
-  Node largs = d_nodeManager->mkNode(kind::BOUND_VAR_LIST, w);
+  Node largs = d_nodeManager->mkNode(Kind::BOUND_VAR_LIST, w);
   Node lbody = d_nodeManager->mkNode(
-      kind::BITVECTOR_CONCAT, bv::utils::mkExtract(w, 62, 0), zero);
-  Node lambda = d_nodeManager->mkNode(kind::LAMBDA, largs, lbody);
+      Kind::BITVECTOR_CONCAT, bv::utils::mkExtract(w, 62, 0), zero);
+  Node lambda = d_nodeManager->mkNode(Kind::LAMBDA, largs, lbody);
   Node t =
-      d_nodeManager->mkNode(kind::BITVECTOR_AND,
-                            d_nodeManager->mkNode(kind::APPLY_UF, lambda, one),
-                            d_nodeManager->mkNode(kind::APPLY_UF, lambda, x));
+      d_nodeManager->mkNode(Kind::BITVECTOR_AND,
+                            d_nodeManager->mkNode(Kind::APPLY_UF, lambda, one),
+                            d_nodeManager->mkNode(Kind::APPLY_UF, lambda, x));
 
   std::vector<Node> args = {x};
   std::vector<Node> vals = {c};
@@ -112,25 +111,25 @@ TEST_F(TestTheoryWhiteEvaluator, strIdOf)
   Evaluator eval(rr);
 
   {
-    Node n = d_nodeManager->mkNode(kind::STRING_INDEXOF, a, empty, one);
+    Node n = d_nodeManager->mkNode(Kind::STRING_INDEXOF, a, empty, one);
     Node r = eval.eval(n, args, vals);
     ASSERT_EQ(r, rr->rewrite(n));
   }
 
   {
-    Node n = d_nodeManager->mkNode(kind::STRING_INDEXOF, a, a, one);
+    Node n = d_nodeManager->mkNode(Kind::STRING_INDEXOF, a, a, one);
     Node r = eval.eval(n, args, vals);
     ASSERT_EQ(r, rr->rewrite(n));
   }
 
   {
-    Node n = d_nodeManager->mkNode(kind::STRING_INDEXOF, a, empty, two);
+    Node n = d_nodeManager->mkNode(Kind::STRING_INDEXOF, a, empty, two);
     Node r = eval.eval(n, args, vals);
     ASSERT_EQ(r, rr->rewrite(n));
   }
 
   {
-    Node n = d_nodeManager->mkNode(kind::STRING_INDEXOF, a, a, two);
+    Node n = d_nodeManager->mkNode(Kind::STRING_INDEXOF, a, a, two);
     Node r = eval.eval(n, args, vals);
     ASSERT_EQ(r, rr->rewrite(n));
   }
@@ -148,14 +147,14 @@ TEST_F(TestTheoryWhiteEvaluator, code)
 
   // (str.code "A") ---> 65
   {
-    Node n = d_nodeManager->mkNode(kind::STRING_TO_CODE, a);
+    Node n = d_nodeManager->mkNode(Kind::STRING_TO_CODE, a);
     Node r = eval.eval(n, args, vals);
     ASSERT_EQ(r, d_nodeManager->mkConstInt(Rational(65)));
   }
 
   // (str.code "") ---> -1
   {
-    Node n = d_nodeManager->mkNode(kind::STRING_TO_CODE, empty);
+    Node n = d_nodeManager->mkNode(Kind::STRING_TO_CODE, empty);
     Node r = eval.eval(n, args, vals);
     ASSERT_EQ(r, d_nodeManager->mkConstInt(Rational(-1)));
   }
