@@ -28,7 +28,6 @@
 
 namespace cvc5::internal {
 
-using namespace kind;
 using namespace theory;
 using namespace theory::strings;
 
@@ -63,17 +62,17 @@ class TestTheoryBlackRegexpOperation : public TestSmt
 
 TEST_F(TestTheoryBlackRegexpOperation, basic)
 {
-  Node sigma = d_nodeManager->mkNode(REGEXP_ALLCHAR);
-  Node sigmaStar = d_nodeManager->mkNode(REGEXP_STAR, sigma);
-  Node a = d_nodeManager->mkNode(STRING_TO_REGEXP,
+  Node sigma = d_nodeManager->mkNode(Kind::REGEXP_ALLCHAR);
+  Node sigmaStar = d_nodeManager->mkNode(Kind::REGEXP_STAR, sigma);
+  Node a = d_nodeManager->mkNode(Kind::STRING_TO_REGEXP,
                                  d_nodeManager->mkConst(String("a")));
-  Node c = d_nodeManager->mkNode(STRING_TO_REGEXP,
+  Node c = d_nodeManager->mkNode(Kind::STRING_TO_REGEXP,
                                  d_nodeManager->mkConst(String("c")));
-  Node abc = d_nodeManager->mkNode(STRING_TO_REGEXP,
+  Node abc = d_nodeManager->mkNode(Kind::STRING_TO_REGEXP,
                                    d_nodeManager->mkConst(String("abc")));
-  Node sigma3 = d_nodeManager->mkNode(REGEXP_CONCAT, sigma, sigma, sigma);
-  Node asc = d_nodeManager->mkNode(REGEXP_CONCAT, a, sigma, c);
-  Node asw = d_nodeManager->mkNode(REGEXP_CONCAT, a, sigma, sigmaStar);
+  Node sigma3 = d_nodeManager->mkNode(Kind::REGEXP_CONCAT, sigma, sigma, sigma);
+  Node asc = d_nodeManager->mkNode(Kind::REGEXP_CONCAT, a, sigma, c);
+  Node asw = d_nodeManager->mkNode(Kind::REGEXP_CONCAT, a, sigma, sigmaStar);
 
   includes(sigma3, abc);
   doesNotInclude(abc, sigma3);
@@ -91,33 +90,34 @@ TEST_F(TestTheoryBlackRegexpOperation, basic)
 TEST_F(TestTheoryBlackRegexpOperation, star_wildcards)
 {
   Rewriter* rr = d_slvEngine->getEnv().getRewriter();
-  Node sigma = d_nodeManager->mkNode(REGEXP_ALLCHAR);
-  Node sigmaStar = d_nodeManager->mkNode(REGEXP_STAR, sigma);
-  Node a = d_nodeManager->mkNode(STRING_TO_REGEXP,
+  Node sigma = d_nodeManager->mkNode(Kind::REGEXP_ALLCHAR);
+  Node sigmaStar = d_nodeManager->mkNode(Kind::REGEXP_STAR, sigma);
+  Node a = d_nodeManager->mkNode(Kind::STRING_TO_REGEXP,
                                  d_nodeManager->mkConst(String("a")));
-  Node c = d_nodeManager->mkNode(STRING_TO_REGEXP,
+  Node c = d_nodeManager->mkNode(Kind::STRING_TO_REGEXP,
                                  d_nodeManager->mkConst(String("c")));
-  Node abc = d_nodeManager->mkNode(STRING_TO_REGEXP,
+  Node abc = d_nodeManager->mkNode(Kind::STRING_TO_REGEXP,
                                    d_nodeManager->mkConst(String("abc")));
 
-  Node _abc_ = d_nodeManager->mkNode(REGEXP_CONCAT, sigmaStar, abc, sigmaStar);
-  Node _asc_ =
-      d_nodeManager->mkNode(REGEXP_CONCAT, {sigmaStar, a, sigma, c, sigmaStar});
-  Node _sc_ = rr->rewrite(
-      d_nodeManager->mkNode(REGEXP_CONCAT, {sigmaStar, sigma, c, sigmaStar}));
-  Node _as_ = rr->rewrite(
-      d_nodeManager->mkNode(REGEXP_CONCAT, {sigmaStar, a, sigma, sigmaStar}));
+  Node _abc_ =
+      d_nodeManager->mkNode(Kind::REGEXP_CONCAT, sigmaStar, abc, sigmaStar);
+  Node _asc_ = d_nodeManager->mkNode(Kind::REGEXP_CONCAT,
+                                     {sigmaStar, a, sigma, c, sigmaStar});
+  Node _sc_ = rr->rewrite(d_nodeManager->mkNode(
+      Kind::REGEXP_CONCAT, {sigmaStar, sigma, c, sigmaStar}));
+  Node _as_ = rr->rewrite(d_nodeManager->mkNode(
+      Kind::REGEXP_CONCAT, {sigmaStar, a, sigma, sigmaStar}));
   Node _assc_ = d_nodeManager->mkNode(
-      REGEXP_CONCAT,
+      Kind::REGEXP_CONCAT,
       std::vector<Node>{sigmaStar, a, sigma, sigma, c, sigmaStar});
-  Node _csa_ =
-      d_nodeManager->mkNode(REGEXP_CONCAT, {sigmaStar, c, sigma, a, sigmaStar});
-  Node _c_a_ = d_nodeManager->mkNode(REGEXP_CONCAT,
+  Node _csa_ = d_nodeManager->mkNode(Kind::REGEXP_CONCAT,
+                                     {sigmaStar, c, sigma, a, sigmaStar});
+  Node _c_a_ = d_nodeManager->mkNode(Kind::REGEXP_CONCAT,
                                      {sigmaStar, c, sigmaStar, a, sigmaStar});
   Node _s_s_ = rr->rewrite(d_nodeManager->mkNode(
-      REGEXP_CONCAT, {sigmaStar, sigma, sigmaStar, sigma, sigmaStar}));
+      Kind::REGEXP_CONCAT, {sigmaStar, sigma, sigmaStar, sigma, sigmaStar}));
   Node _a_abc_ = rr->rewrite(d_nodeManager->mkNode(
-      REGEXP_CONCAT, {sigmaStar, a, sigmaStar, abc, sigmaStar}));
+      Kind::REGEXP_CONCAT, {sigmaStar, a, sigmaStar, abc, sigmaStar}));
 
   includes(_asc_, _abc_);
   doesNotInclude(_abc_, _asc_);
