@@ -26,7 +26,6 @@
 #include "util/rational.h"
 namespace cvc5::internal {
 
-using namespace kind;
 using namespace theory;
 
 namespace test {
@@ -144,37 +143,37 @@ TEST_F(TestTheoryWhiteBvIntblaster, intblaster_with_children)
   Node result;
 
   // sum
-  original = d_nodeManager->mkNode(BITVECTOR_ADD, v1, v2);
+  original = d_nodeManager->mkNode(Kind::BITVECTOR_ADD, v1, v2);
   result = intBlaster.translateWithChildren(original, {i1, i2}, lemmas);
   ASSERT_TRUE(result.getType().isInteger());
 
   // multiplication
-  original = d_nodeManager->mkNode(BITVECTOR_MULT, v1, v2);
+  original = d_nodeManager->mkNode(Kind::BITVECTOR_MULT, v1, v2);
   result = intBlaster.translateWithChildren(original, {i1, i2}, lemmas);
   ASSERT_TRUE(result.getType().isInteger());
 
   // division 1
-  original = d_nodeManager->mkNode(BITVECTOR_UDIV, v1, v2);
+  original = d_nodeManager->mkNode(Kind::BITVECTOR_UDIV, v1, v2);
   result = intBlaster.translateWithChildren(original, {i1, i2}, lemmas);
   ASSERT_TRUE(result.getType().isInteger());
 
   // division 2
-  original = d_nodeManager->mkNode(BITVECTOR_UREM, v1, v2);
+  original = d_nodeManager->mkNode(Kind::BITVECTOR_UREM, v1, v2);
   result = intBlaster.translateWithChildren(original, {i1, i2}, lemmas);
   ASSERT_TRUE(result.getType().isInteger());
 
   // bit-wise negation
-  original = d_nodeManager->mkNode(BITVECTOR_NOT, v1);
+  original = d_nodeManager->mkNode(Kind::BITVECTOR_NOT, v1);
   result = intBlaster.translateWithChildren(original, {i1}, lemmas);
   ASSERT_TRUE(result.getType().isInteger());
 
   // arithmetic negation
-  original = d_nodeManager->mkNode(BITVECTOR_NEG, v1);
+  original = d_nodeManager->mkNode(Kind::BITVECTOR_NEG, v1);
   result = intBlaster.translateWithChildren(original, {i1}, lemmas);
   ASSERT_TRUE(result.getType().isInteger());
 
   // bv2nat
-  original = d_nodeManager->mkNode(BITVECTOR_TO_NAT, v1);
+  original = d_nodeManager->mkNode(Kind::BITVECTOR_TO_NAT, v1);
   result = intBlaster.translateWithChildren(original, {i1}, lemmas);
   ASSERT_TRUE(result.getType().isInteger());
 
@@ -200,7 +199,7 @@ TEST_F(TestTheoryWhiteBvIntblaster, intblaster_with_children)
 
   // extract + BV ITE
   Node extract = theory::bv::utils::mkExtract(v1, 0, 0);
-  original = d_nodeManager->mkNode(BITVECTOR_ITE, extract, v2, v1);
+  original = d_nodeManager->mkNode(Kind::BITVECTOR_ITE, extract, v2, v1);
   Node intExtract = intBlaster.translateWithChildren(extract, {i1}, lemmas);
   result =
       intBlaster.translateWithChildren(original, {intExtract, i1, i2}, lemmas);
@@ -208,58 +207,58 @@ TEST_F(TestTheoryWhiteBvIntblaster, intblaster_with_children)
   ASSERT_TRUE(intExtract.getType().isInteger());
 
   // left shift
-  original = d_nodeManager->mkNode(BITVECTOR_SHL, v1, v2);
+  original = d_nodeManager->mkNode(Kind::BITVECTOR_SHL, v1, v2);
   result = intBlaster.translateWithChildren(original, {i1, i2}, lemmas);
   ASSERT_TRUE(result.getType().isInteger());
 
   // logical right shift
-  original = d_nodeManager->mkNode(BITVECTOR_LSHR, v1, v2);
+  original = d_nodeManager->mkNode(Kind::BITVECTOR_LSHR, v1, v2);
   result = intBlaster.translateWithChildren(original, {i1, i2}, lemmas);
   ASSERT_TRUE(result.getType().isInteger());
 
   // arithmetic right shift
-  original = d_nodeManager->mkNode(BITVECTOR_ASHR, v1, v2);
+  original = d_nodeManager->mkNode(Kind::BITVECTOR_ASHR, v1, v2);
   result = intBlaster.translateWithChildren(original, {i1, i2}, lemmas);
   ASSERT_TRUE(result.getType().isInteger());
 
   // bvand
-  original = d_nodeManager->mkNode(BITVECTOR_AND, v1, v2);
+  original = d_nodeManager->mkNode(Kind::BITVECTOR_AND, v1, v2);
   result = intBlaster.translateWithChildren(original, {i1, i2}, lemmas);
   ASSERT_TRUE(result.getType().isInteger());
 
   // bvor
-  original = d_nodeManager->mkNode(BITVECTOR_OR, v1, v2);
+  original = d_nodeManager->mkNode(Kind::BITVECTOR_OR, v1, v2);
   result = intBlaster.translateWithChildren(original, {i1, i2}, lemmas);
   ASSERT_TRUE(result.getType().isInteger());
 
   // concat
-  original = d_nodeManager->mkNode(BITVECTOR_CONCAT, v1, v2);
+  original = d_nodeManager->mkNode(Kind::BITVECTOR_CONCAT, v1, v2);
   result = intBlaster.translateWithChildren(original, {i1, i2}, lemmas);
   ASSERT_TRUE(result.getType().isInteger());
 
   // predicates
-  original = d_nodeManager->mkNode(EQUAL, v1, v2);
+  original = d_nodeManager->mkNode(Kind::EQUAL, v1, v2);
   result = intBlaster.translateWithChildren(original, {i1, i2}, lemmas);
   ASSERT_TRUE(result.getType().isBoolean());
 
-  original = d_nodeManager->mkNode(BITVECTOR_ULT, v1, v2);
+  original = d_nodeManager->mkNode(Kind::BITVECTOR_ULT, v1, v2);
   result = intBlaster.translateWithChildren(original, {i1, i2}, lemmas);
   ASSERT_TRUE(result.getType().isBoolean());
 
-  original = d_nodeManager->mkNode(BITVECTOR_ULE, v1, v2);
+  original = d_nodeManager->mkNode(Kind::BITVECTOR_ULE, v1, v2);
   result = intBlaster.translateWithChildren(original, {i1, i2}, lemmas);
   ASSERT_TRUE(result.getType().isBoolean());
 
-  original = d_nodeManager->mkNode(BITVECTOR_UGT, v1, v2);
+  original = d_nodeManager->mkNode(Kind::BITVECTOR_UGT, v1, v2);
   result = intBlaster.translateWithChildren(original, {i1, i2}, lemmas);
   ASSERT_TRUE(result.getType().isBoolean());
 
-  original = d_nodeManager->mkNode(BITVECTOR_UGE, v1, v2);
+  original = d_nodeManager->mkNode(Kind::BITVECTOR_UGE, v1, v2);
   result = intBlaster.translateWithChildren(original, {i1, i2}, lemmas);
   ASSERT_TRUE(result.getType().isBoolean());
 
   // BVULT with a BV result
-  original = d_nodeManager->mkNode(BITVECTOR_ULTBV, v1, v2);
+  original = d_nodeManager->mkNode(Kind::BITVECTOR_ULTBV, v1, v2);
   result = intBlaster.translateWithChildren(original, {i1, i2}, lemmas);
   ASSERT_TRUE(result.getType().isInteger());
 }
@@ -292,11 +291,11 @@ TEST_F(TestTheoryWhiteBvIntblaster, intblaster_bitwise)
   Node result;
 
   // bvand
-  original = d_nodeManager->mkNode(BITVECTOR_AND, v1, v2);
+  original = d_nodeManager->mkNode(Kind::BITVECTOR_AND, v1, v2);
   size_t orig_num_lemmas = lemmas.size();
   result = intBlaster.translateWithChildren(original, {i1, i2}, lemmas);
   // should have kind skolem, would use bitwise comparisons to refine
-  ASSERT_TRUE(result.getKind() == kind::SKOLEM);
+  ASSERT_TRUE(result.getKind() == Kind::SKOLEM);
   // check that a lemma was added
   ASSERT_TRUE(lemmas.size() > orig_num_lemmas);
 }
